/* Automatically @generated by tree-sitter v0.26.0 */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 15
#define STATE_COUNT 1017
#define LARGE_STATE_COUNT 4
#define SYMBOL_COUNT 281
#define ALIAS_COUNT 2
#define TOKEN_COUNT 111
#define EXTERNAL_TOKEN_COUNT 8
#define FIELD_COUNT 39
#define MAX_ALIAS_SEQUENCE_LENGTH 14
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 120
#define SUPERTYPE_COUNT 11

enum ts_symbol_identifiers {
  sym_line_comment = 1,
  anon_sym_PERCENT_STAR_BANG = 2,
  aux_sym_doc_comment_token1 = 3,
  anon_sym_STAR_PERCENT = 4,
  anon_sym_COMMA = 5,
  aux_sym_doc_predicate_token1 = 6,
  anon_sym_RPAREN = 7,
  sym_doc_var = 8,
  sym_doc_fragment_emph = 9,
  sym_doc_fragment_bold = 10,
  sym_doc_fragment_italic = 11,
  sym_doc_fragment_code = 12,
  anon_sym_COLON = 13,
  sym_identifier = 14,
  anon_sym_DQUOTE = 15,
  anon_sym_f_DQUOTE = 16,
  sym__string_fragment = 17,
  sym__fstring_fragment = 18,
  sym__string_escape = 19,
  sym__fstring_escape = 20,
  aux_sym_fstring_accessor_token1 = 21,
  aux_sym_fstring_accessor_token2 = 22,
  aux_sym_fstring_accessor_token3 = 23,
  aux_sym_fstring_accessor_token4 = 24,
  aux_sym_fstring_conversion_token1 = 25,
  aux_sym_fstring_conversion_token2 = 26,
  sym_fstring_align = 27,
  sym_fstring_sign = 28,
  sym_fstring_alternate = 29,
  sym_fstring_grouping = 30,
  sym_fstring_type = 31,
  aux_sym_fstring_spec_token1 = 32,
  anon_sym_LBRACE = 33,
  anon_sym_RBRACE = 34,
  sym_supremum = 35,
  sym_infimum = 36,
  sym_number = 37,
  sym_anonymous = 38,
  sym_variable = 39,
  anon_sym_CARET = 40,
  anon_sym_QMARK = 41,
  anon_sym_AMP = 42,
  anon_sym_PLUS = 43,
  anon_sym_DASH = 44,
  anon_sym_STAR = 45,
  anon_sym_SLASH = 46,
  anon_sym_BSLASH = 47,
  anon_sym_STAR_STAR = 48,
  anon_sym_TILDE = 49,
  anon_sym_PIPE = 50,
  anon_sym_COMMA2 = 51,
  anon_sym_LPAREN = 52,
  anon_sym_RPAREN2 = 53,
  anon_sym_DOT_DOT = 54,
  anon_sym_SEMI = 55,
  anon_sym_AT = 56,
  sym_theory_operator = 57,
  anon_sym_LBRACK = 58,
  anon_sym_RBRACK = 59,
  anon_sym_RBRACE2 = 60,
  sym_boolean_constant = 61,
  sym_relation = 62,
  sym_default_negation = 63,
  sym_double_default_negation = 64,
  sym_aggregate_function = 65,
  anon_sym_DOT = 66,
  anon_sym_COLON_DASH = 67,
  anon_sym_COLON_TILDE = 68,
  anon_sym_POUNDmaximize = 69,
  anon_sym_POUNDmaximise = 70,
  anon_sym_POUNDminimize = 71,
  anon_sym_POUNDminimise = 72,
  anon_sym_POUNDshow = 73,
  anon_sym_true = 74,
  anon_sym_false = 75,
  anon_sym_POUNDdefined = 76,
  anon_sym_POUNDproject = 77,
  anon_sym_POUNDprogram = 78,
  sym_code = 79,
  anon_sym_POUNDscript = 80,
  anon_sym_POUNDend = 81,
  sym_const_type = 82,
  anon_sym_POUNDconst = 83,
  anon_sym_EQ = 84,
  anon_sym_POUNDedge = 85,
  anon_sym_POUNDheuristic = 86,
  anon_sym_POUNDinclude = 87,
  anon_sym_LT = 88,
  anon_sym_GT = 89,
  anon_sym_POUNDexternal = 90,
  sym_theory_operator_arity = 91,
  anon_sym_binary = 92,
  sym_theory_operator_associativity = 93,
  sym_theory_atom_type = 94,
  anon_sym_POUNDtheory = 95,
  anon_sym_POUNDtype = 96,
  anon_sym_expressions = 97,
  anon_sym_COLON2 = 98,
  anon_sym_subtypes = 99,
  anon_sym_macros = 100,
  anon_sym_where = 101,
  anon_sym_occurrence = 102,
  sym_empty_pool_item_first = 103,
  sym_empty_pool_item = 104,
  sym_colon = 105,
  sym_block_comment = 106,
  sym_doc_fragment_string = 107,
  sym__doc_token_args = 108,
  sym__doc_token_paren = 109,
  sym__doc_token_minus = 110,
  sym_source_file = 111,
  sym_doc_comment = 112,
  sym_variables = 113,
  sym_doc_predicate = 114,
  sym_doc_desc = 115,
  sym_doc_args = 116,
  sym_doc_arg = 117,
  sym_string = 118,
  sym_fstring = 119,
  sym_fstring_accessor = 120,
  sym_fstring_conversion = 121,
  sym_fstring_width = 122,
  sym_fstring_spec = 123,
  sym_fstring_field = 124,
  sym__const_term = 125,
  sym_const_binary_operation = 126,
  sym_const_unary_operation = 127,
  sym_const_abs = 128,
  sym_const_terms = 129,
  sym__const_arg_pool = 130,
  sym_const_function = 131,
  sym__const_term_comma = 132,
  sym__const_terms_trail = 133,
  sym_const_tuple = 134,
  sym_binary_operation = 135,
  sym_unary_operation = 136,
  sym_abs = 137,
  sym_terms = 138,
  sym_projection = 139,
  sym__term_or_projection = 140,
  sym__terms_or_projection = 141,
  sym__arg_pool_n = 142,
  sym__arg_pool = 143,
  sym_function = 144,
  sym_external_function = 145,
  sym__term_comma = 146,
  sym__terms_trail = 147,
  sym_tuple_pool_item = 148,
  sym__tuple_pool_n = 149,
  sym_tuple = 150,
  sym_term = 151,
  sym_theory_operators = 152,
  sym_theory_terms = 153,
  sym__theory_arguments = 154,
  sym_theory_function = 155,
  sym__theory_terms_trail = 156,
  sym_theory_tuple = 157,
  sym_theory_list = 158,
  sym_theory_set = 159,
  sym_theory_unparsed_term = 160,
  sym_theory_term = 161,
  sym_theory_root_term = 162,
  sym_symbolic_atom = 163,
  sym_comparison = 164,
  sym_simple_atom = 165,
  sym_literal_sign = 166,
  sym_literal = 167,
  sym_condition = 168,
  sym_upper = 169,
  sym_lower = 170,
  sym_set_aggregate_element = 171,
  sym_set_aggregate_elements = 172,
  sym_set_aggregate = 173,
  sym_theory_element = 174,
  sym_theory_elements = 175,
  sym_theory_atom_upper = 176,
  sym_theory_atom = 177,
  sym_body_aggregate_element = 178,
  sym_body_aggregate_elements = 179,
  sym_body_aggregate = 180,
  sym_body_literal = 181,
  sym_body = 182,
  sym_head_aggregate_element = 183,
  sym_head_aggregate_elements = 184,
  sym_head_aggregate = 185,
  sym__conditional_literal_n = 186,
  sym__conditional_literal_0 = 187,
  sym_conditional_literal = 188,
  sym_disjunction = 189,
  sym_head = 190,
  sym_rule = 191,
  sym_integrity_constraint = 192,
  sym_weight = 193,
  sym_optimize_element = 194,
  sym_optimize_elements = 195,
  sym_weak_constraint = 196,
  sym_maximize = 197,
  sym_minimize = 198,
  sym_signature = 199,
  sym_extended_signature = 200,
  sym_extended_symbolic_atom = 201,
  sym_show = 202,
  sym_show_term = 203,
  sym_boolean = 204,
  sym_show_signature = 205,
  sym_defined = 206,
  sym_project_signature = 207,
  sym_project_atom = 208,
  sym_parameters = 209,
  sym_program = 210,
  sym_script = 211,
  sym_const = 212,
  sym_edge_pair = 213,
  sym_edge = 214,
  sym_heuristic = 215,
  sym_include = 216,
  sym_external = 217,
  sym__theory_operator_arity_binary = 218,
  sym_theory_operator_definition = 219,
  sym_theory_operator_definitions = 220,
  sym_theory_term_definition = 221,
  sym__theory_operators_sep = 222,
  sym_theory_atom_definition = 223,
  sym_theory = 224,
  sym__metasp_identifier = 225,
  sym_metasp_symbolic_atom = 226,
  sym_metasp_function = 227,
  sym_metasp_const_function = 228,
  sym_metasp_signature = 229,
  sym_metasp_type = 230,
  sym_metasp_type_keyword = 231,
  sym_metasp_expression_definitions = 232,
  sym_metasp_expression_definition = 233,
  sym_metasp_argument_definitions = 234,
  sym_metasp_argument_definition = 235,
  sym_metasp_keyword_arg = 236,
  sym_metasp_subtypes = 237,
  sym_metasp_macros = 238,
  sym_metasp_macro_definition = 239,
  sym_metasp_macro_where = 240,
  sym_metasp_occurrence = 241,
  sym_statement = 242,
  aux_sym_source_file_repeat1 = 243,
  aux_sym_variables_repeat1 = 244,
  aux_sym_doc_desc_repeat1 = 245,
  aux_sym_doc_args_repeat1 = 246,
  aux_sym_string_repeat1 = 247,
  aux_sym_fstring_repeat1 = 248,
  aux_sym_fstring_accessor_repeat1 = 249,
  aux_sym_const_terms_repeat1 = 250,
  aux_sym_abs_repeat1 = 251,
  aux_sym_terms_repeat1 = 252,
  aux_sym__terms_or_projection_repeat1 = 253,
  aux_sym__arg_pool_n_repeat1 = 254,
  aux_sym__tuple_pool_n_repeat1 = 255,
  aux_sym_theory_operators_repeat1 = 256,
  aux_sym_theory_terms_repeat1 = 257,
  aux_sym_theory_unparsed_term_repeat1 = 258,
  aux_sym_comparison_repeat1 = 259,
  aux_sym_condition_repeat1 = 260,
  aux_sym_set_aggregate_elements_repeat1 = 261,
  aux_sym_theory_elements_repeat1 = 262,
  aux_sym_body_aggregate_elements_repeat1 = 263,
  aux_sym_body_repeat1 = 264,
  aux_sym_head_aggregate_elements_repeat1 = 265,
  aux_sym_disjunction_repeat1 = 266,
  aux_sym_optimize_elements_repeat1 = 267,
  aux_sym_parameters_repeat1 = 268,
  aux_sym_edge_repeat1 = 269,
  aux_sym_theory_operator_definitions_repeat1 = 270,
  aux_sym__theory_operators_sep_repeat1 = 271,
  aux_sym__theory_definitions_repeat1 = 272,
  aux_sym__theory_definitions_repeat2 = 273,
  aux_sym_metasp_type_repeat1 = 274,
  aux_sym_metasp_expression_definitions_repeat1 = 275,
  aux_sym_metasp_argument_definitions_repeat1 = 276,
  aux_sym_metasp_argument_definition_repeat1 = 277,
  aux_sym_metasp_subtypes_repeat1 = 278,
  aux_sym_metasp_macros_repeat1 = 279,
  aux_sym_metasp_macro_where_repeat1 = 280,
  alias_sym_classical_negation = 281,
  alias_sym_lone_comma = 282,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [sym_line_comment] = "line_comment",
  [anon_sym_PERCENT_STAR_BANG] = "%*!",
  [aux_sym_doc_comment_token1] = "doc_comment_token1",
  [anon_sym_STAR_PERCENT] = "*%",
  [anon_sym_COMMA] = ",",
  [aux_sym_doc_predicate_token1] = "identifier",
  [anon_sym_RPAREN] = ")",
  [sym_doc_var] = "variable",
  [sym_doc_fragment_emph] = "doc_fragment_emph",
  [sym_doc_fragment_bold] = "doc_fragment_bold",
  [sym_doc_fragment_italic] = "doc_fragment_italic",
  [sym_doc_fragment_code] = "doc_fragment_code",
  [anon_sym_COLON] = ":",
  [sym_identifier] = "identifier",
  [anon_sym_DQUOTE] = "\"",
  [anon_sym_f_DQUOTE] = "f\"",
  [sym__string_fragment] = "string_fragment",
  [sym__fstring_fragment] = "string_fragment",
  [sym__string_escape] = "escape_sequence",
  [sym__fstring_escape] = "escape_sequence",
  [aux_sym_fstring_accessor_token1] = "identifier",
  [aux_sym_fstring_accessor_token2] = "fstring_accessor_token2",
  [aux_sym_fstring_accessor_token3] = "fstring_accessor_token3",
  [aux_sym_fstring_accessor_token4] = "fstring_accessor_token4",
  [aux_sym_fstring_conversion_token1] = "fstring_conversion_token1",
  [aux_sym_fstring_conversion_token2] = "fstring_conversion_token2",
  [sym_fstring_align] = "fstring_align",
  [sym_fstring_sign] = "fstring_sign",
  [sym_fstring_alternate] = "fstring_alternate",
  [sym_fstring_grouping] = "fstring_grouping",
  [sym_fstring_type] = "fstring_type",
  [aux_sym_fstring_spec_token1] = "fstring_spec_token1",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [sym_supremum] = "supremum",
  [sym_infimum] = "infimum",
  [sym_number] = "number",
  [sym_anonymous] = "anonymous",
  [sym_variable] = "variable",
  [anon_sym_CARET] = "^",
  [anon_sym_QMARK] = "\?",
  [anon_sym_AMP] = "&",
  [anon_sym_PLUS] = "+",
  [anon_sym_DASH] = "-",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_BSLASH] = "\\",
  [anon_sym_STAR_STAR] = "**",
  [anon_sym_TILDE] = "~",
  [anon_sym_PIPE] = "|",
  [anon_sym_COMMA2] = ",",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN2] = ")",
  [anon_sym_DOT_DOT] = "..",
  [anon_sym_SEMI] = ";",
  [anon_sym_AT] = "@",
  [sym_theory_operator] = "theory_operator",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_RBRACE2] = "}",
  [sym_boolean_constant] = "boolean_constant",
  [sym_relation] = "relation",
  [sym_default_negation] = "default_negation",
  [sym_double_default_negation] = "double_default_negation",
  [sym_aggregate_function] = "aggregate_function",
  [anon_sym_DOT] = ".",
  [anon_sym_COLON_DASH] = ":-",
  [anon_sym_COLON_TILDE] = ":~",
  [anon_sym_POUNDmaximize] = "#maximize",
  [anon_sym_POUNDmaximise] = "#maximise",
  [anon_sym_POUNDminimize] = "#minimize",
  [anon_sym_POUNDminimise] = "#minimise",
  [anon_sym_POUNDshow] = "#show",
  [anon_sym_true] = "true",
  [anon_sym_false] = "false",
  [anon_sym_POUNDdefined] = "#defined",
  [anon_sym_POUNDproject] = "#project",
  [anon_sym_POUNDprogram] = "#program",
  [sym_code] = "code",
  [anon_sym_POUNDscript] = "#script",
  [anon_sym_POUNDend] = "#end",
  [sym_const_type] = "const_type",
  [anon_sym_POUNDconst] = "#const",
  [anon_sym_EQ] = "=",
  [anon_sym_POUNDedge] = "#edge",
  [anon_sym_POUNDheuristic] = "#heuristic",
  [anon_sym_POUNDinclude] = "#include",
  [anon_sym_LT] = "<",
  [anon_sym_GT] = ">",
  [anon_sym_POUNDexternal] = "#external",
  [sym_theory_operator_arity] = "theory_operator_arity",
  [anon_sym_binary] = "binary",
  [sym_theory_operator_associativity] = "theory_operator_associativity",
  [sym_theory_atom_type] = "theory_atom_type",
  [anon_sym_POUNDtheory] = "#theory",
  [anon_sym_POUNDtype] = "#type",
  [anon_sym_expressions] = "expressions",
  [anon_sym_COLON2] = ":",
  [anon_sym_subtypes] = "subtypes",
  [anon_sym_macros] = "macros",
  [anon_sym_where] = "where",
  [anon_sym_occurrence] = "occurrence",
  [sym_empty_pool_item_first] = "empty_pool_item",
  [sym_empty_pool_item] = "empty_pool_item",
  [sym_colon] = ":",
  [sym_block_comment] = "block_comment",
  [sym_doc_fragment_string] = "doc_fragment_string",
  [sym__doc_token_args] = "Args:",
  [sym__doc_token_paren] = "(",
  [sym__doc_token_minus] = "-",
  [sym_source_file] = "source_file",
  [sym_doc_comment] = "doc_comment",
  [sym_variables] = "variables",
  [sym_doc_predicate] = "doc_predicate",
  [sym_doc_desc] = "doc_desc",
  [sym_doc_args] = "doc_args",
  [sym_doc_arg] = "doc_arg",
  [sym_string] = "string",
  [sym_fstring] = "fstring",
  [sym_fstring_accessor] = "fstring_accessor",
  [sym_fstring_conversion] = "fstring_conversion",
  [sym_fstring_width] = "fstring_width",
  [sym_fstring_spec] = "fstring_spec",
  [sym_fstring_field] = "fstring_field",
  [sym__const_term] = "_const_term",
  [sym_const_binary_operation] = "binary_operation",
  [sym_const_unary_operation] = "unary_operation",
  [sym_const_abs] = "abs",
  [sym_const_terms] = "terms",
  [sym__const_arg_pool] = "_const_arg_pool",
  [sym_const_function] = "function",
  [sym__const_term_comma] = "terms",
  [sym__const_terms_trail] = "terms",
  [sym_const_tuple] = "tuple",
  [sym_binary_operation] = "binary_operation",
  [sym_unary_operation] = "unary_operation",
  [sym_abs] = "abs",
  [sym_terms] = "terms",
  [sym_projection] = "projection",
  [sym__term_or_projection] = "_term_or_projection",
  [sym__terms_or_projection] = "terms",
  [sym__arg_pool_n] = "_arg_pool_n",
  [sym__arg_pool] = "_arg_pool",
  [sym_function] = "function",
  [sym_external_function] = "external_function",
  [sym__term_comma] = "terms",
  [sym__terms_trail] = "terms",
  [sym_tuple_pool_item] = "tuple_pool_item",
  [sym__tuple_pool_n] = "_tuple_pool_n",
  [sym_tuple] = "tuple",
  [sym_term] = "term",
  [sym_theory_operators] = "theory_operators",
  [sym_theory_terms] = "theory_terms",
  [sym__theory_arguments] = "_theory_arguments",
  [sym_theory_function] = "theory_function",
  [sym__theory_terms_trail] = "theory_terms",
  [sym_theory_tuple] = "theory_tuple",
  [sym_theory_list] = "theory_list",
  [sym_theory_set] = "theory_set",
  [sym_theory_unparsed_term] = "theory_unparsed_term",
  [sym_theory_term] = "theory_term",
  [sym_theory_root_term] = "theory_root_term",
  [sym_symbolic_atom] = "symbolic_atom",
  [sym_comparison] = "comparison",
  [sym_simple_atom] = "simple_atom",
  [sym_literal_sign] = "literal_sign",
  [sym_literal] = "literal",
  [sym_condition] = "condition",
  [sym_upper] = "upper",
  [sym_lower] = "lower",
  [sym_set_aggregate_element] = "set_aggregate_element",
  [sym_set_aggregate_elements] = "set_aggregate_elements",
  [sym_set_aggregate] = "set_aggregate",
  [sym_theory_element] = "theory_element",
  [sym_theory_elements] = "theory_elements",
  [sym_theory_atom_upper] = "theory_atom_upper",
  [sym_theory_atom] = "theory_atom",
  [sym_body_aggregate_element] = "body_aggregate_element",
  [sym_body_aggregate_elements] = "body_aggregate_elements",
  [sym_body_aggregate] = "body_aggregate",
  [sym_body_literal] = "body_literal",
  [sym_body] = "body",
  [sym_head_aggregate_element] = "head_aggregate_element",
  [sym_head_aggregate_elements] = "head_aggregate_elements",
  [sym_head_aggregate] = "head_aggregate",
  [sym__conditional_literal_n] = "_conditional_literal_n",
  [sym__conditional_literal_0] = "_conditional_literal_0",
  [sym_conditional_literal] = "conditional_literal",
  [sym_disjunction] = "disjunction",
  [sym_head] = "head",
  [sym_rule] = "rule",
  [sym_integrity_constraint] = "integrity_constraint",
  [sym_weight] = "weight",
  [sym_optimize_element] = "optimize_element",
  [sym_optimize_elements] = "optimize_elements",
  [sym_weak_constraint] = "weak_constraint",
  [sym_maximize] = "maximize",
  [sym_minimize] = "minimize",
  [sym_signature] = "signature",
  [sym_extended_signature] = "extended_signature",
  [sym_extended_symbolic_atom] = "extended_symbolic_atom",
  [sym_show] = "show",
  [sym_show_term] = "show_term",
  [sym_boolean] = "boolean",
  [sym_show_signature] = "show_signature",
  [sym_defined] = "defined",
  [sym_project_signature] = "project_signature",
  [sym_project_atom] = "project_atom",
  [sym_parameters] = "parameters",
  [sym_program] = "program",
  [sym_script] = "script",
  [sym_const] = "const",
  [sym_edge_pair] = "edge_pair",
  [sym_edge] = "edge",
  [sym_heuristic] = "heuristic",
  [sym_include] = "include",
  [sym_external] = "external",
  [sym__theory_operator_arity_binary] = "theory_operator_arity",
  [sym_theory_operator_definition] = "theory_operator_definition",
  [sym_theory_operator_definitions] = "theory_operator_definitions",
  [sym_theory_term_definition] = "theory_term_definition",
  [sym__theory_operators_sep] = "theory_operators",
  [sym_theory_atom_definition] = "theory_atom_definition",
  [sym_theory] = "theory",
  [sym__metasp_identifier] = "_metasp_identifier",
  [sym_metasp_symbolic_atom] = "metasp_symbolic_atom",
  [sym_metasp_function] = "metasp_function",
  [sym_metasp_const_function] = "metasp_function",
  [sym_metasp_signature] = "metasp_signature",
  [sym_metasp_type] = "metasp_type",
  [sym_metasp_type_keyword] = "metasp_type_keyword",
  [sym_metasp_expression_definitions] = "metasp_expression_definitions",
  [sym_metasp_expression_definition] = "metasp_expression_definition",
  [sym_metasp_argument_definitions] = "metasp_argument_definitions",
  [sym_metasp_argument_definition] = "metasp_argument_definition",
  [sym_metasp_keyword_arg] = "metasp_keyword_arg",
  [sym_metasp_subtypes] = "metasp_subtypes",
  [sym_metasp_macros] = "metasp_macros",
  [sym_metasp_macro_definition] = "metasp_macro_definition",
  [sym_metasp_macro_where] = "metasp_macro_where",
  [sym_metasp_occurrence] = "metasp_occurrence",
  [sym_statement] = "statement",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_variables_repeat1] = "variables_repeat1",
  [aux_sym_doc_desc_repeat1] = "doc_desc_repeat1",
  [aux_sym_doc_args_repeat1] = "doc_args_repeat1",
  [aux_sym_string_repeat1] = "string_repeat1",
  [aux_sym_fstring_repeat1] = "fstring_repeat1",
  [aux_sym_fstring_accessor_repeat1] = "fstring_accessor_repeat1",
  [aux_sym_const_terms_repeat1] = "const_terms_repeat1",
  [aux_sym_abs_repeat1] = "abs_repeat1",
  [aux_sym_terms_repeat1] = "terms_repeat1",
  [aux_sym__terms_or_projection_repeat1] = "_terms_or_projection_repeat1",
  [aux_sym__arg_pool_n_repeat1] = "_arg_pool_n_repeat1",
  [aux_sym__tuple_pool_n_repeat1] = "_tuple_pool_n_repeat1",
  [aux_sym_theory_operators_repeat1] = "theory_operators_repeat1",
  [aux_sym_theory_terms_repeat1] = "theory_terms_repeat1",
  [aux_sym_theory_unparsed_term_repeat1] = "theory_unparsed_term_repeat1",
  [aux_sym_comparison_repeat1] = "comparison_repeat1",
  [aux_sym_condition_repeat1] = "condition_repeat1",
  [aux_sym_set_aggregate_elements_repeat1] = "set_aggregate_elements_repeat1",
  [aux_sym_theory_elements_repeat1] = "theory_elements_repeat1",
  [aux_sym_body_aggregate_elements_repeat1] = "body_aggregate_elements_repeat1",
  [aux_sym_body_repeat1] = "body_repeat1",
  [aux_sym_head_aggregate_elements_repeat1] = "head_aggregate_elements_repeat1",
  [aux_sym_disjunction_repeat1] = "disjunction_repeat1",
  [aux_sym_optimize_elements_repeat1] = "optimize_elements_repeat1",
  [aux_sym_parameters_repeat1] = "parameters_repeat1",
  [aux_sym_edge_repeat1] = "edge_repeat1",
  [aux_sym_theory_operator_definitions_repeat1] = "theory_operator_definitions_repeat1",
  [aux_sym__theory_operators_sep_repeat1] = "_theory_operators_sep_repeat1",
  [aux_sym__theory_definitions_repeat1] = "_theory_definitions_repeat1",
  [aux_sym__theory_definitions_repeat2] = "_theory_definitions_repeat2",
  [aux_sym_metasp_type_repeat1] = "metasp_type_repeat1",
  [aux_sym_metasp_expression_definitions_repeat1] = "metasp_expression_definitions_repeat1",
  [aux_sym_metasp_argument_definitions_repeat1] = "metasp_argument_definitions_repeat1",
  [aux_sym_metasp_argument_definition_repeat1] = "metasp_argument_definition_repeat1",
  [aux_sym_metasp_subtypes_repeat1] = "metasp_subtypes_repeat1",
  [aux_sym_metasp_macros_repeat1] = "metasp_macros_repeat1",
  [aux_sym_metasp_macro_where_repeat1] = "metasp_macro_where_repeat1",
  [alias_sym_classical_negation] = "classical_negation",
  [alias_sym_lone_comma] = "lone_comma",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [sym_line_comment] = sym_line_comment,
  [anon_sym_PERCENT_STAR_BANG] = anon_sym_PERCENT_STAR_BANG,
  [aux_sym_doc_comment_token1] = aux_sym_doc_comment_token1,
  [anon_sym_STAR_PERCENT] = anon_sym_STAR_PERCENT,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [aux_sym_doc_predicate_token1] = sym_identifier,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [sym_doc_var] = sym_variable,
  [sym_doc_fragment_emph] = sym_doc_fragment_emph,
  [sym_doc_fragment_bold] = sym_doc_fragment_bold,
  [sym_doc_fragment_italic] = sym_doc_fragment_italic,
  [sym_doc_fragment_code] = sym_doc_fragment_code,
  [anon_sym_COLON] = anon_sym_COLON,
  [sym_identifier] = sym_identifier,
  [anon_sym_DQUOTE] = anon_sym_DQUOTE,
  [anon_sym_f_DQUOTE] = anon_sym_f_DQUOTE,
  [sym__string_fragment] = sym__string_fragment,
  [sym__fstring_fragment] = sym__string_fragment,
  [sym__string_escape] = sym__string_escape,
  [sym__fstring_escape] = sym__string_escape,
  [aux_sym_fstring_accessor_token1] = sym_identifier,
  [aux_sym_fstring_accessor_token2] = aux_sym_fstring_accessor_token2,
  [aux_sym_fstring_accessor_token3] = aux_sym_fstring_accessor_token3,
  [aux_sym_fstring_accessor_token4] = aux_sym_fstring_accessor_token4,
  [aux_sym_fstring_conversion_token1] = aux_sym_fstring_conversion_token1,
  [aux_sym_fstring_conversion_token2] = aux_sym_fstring_conversion_token2,
  [sym_fstring_align] = sym_fstring_align,
  [sym_fstring_sign] = sym_fstring_sign,
  [sym_fstring_alternate] = sym_fstring_alternate,
  [sym_fstring_grouping] = sym_fstring_grouping,
  [sym_fstring_type] = sym_fstring_type,
  [aux_sym_fstring_spec_token1] = aux_sym_fstring_spec_token1,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [sym_supremum] = sym_supremum,
  [sym_infimum] = sym_infimum,
  [sym_number] = sym_number,
  [sym_anonymous] = sym_anonymous,
  [sym_variable] = sym_variable,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_BSLASH] = anon_sym_BSLASH,
  [anon_sym_STAR_STAR] = anon_sym_STAR_STAR,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_COMMA2] = anon_sym_COMMA,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN2] = anon_sym_RPAREN,
  [anon_sym_DOT_DOT] = anon_sym_DOT_DOT,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_AT] = anon_sym_AT,
  [sym_theory_operator] = sym_theory_operator,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_RBRACE2] = anon_sym_RBRACE,
  [sym_boolean_constant] = sym_boolean_constant,
  [sym_relation] = sym_relation,
  [sym_default_negation] = sym_default_negation,
  [sym_double_default_negation] = sym_double_default_negation,
  [sym_aggregate_function] = sym_aggregate_function,
  [anon_sym_DOT] = anon_sym_DOT,
  [anon_sym_COLON_DASH] = anon_sym_COLON_DASH,
  [anon_sym_COLON_TILDE] = anon_sym_COLON_TILDE,
  [anon_sym_POUNDmaximize] = anon_sym_POUNDmaximize,
  [anon_sym_POUNDmaximise] = anon_sym_POUNDmaximise,
  [anon_sym_POUNDminimize] = anon_sym_POUNDminimize,
  [anon_sym_POUNDminimise] = anon_sym_POUNDminimise,
  [anon_sym_POUNDshow] = anon_sym_POUNDshow,
  [anon_sym_true] = anon_sym_true,
  [anon_sym_false] = anon_sym_false,
  [anon_sym_POUNDdefined] = anon_sym_POUNDdefined,
  [anon_sym_POUNDproject] = anon_sym_POUNDproject,
  [anon_sym_POUNDprogram] = anon_sym_POUNDprogram,
  [sym_code] = sym_code,
  [anon_sym_POUNDscript] = anon_sym_POUNDscript,
  [anon_sym_POUNDend] = anon_sym_POUNDend,
  [sym_const_type] = sym_const_type,
  [anon_sym_POUNDconst] = anon_sym_POUNDconst,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_POUNDedge] = anon_sym_POUNDedge,
  [anon_sym_POUNDheuristic] = anon_sym_POUNDheuristic,
  [anon_sym_POUNDinclude] = anon_sym_POUNDinclude,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_POUNDexternal] = anon_sym_POUNDexternal,
  [sym_theory_operator_arity] = sym_theory_operator_arity,
  [anon_sym_binary] = anon_sym_binary,
  [sym_theory_operator_associativity] = sym_theory_operator_associativity,
  [sym_theory_atom_type] = sym_theory_atom_type,
  [anon_sym_POUNDtheory] = anon_sym_POUNDtheory,
  [anon_sym_POUNDtype] = anon_sym_POUNDtype,
  [anon_sym_expressions] = anon_sym_expressions,
  [anon_sym_COLON2] = anon_sym_COLON,
  [anon_sym_subtypes] = anon_sym_subtypes,
  [anon_sym_macros] = anon_sym_macros,
  [anon_sym_where] = anon_sym_where,
  [anon_sym_occurrence] = anon_sym_occurrence,
  [sym_empty_pool_item_first] = sym_empty_pool_item,
  [sym_empty_pool_item] = sym_empty_pool_item,
  [sym_colon] = anon_sym_COLON,
  [sym_block_comment] = sym_block_comment,
  [sym_doc_fragment_string] = sym_doc_fragment_string,
  [sym__doc_token_args] = sym__doc_token_args,
  [sym__doc_token_paren] = anon_sym_LPAREN,
  [sym__doc_token_minus] = anon_sym_DASH,
  [sym_source_file] = sym_source_file,
  [sym_doc_comment] = sym_doc_comment,
  [sym_variables] = sym_variables,
  [sym_doc_predicate] = sym_doc_predicate,
  [sym_doc_desc] = sym_doc_desc,
  [sym_doc_args] = sym_doc_args,
  [sym_doc_arg] = sym_doc_arg,
  [sym_string] = sym_string,
  [sym_fstring] = sym_fstring,
  [sym_fstring_accessor] = sym_fstring_accessor,
  [sym_fstring_conversion] = sym_fstring_conversion,
  [sym_fstring_width] = sym_fstring_width,
  [sym_fstring_spec] = sym_fstring_spec,
  [sym_fstring_field] = sym_fstring_field,
  [sym__const_term] = sym__const_term,
  [sym_const_binary_operation] = sym_binary_operation,
  [sym_const_unary_operation] = sym_unary_operation,
  [sym_const_abs] = sym_abs,
  [sym_const_terms] = sym_terms,
  [sym__const_arg_pool] = sym__const_arg_pool,
  [sym_const_function] = sym_function,
  [sym__const_term_comma] = sym_terms,
  [sym__const_terms_trail] = sym_terms,
  [sym_const_tuple] = sym_tuple,
  [sym_binary_operation] = sym_binary_operation,
  [sym_unary_operation] = sym_unary_operation,
  [sym_abs] = sym_abs,
  [sym_terms] = sym_terms,
  [sym_projection] = sym_projection,
  [sym__term_or_projection] = sym__term_or_projection,
  [sym__terms_or_projection] = sym_terms,
  [sym__arg_pool_n] = sym__arg_pool_n,
  [sym__arg_pool] = sym__arg_pool,
  [sym_function] = sym_function,
  [sym_external_function] = sym_external_function,
  [sym__term_comma] = sym_terms,
  [sym__terms_trail] = sym_terms,
  [sym_tuple_pool_item] = sym_tuple_pool_item,
  [sym__tuple_pool_n] = sym__tuple_pool_n,
  [sym_tuple] = sym_tuple,
  [sym_term] = sym_term,
  [sym_theory_operators] = sym_theory_operators,
  [sym_theory_terms] = sym_theory_terms,
  [sym__theory_arguments] = sym__theory_arguments,
  [sym_theory_function] = sym_theory_function,
  [sym__theory_terms_trail] = sym_theory_terms,
  [sym_theory_tuple] = sym_theory_tuple,
  [sym_theory_list] = sym_theory_list,
  [sym_theory_set] = sym_theory_set,
  [sym_theory_unparsed_term] = sym_theory_unparsed_term,
  [sym_theory_term] = sym_theory_term,
  [sym_theory_root_term] = sym_theory_root_term,
  [sym_symbolic_atom] = sym_symbolic_atom,
  [sym_comparison] = sym_comparison,
  [sym_simple_atom] = sym_simple_atom,
  [sym_literal_sign] = sym_literal_sign,
  [sym_literal] = sym_literal,
  [sym_condition] = sym_condition,
  [sym_upper] = sym_upper,
  [sym_lower] = sym_lower,
  [sym_set_aggregate_element] = sym_set_aggregate_element,
  [sym_set_aggregate_elements] = sym_set_aggregate_elements,
  [sym_set_aggregate] = sym_set_aggregate,
  [sym_theory_element] = sym_theory_element,
  [sym_theory_elements] = sym_theory_elements,
  [sym_theory_atom_upper] = sym_theory_atom_upper,
  [sym_theory_atom] = sym_theory_atom,
  [sym_body_aggregate_element] = sym_body_aggregate_element,
  [sym_body_aggregate_elements] = sym_body_aggregate_elements,
  [sym_body_aggregate] = sym_body_aggregate,
  [sym_body_literal] = sym_body_literal,
  [sym_body] = sym_body,
  [sym_head_aggregate_element] = sym_head_aggregate_element,
  [sym_head_aggregate_elements] = sym_head_aggregate_elements,
  [sym_head_aggregate] = sym_head_aggregate,
  [sym__conditional_literal_n] = sym__conditional_literal_n,
  [sym__conditional_literal_0] = sym__conditional_literal_0,
  [sym_conditional_literal] = sym_conditional_literal,
  [sym_disjunction] = sym_disjunction,
  [sym_head] = sym_head,
  [sym_rule] = sym_rule,
  [sym_integrity_constraint] = sym_integrity_constraint,
  [sym_weight] = sym_weight,
  [sym_optimize_element] = sym_optimize_element,
  [sym_optimize_elements] = sym_optimize_elements,
  [sym_weak_constraint] = sym_weak_constraint,
  [sym_maximize] = sym_maximize,
  [sym_minimize] = sym_minimize,
  [sym_signature] = sym_signature,
  [sym_extended_signature] = sym_extended_signature,
  [sym_extended_symbolic_atom] = sym_extended_symbolic_atom,
  [sym_show] = sym_show,
  [sym_show_term] = sym_show_term,
  [sym_boolean] = sym_boolean,
  [sym_show_signature] = sym_show_signature,
  [sym_defined] = sym_defined,
  [sym_project_signature] = sym_project_signature,
  [sym_project_atom] = sym_project_atom,
  [sym_parameters] = sym_parameters,
  [sym_program] = sym_program,
  [sym_script] = sym_script,
  [sym_const] = sym_const,
  [sym_edge_pair] = sym_edge_pair,
  [sym_edge] = sym_edge,
  [sym_heuristic] = sym_heuristic,
  [sym_include] = sym_include,
  [sym_external] = sym_external,
  [sym__theory_operator_arity_binary] = sym_theory_operator_arity,
  [sym_theory_operator_definition] = sym_theory_operator_definition,
  [sym_theory_operator_definitions] = sym_theory_operator_definitions,
  [sym_theory_term_definition] = sym_theory_term_definition,
  [sym__theory_operators_sep] = sym_theory_operators,
  [sym_theory_atom_definition] = sym_theory_atom_definition,
  [sym_theory] = sym_theory,
  [sym__metasp_identifier] = sym__metasp_identifier,
  [sym_metasp_symbolic_atom] = sym_metasp_symbolic_atom,
  [sym_metasp_function] = sym_metasp_function,
  [sym_metasp_const_function] = sym_metasp_function,
  [sym_metasp_signature] = sym_metasp_signature,
  [sym_metasp_type] = sym_metasp_type,
  [sym_metasp_type_keyword] = sym_metasp_type_keyword,
  [sym_metasp_expression_definitions] = sym_metasp_expression_definitions,
  [sym_metasp_expression_definition] = sym_metasp_expression_definition,
  [sym_metasp_argument_definitions] = sym_metasp_argument_definitions,
  [sym_metasp_argument_definition] = sym_metasp_argument_definition,
  [sym_metasp_keyword_arg] = sym_metasp_keyword_arg,
  [sym_metasp_subtypes] = sym_metasp_subtypes,
  [sym_metasp_macros] = sym_metasp_macros,
  [sym_metasp_macro_definition] = sym_metasp_macro_definition,
  [sym_metasp_macro_where] = sym_metasp_macro_where,
  [sym_metasp_occurrence] = sym_metasp_occurrence,
  [sym_statement] = sym_statement,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_variables_repeat1] = aux_sym_variables_repeat1,
  [aux_sym_doc_desc_repeat1] = aux_sym_doc_desc_repeat1,
  [aux_sym_doc_args_repeat1] = aux_sym_doc_args_repeat1,
  [aux_sym_string_repeat1] = aux_sym_string_repeat1,
  [aux_sym_fstring_repeat1] = aux_sym_fstring_repeat1,
  [aux_sym_fstring_accessor_repeat1] = aux_sym_fstring_accessor_repeat1,
  [aux_sym_const_terms_repeat1] = aux_sym_const_terms_repeat1,
  [aux_sym_abs_repeat1] = aux_sym_abs_repeat1,
  [aux_sym_terms_repeat1] = aux_sym_terms_repeat1,
  [aux_sym__terms_or_projection_repeat1] = aux_sym__terms_or_projection_repeat1,
  [aux_sym__arg_pool_n_repeat1] = aux_sym__arg_pool_n_repeat1,
  [aux_sym__tuple_pool_n_repeat1] = aux_sym__tuple_pool_n_repeat1,
  [aux_sym_theory_operators_repeat1] = aux_sym_theory_operators_repeat1,
  [aux_sym_theory_terms_repeat1] = aux_sym_theory_terms_repeat1,
  [aux_sym_theory_unparsed_term_repeat1] = aux_sym_theory_unparsed_term_repeat1,
  [aux_sym_comparison_repeat1] = aux_sym_comparison_repeat1,
  [aux_sym_condition_repeat1] = aux_sym_condition_repeat1,
  [aux_sym_set_aggregate_elements_repeat1] = aux_sym_set_aggregate_elements_repeat1,
  [aux_sym_theory_elements_repeat1] = aux_sym_theory_elements_repeat1,
  [aux_sym_body_aggregate_elements_repeat1] = aux_sym_body_aggregate_elements_repeat1,
  [aux_sym_body_repeat1] = aux_sym_body_repeat1,
  [aux_sym_head_aggregate_elements_repeat1] = aux_sym_head_aggregate_elements_repeat1,
  [aux_sym_disjunction_repeat1] = aux_sym_disjunction_repeat1,
  [aux_sym_optimize_elements_repeat1] = aux_sym_optimize_elements_repeat1,
  [aux_sym_parameters_repeat1] = aux_sym_parameters_repeat1,
  [aux_sym_edge_repeat1] = aux_sym_edge_repeat1,
  [aux_sym_theory_operator_definitions_repeat1] = aux_sym_theory_operator_definitions_repeat1,
  [aux_sym__theory_operators_sep_repeat1] = aux_sym__theory_operators_sep_repeat1,
  [aux_sym__theory_definitions_repeat1] = aux_sym__theory_definitions_repeat1,
  [aux_sym__theory_definitions_repeat2] = aux_sym__theory_definitions_repeat2,
  [aux_sym_metasp_type_repeat1] = aux_sym_metasp_type_repeat1,
  [aux_sym_metasp_expression_definitions_repeat1] = aux_sym_metasp_expression_definitions_repeat1,
  [aux_sym_metasp_argument_definitions_repeat1] = aux_sym_metasp_argument_definitions_repeat1,
  [aux_sym_metasp_argument_definition_repeat1] = aux_sym_metasp_argument_definition_repeat1,
  [aux_sym_metasp_subtypes_repeat1] = aux_sym_metasp_subtypes_repeat1,
  [aux_sym_metasp_macros_repeat1] = aux_sym_metasp_macros_repeat1,
  [aux_sym_metasp_macro_where_repeat1] = aux_sym_metasp_macro_where_repeat1,
  [alias_sym_classical_negation] = alias_sym_classical_negation,
  [alias_sym_lone_comma] = alias_sym_lone_comma,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [sym_line_comment] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_PERCENT_STAR_BANG] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_doc_comment_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_STAR_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_doc_predicate_token1] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [sym_doc_var] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_fragment_emph] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_fragment_bold] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_fragment_italic] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_fragment_code] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [sym_identifier] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_f_DQUOTE] = {
    .visible = true,
    .named = false,
  },
  [sym__string_fragment] = {
    .visible = true,
    .named = true,
  },
  [sym__fstring_fragment] = {
    .visible = true,
    .named = true,
  },
  [sym__string_escape] = {
    .visible = true,
    .named = true,
  },
  [sym__fstring_escape] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_fstring_accessor_token1] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_fstring_accessor_token2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fstring_accessor_token3] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fstring_accessor_token4] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fstring_conversion_token1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fstring_conversion_token2] = {
    .visible = false,
    .named = false,
  },
  [sym_fstring_align] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring_sign] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring_alternate] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring_grouping] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring_type] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_fstring_spec_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [sym_supremum] = {
    .visible = true,
    .named = true,
  },
  [sym_infimum] = {
    .visible = true,
    .named = true,
  },
  [sym_number] = {
    .visible = true,
    .named = true,
  },
  [sym_anonymous] = {
    .visible = true,
    .named = true,
  },
  [sym_variable] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BSLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOT_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AT] = {
    .visible = true,
    .named = false,
  },
  [sym_theory_operator] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE2] = {
    .visible = true,
    .named = false,
  },
  [sym_boolean_constant] = {
    .visible = true,
    .named = true,
  },
  [sym_relation] = {
    .visible = true,
    .named = true,
  },
  [sym_default_negation] = {
    .visible = true,
    .named = true,
  },
  [sym_double_default_negation] = {
    .visible = true,
    .named = true,
  },
  [sym_aggregate_function] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_DOT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDmaximize] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDmaximise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDminimize] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDminimise] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDshow] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_true] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_false] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDdefined] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDproject] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDprogram] = {
    .visible = true,
    .named = false,
  },
  [sym_code] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_POUNDscript] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDend] = {
    .visible = true,
    .named = false,
  },
  [sym_const_type] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_POUNDconst] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDedge] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDheuristic] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDinclude] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDexternal] = {
    .visible = true,
    .named = false,
  },
  [sym_theory_operator_arity] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_binary] = {
    .visible = true,
    .named = false,
  },
  [sym_theory_operator_associativity] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_atom_type] = {
    .visible = true,
    .named = true,
  },
  [anon_sym_POUNDtheory] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_POUNDtype] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_expressions] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON2] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_subtypes] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_macros] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_where] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_occurrence] = {
    .visible = true,
    .named = false,
  },
  [sym_empty_pool_item_first] = {
    .visible = true,
    .named = true,
  },
  [sym_empty_pool_item] = {
    .visible = true,
    .named = true,
  },
  [sym_colon] = {
    .visible = true,
    .named = false,
  },
  [sym_block_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_fragment_string] = {
    .visible = true,
    .named = true,
  },
  [sym__doc_token_args] = {
    .visible = true,
    .named = false,
  },
  [sym__doc_token_paren] = {
    .visible = true,
    .named = false,
  },
  [sym__doc_token_minus] = {
    .visible = true,
    .named = false,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_variables] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_predicate] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_desc] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_args] = {
    .visible = true,
    .named = true,
  },
  [sym_doc_arg] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring_accessor] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring_conversion] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring_width] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring_spec] = {
    .visible = true,
    .named = true,
  },
  [sym_fstring_field] = {
    .visible = true,
    .named = true,
  },
  [sym__const_term] = {
    .visible = false,
    .named = true,
  },
  [sym_const_binary_operation] = {
    .visible = true,
    .named = true,
  },
  [sym_const_unary_operation] = {
    .visible = true,
    .named = true,
  },
  [sym_const_abs] = {
    .visible = true,
    .named = true,
  },
  [sym_const_terms] = {
    .visible = true,
    .named = true,
  },
  [sym__const_arg_pool] = {
    .visible = false,
    .named = true,
  },
  [sym_const_function] = {
    .visible = true,
    .named = true,
  },
  [sym__const_term_comma] = {
    .visible = true,
    .named = true,
  },
  [sym__const_terms_trail] = {
    .visible = true,
    .named = true,
  },
  [sym_const_tuple] = {
    .visible = true,
    .named = true,
  },
  [sym_binary_operation] = {
    .visible = true,
    .named = true,
  },
  [sym_unary_operation] = {
    .visible = true,
    .named = true,
  },
  [sym_abs] = {
    .visible = true,
    .named = true,
  },
  [sym_terms] = {
    .visible = true,
    .named = true,
  },
  [sym_projection] = {
    .visible = true,
    .named = true,
  },
  [sym__term_or_projection] = {
    .visible = false,
    .named = true,
  },
  [sym__terms_or_projection] = {
    .visible = true,
    .named = true,
  },
  [sym__arg_pool_n] = {
    .visible = false,
    .named = true,
  },
  [sym__arg_pool] = {
    .visible = false,
    .named = true,
  },
  [sym_function] = {
    .visible = true,
    .named = true,
  },
  [sym_external_function] = {
    .visible = true,
    .named = true,
  },
  [sym__term_comma] = {
    .visible = true,
    .named = true,
  },
  [sym__terms_trail] = {
    .visible = true,
    .named = true,
  },
  [sym_tuple_pool_item] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym__tuple_pool_n] = {
    .visible = false,
    .named = true,
  },
  [sym_tuple] = {
    .visible = true,
    .named = true,
  },
  [sym_term] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_theory_operators] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_terms] = {
    .visible = true,
    .named = true,
  },
  [sym__theory_arguments] = {
    .visible = false,
    .named = true,
  },
  [sym_theory_function] = {
    .visible = true,
    .named = true,
  },
  [sym__theory_terms_trail] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_tuple] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_list] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_set] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_unparsed_term] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_term] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_theory_root_term] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_symbolic_atom] = {
    .visible = true,
    .named = true,
  },
  [sym_comparison] = {
    .visible = true,
    .named = true,
  },
  [sym_simple_atom] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_literal_sign] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_condition] = {
    .visible = true,
    .named = true,
  },
  [sym_upper] = {
    .visible = true,
    .named = true,
  },
  [sym_lower] = {
    .visible = true,
    .named = true,
  },
  [sym_set_aggregate_element] = {
    .visible = true,
    .named = true,
  },
  [sym_set_aggregate_elements] = {
    .visible = true,
    .named = true,
  },
  [sym_set_aggregate] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_element] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_elements] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_atom_upper] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_atom] = {
    .visible = true,
    .named = true,
  },
  [sym_body_aggregate_element] = {
    .visible = true,
    .named = true,
  },
  [sym_body_aggregate_elements] = {
    .visible = true,
    .named = true,
  },
  [sym_body_aggregate] = {
    .visible = true,
    .named = true,
  },
  [sym_body_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_body] = {
    .visible = true,
    .named = true,
  },
  [sym_head_aggregate_element] = {
    .visible = true,
    .named = true,
  },
  [sym_head_aggregate_elements] = {
    .visible = true,
    .named = true,
  },
  [sym_head_aggregate] = {
    .visible = true,
    .named = true,
  },
  [sym__conditional_literal_n] = {
    .visible = false,
    .named = true,
  },
  [sym__conditional_literal_0] = {
    .visible = false,
    .named = true,
  },
  [sym_conditional_literal] = {
    .visible = true,
    .named = true,
  },
  [sym_disjunction] = {
    .visible = true,
    .named = true,
  },
  [sym_head] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_rule] = {
    .visible = true,
    .named = true,
  },
  [sym_integrity_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_weight] = {
    .visible = true,
    .named = true,
  },
  [sym_optimize_element] = {
    .visible = true,
    .named = true,
  },
  [sym_optimize_elements] = {
    .visible = true,
    .named = true,
  },
  [sym_weak_constraint] = {
    .visible = true,
    .named = true,
  },
  [sym_maximize] = {
    .visible = true,
    .named = true,
  },
  [sym_minimize] = {
    .visible = true,
    .named = true,
  },
  [sym_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_extended_signature] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_extended_symbolic_atom] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_show] = {
    .visible = true,
    .named = true,
  },
  [sym_show_term] = {
    .visible = true,
    .named = true,
  },
  [sym_boolean] = {
    .visible = true,
    .named = true,
  },
  [sym_show_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_defined] = {
    .visible = true,
    .named = true,
  },
  [sym_project_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_project_atom] = {
    .visible = true,
    .named = true,
  },
  [sym_parameters] = {
    .visible = true,
    .named = true,
  },
  [sym_program] = {
    .visible = true,
    .named = true,
  },
  [sym_script] = {
    .visible = true,
    .named = true,
  },
  [sym_const] = {
    .visible = true,
    .named = true,
  },
  [sym_edge_pair] = {
    .visible = true,
    .named = true,
  },
  [sym_edge] = {
    .visible = true,
    .named = true,
  },
  [sym_heuristic] = {
    .visible = true,
    .named = true,
  },
  [sym_include] = {
    .visible = true,
    .named = true,
  },
  [sym_external] = {
    .visible = true,
    .named = true,
  },
  [sym__theory_operator_arity_binary] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_operator_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_operator_definitions] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_term_definition] = {
    .visible = true,
    .named = true,
  },
  [sym__theory_operators_sep] = {
    .visible = true,
    .named = true,
  },
  [sym_theory_atom_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_theory] = {
    .visible = true,
    .named = true,
  },
  [sym__metasp_identifier] = {
    .visible = false,
    .named = true,
  },
  [sym_metasp_symbolic_atom] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_function] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_const_function] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_signature] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_type] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_type_keyword] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [sym_metasp_expression_definitions] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_expression_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_argument_definitions] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_argument_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_keyword_arg] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_subtypes] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_macros] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_macro_definition] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_macro_where] = {
    .visible = true,
    .named = true,
  },
  [sym_metasp_occurrence] = {
    .visible = true,
    .named = true,
  },
  [sym_statement] = {
    .visible = false,
    .named = true,
    .supertype = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_variables_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_doc_desc_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_doc_args_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_string_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fstring_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_fstring_accessor_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_const_terms_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_abs_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_terms_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__terms_or_projection_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__arg_pool_n_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__tuple_pool_n_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_theory_operators_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_theory_terms_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_theory_unparsed_term_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_comparison_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_condition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_set_aggregate_elements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_theory_elements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_body_aggregate_elements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_head_aggregate_elements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_disjunction_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_optimize_elements_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_parameters_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_edge_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_theory_operator_definitions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__theory_operators_sep_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__theory_definitions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__theory_definitions_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metasp_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metasp_expression_definitions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metasp_argument_definitions_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metasp_argument_definition_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metasp_subtypes_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metasp_macros_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_metasp_macro_where_repeat1] = {
    .visible = false,
    .named = false,
  },
  [alias_sym_classical_negation] = {
    .visible = true,
    .named = true,
  },
  [alias_sym_lone_comma] = {
    .visible = true,
    .named = true,
  },
};

enum ts_field_identifiers {
  field_arguments = 1,
  field_arity = 2,
  field_associativity = 3,
  field_atom = 4,
  field_atom_type = 5,
  field_body = 6,
  field_code = 7,
  field_condition = 8,
  field_description = 9,
  field_edge_pair = 10,
  field_elements = 11,
  field_expressions = 12,
  field_function = 13,
  field_guard = 14,
  field_head = 15,
  field_language = 16,
  field_left = 17,
  field_literal = 18,
  field_macros = 19,
  field_name = 20,
  field_occurrence = 21,
  field_operator = 22,
  field_operators = 23,
  field_parameters = 24,
  field_predicate = 25,
  field_priority = 26,
  field_right = 27,
  field_sign = 28,
  field_signature = 29,
  field_subtypes = 30,
  field_term = 31,
  field_terms = 32,
  field_theory_term_name = 33,
  field_theory_terms = 34,
  field_type = 35,
  field_value = 36,
  field_variable = 37,
  field_variables = 38,
  field_weight = 39,
};

static const char * const ts_field_names[] = {
  [0] = NULL,
  [field_arguments] = "arguments",
  [field_arity] = "arity",
  [field_associativity] = "associativity",
  [field_atom] = "atom",
  [field_atom_type] = "atom_type",
  [field_body] = "body",
  [field_code] = "code",
  [field_condition] = "condition",
  [field_description] = "description",
  [field_edge_pair] = "edge_pair",
  [field_elements] = "elements",
  [field_expressions] = "expressions",
  [field_function] = "function",
  [field_guard] = "guard",
  [field_head] = "head",
  [field_language] = "language",
  [field_left] = "left",
  [field_literal] = "literal",
  [field_macros] = "macros",
  [field_name] = "name",
  [field_occurrence] = "occurrence",
  [field_operator] = "operator",
  [field_operators] = "operators",
  [field_parameters] = "parameters",
  [field_predicate] = "predicate",
  [field_priority] = "priority",
  [field_right] = "right",
  [field_sign] = "sign",
  [field_signature] = "signature",
  [field_subtypes] = "subtypes",
  [field_term] = "term",
  [field_terms] = "terms",
  [field_theory_term_name] = "theory_term_name",
  [field_theory_terms] = "theory_terms",
  [field_type] = "type",
  [field_value] = "value",
  [field_variable] = "variable",
  [field_variables] = "variables",
  [field_weight] = "weight",
};

static const TSMapSlice ts_field_map_slices[PRODUCTION_ID_COUNT] = {
  [1] = {.index = 0, .length = 1},
  [2] = {.index = 1, .length = 1},
  [3] = {.index = 2, .length = 2},
  [4] = {.index = 4, .length = 1},
  [5] = {.index = 5, .length = 2},
  [6] = {.index = 7, .length = 1},
  [7] = {.index = 8, .length = 2},
  [8] = {.index = 10, .length = 2},
  [10] = {.index = 12, .length = 1},
  [11] = {.index = 13, .length = 2},
  [12] = {.index = 2, .length = 2},
  [13] = {.index = 4, .length = 1},
  [14] = {.index = 15, .length = 1},
  [15] = {.index = 16, .length = 3},
  [16] = {.index = 19, .length = 1},
  [17] = {.index = 20, .length = 1},
  [18] = {.index = 21, .length = 3},
  [19] = {.index = 24, .length = 4},
  [20] = {.index = 28, .length = 2},
  [21] = {.index = 30, .length = 1},
  [22] = {.index = 31, .length = 1},
  [23] = {.index = 32, .length = 1},
  [24] = {.index = 33, .length = 1},
  [25] = {.index = 34, .length = 1},
  [26] = {.index = 35, .length = 1},
  [27] = {.index = 36, .length = 1},
  [28] = {.index = 37, .length = 3},
  [29] = {.index = 40, .length = 2},
  [30] = {.index = 42, .length = 1},
  [31] = {.index = 43, .length = 1},
  [32] = {.index = 44, .length = 2},
  [33] = {.index = 46, .length = 1},
  [34] = {.index = 47, .length = 1},
  [35] = {.index = 48, .length = 2},
  [37] = {.index = 50, .length = 1},
  [38] = {.index = 51, .length = 1},
  [39] = {.index = 52, .length = 2},
  [40] = {.index = 54, .length = 2},
  [41] = {.index = 56, .length = 1},
  [42] = {.index = 57, .length = 2},
  [43] = {.index = 59, .length = 4},
  [44] = {.index = 63, .length = 1},
  [45] = {.index = 64, .length = 1},
  [46] = {.index = 65, .length = 1},
  [47] = {.index = 66, .length = 1},
  [48] = {.index = 67, .length = 2},
  [49] = {.index = 69, .length = 2},
  [50] = {.index = 71, .length = 2},
  [51] = {.index = 73, .length = 2},
  [52] = {.index = 75, .length = 2},
  [53] = {.index = 77, .length = 2},
  [54] = {.index = 79, .length = 2},
  [55] = {.index = 81, .length = 1},
  [56] = {.index = 82, .length = 2},
  [57] = {.index = 84, .length = 2},
  [58] = {.index = 86, .length = 3},
  [59] = {.index = 89, .length = 2},
  [60] = {.index = 91, .length = 3},
  [61] = {.index = 94, .length = 1},
  [62] = {.index = 95, .length = 2},
  [63] = {.index = 97, .length = 2},
  [64] = {.index = 99, .length = 3},
  [65] = {.index = 102, .length = 1},
  [66] = {.index = 103, .length = 3},
  [67] = {.index = 106, .length = 2},
  [68] = {.index = 108, .length = 2},
  [69] = {.index = 110, .length = 2},
  [70] = {.index = 112, .length = 1},
  [71] = {.index = 113, .length = 1},
  [72] = {.index = 114, .length = 2},
  [73] = {.index = 116, .length = 3},
  [74] = {.index = 119, .length = 3},
  [75] = {.index = 122, .length = 3},
  [76] = {.index = 125, .length = 3},
  [78] = {.index = 128, .length = 2},
  [79] = {.index = 130, .length = 3},
  [80] = {.index = 133, .length = 4},
  [81] = {.index = 137, .length = 4},
  [82] = {.index = 141, .length = 2},
  [83] = {.index = 143, .length = 2},
  [84] = {.index = 145, .length = 2},
  [85] = {.index = 147, .length = 2},
  [86] = {.index = 149, .length = 2},
  [88] = {.index = 151, .length = 2},
  [89] = {.index = 153, .length = 2},
  [90] = {.index = 155, .length = 4},
  [91] = {.index = 159, .length = 5},
  [92] = {.index = 164, .length = 3},
  [93] = {.index = 167, .length = 3},
  [94] = {.index = 170, .length = 4},
  [95] = {.index = 174, .length = 2},
  [96] = {.index = 176, .length = 2},
  [97] = {.index = 178, .length = 2},
  [98] = {.index = 180, .length = 2},
  [99] = {.index = 182, .length = 1},
  [100] = {.index = 183, .length = 4},
  [101] = {.index = 187, .length = 3},
  [102] = {.index = 190, .length = 3},
  [103] = {.index = 193, .length = 3},
  [104] = {.index = 196, .length = 3},
  [105] = {.index = 199, .length = 2},
  [106] = {.index = 201, .length = 3},
  [107] = {.index = 204, .length = 4},
  [108] = {.index = 208, .length = 3},
  [109] = {.index = 208, .length = 3},
  [110] = {.index = 211, .length = 1},
  [111] = {.index = 212, .length = 4},
  [112] = {.index = 216, .length = 2},
  [113] = {.index = 218, .length = 2},
  [114] = {.index = 220, .length = 4},
  [115] = {.index = 220, .length = 4},
  [116] = {.index = 224, .length = 2},
  [118] = {.index = 226, .length = 5},
  [119] = {.index = 231, .length = 6},
};

static const TSFieldMapEntry ts_field_map_entries[] = {
  [0] =
    {field_name, 0},
  [1] =
    {field_atom, 0},
  [2] =
    {field_condition, 0, .inherited = true},
    {field_literal, 0, .inherited = true},
  [4] =
    {field_literal, 0, .inherited = true},
  [5] =
    {field_arguments, 1, .inherited = true},
    {field_name, 0},
  [7] =
    {field_literal, 0},
  [8] =
    {field_name, 1},
    {field_sign, 0},
  [10] =
    {field_operator, 0},
    {field_right, 1},
  [12] =
    {field_name, 1},
  [13] =
    {field_atom, 1},
    {field_sign, 0},
  [15] =
    {field_head, 0},
  [16] =
    {field_arguments, 1},
    {field_arguments, 1, .inherited = true},
    {field_name, 0},
  [19] =
    {field_right, 2},
  [20] =
    {field_elements, 1},
  [21] =
    {field_arguments, 2, .inherited = true},
    {field_name, 1},
    {field_sign, 0},
  [24] =
    {field_arguments, 2},
    {field_arguments, 2, .inherited = true},
    {field_name, 1},
    {field_sign, 0},
  [28] =
    {field_arguments, 2, .inherited = true},
    {field_name, 1},
  [30] =
    {field_function, 0},
  [31] =
    {field_body, 1},
  [32] =
    {field_term, 0},
  [33] =
    {field_weight, 0},
  [34] =
    {field_term, 1},
  [35] =
    {field_signature, 1},
  [36] =
    {field_atom, 1},
  [37] =
    {field_left, 0},
    {field_operator, 1},
    {field_right, 2},
  [40] =
    {field_condition, 2},
    {field_literal, 0},
  [42] =
    {field_left, 0},
  [43] =
    {field_predicate, 2},
  [44] =
    {field_arguments, 0},
    {field_arguments, 1, .inherited = true},
  [46] =
    {field_arguments, 1},
  [47] =
    {field_arguments, 1, .inherited = true},
  [48] =
    {field_elements, 1},
    {field_right, 3},
  [50] =
    {field_theory_terms, 0},
  [51] =
    {field_literal, 1},
  [52] =
    {field_function, 0},
    {field_right, 3},
  [54] =
    {field_elements, 2},
    {field_function, 0},
  [56] =
    {field_terms, 0},
  [57] =
    {field_arity, 2},
    {field_name, 0},
  [59] =
    {field_expressions, 0, .inherited = true},
    {field_macros, 0, .inherited = true},
    {field_occurrence, 0, .inherited = true},
    {field_subtypes, 0, .inherited = true},
  [63] =
    {field_expressions, 0},
  [64] =
    {field_subtypes, 0},
  [65] =
    {field_macros, 0},
  [66] =
    {field_occurrence, 0},
  [67] =
    {field_left, 0},
    {field_right, 3},
  [69] =
    {field_elements, 2},
    {field_left, 0},
  [71] =
    {field_function, 1},
    {field_left, 0},
  [73] =
    {field_body, 2},
    {field_head, 0},
  [75] =
    {field_description, 3},
    {field_predicate, 2},
  [77] =
    {field_arguments, 3},
    {field_predicate, 2},
  [79] =
    {field_arguments, 0, .inherited = true},
    {field_arguments, 1, .inherited = true},
  [81] =
    {field_condition, 1},
  [82] =
    {field_name, 1},
    {field_right, 4},
  [84] =
    {field_elements, 3},
    {field_name, 1},
  [86] =
    {field_arguments, 2},
    {field_arguments, 2, .inherited = true},
    {field_name, 1},
  [89] =
    {field_literal, 2},
    {field_terms, 0},
  [91] =
    {field_elements, 2},
    {field_function, 0},
    {field_right, 4},
  [94] =
    {field_weight, 3},
  [95] =
    {field_priority, 2},
    {field_term, 0},
  [97] =
    {field_condition, 2},
    {field_weight, 0},
  [99] =
    {field_terms, 1},
    {field_terms, 2},
    {field_weight, 0},
  [102] =
    {field_elements, 2},
  [103] =
    {field_arity, 3},
    {field_name, 1},
    {field_sign, 0},
  [106] =
    {field_body, 3},
    {field_term, 1},
  [108] =
    {field_atom, 1},
    {field_body, 3},
  [110] =
    {field_name, 1},
    {field_value, 3},
  [112] =
    {field_edge_pair, 2},
  [113] =
    {field_edge_pair, 1},
  [114] =
    {field_edge_pair, 0, .inherited = true},
    {field_edge_pair, 1, .inherited = true},
  [116] =
    {field_elements, 2},
    {field_left, 0},
    {field_right, 4},
  [119] =
    {field_function, 1},
    {field_left, 0},
    {field_right, 4},
  [122] =
    {field_elements, 3},
    {field_function, 1},
    {field_left, 0},
  [125] =
    {field_arguments, 4},
    {field_description, 3},
    {field_predicate, 2},
  [128] =
    {field_condition, 2},
    {field_theory_terms, 0},
  [130] =
    {field_elements, 3},
    {field_name, 1},
    {field_right, 5},
  [133] =
    {field_arguments, 2},
    {field_arguments, 2, .inherited = true},
    {field_name, 1},
    {field_right, 5},
  [137] =
    {field_arguments, 2},
    {field_arguments, 2, .inherited = true},
    {field_elements, 4},
    {field_name, 1},
  [141] =
    {field_condition, 3},
    {field_literal, 1},
  [143] =
    {field_condition, 2},
    {field_terms, 0},
  [145] =
    {field_body, 1},
    {field_weight, 4},
  [147] =
    {field_signature, 1},
    {field_value, 4},
  [149] =
    {field_name, 1},
    {field_parameters, 3},
  [151] =
    {field_edge_pair, 2},
    {field_edge_pair, 3, .inherited = true},
  [153] =
    {field_atom, 1},
    {field_type, 4},
  [155] =
    {field_elements, 3},
    {field_function, 1},
    {field_left, 0},
    {field_right, 5},
  [159] =
    {field_arguments, 2},
    {field_arguments, 2, .inherited = true},
    {field_elements, 4},
    {field_name, 1},
    {field_right, 6},
  [164] =
    {field_condition, 4},
    {field_literal, 2},
    {field_terms, 0},
  [167] =
    {field_terms, 4},
    {field_terms, 5},
    {field_weight, 3},
  [170] =
    {field_condition, 4},
    {field_terms, 1},
    {field_terms, 2},
    {field_weight, 0},
  [174] =
    {field_code, 4},
    {field_language, 2},
  [176] =
    {field_body, 5},
    {field_edge_pair, 2},
  [178] =
    {field_atom, 1},
    {field_type, 5},
  [180] =
    {field_name, 0},
    {field_operators, 2},
  [182] =
    {field_signature, 0},
  [183] =
    {field_body, 1},
    {field_terms, 5},
    {field_terms, 6},
    {field_weight, 4},
  [187] =
    {field_name, 1},
    {field_type, 6},
    {field_value, 3},
  [190] =
    {field_body, 6},
    {field_edge_pair, 2},
    {field_edge_pair, 3, .inherited = true},
  [193] =
    {field_atom, 1},
    {field_type, 6},
    {field_weight, 4},
  [196] =
    {field_atom, 1},
    {field_body, 3},
    {field_type, 6},
  [199] =
    {field_name, 0},
    {field_variables, 4},
  [201] =
    {field_atom, 1},
    {field_type, 7},
    {field_weight, 5},
  [204] =
    {field_atom, 1},
    {field_body, 3},
    {field_type, 8},
    {field_weight, 6},
  [208] =
    {field_arity, 4},
    {field_operator, 0},
    {field_priority, 2},
  [211] =
    {field_variable, 2},
  [212] =
    {field_arity, 3},
    {field_atom_type, 7},
    {field_name, 1},
    {field_theory_term_name, 5},
  [216] =
    {field_arguments, 3},
    {field_signature, 0},
  [218] =
    {field_description, 6},
    {field_variable, 2},
  [220] =
    {field_arity, 4},
    {field_associativity, 6},
    {field_operator, 0},
    {field_priority, 2},
  [224] =
    {field_name, 0},
    {field_value, 2},
  [226] =
    {field_arity, 3},
    {field_atom_type, 12},
    {field_guard, 10},
    {field_name, 1},
    {field_theory_term_name, 5},
  [231] =
    {field_arity, 3},
    {field_atom_type, 13},
    {field_guard, 11},
    {field_name, 1},
    {field_operators, 8},
    {field_theory_term_name, 5},
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [7] = {
    [0] = alias_sym_classical_negation,
  },
  [9] = {
    [0] = alias_sym_lone_comma,
  },
  [12] = {
    [0] = sym_conditional_literal,
  },
  [13] = {
    [0] = sym_conditional_literal,
  },
  [18] = {
    [0] = alias_sym_classical_negation,
  },
  [19] = {
    [0] = alias_sym_classical_negation,
  },
  [36] = {
    [0] = sym_theory_operator,
  },
  [66] = {
    [0] = alias_sym_classical_negation,
  },
  [77] = {
    [1] = sym_number,
  },
  [87] = {
    [1] = alias_sym_lone_comma,
  },
  [109] = {
    [0] = sym_theory_operator,
  },
  [115] = {
    [0] = sym_theory_operator,
  },
  [117] = {
    [1] = sym_theory_operator,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__conditional_literal_n, 2,
    sym__conditional_literal_n,
    sym_conditional_literal,
  sym__conditional_literal_0, 2,
    sym__conditional_literal_0,
    sym_conditional_literal,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 6,
  [7] = 7,
  [8] = 8,
  [9] = 9,
  [10] = 10,
  [11] = 11,
  [12] = 12,
  [13] = 13,
  [14] = 14,
  [15] = 15,
  [16] = 16,
  [17] = 17,
  [18] = 18,
  [19] = 19,
  [20] = 20,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 24,
  [25] = 25,
  [26] = 26,
  [27] = 27,
  [28] = 28,
  [29] = 29,
  [30] = 30,
  [31] = 31,
  [32] = 32,
  [33] = 33,
  [34] = 34,
  [35] = 35,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 41,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 45,
  [46] = 46,
  [47] = 47,
  [48] = 48,
  [49] = 49,
  [50] = 50,
  [51] = 51,
  [52] = 52,
  [53] = 53,
  [54] = 54,
  [55] = 55,
  [56] = 56,
  [57] = 57,
  [58] = 58,
  [59] = 59,
  [60] = 60,
  [61] = 61,
  [62] = 62,
  [63] = 63,
  [64] = 64,
  [65] = 65,
  [66] = 66,
  [67] = 67,
  [68] = 68,
  [69] = 69,
  [70] = 70,
  [71] = 71,
  [72] = 72,
  [73] = 73,
  [74] = 74,
  [75] = 75,
  [76] = 76,
  [77] = 77,
  [78] = 78,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 82,
  [83] = 83,
  [84] = 84,
  [85] = 85,
  [86] = 86,
  [87] = 87,
  [88] = 85,
  [89] = 80,
  [90] = 90,
  [91] = 90,
  [92] = 74,
  [93] = 93,
  [94] = 93,
  [95] = 93,
  [96] = 96,
  [97] = 97,
  [98] = 98,
  [99] = 99,
  [100] = 97,
  [101] = 101,
  [102] = 102,
  [103] = 102,
  [104] = 102,
  [105] = 105,
  [106] = 106,
  [107] = 107,
  [108] = 108,
  [109] = 109,
  [110] = 110,
  [111] = 111,
  [112] = 112,
  [113] = 113,
  [114] = 114,
  [115] = 115,
  [116] = 116,
  [117] = 110,
  [118] = 110,
  [119] = 119,
  [120] = 120,
  [121] = 121,
  [122] = 116,
  [123] = 121,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 127,
  [128] = 128,
  [129] = 124,
  [130] = 108,
  [131] = 107,
  [132] = 105,
  [133] = 106,
  [134] = 111,
  [135] = 112,
  [136] = 113,
  [137] = 137,
  [138] = 138,
  [139] = 139,
  [140] = 140,
  [141] = 141,
  [142] = 142,
  [143] = 143,
  [144] = 144,
  [145] = 145,
  [146] = 146,
  [147] = 147,
  [148] = 148,
  [149] = 149,
  [150] = 150,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 154,
  [155] = 155,
  [156] = 147,
  [157] = 157,
  [158] = 158,
  [159] = 159,
  [160] = 160,
  [161] = 161,
  [162] = 162,
  [163] = 163,
  [164] = 164,
  [165] = 165,
  [166] = 166,
  [167] = 167,
  [168] = 168,
  [169] = 169,
  [170] = 169,
  [171] = 171,
  [172] = 172,
  [173] = 173,
  [174] = 174,
  [175] = 175,
  [176] = 176,
  [177] = 177,
  [178] = 178,
  [179] = 179,
  [180] = 180,
  [181] = 174,
  [182] = 166,
  [183] = 175,
  [184] = 184,
  [185] = 168,
  [186] = 176,
  [187] = 187,
  [188] = 188,
  [189] = 189,
  [190] = 169,
  [191] = 178,
  [192] = 173,
  [193] = 174,
  [194] = 175,
  [195] = 176,
  [196] = 196,
  [197] = 169,
  [198] = 198,
  [199] = 196,
  [200] = 200,
  [201] = 172,
  [202] = 173,
  [203] = 174,
  [204] = 175,
  [205] = 176,
  [206] = 179,
  [207] = 179,
  [208] = 208,
  [209] = 171,
  [210] = 198,
  [211] = 188,
  [212] = 184,
  [213] = 168,
  [214] = 214,
  [215] = 163,
  [216] = 172,
  [217] = 217,
  [218] = 173,
  [219] = 198,
  [220] = 196,
  [221] = 172,
  [222] = 222,
  [223] = 223,
  [224] = 224,
  [225] = 225,
  [226] = 226,
  [227] = 227,
  [228] = 228,
  [229] = 229,
  [230] = 230,
  [231] = 231,
  [232] = 232,
  [233] = 233,
  [234] = 234,
  [235] = 235,
  [236] = 236,
  [237] = 237,
  [238] = 238,
  [239] = 239,
  [240] = 237,
  [241] = 241,
  [242] = 242,
  [243] = 243,
  [244] = 177,
  [245] = 245,
  [246] = 246,
  [247] = 247,
  [248] = 248,
  [249] = 222,
  [250] = 250,
  [251] = 160,
  [252] = 252,
  [253] = 157,
  [254] = 149,
  [255] = 227,
  [256] = 226,
  [257] = 257,
  [258] = 258,
  [259] = 259,
  [260] = 260,
  [261] = 261,
  [262] = 262,
  [263] = 149,
  [264] = 264,
  [265] = 265,
  [266] = 248,
  [267] = 225,
  [268] = 224,
  [269] = 269,
  [270] = 245,
  [271] = 236,
  [272] = 272,
  [273] = 273,
  [274] = 274,
  [275] = 275,
  [276] = 276,
  [277] = 157,
  [278] = 242,
  [279] = 160,
  [280] = 280,
  [281] = 246,
  [282] = 282,
  [283] = 177,
  [284] = 243,
  [285] = 228,
  [286] = 223,
  [287] = 287,
  [288] = 288,
  [289] = 247,
  [290] = 230,
  [291] = 291,
  [292] = 234,
  [293] = 293,
  [294] = 232,
  [295] = 295,
  [296] = 264,
  [297] = 231,
  [298] = 298,
  [299] = 233,
  [300] = 288,
  [301] = 301,
  [302] = 269,
  [303] = 273,
  [304] = 276,
  [305] = 272,
  [306] = 287,
  [307] = 274,
  [308] = 275,
  [309] = 291,
  [310] = 295,
  [311] = 311,
  [312] = 298,
  [313] = 223,
  [314] = 311,
  [315] = 315,
  [316] = 262,
  [317] = 259,
  [318] = 258,
  [319] = 319,
  [320] = 320,
  [321] = 260,
  [322] = 224,
  [323] = 236,
  [324] = 222,
  [325] = 228,
  [326] = 295,
  [327] = 230,
  [328] = 234,
  [329] = 231,
  [330] = 330,
  [331] = 233,
  [332] = 332,
  [333] = 288,
  [334] = 269,
  [335] = 273,
  [336] = 291,
  [337] = 264,
  [338] = 226,
  [339] = 227,
  [340] = 340,
  [341] = 225,
  [342] = 232,
  [343] = 245,
  [344] = 242,
  [345] = 247,
  [346] = 248,
  [347] = 347,
  [348] = 347,
  [349] = 288,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 298,
  [357] = 246,
  [358] = 243,
  [359] = 269,
  [360] = 273,
  [361] = 291,
  [362] = 264,
  [363] = 295,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 368,
  [369] = 369,
  [370] = 370,
  [371] = 371,
  [372] = 311,
  [373] = 373,
  [374] = 374,
  [375] = 375,
  [376] = 352,
  [377] = 354,
  [378] = 378,
  [379] = 379,
  [380] = 380,
  [381] = 381,
  [382] = 378,
  [383] = 383,
  [384] = 384,
  [385] = 385,
  [386] = 386,
  [387] = 378,
  [388] = 388,
  [389] = 389,
  [390] = 390,
  [391] = 368,
  [392] = 392,
  [393] = 393,
  [394] = 371,
  [395] = 395,
  [396] = 396,
  [397] = 397,
  [398] = 398,
  [399] = 364,
  [400] = 400,
  [401] = 401,
  [402] = 402,
  [403] = 403,
  [404] = 404,
  [405] = 405,
  [406] = 366,
  [407] = 407,
  [408] = 408,
  [409] = 409,
  [410] = 410,
  [411] = 411,
  [412] = 408,
  [413] = 413,
  [414] = 414,
  [415] = 415,
  [416] = 416,
  [417] = 417,
  [418] = 408,
  [419] = 419,
  [420] = 420,
  [421] = 421,
  [422] = 422,
  [423] = 388,
  [424] = 404,
  [425] = 405,
  [426] = 389,
  [427] = 427,
  [428] = 403,
  [429] = 429,
  [430] = 430,
  [431] = 431,
  [432] = 432,
  [433] = 433,
  [434] = 434,
  [435] = 435,
  [436] = 436,
  [437] = 437,
  [438] = 438,
  [439] = 439,
  [440] = 440,
  [441] = 441,
  [442] = 442,
  [443] = 443,
  [444] = 444,
  [445] = 445,
  [446] = 446,
  [447] = 395,
  [448] = 396,
  [449] = 246,
  [450] = 243,
  [451] = 397,
  [452] = 398,
  [453] = 453,
  [454] = 454,
  [455] = 455,
  [456] = 456,
  [457] = 431,
  [458] = 458,
  [459] = 411,
  [460] = 460,
  [461] = 458,
  [462] = 462,
  [463] = 463,
  [464] = 463,
  [465] = 435,
  [466] = 466,
  [467] = 467,
  [468] = 468,
  [469] = 469,
  [470] = 470,
  [471] = 471,
  [472] = 472,
  [473] = 473,
  [474] = 474,
  [475] = 475,
  [476] = 476,
  [477] = 477,
  [478] = 478,
  [479] = 479,
  [480] = 480,
  [481] = 481,
  [482] = 482,
  [483] = 483,
  [484] = 484,
  [485] = 485,
  [486] = 453,
  [487] = 446,
  [488] = 488,
  [489] = 438,
  [490] = 490,
  [491] = 491,
  [492] = 442,
  [493] = 493,
  [494] = 443,
  [495] = 444,
  [496] = 246,
  [497] = 436,
  [498] = 498,
  [499] = 445,
  [500] = 243,
  [501] = 478,
  [502] = 485,
  [503] = 439,
  [504] = 440,
  [505] = 505,
  [506] = 441,
  [507] = 507,
  [508] = 490,
  [509] = 484,
  [510] = 507,
  [511] = 507,
  [512] = 490,
  [513] = 513,
  [514] = 514,
  [515] = 515,
  [516] = 516,
  [517] = 517,
  [518] = 518,
  [519] = 519,
  [520] = 520,
  [521] = 431,
  [522] = 522,
  [523] = 435,
  [524] = 524,
  [525] = 525,
  [526] = 517,
  [527] = 527,
  [528] = 528,
  [529] = 529,
  [530] = 530,
  [531] = 531,
  [532] = 532,
  [533] = 516,
  [534] = 534,
  [535] = 535,
  [536] = 536,
  [537] = 537,
  [538] = 538,
  [539] = 539,
  [540] = 540,
  [541] = 541,
  [542] = 531,
  [543] = 543,
  [544] = 544,
  [545] = 545,
  [546] = 546,
  [547] = 547,
  [548] = 548,
  [549] = 549,
  [550] = 550,
  [551] = 551,
  [552] = 552,
  [553] = 553,
  [554] = 554,
  [555] = 555,
  [556] = 556,
  [557] = 557,
  [558] = 558,
  [559] = 470,
  [560] = 560,
  [561] = 561,
  [562] = 562,
  [563] = 563,
  [564] = 564,
  [565] = 565,
  [566] = 566,
  [567] = 567,
  [568] = 568,
  [569] = 569,
  [570] = 570,
  [571] = 571,
  [572] = 572,
  [573] = 573,
  [574] = 574,
  [575] = 575,
  [576] = 576,
  [577] = 577,
  [578] = 578,
  [579] = 579,
  [580] = 550,
  [581] = 581,
  [582] = 582,
  [583] = 583,
  [584] = 584,
  [585] = 585,
  [586] = 586,
  [587] = 587,
  [588] = 588,
  [589] = 576,
  [590] = 475,
  [591] = 471,
  [592] = 576,
  [593] = 593,
  [594] = 594,
  [595] = 550,
  [596] = 596,
  [597] = 597,
  [598] = 576,
  [599] = 550,
  [600] = 576,
  [601] = 601,
  [602] = 602,
  [603] = 550,
  [604] = 468,
  [605] = 605,
  [606] = 606,
  [607] = 607,
  [608] = 564,
  [609] = 609,
  [610] = 610,
  [611] = 611,
  [612] = 612,
  [613] = 613,
  [614] = 614,
  [615] = 615,
  [616] = 616,
  [617] = 617,
  [618] = 618,
  [619] = 619,
  [620] = 620,
  [621] = 621,
  [622] = 622,
  [623] = 623,
  [624] = 624,
  [625] = 625,
  [626] = 626,
  [627] = 627,
  [628] = 628,
  [629] = 629,
  [630] = 630,
  [631] = 631,
  [632] = 632,
  [633] = 633,
  [634] = 634,
  [635] = 635,
  [636] = 636,
  [637] = 637,
  [638] = 638,
  [639] = 639,
  [640] = 640,
  [641] = 641,
  [642] = 642,
  [643] = 643,
  [644] = 644,
  [645] = 645,
  [646] = 646,
  [647] = 647,
  [648] = 648,
  [649] = 649,
  [650] = 650,
  [651] = 651,
  [652] = 652,
  [653] = 653,
  [654] = 654,
  [655] = 655,
  [656] = 656,
  [657] = 657,
  [658] = 658,
  [659] = 659,
  [660] = 660,
  [661] = 661,
  [662] = 662,
  [663] = 663,
  [664] = 529,
  [665] = 665,
  [666] = 666,
  [667] = 667,
  [668] = 668,
  [669] = 543,
  [670] = 670,
  [671] = 671,
  [672] = 672,
  [673] = 673,
  [674] = 674,
  [675] = 675,
  [676] = 676,
  [677] = 677,
  [678] = 678,
  [679] = 679,
  [680] = 680,
  [681] = 681,
  [682] = 682,
  [683] = 683,
  [684] = 684,
  [685] = 685,
  [686] = 686,
  [687] = 687,
  [688] = 688,
  [689] = 689,
  [690] = 690,
  [691] = 691,
  [692] = 692,
  [693] = 693,
  [694] = 653,
  [695] = 695,
  [696] = 696,
  [697] = 697,
  [698] = 668,
  [699] = 651,
  [700] = 700,
  [701] = 701,
  [702] = 702,
  [703] = 703,
  [704] = 653,
  [705] = 668,
  [706] = 651,
  [707] = 707,
  [708] = 708,
  [709] = 709,
  [710] = 710,
  [711] = 711,
  [712] = 712,
  [713] = 713,
  [714] = 714,
  [715] = 715,
  [716] = 716,
  [717] = 717,
  [718] = 718,
  [719] = 719,
  [720] = 720,
  [721] = 721,
  [722] = 722,
  [723] = 723,
  [724] = 724,
  [725] = 725,
  [726] = 726,
  [727] = 727,
  [728] = 728,
  [729] = 729,
  [730] = 730,
  [731] = 731,
  [732] = 732,
  [733] = 733,
  [734] = 734,
  [735] = 735,
  [736] = 736,
  [737] = 737,
  [738] = 738,
  [739] = 739,
  [740] = 740,
  [741] = 741,
  [742] = 742,
  [743] = 743,
  [744] = 744,
  [745] = 745,
  [746] = 746,
  [747] = 747,
  [748] = 748,
  [749] = 749,
  [750] = 750,
  [751] = 751,
  [752] = 752,
  [753] = 753,
  [754] = 754,
  [755] = 755,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 759,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 772,
  [773] = 773,
  [774] = 774,
  [775] = 775,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 779,
  [780] = 780,
  [781] = 781,
  [782] = 782,
  [783] = 783,
  [784] = 784,
  [785] = 785,
  [786] = 786,
  [787] = 787,
  [788] = 788,
  [789] = 779,
  [790] = 790,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 796,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 801,
  [802] = 802,
  [803] = 801,
  [804] = 804,
  [805] = 805,
  [806] = 806,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 810,
  [811] = 811,
  [812] = 812,
  [813] = 813,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 826,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 838,
  [839] = 839,
  [840] = 840,
  [841] = 841,
  [842] = 842,
  [843] = 843,
  [844] = 844,
  [845] = 845,
  [846] = 846,
  [847] = 847,
  [848] = 848,
  [849] = 849,
  [850] = 850,
  [851] = 851,
  [852] = 852,
  [853] = 853,
  [854] = 854,
  [855] = 855,
  [856] = 856,
  [857] = 857,
  [858] = 858,
  [859] = 859,
  [860] = 860,
  [861] = 861,
  [862] = 862,
  [863] = 863,
  [864] = 864,
  [865] = 865,
  [866] = 866,
  [867] = 867,
  [868] = 868,
  [869] = 869,
  [870] = 870,
  [871] = 871,
  [872] = 872,
  [873] = 873,
  [874] = 874,
  [875] = 875,
  [876] = 876,
  [877] = 877,
  [878] = 878,
  [879] = 879,
  [880] = 880,
  [881] = 881,
  [882] = 882,
  [883] = 883,
  [884] = 884,
  [885] = 885,
  [886] = 886,
  [887] = 887,
  [888] = 888,
  [889] = 889,
  [890] = 890,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 896,
  [897] = 897,
  [898] = 898,
  [899] = 899,
  [900] = 900,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 904,
  [905] = 905,
  [906] = 906,
  [907] = 907,
  [908] = 908,
  [909] = 909,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 914,
  [915] = 915,
  [916] = 916,
  [917] = 917,
  [918] = 918,
  [919] = 919,
  [920] = 920,
  [921] = 921,
  [922] = 922,
  [923] = 923,
  [924] = 924,
  [925] = 925,
  [926] = 926,
  [927] = 927,
  [928] = 928,
  [929] = 848,
  [930] = 930,
  [931] = 931,
  [932] = 932,
  [933] = 928,
  [934] = 934,
  [935] = 935,
  [936] = 936,
  [937] = 937,
  [938] = 801,
  [939] = 939,
  [940] = 940,
  [941] = 941,
  [942] = 942,
  [943] = 943,
  [944] = 944,
  [945] = 945,
  [946] = 946,
  [947] = 947,
  [948] = 873,
  [949] = 949,
  [950] = 950,
  [951] = 951,
  [952] = 952,
  [953] = 953,
  [954] = 954,
  [955] = 955,
  [956] = 956,
  [957] = 822,
  [958] = 958,
  [959] = 959,
  [960] = 960,
  [961] = 945,
  [962] = 962,
  [963] = 963,
  [964] = 964,
  [965] = 965,
  [966] = 966,
  [967] = 854,
  [968] = 859,
  [969] = 868,
  [970] = 970,
  [971] = 971,
  [972] = 867,
  [973] = 973,
  [974] = 974,
  [975] = 975,
  [976] = 976,
  [977] = 848,
  [978] = 978,
  [979] = 979,
  [980] = 980,
  [981] = 928,
  [982] = 982,
  [983] = 983,
  [984] = 984,
  [985] = 985,
  [986] = 873,
  [987] = 987,
  [988] = 988,
  [989] = 989,
  [990] = 990,
  [991] = 991,
  [992] = 992,
  [993] = 935,
  [994] = 994,
  [995] = 855,
  [996] = 964,
  [997] = 997,
  [998] = 916,
  [999] = 999,
  [1000] = 1000,
  [1001] = 1001,
  [1002] = 1002,
  [1003] = 1003,
  [1004] = 970,
  [1005] = 1005,
  [1006] = 1006,
  [1007] = 1007,
  [1008] = 1008,
  [1009] = 1009,
  [1010] = 1010,
  [1011] = 1011,
  [1012] = 1012,
  [1013] = 1013,
  [1014] = 1014,
  [1015] = 1015,
  [1016] = 1016,
};

static const TSSymbol ts_supertype_symbols[SUPERTYPE_COUNT] = {
  sym_extended_signature,
  sym_extended_symbolic_atom,
  sym_head,
  sym_literal_sign,
  sym_metasp_type_keyword,
  sym_simple_atom,
  sym_statement,
  sym_term,
  sym_theory_root_term,
  sym_theory_term,
  sym_tuple_pool_item,
};

static const TSMapSlice ts_supertype_map_slices[] = {
  [sym_extended_signature] = {.index = 0, .length = 2},
  [sym_extended_symbolic_atom] = {.index = 2, .length = 2},
  [sym_head] = {.index = 4, .length = 5},
  [sym_literal_sign] = {.index = 9, .length = 2},
  [sym_metasp_type_keyword] = {.index = 11, .length = 4},
  [sym_simple_atom] = {.index = 15, .length = 4},
  [sym_statement] = {.index = 19, .length = 21},
  [sym_term] = {.index = 40, .length = 14},
  [sym_theory_root_term] = {.index = 54, .length = 10},
  [sym_theory_term] = {.index = 64, .length = 2},
  [sym_tuple_pool_item] = {.index = 66, .length = 9},
};

static const TSSymbol ts_supertype_map_entries[] = {
  [0] =
    sym_metasp_signature,
    sym_signature,
  [2] =
    sym_metasp_symbolic_atom,
    sym_symbolic_atom,
  [4] =
    sym_disjunction,
    sym_head_aggregate,
    sym_literal,
    sym_set_aggregate,
    sym_theory_atom,
  [9] =
    sym_default_negation,
    sym_double_default_negation,
  [11] =
    sym_metasp_expression_definitions,
    sym_metasp_macros,
    sym_metasp_occurrence,
    sym_metasp_subtypes,
  [15] =
    sym_boolean_constant,
    sym_comparison,
    sym_metasp_symbolic_atom,
    sym_symbolic_atom,
  [19] =
    sym_const,
    sym_defined,
    sym_doc_comment,
    sym_edge,
    sym_external,
    sym_heuristic,
    sym_include,
    sym_integrity_constraint,
    sym_maximize,
    sym_metasp_type,
    sym_minimize,
    sym_program,
    sym_project_atom,
    sym_project_signature,
    sym_rule,
    sym_script,
    sym_show,
    sym_show_signature,
    sym_show_term,
    sym_theory,
    sym_weak_constraint,
  [40] =
    sym_abs,
    sym_anonymous,
    sym_binary_operation,
    sym_external_function,
    sym_fstring,
    sym_function,
    sym_infimum,
    sym_metasp_function,
    sym_number,
    sym_string,
    sym_supremum,
    sym_tuple,
    sym_unary_operation,
    sym_variable,
  [54] =
    sym_anonymous,
    sym_infimum,
    sym_number,
    sym_string,
    sym_supremum,
    sym_theory_function,
    sym_theory_list,
    sym_theory_set,
    sym_theory_tuple,
    sym_variable,
  [64] =
    sym_theory_root_term,
    sym_theory_unparsed_term,
  [66] =
    alias_sym_lone_comma,
    sym__const_term_comma,
    sym__const_terms_trail,
    sym__term_comma,
    sym__terms_or_projection,
    sym__terms_trail,
    sym_const_terms,
    sym_term,
    sym_terms,
};

static const TSCharacterRange sym_theory_operator_character_set_1[] = {
  {'!', '!'}, {'&', '&'}, {'*', '+'}, {'-', '/'}, {':', '@'}, {'\\', '\\'}, {'^', '^'}, {'|', '|'},
  {'~', '~'},
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(260);
      ADVANCE_MAP(
        '!', 313,
        '"', 293,
        '#', 322,
        '%', 264,
        '&', 353,
        '\'', 239,
        '(', 364,
        ')', 365,
        '*', 357,
        '+', 354,
        ',', 363,
        '-', 355,
        '.', 389,
        '/', 358,
        '0', 307,
        ':', 426,
        ';', 367,
        '<', 415,
        '=', 410,
        '>', 417,
        '?', 352,
        '@', 369,
        'X', 277,
        '[', 373,
        '\\', 359,
        ']', 374,
        '^', 351,
        '_', 347,
        '`', 253,
        'a', 139,
        'b', 329,
        'd', 328,
        'e', 229,
        'f', 15,
        'h', 88,
        'l', 86,
        'm', 35,
        'n', 330,
        'o', 327,
        'r', 111,
        's', 331,
        't', 171,
        'u', 144,
        'w', 109,
        '{', 334,
        '|', 362,
        '}', 375,
        '~', 361,
        'c', 326,
        'x', 326,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(257);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(310);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(277);
      END_STATE();
    case 1:
      if (lookahead == '\n') SKIP(21);
      if (lookahead == ' ') ADVANCE(319);
      if (lookahead == '#') ADVANCE(323);
      if (lookahead == '%') ADVANCE(268);
      if (lookahead == '0') ADVANCE(308);
      if (lookahead == '}') ADVANCE(337);
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(320);
      if (lookahead == ',' ||
          lookahead == '_') ADVANCE(325);
      if (('\t' <= lookahead && lookahead <= '\r')) ADVANCE(20);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(317);
      if (lookahead == 'X' ||
          ('b' <= lookahead && lookahead <= 'd') ||
          lookahead == 'n' ||
          lookahead == 'o' ||
          lookahead == 's' ||
          lookahead == 'x') ADVANCE(332);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(309);
      if (lookahead != 0) ADVANCE(247);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        ' ', 319,
        '#', 321,
        '%', 269,
        '0', 307,
        '}', 336,
        '+', 319,
        '-', 319,
        ',', 324,
        '_', 324,
      );
      if (('\t' <= lookahead && lookahead <= '\r')) SKIP(21);
      if (lookahead == 'X' ||
          ('b' <= lookahead && lookahead <= 'd') ||
          lookahead == 'n' ||
          lookahead == 'o' ||
          lookahead == 's' ||
          lookahead == 'x') ADVANCE(326);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(310);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '!', 313,
        '#', 56,
        '%', 269,
        '&', 353,
        '(', 364,
        ')', 365,
        '*', 357,
        '+', 354,
        ',', 363,
        '-', 355,
        '.', 30,
        '/', 358,
        '0', 307,
        ':', 333,
        ';', 367,
        '<', 378,
        '=', 377,
        '>', 378,
        '?', 352,
        '@', 369,
        '[', 306,
        '\\', 359,
        ']', 374,
        '^', 351,
        'a', 139,
        'b', 123,
        'd', 70,
        'f', 34,
        'h', 88,
        'l', 86,
        'o', 226,
        'r', 111,
        't', 171,
        'u', 144,
        '{', 334,
        '|', 362,
        '}', 336,
        '\'', 239,
        '_', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(310);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(277);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '!', 313,
        '#', 56,
        '%', 269,
        '&', 353,
        '(', 364,
        ')', 365,
        '*', 357,
        '+', 354,
        ',', 363,
        '-', 355,
        '.', 30,
        '/', 358,
        ':', 333,
        ';', 367,
        '<', 378,
        '=', 377,
        '>', 378,
        '?', 352,
        '@', 369,
        '[', 306,
        '\\', 359,
        ']', 374,
        '^', 351,
        'a', 139,
        'b', 123,
        'd', 70,
        'f', 34,
        'h', 88,
        'l', 86,
        'o', 226,
        'r', 111,
        't', 171,
        'u', 144,
        '{', 334,
        '|', 362,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(4);
      END_STATE();
    case 5:
      if (lookahead == '!') ADVANCE(271);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '!', 31,
        '"', 293,
        '#', 55,
        '%', 269,
        '&', 353,
        '\'', 240,
        '(', 364,
        ')', 365,
        '*', 356,
        ',', 363,
        '-', 355,
        '.', 388,
        '0', 342,
        ':', 26,
        ';', 367,
        '<', 378,
        '=', 377,
        '>', 378,
        '@', 369,
        '[', 373,
        ']', 311,
        '_', 348,
        'f', 283,
        '{', 334,
        '|', 362,
        '}', 375,
        '~', 361,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(345);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '!', 31,
        '"', 293,
        '#', 55,
        '%', 269,
        '&', 353,
        '\'', 240,
        '(', 364,
        ')', 365,
        '*', 356,
        ',', 363,
        '-', 355,
        '.', 388,
        '0', 342,
        ':', 26,
        ';', 367,
        '<', 378,
        '=', 377,
        '>', 378,
        '@', 369,
        '[', 373,
        '_', 348,
        'f', 283,
        '{', 334,
        '|', 362,
        '}', 375,
        '~', 361,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(7);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(345);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '!', 31,
        '%', 269,
        '&', 353,
        '(', 364,
        ')', 276,
        '*', 357,
        '+', 354,
        ',', 363,
        '-', 355,
        '.', 389,
        '/', 358,
        ':', 427,
        ';', 367,
        '<', 378,
        '=', 377,
        '>', 378,
        '?', 352,
        '\\', 359,
        '^', 351,
        'e', 229,
        'm', 35,
        'o', 49,
        's', 213,
        '|', 362,
        '}', 375,
        '\'', 239,
        '_', 239,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(277);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '!', 31,
        '%', 269,
        '&', 353,
        '(', 364,
        '*', 357,
        '+', 354,
        ',', 363,
        '-', 355,
        '.', 389,
        '/', 358,
        ':', 427,
        ';', 367,
        '<', 378,
        '=', 377,
        '>', 378,
        '?', 352,
        '\\', 359,
        '^', 351,
        'e', 229,
        'm', 35,
        'o', 49,
        's', 213,
        '|', 362,
        '}', 375,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(9);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '!', 312,
        '"', 293,
        '#', 321,
        '%', 269,
        '&', 353,
        ')', 276,
        '*', 357,
        '+', 354,
        '-', 355,
        '.', 30,
        '/', 358,
        '0', 307,
        ':', 333,
        '<', 414,
        '=', 410,
        '>', 416,
        '?', 352,
        '[', 306,
        '\\', 359,
        '^', 351,
        '}', 336,
        ',', 324,
        '_', 324,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      if (lookahead == 'X' ||
          ('b' <= lookahead && lookahead <= 'd') ||
          lookahead == 'n' ||
          lookahead == 'o' ||
          lookahead == 's' ||
          lookahead == 'x') ADVANCE(326);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(310);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '!', 312,
        '"', 293,
        '%', 269,
        '&', 353,
        '*', 357,
        '+', 354,
        '-', 355,
        '.', 30,
        '/', 358,
        ':', 333,
        '<', 414,
        '=', 410,
        '>', 416,
        '?', 352,
        '[', 306,
        '\\', 359,
        '^', 351,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(11);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '"', 293,
        '#', 120,
        '%', 269,
        '\'', 240,
        '(', 364,
        ')', 365,
        ',', 363,
        '0', 342,
        ':', 29,
        '[', 373,
        ']', 374,
        '_', 348,
        'n', 288,
        '{', 334,
        '}', 375,
        '.', 249,
        ';', 249,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(12);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(345);
      if (lookahead == '!' ||
          ('&' <= lookahead && lookahead <= '@') ||
          ('\\' <= lookahead && lookahead <= '^') ||
          ('|' <= lookahead && lookahead <= '~')) ADVANCE(371);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      END_STATE();
    case 13:
      if (lookahead == '"') ADVANCE(293);
      if (lookahead == '%') ADVANCE(301);
      if (lookahead == '\\') ADVANCE(245);
      if (lookahead == '{') ADVANCE(335);
      if (lookahead == '}') ADVANCE(238);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(299);
      if (lookahead != 0) ADVANCE(302);
      END_STATE();
    case 14:
      if (lookahead == '"') ADVANCE(293);
      if (lookahead == '%') ADVANCE(297);
      if (lookahead == '\\') ADVANCE(246);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(295);
      if (lookahead != 0) ADVANCE(298);
      END_STATE();
    case 15:
      if (lookahead == '"') ADVANCE(294);
      if (lookahead == 'a') ADVANCE(125);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '%', 269,
        '&', 353,
        '(', 364,
        ')', 365,
        '*', 357,
        '+', 354,
        ',', 363,
        '-', 355,
        '.', 388,
        '/', 358,
        ':', 426,
        ';', 367,
        '?', 352,
        '\\', 359,
        '^', 351,
        'w', 286,
        '|', 362,
        '}', 375,
        '\'', 241,
        '_', 241,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(16);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '%', 269,
        '(', 364,
        ')', 365,
        ',', 363,
        '.', 390,
        ':', 28,
        ';', 368,
        ']', 374,
        'n', 165,
        '}', 375,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(17);
      if (lookahead == '!' ||
          lookahead == '&' ||
          ('*' <= lookahead && lookahead <= '/') ||
          ('<' <= lookahead && lookahead <= '@') ||
          ('\\' <= lookahead && lookahead <= '^') ||
          ('|' <= lookahead && lookahead <= '~')) ADVANCE(371);
      END_STATE();
    case 18:
      if (lookahead == '%') ADVANCE(269);
      if (lookahead == ')') ADVANCE(276);
      if (lookahead == '*') ADVANCE(22);
      if (lookahead == ',') ADVANCE(274);
      if (lookahead == ':') ADVANCE(282);
      if (lookahead == '_') ADVANCE(254);
      if (lookahead == '`') ADVANCE(253);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      END_STATE();
    case 19:
      if (lookahead == '%') ADVANCE(269);
      if (lookahead == '\'' ||
          lookahead == '_') ADVANCE(243);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(275);
      END_STATE();
    case 20:
      if (lookahead == '%') ADVANCE(269);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      END_STATE();
    case 21:
      if (lookahead == '%') ADVANCE(269);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(21);
      END_STATE();
    case 22:
      if (lookahead == '%') ADVANCE(273);
      if (lookahead == '*') ADVANCE(252);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '_' &&
          lookahead != '`') ADVANCE(23);
      END_STATE();
    case 23:
      if (lookahead == '*') ADVANCE(278);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '_' &&
          lookahead != '`') ADVANCE(23);
      END_STATE();
    case 24:
      if (lookahead == '*') ADVANCE(25);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '_' &&
          lookahead != '`') ADVANCE(24);
      END_STATE();
    case 25:
      if (lookahead == '*') ADVANCE(279);
      END_STATE();
    case 26:
      if (lookahead == '-') ADVANCE(391);
      END_STATE();
    case 27:
      if (lookahead == '-') ADVANCE(391);
      if (lookahead == '~') ADVANCE(393);
      END_STATE();
    case 28:
      if (lookahead == '-') ADVANCE(392);
      if (set_contains(sym_theory_operator_character_set_1, 9, lookahead)) ADVANCE(372);
      END_STATE();
    case 29:
      if (lookahead == '-') ADVANCE(250);
      if (set_contains(sym_theory_operator_character_set_1, 9, lookahead)) ADVANCE(372);
      END_STATE();
    case 30:
      if (lookahead == '.') ADVANCE(366);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(305);
      END_STATE();
    case 31:
      if (lookahead == '=') ADVANCE(377);
      END_STATE();
    case 32:
      if (lookahead == '_') ADVANCE(280);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '*' &&
          lookahead != '_' &&
          lookahead != '`') ADVANCE(32);
      END_STATE();
    case 33:
      if (lookahead == '`') ADVANCE(281);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '*' &&
          lookahead != '_' &&
          lookahead != '`') ADVANCE(33);
      END_STATE();
    case 34:
      if (lookahead == 'a') ADVANCE(125);
      END_STATE();
    case 35:
      if (lookahead == 'a') ADVANCE(59);
      END_STATE();
    case 36:
      if (lookahead == 'a') ADVANCE(232);
      if (lookahead == 'i') ADVANCE(155);
      END_STATE();
    case 37:
      if (lookahead == 'a') ADVANCE(230);
      if (lookahead == 'i') ADVANCE(154);
      END_STATE();
    case 38:
      if (lookahead == 'a') ADVANCE(62);
      END_STATE();
    case 39:
      if (lookahead == 'a') ADVANCE(231);
      if (lookahead == 'i') ADVANCE(141);
      END_STATE();
    case 40:
      if (lookahead == 'a') ADVANCE(126);
      END_STATE();
    case 41:
      if (lookahead == 'a') ADVANCE(215);
      END_STATE();
    case 42:
      if (lookahead == 'a') ADVANCE(131);
      END_STATE();
    case 43:
      if (lookahead == 'a') ADVANCE(174);
      END_STATE();
    case 44:
      if (lookahead == 'a') ADVANCE(176);
      END_STATE();
    case 45:
      if (lookahead == 'a') ADVANCE(129);
      END_STATE();
    case 46:
      if (lookahead == 'b') ADVANCE(209);
      END_STATE();
    case 47:
      if (lookahead == 'c') ADVANCE(412);
      END_STATE();
    case 48:
      if (lookahead == 'c') ADVANCE(127);
      if (lookahead == 'f') ADVANCE(341);
      END_STATE();
    case 49:
      if (lookahead == 'c') ADVANCE(60);
      END_STATE();
    case 50:
      if (lookahead == 'c') ADVANCE(60);
      if (lookahead == 'v') ADVANCE(93);
      END_STATE();
    case 51:
      if (lookahead == 'c') ADVANCE(210);
      END_STATE();
    case 52:
      ADVANCE_MAP(
        'c', 158,
        'd', 89,
        'e', 66,
        'f', 45,
        'h', 91,
        'i', 140,
        'm', 37,
        'p', 172,
        's', 57,
        't', 110,
      );
      END_STATE();
    case 53:
      if (lookahead == 'c') ADVANCE(204);
      END_STATE();
    case 54:
      if (lookahead == 'c') ADVANCE(163);
      if (lookahead == 'e') ADVANCE(143);
      if (lookahead == 'f') ADVANCE(45);
      if (lookahead == 'i') ADVANCE(145);
      if (lookahead == 'm') ADVANCE(39);
      if (lookahead == 's') ADVANCE(214);
      if (lookahead == 't') ADVANCE(186);
      END_STATE();
    case 55:
      if (lookahead == 'c') ADVANCE(163);
      if (lookahead == 'f') ADVANCE(45);
      if (lookahead == 'i') ADVANCE(145);
      if (lookahead == 'm') ADVANCE(39);
      if (lookahead == 's') ADVANCE(214);
      if (lookahead == 't') ADVANCE(186);
      END_STATE();
    case 56:
      if (lookahead == 'c') ADVANCE(163);
      if (lookahead == 'm') ADVANCE(39);
      if (lookahead == 's') ADVANCE(221);
      END_STATE();
    case 57:
      if (lookahead == 'c') ADVANCE(182);
      if (lookahead == 'h') ADVANCE(159);
      if (lookahead == 'u') ADVANCE(133);
      END_STATE();
    case 58:
      if (lookahead == 'c') ADVANCE(84);
      END_STATE();
    case 59:
      if (lookahead == 'c') ADVANCE(177);
      END_STATE();
    case 60:
      if (lookahead == 'c') ADVANCE(223);
      END_STATE();
    case 61:
      if (lookahead == 'd') ADVANCE(233);
      END_STATE();
    case 62:
      if (lookahead == 'd') ADVANCE(422);
      END_STATE();
    case 63:
      if (lookahead == 'd') ADVANCE(407);
      END_STATE();
    case 64:
      if (lookahead == 'd') ADVANCE(401);
      END_STATE();
    case 65:
      if (lookahead == 'd') ADVANCE(106);
      if (lookahead == 'n') ADVANCE(63);
      if (lookahead == 'x') ADVANCE(212);
      END_STATE();
    case 66:
      if (lookahead == 'd') ADVANCE(106);
      if (lookahead == 'x') ADVANCE(212);
      END_STATE();
    case 67:
      if (lookahead == 'd') ADVANCE(79);
      END_STATE();
    case 68:
      if (lookahead == 'd') ADVANCE(78);
      END_STATE();
    case 69:
      if (lookahead == 'e') ADVANCE(65);
      if (lookahead == 'f') ADVANCE(45);
      if (lookahead == 'h') ADVANCE(91);
      if (lookahead == 'i') ADVANCE(140);
      if (lookahead == 'm') ADVANCE(36);
      if (lookahead == 'p') ADVANCE(172);
      if (lookahead == 't') ADVANCE(110);
      END_STATE();
    case 70:
      if (lookahead == 'e') ADVANCE(103);
      if (lookahead == 'i') ADVANCE(180);
      END_STATE();
    case 71:
      if (lookahead == 'e') ADVANCE(422);
      END_STATE();
    case 72:
      if (lookahead == 'e') ADVANCE(399);
      END_STATE();
    case 73:
      if (lookahead == 'e') ADVANCE(411);
      END_STATE();
    case 74:
      if (lookahead == 'e') ADVANCE(376);
      END_STATE();
    case 75:
      if (lookahead == 'e') ADVANCE(424);
      END_STATE();
    case 76:
      if (lookahead == 'e') ADVANCE(400);
      END_STATE();
    case 77:
      if (lookahead == 'e') ADVANCE(430);
      END_STATE();
    case 78:
      if (lookahead == 'e') ADVANCE(408);
      END_STATE();
    case 79:
      if (lookahead == 'e') ADVANCE(413);
      END_STATE();
    case 80:
      if (lookahead == 'e') ADVANCE(395);
      END_STATE();
    case 81:
      if (lookahead == 'e') ADVANCE(394);
      END_STATE();
    case 82:
      if (lookahead == 'e') ADVANCE(397);
      END_STATE();
    case 83:
      if (lookahead == 'e') ADVANCE(396);
      END_STATE();
    case 84:
      if (lookahead == 'e') ADVANCE(432);
      END_STATE();
    case 85:
      if (lookahead == 'e') ADVANCE(142);
      if (lookahead != 0) ADVANCE(255);
      END_STATE();
    case 86:
      if (lookahead == 'e') ADVANCE(102);
      END_STATE();
    case 87:
      if (lookahead == 'e') ADVANCE(192);
      END_STATE();
    case 88:
      if (lookahead == 'e') ADVANCE(38);
      END_STATE();
    case 89:
      if (lookahead == 'e') ADVANCE(104);
      END_STATE();
    case 90:
      if (lookahead == 'e') ADVANCE(51);
      END_STATE();
    case 91:
      if (lookahead == 'e') ADVANCE(220);
      END_STATE();
    case 92:
      if (lookahead == 'e') ADVANCE(164);
      END_STATE();
    case 93:
      if (lookahead == 'e') ADVANCE(181);
      END_STATE();
    case 94:
      if (lookahead == 'e') ADVANCE(64);
      END_STATE();
    case 95:
      if (lookahead == 'e') ADVANCE(146);
      END_STATE();
    case 96:
      if (lookahead == 'e') ADVANCE(190);
      END_STATE();
    case 97:
      if (lookahead == 'e') ADVANCE(187);
      END_STATE();
    case 98:
      if (lookahead == 'e') ADVANCE(137);
      END_STATE();
    case 99:
      if (lookahead == 'e') ADVANCE(53);
      END_STATE();
    case 100:
      if (lookahead == 'e') ADVANCE(184);
      END_STATE();
    case 101:
      if (lookahead == 'f') ADVANCE(341);
      END_STATE();
    case 102:
      if (lookahead == 'f') ADVANCE(201);
      END_STATE();
    case 103:
      if (lookahead == 'f') ADVANCE(41);
      END_STATE();
    case 104:
      if (lookahead == 'f') ADVANCE(119);
      END_STATE();
    case 105:
      if (lookahead == 'g') ADVANCE(108);
      END_STATE();
    case 106:
      if (lookahead == 'g') ADVANCE(73);
      END_STATE();
    case 107:
      if (lookahead == 'g') ADVANCE(179);
      if (lookahead == 'j') ADVANCE(99);
      END_STATE();
    case 108:
      if (lookahead == 'h') ADVANCE(201);
      END_STATE();
    case 109:
      if (lookahead == 'h') ADVANCE(100);
      END_STATE();
    case 110:
      if (lookahead == 'h') ADVANCE(92);
      if (lookahead == 'r') ADVANCE(225);
      if (lookahead == 'y') ADVANCE(167);
      END_STATE();
    case 111:
      if (lookahead == 'i') ADVANCE(105);
      END_STATE();
    case 112:
      if (lookahead == 'i') ADVANCE(197);
      END_STATE();
    case 113:
      if (lookahead == 'i') ADVANCE(227);
      END_STATE();
    case 114:
      if (lookahead == 'i') ADVANCE(135);
      END_STATE();
    case 115:
      if (lookahead == 'i') ADVANCE(168);
      END_STATE();
    case 116:
      if (lookahead == 'i') ADVANCE(199);
      END_STATE();
    case 117:
      if (lookahead == 'i') ADVANCE(47);
      END_STATE();
    case 118:
      if (lookahead == 'i') ADVANCE(161);
      END_STATE();
    case 119:
      if (lookahead == 'i') ADVANCE(151);
      END_STATE();
    case 120:
      if (lookahead == 'i') ADVANCE(145);
      if (lookahead == 's') ADVANCE(218);
      END_STATE();
    case 121:
      if (lookahead == 'i') ADVANCE(198);
      END_STATE();
    case 122:
      if (lookahead == 'i') ADVANCE(68);
      END_STATE();
    case 123:
      if (lookahead == 'i') ADVANCE(152);
      if (lookahead == 'o') ADVANCE(61);
      END_STATE();
    case 124:
      if (lookahead == 'i') ADVANCE(138);
      END_STATE();
    case 125:
      if (lookahead == 'l') ADVANCE(196);
      END_STATE();
    case 126:
      if (lookahead == 'l') ADVANCE(418);
      END_STATE();
    case 127:
      if (lookahead == 'l') ADVANCE(217);
      END_STATE();
    case 128:
      if (lookahead == 'l') ADVANCE(202);
      END_STATE();
    case 129:
      if (lookahead == 'l') ADVANCE(195);
      END_STATE();
    case 130:
      if (lookahead == 'm') ADVANCE(340);
      END_STATE();
    case 131:
      if (lookahead == 'm') ADVANCE(403);
      END_STATE();
    case 132:
      if (lookahead == 'm') ADVANCE(385);
      END_STATE();
    case 133:
      if (lookahead == 'm') ADVANCE(385);
      if (lookahead == 'p') ADVANCE(339);
      END_STATE();
    case 134:
      if (lookahead == 'm') ADVANCE(338);
      END_STATE();
    case 135:
      if (lookahead == 'm') ADVANCE(112);
      END_STATE();
    case 136:
      if (lookahead == 'm') ADVANCE(216);
      END_STATE();
    case 137:
      if (lookahead == 'm') ADVANCE(219);
      END_STATE();
    case 138:
      if (lookahead == 'm') ADVANCE(121);
      END_STATE();
    case 139:
      if (lookahead == 'n') ADVANCE(233);
      END_STATE();
    case 140:
      if (lookahead == 'n') ADVANCE(48);
      END_STATE();
    case 141:
      if (lookahead == 'n') ADVANCE(384);
      END_STATE();
    case 142:
      if (lookahead == 'n') ADVANCE(256);
      if (lookahead != 0) ADVANCE(255);
      END_STATE();
    case 143:
      if (lookahead == 'n') ADVANCE(63);
      END_STATE();
    case 144:
      if (lookahead == 'n') ADVANCE(43);
      END_STATE();
    case 145:
      if (lookahead == 'n') ADVANCE(101);
      END_STATE();
    case 146:
      if (lookahead == 'n') ADVANCE(58);
      END_STATE();
    case 147:
      if (lookahead == 'n') ADVANCE(162);
      END_STATE();
    case 148:
      if (lookahead == 'n') ADVANCE(40);
      END_STATE();
    case 149:
      if (lookahead == 'n') ADVANCE(191);
      END_STATE();
    case 150:
      if (lookahead == 'n') ADVANCE(205);
      END_STATE();
    case 151:
      if (lookahead == 'n') ADVANCE(94);
      END_STATE();
    case 152:
      if (lookahead == 'n') ADVANCE(44);
      END_STATE();
    case 153:
      if (lookahead == 'n') ADVANCE(194);
      if (lookahead == 'u') ADVANCE(150);
      END_STATE();
    case 154:
      if (lookahead == 'n') ADVANCE(387);
      END_STATE();
    case 155:
      if (lookahead == 'n') ADVANCE(124);
      END_STATE();
    case 156:
      if (lookahead == 'o') ADVANCE(200);
      END_STATE();
    case 157:
      if (lookahead == 'o') ADVANCE(107);
      END_STATE();
    case 158:
      if (lookahead == 'o') ADVANCE(153);
      END_STATE();
    case 159:
      if (lookahead == 'o') ADVANCE(228);
      END_STATE();
    case 160:
      if (lookahead == 'o') ADVANCE(189);
      END_STATE();
    case 161:
      if (lookahead == 'o') ADVANCE(149);
      END_STATE();
    case 162:
      if (lookahead == 'o') ADVANCE(203);
      END_STATE();
    case 163:
      if (lookahead == 'o') ADVANCE(224);
      END_STATE();
    case 164:
      if (lookahead == 'o') ADVANCE(178);
      END_STATE();
    case 165:
      if (lookahead == 'o') ADVANCE(208);
      END_STATE();
    case 166:
      if (lookahead == 'p') ADVANCE(339);
      END_STATE();
    case 167:
      if (lookahead == 'p') ADVANCE(75);
      END_STATE();
    case 168:
      if (lookahead == 'p') ADVANCE(207);
      END_STATE();
    case 169:
      if (lookahead == 'p') ADVANCE(96);
      END_STATE();
    case 170:
      if (lookahead == 'p') ADVANCE(183);
      END_STATE();
    case 171:
      if (lookahead == 'r') ADVANCE(222);
      END_STATE();
    case 172:
      if (lookahead == 'r') ADVANCE(157);
      END_STATE();
    case 173:
      if (lookahead == 'r') ADVANCE(116);
      END_STATE();
    case 174:
      if (lookahead == 'r') ADVANCE(234);
      END_STATE();
    case 175:
      if (lookahead == 'r') ADVANCE(122);
      END_STATE();
    case 176:
      if (lookahead == 'r') ADVANCE(235);
      END_STATE();
    case 177:
      if (lookahead == 'r') ADVANCE(160);
      END_STATE();
    case 178:
      if (lookahead == 'r') ADVANCE(236);
      END_STATE();
    case 179:
      if (lookahead == 'r') ADVANCE(42);
      END_STATE();
    case 180:
      if (lookahead == 'r') ADVANCE(90);
      END_STATE();
    case 181:
      if (lookahead == 'r') ADVANCE(175);
      END_STATE();
    case 182:
      if (lookahead == 'r') ADVANCE(115);
      END_STATE();
    case 183:
      if (lookahead == 'r') ADVANCE(87);
      END_STATE();
    case 184:
      if (lookahead == 'r') ADVANCE(77);
      END_STATE();
    case 185:
      if (lookahead == 'r') ADVANCE(95);
      END_STATE();
    case 186:
      if (lookahead == 'r') ADVANCE(225);
      END_STATE();
    case 187:
      if (lookahead == 'r') ADVANCE(148);
      END_STATE();
    case 188:
      if (lookahead == 'r') ADVANCE(185);
      END_STATE();
    case 189:
      if (lookahead == 's') ADVANCE(429);
      END_STATE();
    case 190:
      if (lookahead == 's') ADVANCE(428);
      END_STATE();
    case 191:
      if (lookahead == 's') ADVANCE(425);
      END_STATE();
    case 192:
      if (lookahead == 's') ADVANCE(193);
      END_STATE();
    case 193:
      if (lookahead == 's') ADVANCE(118);
      END_STATE();
    case 194:
      if (lookahead == 's') ADVANCE(206);
      END_STATE();
    case 195:
      if (lookahead == 's') ADVANCE(74);
      END_STATE();
    case 196:
      if (lookahead == 's') ADVANCE(76);
      END_STATE();
    case 197:
      if (lookahead == 's') ADVANCE(80);
      if (lookahead == 'z') ADVANCE(81);
      END_STATE();
    case 198:
      if (lookahead == 's') ADVANCE(82);
      if (lookahead == 'z') ADVANCE(83);
      END_STATE();
    case 199:
      if (lookahead == 's') ADVANCE(211);
      END_STATE();
    case 200:
      if (lookahead == 't') ADVANCE(380);
      END_STATE();
    case 201:
      if (lookahead == 't') ADVANCE(421);
      END_STATE();
    case 202:
      if (lookahead == 't') ADVANCE(408);
      END_STATE();
    case 203:
      if (lookahead == 't') ADVANCE(383);
      END_STATE();
    case 204:
      if (lookahead == 't') ADVANCE(402);
      END_STATE();
    case 205:
      if (lookahead == 't') ADVANCE(384);
      END_STATE();
    case 206:
      if (lookahead == 't') ADVANCE(409);
      END_STATE();
    case 207:
      if (lookahead == 't') ADVANCE(406);
      END_STATE();
    case 208:
      if (lookahead == 't') ADVANCE(379);
      END_STATE();
    case 209:
      if (lookahead == 't') ADVANCE(237);
      END_STATE();
    case 210:
      if (lookahead == 't') ADVANCE(113);
      END_STATE();
    case 211:
      if (lookahead == 't') ADVANCE(117);
      END_STATE();
    case 212:
      if (lookahead == 't') ADVANCE(97);
      END_STATE();
    case 213:
      if (lookahead == 'u') ADVANCE(46);
      END_STATE();
    case 214:
      if (lookahead == 'u') ADVANCE(133);
      END_STATE();
    case 215:
      if (lookahead == 'u') ADVANCE(128);
      END_STATE();
    case 216:
      if (lookahead == 'u') ADVANCE(130);
      END_STATE();
    case 217:
      if (lookahead == 'u') ADVANCE(67);
      END_STATE();
    case 218:
      if (lookahead == 'u') ADVANCE(166);
      END_STATE();
    case 219:
      if (lookahead == 'u') ADVANCE(134);
      END_STATE();
    case 220:
      if (lookahead == 'u') ADVANCE(173);
      END_STATE();
    case 221:
      if (lookahead == 'u') ADVANCE(132);
      END_STATE();
    case 222:
      if (lookahead == 'u') ADVANCE(72);
      END_STATE();
    case 223:
      if (lookahead == 'u') ADVANCE(188);
      END_STATE();
    case 224:
      if (lookahead == 'u') ADVANCE(150);
      END_STATE();
    case 225:
      if (lookahead == 'u') ADVANCE(74);
      END_STATE();
    case 226:
      if (lookahead == 'v') ADVANCE(93);
      END_STATE();
    case 227:
      if (lookahead == 'v') ADVANCE(71);
      END_STATE();
    case 228:
      if (lookahead == 'w') ADVANCE(398);
      END_STATE();
    case 229:
      if (lookahead == 'x') ADVANCE(170);
      END_STATE();
    case 230:
      if (lookahead == 'x') ADVANCE(386);
      END_STATE();
    case 231:
      if (lookahead == 'x') ADVANCE(384);
      END_STATE();
    case 232:
      if (lookahead == 'x') ADVANCE(114);
      END_STATE();
    case 233:
      if (lookahead == 'y') ADVANCE(422);
      END_STATE();
    case 234:
      if (lookahead == 'y') ADVANCE(419);
      END_STATE();
    case 235:
      if (lookahead == 'y') ADVANCE(420);
      END_STATE();
    case 236:
      if (lookahead == 'y') ADVANCE(423);
      END_STATE();
    case 237:
      if (lookahead == 'y') ADVANCE(169);
      END_STATE();
    case 238:
      if (lookahead == '}') ADVANCE(304);
      END_STATE();
    case 239:
      if (lookahead == '\'' ||
          lookahead == '_') ADVANCE(239);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(277);
      END_STATE();
    case 240:
      if (lookahead == '\'' ||
          lookahead == '_') ADVANCE(240);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 241:
      if (lookahead == '\'' ||
          lookahead == '_') ADVANCE(241);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 242:
      if (lookahead == '\'' ||
          lookahead == '_') ADVANCE(242);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      END_STATE();
    case 243:
      if (lookahead == '\'' ||
          lookahead == '_') ADVANCE(243);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(275);
      END_STATE();
    case 244:
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(343);
      END_STATE();
    case 245:
      if (lookahead == '"' ||
          lookahead == '\\' ||
          lookahead == 'n') ADVANCE(304);
      END_STATE();
    case 246:
      if (lookahead == '"' ||
          lookahead == '\\' ||
          lookahead == 'n') ADVANCE(303);
      END_STATE();
    case 247:
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      END_STATE();
    case 248:
      if (('1' <= lookahead && lookahead <= '7')) ADVANCE(344);
      END_STATE();
    case 249:
      if (set_contains(sym_theory_operator_character_set_1, 9, lookahead)) ADVANCE(371);
      END_STATE();
    case 250:
      if (set_contains(sym_theory_operator_character_set_1, 9, lookahead)) ADVANCE(370);
      END_STATE();
    case 251:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(346);
      END_STATE();
    case 252:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '%' &&
          lookahead != '*' &&
          lookahead != '_' &&
          lookahead != '`') ADVANCE(24);
      END_STATE();
    case 253:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '*' &&
          lookahead != '_' &&
          lookahead != '`') ADVANCE(33);
      END_STATE();
    case 254:
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '*' &&
          lookahead != '_' &&
          lookahead != '`') ADVANCE(32);
      END_STATE();
    case 255:
      if (lookahead != 0 &&
          lookahead != '#') ADVANCE(405);
      END_STATE();
    case 256:
      if (lookahead != 0 &&
          lookahead != 'd') ADVANCE(255);
      END_STATE();
    case 257:
      if (eof) ADVANCE(260);
      ADVANCE_MAP(
        '!', 313,
        '"', 293,
        '#', 69,
        '%', 264,
        '&', 353,
        '\'', 242,
        '(', 364,
        ')', 365,
        '*', 357,
        '+', 354,
        ',', 363,
        '-', 355,
        '.', 389,
        '/', 358,
        ':', 426,
        ';', 367,
        '<', 415,
        '=', 410,
        '>', 417,
        '?', 352,
        '@', 369,
        '[', 373,
        '\\', 359,
        ']', 374,
        '^', 351,
        '_', 349,
        'a', 139,
        'b', 123,
        'd', 70,
        'e', 229,
        'f', 15,
        'h', 88,
        'l', 86,
        'm', 35,
        'n', 156,
        'o', 50,
        'r', 111,
        's', 213,
        't', 171,
        'u', 144,
        'w', 109,
        '{', 334,
        '|', 362,
        '}', 375,
        '~', 361,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(257);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      END_STATE();
    case 258:
      if (eof) ADVANCE(260);
      ADVANCE_MAP(
        '!', 31,
        '"', 293,
        '#', 54,
        '%', 269,
        '&', 353,
        '\'', 240,
        '(', 364,
        ')', 365,
        '*', 357,
        '+', 354,
        ',', 363,
        '-', 355,
        '.', 389,
        '/', 358,
        '0', 342,
        ':', 26,
        ';', 367,
        '<', 378,
        '=', 377,
        '>', 378,
        '?', 352,
        '@', 369,
        '[', 373,
        '\\', 359,
        ']', 374,
        '^', 351,
        '_', 348,
        'f', 283,
        'n', 287,
        '{', 334,
        '|', 362,
        '}', 375,
        '~', 361,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(258);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(345);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      END_STATE();
    case 259:
      if (eof) ADVANCE(260);
      ADVANCE_MAP(
        '"', 293,
        '#', 52,
        '%', 264,
        '&', 353,
        '\'', 240,
        '(', 364,
        '-', 355,
        '0', 342,
        ':', 27,
        '@', 369,
        '[', 373,
        '_', 348,
        'f', 283,
        'n', 287,
        '{', 334,
        '|', 362,
        '~', 361,
      );
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') SKIP(259);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(345);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      END_STATE();
    case 260:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 261:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead == '#') ADVANCE(270);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(405);
      if (lookahead != 0) ADVANCE(262);
      END_STATE();
    case 262:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead == '#') ADVANCE(266);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(405);
      if (lookahead != 0) ADVANCE(262);
      END_STATE();
    case 263:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead == '#') ADVANCE(266);
      if (lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == '*') ADVANCE(405);
      if (lookahead != 0) ADVANCE(262);
      END_STATE();
    case 264:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead == '*') ADVANCE(5);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(270);
      END_STATE();
    case 265:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead == 'd') ADVANCE(270);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(255);
      if (lookahead != 0) ADVANCE(261);
      END_STATE();
    case 266:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead == 'e') ADVANCE(267);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(255);
      if (lookahead != 0) ADVANCE(261);
      END_STATE();
    case 267:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead == 'n') ADVANCE(265);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(255);
      if (lookahead != 0) ADVANCE(261);
      END_STATE();
    case 268:
      ACCEPT_TOKEN(sym_line_comment);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(318);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '*') ADVANCE(270);
      END_STATE();
    case 269:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != '*') ADVANCE(270);
      END_STATE();
    case 270:
      ACCEPT_TOKEN(sym_line_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(270);
      END_STATE();
    case 271:
      ACCEPT_TOKEN(anon_sym_PERCENT_STAR_BANG);
      END_STATE();
    case 272:
      ACCEPT_TOKEN(aux_sym_doc_comment_token1);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(272);
      END_STATE();
    case 273:
      ACCEPT_TOKEN(anon_sym_STAR_PERCENT);
      END_STATE();
    case 274:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 275:
      ACCEPT_TOKEN(aux_sym_doc_predicate_token1);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(275);
      END_STATE();
    case 276:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 277:
      ACCEPT_TOKEN(sym_doc_var);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(277);
      END_STATE();
    case 278:
      ACCEPT_TOKEN(sym_doc_fragment_emph);
      END_STATE();
    case 279:
      ACCEPT_TOKEN(sym_doc_fragment_bold);
      END_STATE();
    case 280:
      ACCEPT_TOKEN(sym_doc_fragment_italic);
      END_STATE();
    case 281:
      ACCEPT_TOKEN(sym_doc_fragment_code);
      END_STATE();
    case 282:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 283:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '"') ADVANCE(294);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 284:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(289);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 285:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'e') ADVANCE(431);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 286:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'h') ADVANCE(284);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 287:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(290);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 288:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'o') ADVANCE(291);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 289:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 'r') ADVANCE(285);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 290:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(381);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 291:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == 't') ADVANCE(382);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 292:
      ACCEPT_TOKEN(sym_identifier);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 293:
      ACCEPT_TOKEN(anon_sym_DQUOTE);
      END_STATE();
    case 294:
      ACCEPT_TOKEN(anon_sym_f_DQUOTE);
      END_STATE();
    case 295:
      ACCEPT_TOKEN(sym__string_fragment);
      if (lookahead == '%') ADVANCE(297);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(295);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(298);
      END_STATE();
    case 296:
      ACCEPT_TOKEN(sym__string_fragment);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(298);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(296);
      END_STATE();
    case 297:
      ACCEPT_TOKEN(sym__string_fragment);
      if (lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == '*') ADVANCE(298);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(296);
      END_STATE();
    case 298:
      ACCEPT_TOKEN(sym__string_fragment);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\') ADVANCE(298);
      END_STATE();
    case 299:
      ACCEPT_TOKEN(sym__fstring_fragment);
      if (lookahead == '%') ADVANCE(301);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(299);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(302);
      END_STATE();
    case 300:
      ACCEPT_TOKEN(sym__fstring_fragment);
      if (lookahead == '\n' ||
          lookahead == '\r') ADVANCE(302);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(300);
      END_STATE();
    case 301:
      ACCEPT_TOKEN(sym__fstring_fragment);
      if (lookahead == '\n' ||
          lookahead == '\r' ||
          lookahead == '*') ADVANCE(302);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(300);
      END_STATE();
    case 302:
      ACCEPT_TOKEN(sym__fstring_fragment);
      if (lookahead != 0 &&
          lookahead != '"' &&
          lookahead != '\\' &&
          lookahead != '{' &&
          lookahead != '}') ADVANCE(302);
      END_STATE();
    case 303:
      ACCEPT_TOKEN(sym__string_escape);
      END_STATE();
    case 304:
      ACCEPT_TOKEN(sym__fstring_escape);
      END_STATE();
    case 305:
      ACCEPT_TOKEN(aux_sym_fstring_accessor_token1);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(305);
      END_STATE();
    case 306:
      ACCEPT_TOKEN(aux_sym_fstring_accessor_token2);
      END_STATE();
    case 307:
      ACCEPT_TOKEN(aux_sym_fstring_accessor_token3);
      END_STATE();
    case 308:
      ACCEPT_TOKEN(aux_sym_fstring_accessor_token3);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      END_STATE();
    case 309:
      ACCEPT_TOKEN(aux_sym_fstring_accessor_token3);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(310);
      END_STATE();
    case 310:
      ACCEPT_TOKEN(aux_sym_fstring_accessor_token3);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(310);
      END_STATE();
    case 311:
      ACCEPT_TOKEN(aux_sym_fstring_accessor_token4);
      END_STATE();
    case 312:
      ACCEPT_TOKEN(aux_sym_fstring_conversion_token1);
      END_STATE();
    case 313:
      ACCEPT_TOKEN(aux_sym_fstring_conversion_token1);
      if (lookahead == '=') ADVANCE(377);
      END_STATE();
    case 314:
      ACCEPT_TOKEN(aux_sym_fstring_conversion_token2);
      END_STATE();
    case 315:
      ACCEPT_TOKEN(aux_sym_fstring_conversion_token2);
      if (lookahead == 'r' ||
          lookahead == 's') ADVANCE(314);
      END_STATE();
    case 316:
      ACCEPT_TOKEN(sym_fstring_align);
      END_STATE();
    case 317:
      ACCEPT_TOKEN(sym_fstring_align);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      END_STATE();
    case 318:
      ACCEPT_TOKEN(sym_fstring_align);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(270);
      END_STATE();
    case 319:
      ACCEPT_TOKEN(sym_fstring_sign);
      END_STATE();
    case 320:
      ACCEPT_TOKEN(sym_fstring_sign);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      END_STATE();
    case 321:
      ACCEPT_TOKEN(sym_fstring_alternate);
      END_STATE();
    case 322:
      ACCEPT_TOKEN(sym_fstring_alternate);
      if (lookahead == 'e') ADVANCE(65);
      if (lookahead == 'f') ADVANCE(45);
      if (lookahead == 'h') ADVANCE(91);
      if (lookahead == 'i') ADVANCE(140);
      if (lookahead == 'm') ADVANCE(36);
      if (lookahead == 'p') ADVANCE(172);
      if (lookahead == 't') ADVANCE(110);
      END_STATE();
    case 323:
      ACCEPT_TOKEN(sym_fstring_alternate);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      END_STATE();
    case 324:
      ACCEPT_TOKEN(sym_fstring_grouping);
      END_STATE();
    case 325:
      ACCEPT_TOKEN(sym_fstring_grouping);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      END_STATE();
    case 326:
      ACCEPT_TOKEN(sym_fstring_type);
      END_STATE();
    case 327:
      ACCEPT_TOKEN(sym_fstring_type);
      if (lookahead == 'c') ADVANCE(60);
      if (lookahead == 'v') ADVANCE(93);
      END_STATE();
    case 328:
      ACCEPT_TOKEN(sym_fstring_type);
      if (lookahead == 'e') ADVANCE(103);
      if (lookahead == 'i') ADVANCE(180);
      END_STATE();
    case 329:
      ACCEPT_TOKEN(sym_fstring_type);
      if (lookahead == 'i') ADVANCE(152);
      if (lookahead == 'o') ADVANCE(61);
      END_STATE();
    case 330:
      ACCEPT_TOKEN(sym_fstring_type);
      if (lookahead == 'o') ADVANCE(200);
      END_STATE();
    case 331:
      ACCEPT_TOKEN(sym_fstring_type);
      if (lookahead == 'u') ADVANCE(46);
      END_STATE();
    case 332:
      ACCEPT_TOKEN(sym_fstring_type);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      END_STATE();
    case 333:
      ACCEPT_TOKEN(aux_sym_fstring_spec_token1);
      END_STATE();
    case 334:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 335:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      if (lookahead == '{') ADVANCE(304);
      END_STATE();
    case 336:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 337:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      if (('<' <= lookahead && lookahead <= '>') ||
          lookahead == '^') ADVANCE(316);
      END_STATE();
    case 338:
      ACCEPT_TOKEN(sym_supremum);
      END_STATE();
    case 339:
      ACCEPT_TOKEN(sym_supremum);
      if (lookahead == 'r') ADVANCE(98);
      END_STATE();
    case 340:
      ACCEPT_TOKEN(sym_infimum);
      END_STATE();
    case 341:
      ACCEPT_TOKEN(sym_infimum);
      if (lookahead == 'i') ADVANCE(136);
      END_STATE();
    case 342:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == 'b') ADVANCE(244);
      if (lookahead == 'o') ADVANCE(248);
      if (lookahead == 'x') ADVANCE(251);
      END_STATE();
    case 343:
      ACCEPT_TOKEN(sym_number);
      if (lookahead == '0' ||
          lookahead == '1') ADVANCE(343);
      END_STATE();
    case 344:
      ACCEPT_TOKEN(sym_number);
      if (('1' <= lookahead && lookahead <= '7')) ADVANCE(344);
      END_STATE();
    case 345:
      ACCEPT_TOKEN(sym_number);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(345);
      END_STATE();
    case 346:
      ACCEPT_TOKEN(sym_number);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(346);
      END_STATE();
    case 347:
      ACCEPT_TOKEN(sym_anonymous);
      if (lookahead == '\'' ||
          lookahead == '_') ADVANCE(239);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(277);
      END_STATE();
    case 348:
      ACCEPT_TOKEN(sym_anonymous);
      if (lookahead == '\'' ||
          lookahead == '_') ADVANCE(240);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      if (('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 349:
      ACCEPT_TOKEN(sym_anonymous);
      if (lookahead == '\'' ||
          lookahead == '_') ADVANCE(242);
      if (('A' <= lookahead && lookahead <= 'Z')) ADVANCE(350);
      END_STATE();
    case 350:
      ACCEPT_TOKEN(sym_variable);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(350);
      END_STATE();
    case 351:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 352:
      ACCEPT_TOKEN(anon_sym_QMARK);
      END_STATE();
    case 353:
      ACCEPT_TOKEN(anon_sym_AMP);
      END_STATE();
    case 354:
      ACCEPT_TOKEN(anon_sym_PLUS);
      END_STATE();
    case 355:
      ACCEPT_TOKEN(anon_sym_DASH);
      END_STATE();
    case 356:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 357:
      ACCEPT_TOKEN(anon_sym_STAR);
      if (lookahead == '*') ADVANCE(360);
      END_STATE();
    case 358:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 359:
      ACCEPT_TOKEN(anon_sym_BSLASH);
      END_STATE();
    case 360:
      ACCEPT_TOKEN(anon_sym_STAR_STAR);
      END_STATE();
    case 361:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 362:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 363:
      ACCEPT_TOKEN(anon_sym_COMMA2);
      END_STATE();
    case 364:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 365:
      ACCEPT_TOKEN(anon_sym_RPAREN2);
      END_STATE();
    case 366:
      ACCEPT_TOKEN(anon_sym_DOT_DOT);
      END_STATE();
    case 367:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 368:
      ACCEPT_TOKEN(anon_sym_SEMI);
      if (set_contains(sym_theory_operator_character_set_1, 9, lookahead)) ADVANCE(371);
      END_STATE();
    case 369:
      ACCEPT_TOKEN(anon_sym_AT);
      END_STATE();
    case 370:
      ACCEPT_TOKEN(sym_theory_operator);
      END_STATE();
    case 371:
      ACCEPT_TOKEN(sym_theory_operator);
      if (set_contains(sym_theory_operator_character_set_1, 9, lookahead)) ADVANCE(371);
      END_STATE();
    case 372:
      ACCEPT_TOKEN(sym_theory_operator);
      if (set_contains(sym_theory_operator_character_set_1, 9, lookahead)) ADVANCE(370);
      END_STATE();
    case 373:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 374:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 375:
      ACCEPT_TOKEN(anon_sym_RBRACE2);
      END_STATE();
    case 376:
      ACCEPT_TOKEN(sym_boolean_constant);
      END_STATE();
    case 377:
      ACCEPT_TOKEN(sym_relation);
      END_STATE();
    case 378:
      ACCEPT_TOKEN(sym_relation);
      if (lookahead == '=') ADVANCE(377);
      END_STATE();
    case 379:
      ACCEPT_TOKEN(sym_default_negation);
      END_STATE();
    case 380:
      ACCEPT_TOKEN(sym_default_negation);
      if (lookahead == ' ') ADVANCE(147);
      END_STATE();
    case 381:
      ACCEPT_TOKEN(sym_default_negation);
      if (lookahead == ' ') ADVANCE(147);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 382:
      ACCEPT_TOKEN(sym_default_negation);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 383:
      ACCEPT_TOKEN(sym_double_default_negation);
      END_STATE();
    case 384:
      ACCEPT_TOKEN(sym_aggregate_function);
      END_STATE();
    case 385:
      ACCEPT_TOKEN(sym_aggregate_function);
      if (lookahead == '+') ADVANCE(384);
      END_STATE();
    case 386:
      ACCEPT_TOKEN(sym_aggregate_function);
      if (lookahead == 'i') ADVANCE(135);
      END_STATE();
    case 387:
      ACCEPT_TOKEN(sym_aggregate_function);
      if (lookahead == 'i') ADVANCE(138);
      END_STATE();
    case 388:
      ACCEPT_TOKEN(anon_sym_DOT);
      END_STATE();
    case 389:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (lookahead == '.') ADVANCE(366);
      END_STATE();
    case 390:
      ACCEPT_TOKEN(anon_sym_DOT);
      if (set_contains(sym_theory_operator_character_set_1, 9, lookahead)) ADVANCE(371);
      END_STATE();
    case 391:
      ACCEPT_TOKEN(anon_sym_COLON_DASH);
      END_STATE();
    case 392:
      ACCEPT_TOKEN(anon_sym_COLON_DASH);
      if (set_contains(sym_theory_operator_character_set_1, 9, lookahead)) ADVANCE(370);
      END_STATE();
    case 393:
      ACCEPT_TOKEN(anon_sym_COLON_TILDE);
      END_STATE();
    case 394:
      ACCEPT_TOKEN(anon_sym_POUNDmaximize);
      END_STATE();
    case 395:
      ACCEPT_TOKEN(anon_sym_POUNDmaximise);
      END_STATE();
    case 396:
      ACCEPT_TOKEN(anon_sym_POUNDminimize);
      END_STATE();
    case 397:
      ACCEPT_TOKEN(anon_sym_POUNDminimise);
      END_STATE();
    case 398:
      ACCEPT_TOKEN(anon_sym_POUNDshow);
      END_STATE();
    case 399:
      ACCEPT_TOKEN(anon_sym_true);
      END_STATE();
    case 400:
      ACCEPT_TOKEN(anon_sym_false);
      END_STATE();
    case 401:
      ACCEPT_TOKEN(anon_sym_POUNDdefined);
      END_STATE();
    case 402:
      ACCEPT_TOKEN(anon_sym_POUNDproject);
      END_STATE();
    case 403:
      ACCEPT_TOKEN(anon_sym_POUNDprogram);
      END_STATE();
    case 404:
      ACCEPT_TOKEN(sym_code);
      if (lookahead == '#') ADVANCE(85);
      if (lookahead == '%') ADVANCE(263);
      if (('\t' <= lookahead && lookahead <= '\r') ||
          lookahead == ' ') ADVANCE(404);
      if (lookahead != 0) ADVANCE(405);
      END_STATE();
    case 405:
      ACCEPT_TOKEN(sym_code);
      if (lookahead == '#') ADVANCE(85);
      if (lookahead != 0) ADVANCE(405);
      END_STATE();
    case 406:
      ACCEPT_TOKEN(anon_sym_POUNDscript);
      END_STATE();
    case 407:
      ACCEPT_TOKEN(anon_sym_POUNDend);
      END_STATE();
    case 408:
      ACCEPT_TOKEN(sym_const_type);
      END_STATE();
    case 409:
      ACCEPT_TOKEN(anon_sym_POUNDconst);
      END_STATE();
    case 410:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 411:
      ACCEPT_TOKEN(anon_sym_POUNDedge);
      END_STATE();
    case 412:
      ACCEPT_TOKEN(anon_sym_POUNDheuristic);
      END_STATE();
    case 413:
      ACCEPT_TOKEN(anon_sym_POUNDinclude);
      END_STATE();
    case 414:
      ACCEPT_TOKEN(anon_sym_LT);
      END_STATE();
    case 415:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(377);
      END_STATE();
    case 416:
      ACCEPT_TOKEN(anon_sym_GT);
      END_STATE();
    case 417:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(377);
      END_STATE();
    case 418:
      ACCEPT_TOKEN(anon_sym_POUNDexternal);
      END_STATE();
    case 419:
      ACCEPT_TOKEN(sym_theory_operator_arity);
      END_STATE();
    case 420:
      ACCEPT_TOKEN(anon_sym_binary);
      END_STATE();
    case 421:
      ACCEPT_TOKEN(sym_theory_operator_associativity);
      END_STATE();
    case 422:
      ACCEPT_TOKEN(sym_theory_atom_type);
      END_STATE();
    case 423:
      ACCEPT_TOKEN(anon_sym_POUNDtheory);
      END_STATE();
    case 424:
      ACCEPT_TOKEN(anon_sym_POUNDtype);
      END_STATE();
    case 425:
      ACCEPT_TOKEN(anon_sym_expressions);
      END_STATE();
    case 426:
      ACCEPT_TOKEN(anon_sym_COLON2);
      END_STATE();
    case 427:
      ACCEPT_TOKEN(anon_sym_COLON2);
      if (lookahead == '-') ADVANCE(391);
      END_STATE();
    case 428:
      ACCEPT_TOKEN(anon_sym_subtypes);
      END_STATE();
    case 429:
      ACCEPT_TOKEN(anon_sym_macros);
      END_STATE();
    case 430:
      ACCEPT_TOKEN(anon_sym_where);
      END_STATE();
    case 431:
      ACCEPT_TOKEN(anon_sym_where);
      if (lookahead == '\'' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(292);
      END_STATE();
    case 432:
      ACCEPT_TOKEN(anon_sym_occurrence);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexerMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0, .external_lex_state = 1},
  [1] = {.lex_state = 259, .external_lex_state = 2},
  [2] = {.lex_state = 259, .external_lex_state = 2},
  [3] = {.lex_state = 259, .external_lex_state = 2},
  [4] = {.lex_state = 258, .external_lex_state = 2},
  [5] = {.lex_state = 258, .external_lex_state = 2},
  [6] = {.lex_state = 258, .external_lex_state = 2},
  [7] = {.lex_state = 258, .external_lex_state = 2},
  [8] = {.lex_state = 258, .external_lex_state = 2},
  [9] = {.lex_state = 258, .external_lex_state = 2},
  [10] = {.lex_state = 258, .external_lex_state = 2},
  [11] = {.lex_state = 258, .external_lex_state = 2},
  [12] = {.lex_state = 258, .external_lex_state = 2},
  [13] = {.lex_state = 258, .external_lex_state = 2},
  [14] = {.lex_state = 258, .external_lex_state = 2},
  [15] = {.lex_state = 259, .external_lex_state = 2},
  [16] = {.lex_state = 259, .external_lex_state = 2},
  [17] = {.lex_state = 259, .external_lex_state = 2},
  [18] = {.lex_state = 259, .external_lex_state = 2},
  [19] = {.lex_state = 259, .external_lex_state = 2},
  [20] = {.lex_state = 259, .external_lex_state = 2},
  [21] = {.lex_state = 259, .external_lex_state = 2},
  [22] = {.lex_state = 259, .external_lex_state = 2},
  [23] = {.lex_state = 259, .external_lex_state = 2},
  [24] = {.lex_state = 259, .external_lex_state = 2},
  [25] = {.lex_state = 259, .external_lex_state = 2},
  [26] = {.lex_state = 259, .external_lex_state = 2},
  [27] = {.lex_state = 259, .external_lex_state = 2},
  [28] = {.lex_state = 259, .external_lex_state = 2},
  [29] = {.lex_state = 259, .external_lex_state = 2},
  [30] = {.lex_state = 259, .external_lex_state = 2},
  [31] = {.lex_state = 259, .external_lex_state = 2},
  [32] = {.lex_state = 259, .external_lex_state = 2},
  [33] = {.lex_state = 259, .external_lex_state = 2},
  [34] = {.lex_state = 259, .external_lex_state = 2},
  [35] = {.lex_state = 259, .external_lex_state = 2},
  [36] = {.lex_state = 259, .external_lex_state = 2},
  [37] = {.lex_state = 259, .external_lex_state = 2},
  [38] = {.lex_state = 259, .external_lex_state = 2},
  [39] = {.lex_state = 259, .external_lex_state = 2},
  [40] = {.lex_state = 259, .external_lex_state = 2},
  [41] = {.lex_state = 259, .external_lex_state = 2},
  [42] = {.lex_state = 259, .external_lex_state = 2},
  [43] = {.lex_state = 259, .external_lex_state = 2},
  [44] = {.lex_state = 259, .external_lex_state = 2},
  [45] = {.lex_state = 259, .external_lex_state = 2},
  [46] = {.lex_state = 259, .external_lex_state = 2},
  [47] = {.lex_state = 259, .external_lex_state = 2},
  [48] = {.lex_state = 259, .external_lex_state = 2},
  [49] = {.lex_state = 259, .external_lex_state = 2},
  [50] = {.lex_state = 259, .external_lex_state = 2},
  [51] = {.lex_state = 259, .external_lex_state = 2},
  [52] = {.lex_state = 259, .external_lex_state = 2},
  [53] = {.lex_state = 259, .external_lex_state = 2},
  [54] = {.lex_state = 259, .external_lex_state = 2},
  [55] = {.lex_state = 259, .external_lex_state = 2},
  [56] = {.lex_state = 259, .external_lex_state = 2},
  [57] = {.lex_state = 259, .external_lex_state = 2},
  [58] = {.lex_state = 259, .external_lex_state = 2},
  [59] = {.lex_state = 259, .external_lex_state = 2},
  [60] = {.lex_state = 259, .external_lex_state = 2},
  [61] = {.lex_state = 259, .external_lex_state = 2},
  [62] = {.lex_state = 259, .external_lex_state = 2},
  [63] = {.lex_state = 259, .external_lex_state = 2},
  [64] = {.lex_state = 259, .external_lex_state = 2},
  [65] = {.lex_state = 259, .external_lex_state = 2},
  [66] = {.lex_state = 259, .external_lex_state = 2},
  [67] = {.lex_state = 259, .external_lex_state = 2},
  [68] = {.lex_state = 259, .external_lex_state = 2},
  [69] = {.lex_state = 259, .external_lex_state = 2},
  [70] = {.lex_state = 259, .external_lex_state = 2},
  [71] = {.lex_state = 259, .external_lex_state = 2},
  [72] = {.lex_state = 259, .external_lex_state = 2},
  [73] = {.lex_state = 259, .external_lex_state = 2},
  [74] = {.lex_state = 258, .external_lex_state = 2},
  [75] = {.lex_state = 258, .external_lex_state = 2},
  [76] = {.lex_state = 258, .external_lex_state = 2},
  [77] = {.lex_state = 258, .external_lex_state = 2},
  [78] = {.lex_state = 258, .external_lex_state = 2},
  [79] = {.lex_state = 258, .external_lex_state = 2},
  [80] = {.lex_state = 258, .external_lex_state = 2},
  [81] = {.lex_state = 258, .external_lex_state = 2},
  [82] = {.lex_state = 258, .external_lex_state = 2},
  [83] = {.lex_state = 258, .external_lex_state = 2},
  [84] = {.lex_state = 258, .external_lex_state = 2},
  [85] = {.lex_state = 258, .external_lex_state = 2},
  [86] = {.lex_state = 258, .external_lex_state = 2},
  [87] = {.lex_state = 258, .external_lex_state = 2},
  [88] = {.lex_state = 258, .external_lex_state = 2},
  [89] = {.lex_state = 258, .external_lex_state = 2},
  [90] = {.lex_state = 6, .external_lex_state = 2},
  [91] = {.lex_state = 6, .external_lex_state = 2},
  [92] = {.lex_state = 258, .external_lex_state = 2},
  [93] = {.lex_state = 6, .external_lex_state = 3},
  [94] = {.lex_state = 6, .external_lex_state = 3},
  [95] = {.lex_state = 6, .external_lex_state = 3},
  [96] = {.lex_state = 258, .external_lex_state = 2},
  [97] = {.lex_state = 258, .external_lex_state = 2},
  [98] = {.lex_state = 258, .external_lex_state = 2},
  [99] = {.lex_state = 258, .external_lex_state = 2},
  [100] = {.lex_state = 258, .external_lex_state = 2},
  [101] = {.lex_state = 6, .external_lex_state = 4},
  [102] = {.lex_state = 6, .external_lex_state = 3},
  [103] = {.lex_state = 6, .external_lex_state = 3},
  [104] = {.lex_state = 6, .external_lex_state = 3},
  [105] = {.lex_state = 6, .external_lex_state = 2},
  [106] = {.lex_state = 6, .external_lex_state = 2},
  [107] = {.lex_state = 6, .external_lex_state = 2},
  [108] = {.lex_state = 6, .external_lex_state = 2},
  [109] = {.lex_state = 6, .external_lex_state = 5},
  [110] = {.lex_state = 6, .external_lex_state = 2},
  [111] = {.lex_state = 6, .external_lex_state = 2},
  [112] = {.lex_state = 6, .external_lex_state = 2},
  [113] = {.lex_state = 6, .external_lex_state = 2},
  [114] = {.lex_state = 6, .external_lex_state = 4},
  [115] = {.lex_state = 6, .external_lex_state = 2},
  [116] = {.lex_state = 6, .external_lex_state = 5},
  [117] = {.lex_state = 6, .external_lex_state = 2},
  [118] = {.lex_state = 6, .external_lex_state = 2},
  [119] = {.lex_state = 6, .external_lex_state = 2},
  [120] = {.lex_state = 6, .external_lex_state = 5},
  [121] = {.lex_state = 6, .external_lex_state = 5},
  [122] = {.lex_state = 6, .external_lex_state = 5},
  [123] = {.lex_state = 6, .external_lex_state = 5},
  [124] = {.lex_state = 6, .external_lex_state = 2},
  [125] = {.lex_state = 6, .external_lex_state = 2},
  [126] = {.lex_state = 6, .external_lex_state = 2},
  [127] = {.lex_state = 6, .external_lex_state = 2},
  [128] = {.lex_state = 6, .external_lex_state = 2},
  [129] = {.lex_state = 6, .external_lex_state = 2},
  [130] = {.lex_state = 6, .external_lex_state = 2},
  [131] = {.lex_state = 6, .external_lex_state = 2},
  [132] = {.lex_state = 6, .external_lex_state = 2},
  [133] = {.lex_state = 6, .external_lex_state = 2},
  [134] = {.lex_state = 6, .external_lex_state = 2},
  [135] = {.lex_state = 6, .external_lex_state = 2},
  [136] = {.lex_state = 6, .external_lex_state = 2},
  [137] = {.lex_state = 6, .external_lex_state = 2},
  [138] = {.lex_state = 6, .external_lex_state = 2},
  [139] = {.lex_state = 6, .external_lex_state = 2},
  [140] = {.lex_state = 6, .external_lex_state = 5},
  [141] = {.lex_state = 12, .external_lex_state = 5},
  [142] = {.lex_state = 6, .external_lex_state = 2},
  [143] = {.lex_state = 6, .external_lex_state = 5},
  [144] = {.lex_state = 12, .external_lex_state = 5},
  [145] = {.lex_state = 6, .external_lex_state = 2},
  [146] = {.lex_state = 6, .external_lex_state = 2},
  [147] = {.lex_state = 12, .external_lex_state = 2},
  [148] = {.lex_state = 6, .external_lex_state = 2},
  [149] = {.lex_state = 3, .external_lex_state = 2},
  [150] = {.lex_state = 6, .external_lex_state = 2},
  [151] = {.lex_state = 6, .external_lex_state = 2},
  [152] = {.lex_state = 6, .external_lex_state = 2},
  [153] = {.lex_state = 6, .external_lex_state = 2},
  [154] = {.lex_state = 6, .external_lex_state = 2},
  [155] = {.lex_state = 6, .external_lex_state = 2},
  [156] = {.lex_state = 12, .external_lex_state = 2},
  [157] = {.lex_state = 3, .external_lex_state = 2},
  [158] = {.lex_state = 12, .external_lex_state = 5},
  [159] = {.lex_state = 6, .external_lex_state = 2},
  [160] = {.lex_state = 3, .external_lex_state = 2},
  [161] = {.lex_state = 6, .external_lex_state = 2},
  [162] = {.lex_state = 6, .external_lex_state = 2},
  [163] = {.lex_state = 12, .external_lex_state = 2},
  [164] = {.lex_state = 6, .external_lex_state = 2},
  [165] = {.lex_state = 6, .external_lex_state = 2},
  [166] = {.lex_state = 6, .external_lex_state = 2},
  [167] = {.lex_state = 6, .external_lex_state = 2},
  [168] = {.lex_state = 6, .external_lex_state = 2},
  [169] = {.lex_state = 6, .external_lex_state = 2},
  [170] = {.lex_state = 6, .external_lex_state = 2},
  [171] = {.lex_state = 12, .external_lex_state = 2},
  [172] = {.lex_state = 6, .external_lex_state = 2},
  [173] = {.lex_state = 6, .external_lex_state = 2},
  [174] = {.lex_state = 6, .external_lex_state = 2},
  [175] = {.lex_state = 6, .external_lex_state = 2},
  [176] = {.lex_state = 6, .external_lex_state = 2},
  [177] = {.lex_state = 3, .external_lex_state = 2},
  [178] = {.lex_state = 6, .external_lex_state = 2},
  [179] = {.lex_state = 6, .external_lex_state = 2},
  [180] = {.lex_state = 6, .external_lex_state = 2},
  [181] = {.lex_state = 6, .external_lex_state = 2},
  [182] = {.lex_state = 6, .external_lex_state = 2},
  [183] = {.lex_state = 6, .external_lex_state = 2},
  [184] = {.lex_state = 6, .external_lex_state = 2},
  [185] = {.lex_state = 6, .external_lex_state = 2},
  [186] = {.lex_state = 6, .external_lex_state = 2},
  [187] = {.lex_state = 6, .external_lex_state = 2},
  [188] = {.lex_state = 12, .external_lex_state = 2},
  [189] = {.lex_state = 6, .external_lex_state = 2},
  [190] = {.lex_state = 6, .external_lex_state = 2},
  [191] = {.lex_state = 6, .external_lex_state = 2},
  [192] = {.lex_state = 6, .external_lex_state = 2},
  [193] = {.lex_state = 6, .external_lex_state = 2},
  [194] = {.lex_state = 6, .external_lex_state = 2},
  [195] = {.lex_state = 6, .external_lex_state = 2},
  [196] = {.lex_state = 6, .external_lex_state = 2},
  [197] = {.lex_state = 6, .external_lex_state = 2},
  [198] = {.lex_state = 6, .external_lex_state = 2},
  [199] = {.lex_state = 6, .external_lex_state = 2},
  [200] = {.lex_state = 6, .external_lex_state = 2},
  [201] = {.lex_state = 6, .external_lex_state = 2},
  [202] = {.lex_state = 6, .external_lex_state = 2},
  [203] = {.lex_state = 6, .external_lex_state = 2},
  [204] = {.lex_state = 6, .external_lex_state = 2},
  [205] = {.lex_state = 6, .external_lex_state = 2},
  [206] = {.lex_state = 6, .external_lex_state = 2},
  [207] = {.lex_state = 6, .external_lex_state = 2},
  [208] = {.lex_state = 6, .external_lex_state = 2},
  [209] = {.lex_state = 12, .external_lex_state = 2},
  [210] = {.lex_state = 6, .external_lex_state = 2},
  [211] = {.lex_state = 12, .external_lex_state = 2},
  [212] = {.lex_state = 6, .external_lex_state = 2},
  [213] = {.lex_state = 6, .external_lex_state = 2},
  [214] = {.lex_state = 6, .external_lex_state = 2},
  [215] = {.lex_state = 12, .external_lex_state = 2},
  [216] = {.lex_state = 6, .external_lex_state = 2},
  [217] = {.lex_state = 6, .external_lex_state = 2},
  [218] = {.lex_state = 6, .external_lex_state = 2},
  [219] = {.lex_state = 6, .external_lex_state = 2},
  [220] = {.lex_state = 6, .external_lex_state = 2},
  [221] = {.lex_state = 6, .external_lex_state = 2},
  [222] = {.lex_state = 3, .external_lex_state = 2},
  [223] = {.lex_state = 3, .external_lex_state = 2},
  [224] = {.lex_state = 3, .external_lex_state = 2},
  [225] = {.lex_state = 3, .external_lex_state = 2},
  [226] = {.lex_state = 3, .external_lex_state = 2},
  [227] = {.lex_state = 3, .external_lex_state = 2},
  [228] = {.lex_state = 3, .external_lex_state = 2},
  [229] = {.lex_state = 12, .external_lex_state = 2},
  [230] = {.lex_state = 3, .external_lex_state = 2},
  [231] = {.lex_state = 3, .external_lex_state = 2},
  [232] = {.lex_state = 3, .external_lex_state = 2},
  [233] = {.lex_state = 3, .external_lex_state = 2},
  [234] = {.lex_state = 3, .external_lex_state = 2},
  [235] = {.lex_state = 12, .external_lex_state = 2},
  [236] = {.lex_state = 3, .external_lex_state = 2},
  [237] = {.lex_state = 12, .external_lex_state = 2},
  [238] = {.lex_state = 12, .external_lex_state = 2},
  [239] = {.lex_state = 6, .external_lex_state = 2},
  [240] = {.lex_state = 12, .external_lex_state = 2},
  [241] = {.lex_state = 12, .external_lex_state = 2},
  [242] = {.lex_state = 258, .external_lex_state = 5},
  [243] = {.lex_state = 258, .external_lex_state = 2},
  [244] = {.lex_state = 258, .external_lex_state = 5},
  [245] = {.lex_state = 258, .external_lex_state = 5},
  [246] = {.lex_state = 258, .external_lex_state = 2},
  [247] = {.lex_state = 258, .external_lex_state = 5},
  [248] = {.lex_state = 258, .external_lex_state = 5},
  [249] = {.lex_state = 258, .external_lex_state = 5},
  [250] = {.lex_state = 6, .external_lex_state = 2},
  [251] = {.lex_state = 258, .external_lex_state = 5},
  [252] = {.lex_state = 258, .external_lex_state = 5},
  [253] = {.lex_state = 258, .external_lex_state = 5},
  [254] = {.lex_state = 258, .external_lex_state = 5},
  [255] = {.lex_state = 258, .external_lex_state = 5},
  [256] = {.lex_state = 258, .external_lex_state = 5},
  [257] = {.lex_state = 6, .external_lex_state = 2},
  [258] = {.lex_state = 258, .external_lex_state = 5},
  [259] = {.lex_state = 258, .external_lex_state = 5},
  [260] = {.lex_state = 258, .external_lex_state = 5},
  [261] = {.lex_state = 6, .external_lex_state = 2},
  [262] = {.lex_state = 258, .external_lex_state = 5},
  [263] = {.lex_state = 258, .external_lex_state = 2},
  [264] = {.lex_state = 258, .external_lex_state = 5},
  [265] = {.lex_state = 10, .external_lex_state = 2},
  [266] = {.lex_state = 258, .external_lex_state = 2},
  [267] = {.lex_state = 258, .external_lex_state = 5},
  [268] = {.lex_state = 258, .external_lex_state = 5},
  [269] = {.lex_state = 258, .external_lex_state = 2},
  [270] = {.lex_state = 258, .external_lex_state = 2},
  [271] = {.lex_state = 258, .external_lex_state = 5},
  [272] = {.lex_state = 6, .external_lex_state = 2},
  [273] = {.lex_state = 258, .external_lex_state = 2},
  [274] = {.lex_state = 6, .external_lex_state = 2},
  [275] = {.lex_state = 6, .external_lex_state = 2},
  [276] = {.lex_state = 6, .external_lex_state = 2},
  [277] = {.lex_state = 258, .external_lex_state = 2},
  [278] = {.lex_state = 258, .external_lex_state = 2},
  [279] = {.lex_state = 258, .external_lex_state = 2},
  [280] = {.lex_state = 6, .external_lex_state = 2},
  [281] = {.lex_state = 258, .external_lex_state = 5},
  [282] = {.lex_state = 6, .external_lex_state = 2},
  [283] = {.lex_state = 8, .external_lex_state = 2},
  [284] = {.lex_state = 258, .external_lex_state = 5},
  [285] = {.lex_state = 258, .external_lex_state = 5},
  [286] = {.lex_state = 258, .external_lex_state = 5},
  [287] = {.lex_state = 6, .external_lex_state = 2},
  [288] = {.lex_state = 258, .external_lex_state = 2},
  [289] = {.lex_state = 258, .external_lex_state = 2},
  [290] = {.lex_state = 258, .external_lex_state = 5},
  [291] = {.lex_state = 258, .external_lex_state = 2},
  [292] = {.lex_state = 258, .external_lex_state = 5},
  [293] = {.lex_state = 6, .external_lex_state = 2},
  [294] = {.lex_state = 258, .external_lex_state = 5},
  [295] = {.lex_state = 258, .external_lex_state = 2},
  [296] = {.lex_state = 258, .external_lex_state = 2},
  [297] = {.lex_state = 258, .external_lex_state = 5},
  [298] = {.lex_state = 258, .external_lex_state = 5},
  [299] = {.lex_state = 258, .external_lex_state = 5},
  [300] = {.lex_state = 258, .external_lex_state = 5},
  [301] = {.lex_state = 258, .external_lex_state = 2},
  [302] = {.lex_state = 258, .external_lex_state = 5},
  [303] = {.lex_state = 258, .external_lex_state = 5},
  [304] = {.lex_state = 6, .external_lex_state = 2},
  [305] = {.lex_state = 6, .external_lex_state = 2},
  [306] = {.lex_state = 6, .external_lex_state = 2},
  [307] = {.lex_state = 6, .external_lex_state = 2},
  [308] = {.lex_state = 6, .external_lex_state = 2},
  [309] = {.lex_state = 258, .external_lex_state = 5},
  [310] = {.lex_state = 258, .external_lex_state = 5},
  [311] = {.lex_state = 258, .external_lex_state = 5},
  [312] = {.lex_state = 258, .external_lex_state = 2},
  [313] = {.lex_state = 258, .external_lex_state = 2},
  [314] = {.lex_state = 258, .external_lex_state = 2},
  [315] = {.lex_state = 16, .external_lex_state = 2},
  [316] = {.lex_state = 258, .external_lex_state = 2},
  [317] = {.lex_state = 258, .external_lex_state = 2},
  [318] = {.lex_state = 258, .external_lex_state = 2},
  [319] = {.lex_state = 6, .external_lex_state = 2},
  [320] = {.lex_state = 258, .external_lex_state = 2},
  [321] = {.lex_state = 258, .external_lex_state = 2},
  [322] = {.lex_state = 258, .external_lex_state = 2},
  [323] = {.lex_state = 258, .external_lex_state = 2},
  [324] = {.lex_state = 258, .external_lex_state = 2},
  [325] = {.lex_state = 258, .external_lex_state = 2},
  [326] = {.lex_state = 258, .external_lex_state = 2},
  [327] = {.lex_state = 258, .external_lex_state = 2},
  [328] = {.lex_state = 258, .external_lex_state = 2},
  [329] = {.lex_state = 258, .external_lex_state = 2},
  [330] = {.lex_state = 258, .external_lex_state = 2},
  [331] = {.lex_state = 258, .external_lex_state = 2},
  [332] = {.lex_state = 258, .external_lex_state = 2},
  [333] = {.lex_state = 258, .external_lex_state = 2},
  [334] = {.lex_state = 258, .external_lex_state = 2},
  [335] = {.lex_state = 258, .external_lex_state = 2},
  [336] = {.lex_state = 258, .external_lex_state = 2},
  [337] = {.lex_state = 258, .external_lex_state = 2},
  [338] = {.lex_state = 258, .external_lex_state = 2},
  [339] = {.lex_state = 258, .external_lex_state = 2},
  [340] = {.lex_state = 258, .external_lex_state = 2},
  [341] = {.lex_state = 258, .external_lex_state = 2},
  [342] = {.lex_state = 258, .external_lex_state = 2},
  [343] = {.lex_state = 258, .external_lex_state = 2},
  [344] = {.lex_state = 258, .external_lex_state = 2},
  [345] = {.lex_state = 258, .external_lex_state = 2},
  [346] = {.lex_state = 258, .external_lex_state = 2},
  [347] = {.lex_state = 6, .external_lex_state = 2},
  [348] = {.lex_state = 6, .external_lex_state = 2},
  [349] = {.lex_state = 10, .external_lex_state = 2},
  [350] = {.lex_state = 258, .external_lex_state = 2},
  [351] = {.lex_state = 16, .external_lex_state = 2},
  [352] = {.lex_state = 258, .external_lex_state = 5},
  [353] = {.lex_state = 16, .external_lex_state = 2},
  [354] = {.lex_state = 258, .external_lex_state = 5},
  [355] = {.lex_state = 16, .external_lex_state = 2},
  [356] = {.lex_state = 258, .external_lex_state = 2},
  [357] = {.lex_state = 10, .external_lex_state = 2},
  [358] = {.lex_state = 10, .external_lex_state = 2},
  [359] = {.lex_state = 10, .external_lex_state = 2},
  [360] = {.lex_state = 10, .external_lex_state = 2},
  [361] = {.lex_state = 10, .external_lex_state = 2},
  [362] = {.lex_state = 10, .external_lex_state = 2},
  [363] = {.lex_state = 10, .external_lex_state = 2},
  [364] = {.lex_state = 258, .external_lex_state = 5},
  [365] = {.lex_state = 258, .external_lex_state = 5},
  [366] = {.lex_state = 258, .external_lex_state = 5},
  [367] = {.lex_state = 258, .external_lex_state = 5},
  [368] = {.lex_state = 258, .external_lex_state = 2},
  [369] = {.lex_state = 258, .external_lex_state = 5},
  [370] = {.lex_state = 258, .external_lex_state = 5},
  [371] = {.lex_state = 258, .external_lex_state = 2},
  [372] = {.lex_state = 258, .external_lex_state = 2},
  [373] = {.lex_state = 258, .external_lex_state = 2},
  [374] = {.lex_state = 258, .external_lex_state = 2},
  [375] = {.lex_state = 258, .external_lex_state = 2},
  [376] = {.lex_state = 258, .external_lex_state = 2},
  [377] = {.lex_state = 258, .external_lex_state = 2},
  [378] = {.lex_state = 258, .external_lex_state = 2},
  [379] = {.lex_state = 12, .external_lex_state = 2},
  [380] = {.lex_state = 258, .external_lex_state = 2},
  [381] = {.lex_state = 258, .external_lex_state = 2},
  [382] = {.lex_state = 258, .external_lex_state = 2},
  [383] = {.lex_state = 258, .external_lex_state = 2},
  [384] = {.lex_state = 258, .external_lex_state = 2},
  [385] = {.lex_state = 12, .external_lex_state = 2},
  [386] = {.lex_state = 258, .external_lex_state = 2},
  [387] = {.lex_state = 258, .external_lex_state = 2},
  [388] = {.lex_state = 258, .external_lex_state = 2},
  [389] = {.lex_state = 258, .external_lex_state = 2},
  [390] = {.lex_state = 258, .external_lex_state = 5},
  [391] = {.lex_state = 258, .external_lex_state = 2},
  [392] = {.lex_state = 258, .external_lex_state = 2},
  [393] = {.lex_state = 258, .external_lex_state = 2},
  [394] = {.lex_state = 258, .external_lex_state = 2},
  [395] = {.lex_state = 17, .external_lex_state = 2},
  [396] = {.lex_state = 17, .external_lex_state = 2},
  [397] = {.lex_state = 17, .external_lex_state = 2},
  [398] = {.lex_state = 17, .external_lex_state = 2},
  [399] = {.lex_state = 258, .external_lex_state = 2},
  [400] = {.lex_state = 12, .external_lex_state = 2},
  [401] = {.lex_state = 258, .external_lex_state = 2},
  [402] = {.lex_state = 258, .external_lex_state = 2},
  [403] = {.lex_state = 258, .external_lex_state = 2},
  [404] = {.lex_state = 258, .external_lex_state = 2},
  [405] = {.lex_state = 258, .external_lex_state = 2},
  [406] = {.lex_state = 258, .external_lex_state = 2},
  [407] = {.lex_state = 258, .external_lex_state = 2},
  [408] = {.lex_state = 258, .external_lex_state = 2},
  [409] = {.lex_state = 258, .external_lex_state = 2},
  [410] = {.lex_state = 8, .external_lex_state = 2},
  [411] = {.lex_state = 17, .external_lex_state = 2},
  [412] = {.lex_state = 258, .external_lex_state = 2},
  [413] = {.lex_state = 258, .external_lex_state = 2},
  [414] = {.lex_state = 258, .external_lex_state = 2},
  [415] = {.lex_state = 8, .external_lex_state = 2},
  [416] = {.lex_state = 258, .external_lex_state = 2},
  [417] = {.lex_state = 8, .external_lex_state = 2},
  [418] = {.lex_state = 258, .external_lex_state = 2},
  [419] = {.lex_state = 258, .external_lex_state = 2},
  [420] = {.lex_state = 258, .external_lex_state = 2},
  [421] = {.lex_state = 258, .external_lex_state = 2},
  [422] = {.lex_state = 6, .external_lex_state = 2},
  [423] = {.lex_state = 258, .external_lex_state = 2},
  [424] = {.lex_state = 258, .external_lex_state = 2},
  [425] = {.lex_state = 258, .external_lex_state = 2},
  [426] = {.lex_state = 258, .external_lex_state = 2},
  [427] = {.lex_state = 18, .external_lex_state = 6},
  [428] = {.lex_state = 258, .external_lex_state = 2},
  [429] = {.lex_state = 258, .external_lex_state = 2},
  [430] = {.lex_state = 258, .external_lex_state = 2},
  [431] = {.lex_state = 258, .external_lex_state = 5},
  [432] = {.lex_state = 16, .external_lex_state = 2},
  [433] = {.lex_state = 6, .external_lex_state = 2},
  [434] = {.lex_state = 18, .external_lex_state = 7},
  [435] = {.lex_state = 258, .external_lex_state = 5},
  [436] = {.lex_state = 17, .external_lex_state = 2},
  [437] = {.lex_state = 16, .external_lex_state = 2},
  [438] = {.lex_state = 17, .external_lex_state = 2},
  [439] = {.lex_state = 17, .external_lex_state = 2},
  [440] = {.lex_state = 17, .external_lex_state = 2},
  [441] = {.lex_state = 17, .external_lex_state = 2},
  [442] = {.lex_state = 17, .external_lex_state = 2},
  [443] = {.lex_state = 17, .external_lex_state = 2},
  [444] = {.lex_state = 17, .external_lex_state = 2},
  [445] = {.lex_state = 17, .external_lex_state = 2},
  [446] = {.lex_state = 17, .external_lex_state = 2},
  [447] = {.lex_state = 17, .external_lex_state = 5},
  [448] = {.lex_state = 17, .external_lex_state = 5},
  [449] = {.lex_state = 17, .external_lex_state = 2},
  [450] = {.lex_state = 17, .external_lex_state = 2},
  [451] = {.lex_state = 17, .external_lex_state = 5},
  [452] = {.lex_state = 17, .external_lex_state = 5},
  [453] = {.lex_state = 17, .external_lex_state = 2},
  [454] = {.lex_state = 6, .external_lex_state = 2},
  [455] = {.lex_state = 16, .external_lex_state = 2},
  [456] = {.lex_state = 1, .external_lex_state = 2},
  [457] = {.lex_state = 258, .external_lex_state = 2},
  [458] = {.lex_state = 18, .external_lex_state = 7},
  [459] = {.lex_state = 17, .external_lex_state = 5},
  [460] = {.lex_state = 6, .external_lex_state = 2},
  [461] = {.lex_state = 18, .external_lex_state = 6},
  [462] = {.lex_state = 18, .external_lex_state = 8},
  [463] = {.lex_state = 18, .external_lex_state = 6},
  [464] = {.lex_state = 18, .external_lex_state = 7},
  [465] = {.lex_state = 258, .external_lex_state = 2},
  [466] = {.lex_state = 17, .external_lex_state = 2},
  [467] = {.lex_state = 258, .external_lex_state = 2},
  [468] = {.lex_state = 258, .external_lex_state = 2},
  [469] = {.lex_state = 18, .external_lex_state = 6},
  [470] = {.lex_state = 258, .external_lex_state = 2},
  [471] = {.lex_state = 258, .external_lex_state = 2},
  [472] = {.lex_state = 258, .external_lex_state = 2},
  [473] = {.lex_state = 6, .external_lex_state = 2},
  [474] = {.lex_state = 18, .external_lex_state = 6},
  [475] = {.lex_state = 258, .external_lex_state = 2},
  [476] = {.lex_state = 258, .external_lex_state = 2},
  [477] = {.lex_state = 6, .external_lex_state = 2},
  [478] = {.lex_state = 258, .external_lex_state = 5},
  [479] = {.lex_state = 17, .external_lex_state = 2},
  [480] = {.lex_state = 17, .external_lex_state = 2},
  [481] = {.lex_state = 2, .external_lex_state = 2},
  [482] = {.lex_state = 6, .external_lex_state = 2},
  [483] = {.lex_state = 17, .external_lex_state = 2},
  [484] = {.lex_state = 258, .external_lex_state = 5},
  [485] = {.lex_state = 258, .external_lex_state = 5},
  [486] = {.lex_state = 17, .external_lex_state = 5},
  [487] = {.lex_state = 17, .external_lex_state = 5},
  [488] = {.lex_state = 258, .external_lex_state = 5},
  [489] = {.lex_state = 17, .external_lex_state = 5},
  [490] = {.lex_state = 13, .external_lex_state = 2},
  [491] = {.lex_state = 10, .external_lex_state = 2},
  [492] = {.lex_state = 17, .external_lex_state = 5},
  [493] = {.lex_state = 10, .external_lex_state = 2},
  [494] = {.lex_state = 17, .external_lex_state = 5},
  [495] = {.lex_state = 17, .external_lex_state = 5},
  [496] = {.lex_state = 17, .external_lex_state = 5},
  [497] = {.lex_state = 17, .external_lex_state = 5},
  [498] = {.lex_state = 258, .external_lex_state = 2},
  [499] = {.lex_state = 17, .external_lex_state = 5},
  [500] = {.lex_state = 17, .external_lex_state = 5},
  [501] = {.lex_state = 258, .external_lex_state = 2},
  [502] = {.lex_state = 258, .external_lex_state = 2},
  [503] = {.lex_state = 17, .external_lex_state = 5},
  [504] = {.lex_state = 17, .external_lex_state = 5},
  [505] = {.lex_state = 258, .external_lex_state = 5},
  [506] = {.lex_state = 17, .external_lex_state = 5},
  [507] = {.lex_state = 13, .external_lex_state = 2},
  [508] = {.lex_state = 13, .external_lex_state = 2},
  [509] = {.lex_state = 258, .external_lex_state = 2},
  [510] = {.lex_state = 13, .external_lex_state = 2},
  [511] = {.lex_state = 13, .external_lex_state = 2},
  [512] = {.lex_state = 13, .external_lex_state = 2},
  [513] = {.lex_state = 10, .external_lex_state = 2},
  [514] = {.lex_state = 13, .external_lex_state = 2},
  [515] = {.lex_state = 10, .external_lex_state = 2},
  [516] = {.lex_state = 258, .external_lex_state = 5},
  [517] = {.lex_state = 258, .external_lex_state = 5},
  [518] = {.lex_state = 8, .external_lex_state = 2},
  [519] = {.lex_state = 8, .external_lex_state = 2},
  [520] = {.lex_state = 8, .external_lex_state = 2},
  [521] = {.lex_state = 258, .external_lex_state = 2},
  [522] = {.lex_state = 8, .external_lex_state = 2},
  [523] = {.lex_state = 258, .external_lex_state = 2},
  [524] = {.lex_state = 8, .external_lex_state = 2},
  [525] = {.lex_state = 258, .external_lex_state = 5},
  [526] = {.lex_state = 258, .external_lex_state = 2},
  [527] = {.lex_state = 8, .external_lex_state = 2},
  [528] = {.lex_state = 258, .external_lex_state = 5},
  [529] = {.lex_state = 258, .external_lex_state = 5},
  [530] = {.lex_state = 10, .external_lex_state = 2},
  [531] = {.lex_state = 258, .external_lex_state = 5},
  [532] = {.lex_state = 8, .external_lex_state = 2},
  [533] = {.lex_state = 258, .external_lex_state = 2},
  [534] = {.lex_state = 8, .external_lex_state = 2},
  [535] = {.lex_state = 6, .external_lex_state = 2},
  [536] = {.lex_state = 17, .external_lex_state = 2},
  [537] = {.lex_state = 258, .external_lex_state = 5},
  [538] = {.lex_state = 8, .external_lex_state = 2},
  [539] = {.lex_state = 10, .external_lex_state = 2},
  [540] = {.lex_state = 8, .external_lex_state = 2},
  [541] = {.lex_state = 8, .external_lex_state = 2},
  [542] = {.lex_state = 258, .external_lex_state = 2},
  [543] = {.lex_state = 258, .external_lex_state = 5},
  [544] = {.lex_state = 10, .external_lex_state = 2},
  [545] = {.lex_state = 10, .external_lex_state = 2},
  [546] = {.lex_state = 8, .external_lex_state = 2},
  [547] = {.lex_state = 10, .external_lex_state = 2},
  [548] = {.lex_state = 8, .external_lex_state = 2},
  [549] = {.lex_state = 258, .external_lex_state = 5},
  [550] = {.lex_state = 14, .external_lex_state = 2},
  [551] = {.lex_state = 13, .external_lex_state = 2},
  [552] = {.lex_state = 258, .external_lex_state = 2},
  [553] = {.lex_state = 258, .external_lex_state = 2},
  [554] = {.lex_state = 258, .external_lex_state = 2},
  [555] = {.lex_state = 258, .external_lex_state = 2},
  [556] = {.lex_state = 258, .external_lex_state = 5},
  [557] = {.lex_state = 6, .external_lex_state = 2},
  [558] = {.lex_state = 6, .external_lex_state = 2},
  [559] = {.lex_state = 258, .external_lex_state = 5},
  [560] = {.lex_state = 258, .external_lex_state = 2},
  [561] = {.lex_state = 258, .external_lex_state = 2},
  [562] = {.lex_state = 258, .external_lex_state = 2},
  [563] = {.lex_state = 258, .external_lex_state = 2},
  [564] = {.lex_state = 258, .external_lex_state = 5},
  [565] = {.lex_state = 258, .external_lex_state = 5},
  [566] = {.lex_state = 258, .external_lex_state = 5},
  [567] = {.lex_state = 18, .external_lex_state = 9},
  [568] = {.lex_state = 258, .external_lex_state = 2},
  [569] = {.lex_state = 258, .external_lex_state = 2},
  [570] = {.lex_state = 6, .external_lex_state = 2},
  [571] = {.lex_state = 13, .external_lex_state = 2},
  [572] = {.lex_state = 6, .external_lex_state = 2},
  [573] = {.lex_state = 258, .external_lex_state = 2},
  [574] = {.lex_state = 16, .external_lex_state = 2},
  [575] = {.lex_state = 13, .external_lex_state = 2},
  [576] = {.lex_state = 14, .external_lex_state = 2},
  [577] = {.lex_state = 6, .external_lex_state = 2},
  [578] = {.lex_state = 258, .external_lex_state = 2},
  [579] = {.lex_state = 258, .external_lex_state = 2},
  [580] = {.lex_state = 14, .external_lex_state = 2},
  [581] = {.lex_state = 258, .external_lex_state = 2},
  [582] = {.lex_state = 17, .external_lex_state = 2},
  [583] = {.lex_state = 6, .external_lex_state = 2},
  [584] = {.lex_state = 258, .external_lex_state = 2},
  [585] = {.lex_state = 6, .external_lex_state = 2},
  [586] = {.lex_state = 6, .external_lex_state = 2},
  [587] = {.lex_state = 18, .external_lex_state = 9},
  [588] = {.lex_state = 14, .external_lex_state = 2},
  [589] = {.lex_state = 14, .external_lex_state = 2},
  [590] = {.lex_state = 258, .external_lex_state = 2},
  [591] = {.lex_state = 258, .external_lex_state = 2},
  [592] = {.lex_state = 14, .external_lex_state = 2},
  [593] = {.lex_state = 258, .external_lex_state = 5},
  [594] = {.lex_state = 258, .external_lex_state = 2},
  [595] = {.lex_state = 14, .external_lex_state = 2},
  [596] = {.lex_state = 258, .external_lex_state = 5},
  [597] = {.lex_state = 258, .external_lex_state = 5},
  [598] = {.lex_state = 14, .external_lex_state = 2},
  [599] = {.lex_state = 14, .external_lex_state = 2},
  [600] = {.lex_state = 14, .external_lex_state = 2},
  [601] = {.lex_state = 258, .external_lex_state = 2},
  [602] = {.lex_state = 18, .external_lex_state = 9},
  [603] = {.lex_state = 14, .external_lex_state = 2},
  [604] = {.lex_state = 258, .external_lex_state = 2},
  [605] = {.lex_state = 258, .external_lex_state = 5},
  [606] = {.lex_state = 258, .external_lex_state = 2},
  [607] = {.lex_state = 13, .external_lex_state = 2},
  [608] = {.lex_state = 258, .external_lex_state = 2},
  [609] = {.lex_state = 258, .external_lex_state = 5},
  [610] = {.lex_state = 258, .external_lex_state = 2},
  [611] = {.lex_state = 258, .external_lex_state = 2},
  [612] = {.lex_state = 10, .external_lex_state = 2},
  [613] = {.lex_state = 258, .external_lex_state = 2},
  [614] = {.lex_state = 258, .external_lex_state = 2},
  [615] = {.lex_state = 258, .external_lex_state = 2},
  [616] = {.lex_state = 258, .external_lex_state = 2},
  [617] = {.lex_state = 258, .external_lex_state = 5},
  [618] = {.lex_state = 258, .external_lex_state = 2},
  [619] = {.lex_state = 258, .external_lex_state = 2},
  [620] = {.lex_state = 258, .external_lex_state = 2},
  [621] = {.lex_state = 17, .external_lex_state = 2},
  [622] = {.lex_state = 258, .external_lex_state = 2},
  [623] = {.lex_state = 10, .external_lex_state = 2},
  [624] = {.lex_state = 6, .external_lex_state = 2},
  [625] = {.lex_state = 16, .external_lex_state = 2},
  [626] = {.lex_state = 18, .external_lex_state = 2},
  [627] = {.lex_state = 10, .external_lex_state = 2},
  [628] = {.lex_state = 258, .external_lex_state = 2},
  [629] = {.lex_state = 258, .external_lex_state = 2},
  [630] = {.lex_state = 258, .external_lex_state = 2},
  [631] = {.lex_state = 6, .external_lex_state = 2},
  [632] = {.lex_state = 18, .external_lex_state = 2},
  [633] = {.lex_state = 258, .external_lex_state = 2},
  [634] = {.lex_state = 3, .external_lex_state = 2},
  [635] = {.lex_state = 3, .external_lex_state = 2},
  [636] = {.lex_state = 10, .external_lex_state = 2},
  [637] = {.lex_state = 18, .external_lex_state = 2},
  [638] = {.lex_state = 258, .external_lex_state = 2},
  [639] = {.lex_state = 258, .external_lex_state = 2},
  [640] = {.lex_state = 258, .external_lex_state = 2},
  [641] = {.lex_state = 258, .external_lex_state = 2},
  [642] = {.lex_state = 258, .external_lex_state = 2},
  [643] = {.lex_state = 258, .external_lex_state = 2},
  [644] = {.lex_state = 258, .external_lex_state = 2},
  [645] = {.lex_state = 258, .external_lex_state = 2},
  [646] = {.lex_state = 258, .external_lex_state = 2},
  [647] = {.lex_state = 258, .external_lex_state = 2},
  [648] = {.lex_state = 258, .external_lex_state = 2},
  [649] = {.lex_state = 258, .external_lex_state = 2},
  [650] = {.lex_state = 6, .external_lex_state = 2},
  [651] = {.lex_state = 258, .external_lex_state = 2},
  [652] = {.lex_state = 258, .external_lex_state = 2},
  [653] = {.lex_state = 258, .external_lex_state = 2},
  [654] = {.lex_state = 258, .external_lex_state = 2},
  [655] = {.lex_state = 10, .external_lex_state = 2},
  [656] = {.lex_state = 258, .external_lex_state = 2},
  [657] = {.lex_state = 3, .external_lex_state = 2},
  [658] = {.lex_state = 6, .external_lex_state = 2},
  [659] = {.lex_state = 18, .external_lex_state = 10},
  [660] = {.lex_state = 258, .external_lex_state = 2},
  [661] = {.lex_state = 6, .external_lex_state = 2},
  [662] = {.lex_state = 258, .external_lex_state = 2},
  [663] = {.lex_state = 8, .external_lex_state = 2},
  [664] = {.lex_state = 258, .external_lex_state = 2},
  [665] = {.lex_state = 3, .external_lex_state = 2},
  [666] = {.lex_state = 10, .external_lex_state = 2},
  [667] = {.lex_state = 258, .external_lex_state = 2},
  [668] = {.lex_state = 258, .external_lex_state = 2},
  [669] = {.lex_state = 258, .external_lex_state = 2},
  [670] = {.lex_state = 258, .external_lex_state = 2},
  [671] = {.lex_state = 258, .external_lex_state = 2},
  [672] = {.lex_state = 258, .external_lex_state = 5},
  [673] = {.lex_state = 258, .external_lex_state = 2},
  [674] = {.lex_state = 258, .external_lex_state = 2},
  [675] = {.lex_state = 258, .external_lex_state = 2},
  [676] = {.lex_state = 258, .external_lex_state = 2},
  [677] = {.lex_state = 258, .external_lex_state = 5},
  [678] = {.lex_state = 258, .external_lex_state = 2},
  [679] = {.lex_state = 258, .external_lex_state = 2},
  [680] = {.lex_state = 258, .external_lex_state = 2},
  [681] = {.lex_state = 258, .external_lex_state = 2},
  [682] = {.lex_state = 258, .external_lex_state = 2},
  [683] = {.lex_state = 258, .external_lex_state = 2},
  [684] = {.lex_state = 258, .external_lex_state = 2},
  [685] = {.lex_state = 258, .external_lex_state = 2},
  [686] = {.lex_state = 258, .external_lex_state = 2},
  [687] = {.lex_state = 6, .external_lex_state = 2},
  [688] = {.lex_state = 258, .external_lex_state = 2},
  [689] = {.lex_state = 258, .external_lex_state = 5},
  [690] = {.lex_state = 258, .external_lex_state = 2},
  [691] = {.lex_state = 258, .external_lex_state = 5},
  [692] = {.lex_state = 258, .external_lex_state = 2},
  [693] = {.lex_state = 258, .external_lex_state = 2},
  [694] = {.lex_state = 258, .external_lex_state = 2},
  [695] = {.lex_state = 258, .external_lex_state = 2},
  [696] = {.lex_state = 258, .external_lex_state = 5},
  [697] = {.lex_state = 258, .external_lex_state = 2},
  [698] = {.lex_state = 258, .external_lex_state = 2},
  [699] = {.lex_state = 258, .external_lex_state = 2},
  [700] = {.lex_state = 258, .external_lex_state = 2},
  [701] = {.lex_state = 258, .external_lex_state = 2},
  [702] = {.lex_state = 258, .external_lex_state = 2},
  [703] = {.lex_state = 258, .external_lex_state = 2},
  [704] = {.lex_state = 258, .external_lex_state = 2},
  [705] = {.lex_state = 258, .external_lex_state = 2},
  [706] = {.lex_state = 258, .external_lex_state = 2},
  [707] = {.lex_state = 258, .external_lex_state = 2},
  [708] = {.lex_state = 3, .external_lex_state = 2},
  [709] = {.lex_state = 258, .external_lex_state = 2},
  [710] = {.lex_state = 258, .external_lex_state = 2},
  [711] = {.lex_state = 6, .external_lex_state = 2},
  [712] = {.lex_state = 16, .external_lex_state = 2},
  [713] = {.lex_state = 258, .external_lex_state = 2},
  [714] = {.lex_state = 258, .external_lex_state = 2},
  [715] = {.lex_state = 258, .external_lex_state = 2},
  [716] = {.lex_state = 10, .external_lex_state = 2},
  [717] = {.lex_state = 258, .external_lex_state = 2},
  [718] = {.lex_state = 258, .external_lex_state = 5},
  [719] = {.lex_state = 10, .external_lex_state = 2},
  [720] = {.lex_state = 10, .external_lex_state = 2},
  [721] = {.lex_state = 258, .external_lex_state = 2},
  [722] = {.lex_state = 258, .external_lex_state = 2},
  [723] = {.lex_state = 258, .external_lex_state = 5},
  [724] = {.lex_state = 258, .external_lex_state = 2},
  [725] = {.lex_state = 258, .external_lex_state = 2},
  [726] = {.lex_state = 258, .external_lex_state = 2},
  [727] = {.lex_state = 258, .external_lex_state = 2},
  [728] = {.lex_state = 258, .external_lex_state = 2},
  [729] = {.lex_state = 258, .external_lex_state = 2},
  [730] = {.lex_state = 258, .external_lex_state = 2},
  [731] = {.lex_state = 258, .external_lex_state = 2},
  [732] = {.lex_state = 258, .external_lex_state = 2},
  [733] = {.lex_state = 258, .external_lex_state = 2},
  [734] = {.lex_state = 258, .external_lex_state = 2},
  [735] = {.lex_state = 258, .external_lex_state = 5},
  [736] = {.lex_state = 258, .external_lex_state = 2},
  [737] = {.lex_state = 6, .external_lex_state = 2},
  [738] = {.lex_state = 258, .external_lex_state = 2},
  [739] = {.lex_state = 258, .external_lex_state = 2},
  [740] = {.lex_state = 258, .external_lex_state = 2},
  [741] = {.lex_state = 258, .external_lex_state = 2},
  [742] = {.lex_state = 18, .external_lex_state = 2},
  [743] = {.lex_state = 18, .external_lex_state = 9},
  [744] = {.lex_state = 258, .external_lex_state = 2},
  [745] = {.lex_state = 258, .external_lex_state = 2},
  [746] = {.lex_state = 258, .external_lex_state = 2},
  [747] = {.lex_state = 258, .external_lex_state = 2},
  [748] = {.lex_state = 258, .external_lex_state = 2},
  [749] = {.lex_state = 258, .external_lex_state = 5},
  [750] = {.lex_state = 258, .external_lex_state = 2},
  [751] = {.lex_state = 17, .external_lex_state = 2},
  [752] = {.lex_state = 6, .external_lex_state = 2},
  [753] = {.lex_state = 258, .external_lex_state = 2},
  [754] = {.lex_state = 6, .external_lex_state = 2},
  [755] = {.lex_state = 258, .external_lex_state = 2},
  [756] = {.lex_state = 258, .external_lex_state = 2},
  [757] = {.lex_state = 258, .external_lex_state = 2},
  [758] = {.lex_state = 6, .external_lex_state = 2},
  [759] = {.lex_state = 258, .external_lex_state = 2},
  [760] = {.lex_state = 258, .external_lex_state = 5},
  [761] = {.lex_state = 258, .external_lex_state = 2},
  [762] = {.lex_state = 258, .external_lex_state = 2},
  [763] = {.lex_state = 258, .external_lex_state = 2},
  [764] = {.lex_state = 258, .external_lex_state = 2},
  [765] = {.lex_state = 258, .external_lex_state = 5},
  [766] = {.lex_state = 16, .external_lex_state = 2},
  [767] = {.lex_state = 258, .external_lex_state = 5},
  [768] = {.lex_state = 10, .external_lex_state = 2},
  [769] = {.lex_state = 258, .external_lex_state = 2},
  [770] = {.lex_state = 258, .external_lex_state = 2},
  [771] = {.lex_state = 258, .external_lex_state = 2},
  [772] = {.lex_state = 258, .external_lex_state = 2},
  [773] = {.lex_state = 258, .external_lex_state = 2},
  [774] = {.lex_state = 258, .external_lex_state = 2},
  [775] = {.lex_state = 258, .external_lex_state = 2},
  [776] = {.lex_state = 258, .external_lex_state = 2},
  [777] = {.lex_state = 258, .external_lex_state = 2},
  [778] = {.lex_state = 258, .external_lex_state = 2},
  [779] = {.lex_state = 258, .external_lex_state = 2},
  [780] = {.lex_state = 10, .external_lex_state = 2},
  [781] = {.lex_state = 258, .external_lex_state = 2},
  [782] = {.lex_state = 258, .external_lex_state = 2},
  [783] = {.lex_state = 3, .external_lex_state = 2},
  [784] = {.lex_state = 258, .external_lex_state = 2},
  [785] = {.lex_state = 258, .external_lex_state = 2},
  [786] = {.lex_state = 258, .external_lex_state = 2},
  [787] = {.lex_state = 258, .external_lex_state = 2},
  [788] = {.lex_state = 258, .external_lex_state = 2},
  [789] = {.lex_state = 258, .external_lex_state = 2},
  [790] = {.lex_state = 258, .external_lex_state = 2},
  [791] = {.lex_state = 258, .external_lex_state = 2},
  [792] = {.lex_state = 258, .external_lex_state = 2},
  [793] = {.lex_state = 258, .external_lex_state = 2},
  [794] = {.lex_state = 3, .external_lex_state = 2},
  [795] = {.lex_state = 258, .external_lex_state = 2},
  [796] = {.lex_state = 258, .external_lex_state = 5},
  [797] = {.lex_state = 258, .external_lex_state = 5},
  [798] = {.lex_state = 19, .external_lex_state = 2},
  [799] = {.lex_state = 258, .external_lex_state = 5},
  [800] = {.lex_state = 258, .external_lex_state = 2},
  [801] = {.lex_state = 258, .external_lex_state = 2},
  [802] = {.lex_state = 258, .external_lex_state = 2},
  [803] = {.lex_state = 258, .external_lex_state = 2},
  [804] = {.lex_state = 258, .external_lex_state = 2},
  [805] = {.lex_state = 10, .external_lex_state = 2},
  [806] = {.lex_state = 258, .external_lex_state = 2},
  [807] = {.lex_state = 258, .external_lex_state = 2},
  [808] = {.lex_state = 258, .external_lex_state = 2},
  [809] = {.lex_state = 3, .external_lex_state = 2},
  [810] = {.lex_state = 258, .external_lex_state = 2},
  [811] = {.lex_state = 258, .external_lex_state = 2},
  [812] = {.lex_state = 16, .external_lex_state = 2},
  [813] = {.lex_state = 258, .external_lex_state = 2},
  [814] = {.lex_state = 258, .external_lex_state = 2},
  [815] = {.lex_state = 258, .external_lex_state = 2},
  [816] = {.lex_state = 258, .external_lex_state = 2},
  [817] = {.lex_state = 258, .external_lex_state = 2},
  [818] = {.lex_state = 272, .external_lex_state = 2},
  [819] = {.lex_state = 258, .external_lex_state = 2},
  [820] = {.lex_state = 258, .external_lex_state = 2},
  [821] = {.lex_state = 3, .external_lex_state = 2},
  [822] = {.lex_state = 258, .external_lex_state = 2},
  [823] = {.lex_state = 258, .external_lex_state = 2},
  [824] = {.lex_state = 258, .external_lex_state = 2},
  [825] = {.lex_state = 258, .external_lex_state = 2},
  [826] = {.lex_state = 18, .external_lex_state = 2},
  [827] = {.lex_state = 258, .external_lex_state = 2},
  [828] = {.lex_state = 258, .external_lex_state = 2},
  [829] = {.lex_state = 272, .external_lex_state = 2},
  [830] = {.lex_state = 258, .external_lex_state = 2},
  [831] = {.lex_state = 258, .external_lex_state = 2},
  [832] = {.lex_state = 3, .external_lex_state = 2},
  [833] = {.lex_state = 3, .external_lex_state = 2},
  [834] = {.lex_state = 18, .external_lex_state = 2},
  [835] = {.lex_state = 258, .external_lex_state = 2},
  [836] = {.lex_state = 16, .external_lex_state = 2},
  [837] = {.lex_state = 6, .external_lex_state = 2},
  [838] = {.lex_state = 258, .external_lex_state = 5},
  [839] = {.lex_state = 258, .external_lex_state = 2},
  [840] = {.lex_state = 6, .external_lex_state = 2},
  [841] = {.lex_state = 258, .external_lex_state = 2},
  [842] = {.lex_state = 258, .external_lex_state = 2},
  [843] = {.lex_state = 16, .external_lex_state = 2},
  [844] = {.lex_state = 16, .external_lex_state = 2},
  [845] = {.lex_state = 258, .external_lex_state = 2},
  [846] = {.lex_state = 258, .external_lex_state = 2},
  [847] = {.lex_state = 258, .external_lex_state = 2},
  [848] = {.lex_state = 6, .external_lex_state = 2},
  [849] = {.lex_state = 258, .external_lex_state = 2},
  [850] = {.lex_state = 272, .external_lex_state = 2},
  [851] = {.lex_state = 3, .external_lex_state = 2},
  [852] = {.lex_state = 315, .external_lex_state = 2},
  [853] = {.lex_state = 258, .external_lex_state = 2},
  [854] = {.lex_state = 258, .external_lex_state = 2},
  [855] = {.lex_state = 258, .external_lex_state = 2},
  [856] = {.lex_state = 258, .external_lex_state = 2},
  [857] = {.lex_state = 258, .external_lex_state = 2},
  [858] = {.lex_state = 258, .external_lex_state = 2},
  [859] = {.lex_state = 258, .external_lex_state = 2},
  [860] = {.lex_state = 258, .external_lex_state = 2},
  [861] = {.lex_state = 3, .external_lex_state = 2},
  [862] = {.lex_state = 258, .external_lex_state = 2},
  [863] = {.lex_state = 258, .external_lex_state = 2},
  [864] = {.lex_state = 3, .external_lex_state = 2},
  [865] = {.lex_state = 3, .external_lex_state = 2},
  [866] = {.lex_state = 6, .external_lex_state = 2},
  [867] = {.lex_state = 258, .external_lex_state = 2},
  [868] = {.lex_state = 258, .external_lex_state = 2},
  [869] = {.lex_state = 3, .external_lex_state = 2},
  [870] = {.lex_state = 258, .external_lex_state = 2},
  [871] = {.lex_state = 258, .external_lex_state = 5},
  [872] = {.lex_state = 272, .external_lex_state = 2},
  [873] = {.lex_state = 258, .external_lex_state = 2},
  [874] = {.lex_state = 3, .external_lex_state = 2},
  [875] = {.lex_state = 3, .external_lex_state = 2},
  [876] = {.lex_state = 258, .external_lex_state = 2},
  [877] = {.lex_state = 258, .external_lex_state = 2},
  [878] = {.lex_state = 258, .external_lex_state = 2},
  [879] = {.lex_state = 258, .external_lex_state = 2},
  [880] = {.lex_state = 258, .external_lex_state = 2},
  [881] = {.lex_state = 18, .external_lex_state = 2},
  [882] = {.lex_state = 258, .external_lex_state = 2},
  [883] = {.lex_state = 6, .external_lex_state = 2},
  [884] = {.lex_state = 258, .external_lex_state = 2},
  [885] = {.lex_state = 258, .external_lex_state = 2},
  [886] = {.lex_state = 16, .external_lex_state = 2},
  [887] = {.lex_state = 258, .external_lex_state = 2},
  [888] = {.lex_state = 258, .external_lex_state = 2},
  [889] = {.lex_state = 258, .external_lex_state = 2},
  [890] = {.lex_state = 258, .external_lex_state = 2},
  [891] = {.lex_state = 272, .external_lex_state = 2},
  [892] = {.lex_state = 6, .external_lex_state = 2},
  [893] = {.lex_state = 16, .external_lex_state = 2},
  [894] = {.lex_state = 258, .external_lex_state = 2},
  [895] = {.lex_state = 10, .external_lex_state = 2},
  [896] = {.lex_state = 16, .external_lex_state = 2},
  [897] = {.lex_state = 258, .external_lex_state = 2},
  [898] = {.lex_state = 258, .external_lex_state = 2},
  [899] = {.lex_state = 258, .external_lex_state = 2},
  [900] = {.lex_state = 258, .external_lex_state = 2},
  [901] = {.lex_state = 6, .external_lex_state = 2},
  [902] = {.lex_state = 258, .external_lex_state = 2},
  [903] = {.lex_state = 258, .external_lex_state = 2},
  [904] = {.lex_state = 404, .external_lex_state = 2},
  [905] = {.lex_state = 272, .external_lex_state = 2},
  [906] = {.lex_state = 258, .external_lex_state = 2},
  [907] = {.lex_state = 258, .external_lex_state = 2},
  [908] = {.lex_state = 3, .external_lex_state = 2},
  [909] = {.lex_state = 3, .external_lex_state = 2},
  [910] = {.lex_state = 258, .external_lex_state = 2},
  [911] = {.lex_state = 258, .external_lex_state = 2},
  [912] = {.lex_state = 6, .external_lex_state = 2},
  [913] = {.lex_state = 258, .external_lex_state = 2},
  [914] = {.lex_state = 258, .external_lex_state = 2},
  [915] = {.lex_state = 258, .external_lex_state = 2},
  [916] = {.lex_state = 258, .external_lex_state = 2},
  [917] = {.lex_state = 258, .external_lex_state = 2},
  [918] = {.lex_state = 258, .external_lex_state = 2},
  [919] = {.lex_state = 272, .external_lex_state = 2},
  [920] = {.lex_state = 258, .external_lex_state = 2},
  [921] = {.lex_state = 258, .external_lex_state = 2},
  [922] = {.lex_state = 272, .external_lex_state = 2},
  [923] = {.lex_state = 272, .external_lex_state = 2},
  [924] = {.lex_state = 258, .external_lex_state = 2},
  [925] = {.lex_state = 258, .external_lex_state = 2},
  [926] = {.lex_state = 258, .external_lex_state = 2},
  [927] = {.lex_state = 3, .external_lex_state = 2},
  [928] = {.lex_state = 6, .external_lex_state = 2},
  [929] = {.lex_state = 6, .external_lex_state = 2},
  [930] = {.lex_state = 6, .external_lex_state = 2},
  [931] = {.lex_state = 258, .external_lex_state = 2},
  [932] = {.lex_state = 272, .external_lex_state = 2},
  [933] = {.lex_state = 6, .external_lex_state = 2},
  [934] = {.lex_state = 258, .external_lex_state = 2},
  [935] = {.lex_state = 258, .external_lex_state = 2},
  [936] = {.lex_state = 3, .external_lex_state = 2},
  [937] = {.lex_state = 258, .external_lex_state = 2},
  [938] = {.lex_state = 258, .external_lex_state = 2},
  [939] = {.lex_state = 258, .external_lex_state = 2},
  [940] = {.lex_state = 258, .external_lex_state = 2},
  [941] = {.lex_state = 258, .external_lex_state = 2},
  [942] = {.lex_state = 258, .external_lex_state = 2},
  [943] = {.lex_state = 10, .external_lex_state = 2},
  [944] = {.lex_state = 258, .external_lex_state = 2},
  [945] = {.lex_state = 258, .external_lex_state = 2},
  [946] = {.lex_state = 258, .external_lex_state = 2},
  [947] = {.lex_state = 258, .external_lex_state = 2},
  [948] = {.lex_state = 258, .external_lex_state = 2},
  [949] = {.lex_state = 258, .external_lex_state = 2},
  [950] = {.lex_state = 258, .external_lex_state = 2},
  [951] = {.lex_state = 258, .external_lex_state = 2},
  [952] = {.lex_state = 258, .external_lex_state = 2},
  [953] = {.lex_state = 258, .external_lex_state = 2},
  [954] = {.lex_state = 258, .external_lex_state = 2},
  [955] = {.lex_state = 258, .external_lex_state = 2},
  [956] = {.lex_state = 3, .external_lex_state = 2},
  [957] = {.lex_state = 258, .external_lex_state = 2},
  [958] = {.lex_state = 6, .external_lex_state = 2},
  [959] = {.lex_state = 258, .external_lex_state = 2},
  [960] = {.lex_state = 258, .external_lex_state = 2},
  [961] = {.lex_state = 258, .external_lex_state = 2},
  [962] = {.lex_state = 258, .external_lex_state = 2},
  [963] = {.lex_state = 272, .external_lex_state = 2},
  [964] = {.lex_state = 258, .external_lex_state = 5},
  [965] = {.lex_state = 258, .external_lex_state = 2},
  [966] = {.lex_state = 6, .external_lex_state = 2},
  [967] = {.lex_state = 258, .external_lex_state = 2},
  [968] = {.lex_state = 258, .external_lex_state = 2},
  [969] = {.lex_state = 258, .external_lex_state = 2},
  [970] = {.lex_state = 258, .external_lex_state = 2},
  [971] = {.lex_state = 258, .external_lex_state = 2},
  [972] = {.lex_state = 258, .external_lex_state = 2},
  [973] = {.lex_state = 258, .external_lex_state = 2},
  [974] = {.lex_state = 258, .external_lex_state = 2},
  [975] = {.lex_state = 258, .external_lex_state = 2},
  [976] = {.lex_state = 258, .external_lex_state = 5},
  [977] = {.lex_state = 6, .external_lex_state = 2},
  [978] = {.lex_state = 258, .external_lex_state = 2},
  [979] = {.lex_state = 6, .external_lex_state = 2},
  [980] = {.lex_state = 258, .external_lex_state = 5},
  [981] = {.lex_state = 6, .external_lex_state = 2},
  [982] = {.lex_state = 258, .external_lex_state = 2},
  [983] = {.lex_state = 6, .external_lex_state = 2},
  [984] = {.lex_state = 258, .external_lex_state = 2},
  [985] = {.lex_state = 3, .external_lex_state = 2},
  [986] = {.lex_state = 258, .external_lex_state = 2},
  [987] = {.lex_state = 258, .external_lex_state = 2},
  [988] = {.lex_state = 258, .external_lex_state = 2},
  [989] = {.lex_state = 258, .external_lex_state = 2},
  [990] = {.lex_state = 258, .external_lex_state = 2},
  [991] = {.lex_state = 3, .external_lex_state = 2},
  [992] = {.lex_state = 258, .external_lex_state = 2},
  [993] = {.lex_state = 258, .external_lex_state = 2},
  [994] = {.lex_state = 258, .external_lex_state = 2},
  [995] = {.lex_state = 258, .external_lex_state = 2},
  [996] = {.lex_state = 258, .external_lex_state = 5},
  [997] = {.lex_state = 258, .external_lex_state = 2},
  [998] = {.lex_state = 258, .external_lex_state = 2},
  [999] = {.lex_state = 258, .external_lex_state = 2},
  [1000] = {.lex_state = 258, .external_lex_state = 2},
  [1001] = {.lex_state = 258, .external_lex_state = 2},
  [1002] = {.lex_state = 258, .external_lex_state = 2},
  [1003] = {.lex_state = 258, .external_lex_state = 2},
  [1004] = {.lex_state = 258, .external_lex_state = 2},
  [1005] = {.lex_state = 6, .external_lex_state = 2},
  [1006] = {.lex_state = 6, .external_lex_state = 2},
  [1007] = {.lex_state = 272, .external_lex_state = 2},
  [1008] = {.lex_state = 258, .external_lex_state = 2},
  [1009] = {.lex_state = 258, .external_lex_state = 2},
  [1010] = {.lex_state = 258, .external_lex_state = 2},
  [1011] = {.lex_state = 258, .external_lex_state = 2},
  [1012] = {.lex_state = 258, .external_lex_state = 2},
  [1013] = {.lex_state = 258, .external_lex_state = 2},
  [1014] = {.lex_state = 258, .external_lex_state = 2},
  [1015] = {.lex_state = 258, .external_lex_state = 2},
  [1016] = {.lex_state = 258, .external_lex_state = 2},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [sym_line_comment] = ACTIONS(3),
    [anon_sym_PERCENT_STAR_BANG] = ACTIONS(1),
    [sym_doc_var] = ACTIONS(1),
    [sym_doc_fragment_code] = ACTIONS(1),
    [anon_sym_DQUOTE] = ACTIONS(1),
    [anon_sym_f_DQUOTE] = ACTIONS(1),
    [aux_sym_fstring_accessor_token2] = ACTIONS(1),
    [aux_sym_fstring_accessor_token3] = ACTIONS(1),
    [aux_sym_fstring_accessor_token4] = ACTIONS(1),
    [aux_sym_fstring_conversion_token1] = ACTIONS(1),
    [sym_fstring_alternate] = ACTIONS(1),
    [sym_fstring_grouping] = ACTIONS(1),
    [sym_fstring_type] = ACTIONS(1),
    [aux_sym_fstring_spec_token1] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [sym_infimum] = ACTIONS(1),
    [sym_anonymous] = ACTIONS(1),
    [sym_variable] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_BSLASH] = ACTIONS(1),
    [anon_sym_STAR_STAR] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_COMMA2] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN2] = ACTIONS(1),
    [anon_sym_DOT_DOT] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_AT] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_RBRACE2] = ACTIONS(1),
    [sym_boolean_constant] = ACTIONS(1),
    [sym_relation] = ACTIONS(1),
    [sym_default_negation] = ACTIONS(1),
    [sym_double_default_negation] = ACTIONS(1),
    [anon_sym_DOT] = ACTIONS(1),
    [anon_sym_POUNDmaximize] = ACTIONS(1),
    [anon_sym_POUNDmaximise] = ACTIONS(1),
    [anon_sym_POUNDminimize] = ACTIONS(1),
    [anon_sym_POUNDminimise] = ACTIONS(1),
    [anon_sym_true] = ACTIONS(1),
    [anon_sym_false] = ACTIONS(1),
    [anon_sym_POUNDproject] = ACTIONS(1),
    [anon_sym_POUNDprogram] = ACTIONS(1),
    [anon_sym_POUNDend] = ACTIONS(1),
    [sym_const_type] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_POUNDedge] = ACTIONS(1),
    [anon_sym_POUNDheuristic] = ACTIONS(1),
    [anon_sym_POUNDinclude] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_POUNDexternal] = ACTIONS(1),
    [sym_theory_operator_arity] = ACTIONS(1),
    [anon_sym_binary] = ACTIONS(1),
    [sym_theory_operator_associativity] = ACTIONS(1),
    [sym_theory_atom_type] = ACTIONS(1),
    [anon_sym_POUNDtheory] = ACTIONS(1),
    [anon_sym_POUNDtype] = ACTIONS(1),
    [anon_sym_expressions] = ACTIONS(1),
    [anon_sym_COLON2] = ACTIONS(1),
    [anon_sym_subtypes] = ACTIONS(1),
    [anon_sym_macros] = ACTIONS(1),
    [anon_sym_where] = ACTIONS(1),
    [anon_sym_occurrence] = ACTIONS(1),
    [sym_empty_pool_item_first] = ACTIONS(1),
    [sym_empty_pool_item] = ACTIONS(1),
    [sym_colon] = ACTIONS(1),
    [sym_block_comment] = ACTIONS(5),
    [sym_doc_fragment_string] = ACTIONS(1),
    [sym__doc_token_args] = ACTIONS(1),
    [sym__doc_token_paren] = ACTIONS(1),
    [sym__doc_token_minus] = ACTIONS(1),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(839),
    [sym_doc_comment] = STATE(36),
    [sym_string] = STATE(224),
    [sym_fstring] = STATE(224),
    [sym_binary_operation] = STATE(224),
    [sym_unary_operation] = STATE(224),
    [sym_abs] = STATE(224),
    [sym_function] = STATE(224),
    [sym_external_function] = STATE(224),
    [sym_tuple] = STATE(224),
    [sym_term] = STATE(386),
    [sym_symbolic_atom] = STATE(478),
    [sym_comparison] = STATE(478),
    [sym_simple_atom] = STATE(485),
    [sym_literal_sign] = STATE(117),
    [sym_literal] = STATE(505),
    [sym_lower] = STATE(775),
    [sym_set_aggregate] = STATE(781),
    [sym_theory_atom] = STATE(781),
    [sym_head_aggregate] = STATE(781),
    [sym__conditional_literal_n] = STATE(606),
    [sym__conditional_literal_0] = STATE(682),
    [sym_conditional_literal] = STATE(777),
    [sym_disjunction] = STATE(781),
    [sym_head] = STATE(778),
    [sym_rule] = STATE(36),
    [sym_integrity_constraint] = STATE(36),
    [sym_weak_constraint] = STATE(36),
    [sym_maximize] = STATE(36),
    [sym_minimize] = STATE(36),
    [sym_show] = STATE(36),
    [sym_show_term] = STATE(21),
    [sym_show_signature] = STATE(23),
    [sym_defined] = STATE(36),
    [sym_project_signature] = STATE(36),
    [sym_project_atom] = STATE(36),
    [sym_program] = STATE(36),
    [sym_script] = STATE(36),
    [sym_const] = STATE(36),
    [sym_edge] = STATE(36),
    [sym_heuristic] = STATE(36),
    [sym_include] = STATE(36),
    [sym_external] = STATE(36),
    [sym_theory] = STATE(36),
    [sym__metasp_identifier] = STATE(242),
    [sym_metasp_symbolic_atom] = STATE(478),
    [sym_metasp_function] = STATE(224),
    [sym_metasp_type] = STATE(36),
    [sym_statement] = STATE(3),
    [aux_sym_source_file_repeat1] = STATE(3),
    [aux_sym_disjunction_repeat1] = STATE(75),
    [ts_builtin_sym_end] = ACTIONS(7),
    [sym_line_comment] = ACTIONS(3),
    [anon_sym_PERCENT_STAR_BANG] = ACTIONS(9),
    [sym_identifier] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_f_DQUOTE] = ACTIONS(15),
    [anon_sym_LBRACE] = ACTIONS(17),
    [sym_supremum] = ACTIONS(19),
    [sym_infimum] = ACTIONS(19),
    [sym_number] = ACTIONS(19),
    [sym_anonymous] = ACTIONS(21),
    [sym_variable] = ACTIONS(19),
    [anon_sym_AMP] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(27),
    [anon_sym_PIPE] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(31),
    [anon_sym_AT] = ACTIONS(33),
    [sym_boolean_constant] = ACTIONS(35),
    [sym_default_negation] = ACTIONS(37),
    [sym_double_default_negation] = ACTIONS(39),
    [sym_aggregate_function] = ACTIONS(41),
    [anon_sym_COLON_DASH] = ACTIONS(43),
    [anon_sym_COLON_TILDE] = ACTIONS(45),
    [anon_sym_POUNDmaximize] = ACTIONS(47),
    [anon_sym_POUNDmaximise] = ACTIONS(47),
    [anon_sym_POUNDminimize] = ACTIONS(49),
    [anon_sym_POUNDminimise] = ACTIONS(49),
    [anon_sym_POUNDshow] = ACTIONS(51),
    [anon_sym_POUNDdefined] = ACTIONS(53),
    [anon_sym_POUNDproject] = ACTIONS(55),
    [anon_sym_POUNDprogram] = ACTIONS(57),
    [anon_sym_POUNDscript] = ACTIONS(59),
    [anon_sym_POUNDconst] = ACTIONS(61),
    [anon_sym_POUNDedge] = ACTIONS(63),
    [anon_sym_POUNDheuristic] = ACTIONS(65),
    [anon_sym_POUNDinclude] = ACTIONS(67),
    [anon_sym_POUNDexternal] = ACTIONS(69),
    [anon_sym_POUNDtheory] = ACTIONS(71),
    [anon_sym_POUNDtype] = ACTIONS(73),
    [sym_block_comment] = ACTIONS(5),
  },
  [STATE(2)] = {
    [sym_doc_comment] = STATE(36),
    [sym_string] = STATE(224),
    [sym_fstring] = STATE(224),
    [sym_binary_operation] = STATE(224),
    [sym_unary_operation] = STATE(224),
    [sym_abs] = STATE(224),
    [sym_function] = STATE(224),
    [sym_external_function] = STATE(224),
    [sym_tuple] = STATE(224),
    [sym_term] = STATE(386),
    [sym_symbolic_atom] = STATE(478),
    [sym_comparison] = STATE(478),
    [sym_simple_atom] = STATE(485),
    [sym_literal_sign] = STATE(117),
    [sym_literal] = STATE(505),
    [sym_lower] = STATE(775),
    [sym_set_aggregate] = STATE(781),
    [sym_theory_atom] = STATE(781),
    [sym_head_aggregate] = STATE(781),
    [sym__conditional_literal_n] = STATE(606),
    [sym__conditional_literal_0] = STATE(682),
    [sym_conditional_literal] = STATE(777),
    [sym_disjunction] = STATE(781),
    [sym_head] = STATE(778),
    [sym_rule] = STATE(36),
    [sym_integrity_constraint] = STATE(36),
    [sym_weak_constraint] = STATE(36),
    [sym_maximize] = STATE(36),
    [sym_minimize] = STATE(36),
    [sym_show] = STATE(36),
    [sym_show_term] = STATE(21),
    [sym_show_signature] = STATE(23),
    [sym_defined] = STATE(36),
    [sym_project_signature] = STATE(36),
    [sym_project_atom] = STATE(36),
    [sym_program] = STATE(36),
    [sym_script] = STATE(36),
    [sym_const] = STATE(36),
    [sym_edge] = STATE(36),
    [sym_heuristic] = STATE(36),
    [sym_include] = STATE(36),
    [sym_external] = STATE(36),
    [sym_theory] = STATE(36),
    [sym__metasp_identifier] = STATE(242),
    [sym_metasp_symbolic_atom] = STATE(478),
    [sym_metasp_function] = STATE(224),
    [sym_metasp_type] = STATE(36),
    [sym_statement] = STATE(2),
    [aux_sym_source_file_repeat1] = STATE(2),
    [aux_sym_disjunction_repeat1] = STATE(75),
    [ts_builtin_sym_end] = ACTIONS(75),
    [sym_line_comment] = ACTIONS(3),
    [anon_sym_PERCENT_STAR_BANG] = ACTIONS(77),
    [sym_identifier] = ACTIONS(80),
    [anon_sym_DQUOTE] = ACTIONS(83),
    [anon_sym_f_DQUOTE] = ACTIONS(86),
    [anon_sym_LBRACE] = ACTIONS(89),
    [sym_supremum] = ACTIONS(92),
    [sym_infimum] = ACTIONS(92),
    [sym_number] = ACTIONS(92),
    [sym_anonymous] = ACTIONS(95),
    [sym_variable] = ACTIONS(92),
    [anon_sym_AMP] = ACTIONS(98),
    [anon_sym_DASH] = ACTIONS(101),
    [anon_sym_TILDE] = ACTIONS(104),
    [anon_sym_PIPE] = ACTIONS(107),
    [anon_sym_LPAREN] = ACTIONS(110),
    [anon_sym_AT] = ACTIONS(113),
    [sym_boolean_constant] = ACTIONS(116),
    [sym_default_negation] = ACTIONS(119),
    [sym_double_default_negation] = ACTIONS(122),
    [sym_aggregate_function] = ACTIONS(125),
    [anon_sym_COLON_DASH] = ACTIONS(128),
    [anon_sym_COLON_TILDE] = ACTIONS(131),
    [anon_sym_POUNDmaximize] = ACTIONS(134),
    [anon_sym_POUNDmaximise] = ACTIONS(134),
    [anon_sym_POUNDminimize] = ACTIONS(137),
    [anon_sym_POUNDminimise] = ACTIONS(137),
    [anon_sym_POUNDshow] = ACTIONS(140),
    [anon_sym_POUNDdefined] = ACTIONS(143),
    [anon_sym_POUNDproject] = ACTIONS(146),
    [anon_sym_POUNDprogram] = ACTIONS(149),
    [anon_sym_POUNDscript] = ACTIONS(152),
    [anon_sym_POUNDconst] = ACTIONS(155),
    [anon_sym_POUNDedge] = ACTIONS(158),
    [anon_sym_POUNDheuristic] = ACTIONS(161),
    [anon_sym_POUNDinclude] = ACTIONS(164),
    [anon_sym_POUNDexternal] = ACTIONS(167),
    [anon_sym_POUNDtheory] = ACTIONS(170),
    [anon_sym_POUNDtype] = ACTIONS(173),
    [sym_block_comment] = ACTIONS(5),
  },
  [STATE(3)] = {
    [sym_doc_comment] = STATE(36),
    [sym_string] = STATE(224),
    [sym_fstring] = STATE(224),
    [sym_binary_operation] = STATE(224),
    [sym_unary_operation] = STATE(224),
    [sym_abs] = STATE(224),
    [sym_function] = STATE(224),
    [sym_external_function] = STATE(224),
    [sym_tuple] = STATE(224),
    [sym_term] = STATE(386),
    [sym_symbolic_atom] = STATE(478),
    [sym_comparison] = STATE(478),
    [sym_simple_atom] = STATE(485),
    [sym_literal_sign] = STATE(117),
    [sym_literal] = STATE(505),
    [sym_lower] = STATE(775),
    [sym_set_aggregate] = STATE(781),
    [sym_theory_atom] = STATE(781),
    [sym_head_aggregate] = STATE(781),
    [sym__conditional_literal_n] = STATE(606),
    [sym__conditional_literal_0] = STATE(682),
    [sym_conditional_literal] = STATE(777),
    [sym_disjunction] = STATE(781),
    [sym_head] = STATE(778),
    [sym_rule] = STATE(36),
    [sym_integrity_constraint] = STATE(36),
    [sym_weak_constraint] = STATE(36),
    [sym_maximize] = STATE(36),
    [sym_minimize] = STATE(36),
    [sym_show] = STATE(36),
    [sym_show_term] = STATE(21),
    [sym_show_signature] = STATE(23),
    [sym_defined] = STATE(36),
    [sym_project_signature] = STATE(36),
    [sym_project_atom] = STATE(36),
    [sym_program] = STATE(36),
    [sym_script] = STATE(36),
    [sym_const] = STATE(36),
    [sym_edge] = STATE(36),
    [sym_heuristic] = STATE(36),
    [sym_include] = STATE(36),
    [sym_external] = STATE(36),
    [sym_theory] = STATE(36),
    [sym__metasp_identifier] = STATE(242),
    [sym_metasp_symbolic_atom] = STATE(478),
    [sym_metasp_function] = STATE(224),
    [sym_metasp_type] = STATE(36),
    [sym_statement] = STATE(2),
    [aux_sym_source_file_repeat1] = STATE(2),
    [aux_sym_disjunction_repeat1] = STATE(75),
    [ts_builtin_sym_end] = ACTIONS(176),
    [sym_line_comment] = ACTIONS(3),
    [anon_sym_PERCENT_STAR_BANG] = ACTIONS(9),
    [sym_identifier] = ACTIONS(11),
    [anon_sym_DQUOTE] = ACTIONS(13),
    [anon_sym_f_DQUOTE] = ACTIONS(15),
    [anon_sym_LBRACE] = ACTIONS(17),
    [sym_supremum] = ACTIONS(19),
    [sym_infimum] = ACTIONS(19),
    [sym_number] = ACTIONS(19),
    [sym_anonymous] = ACTIONS(21),
    [sym_variable] = ACTIONS(19),
    [anon_sym_AMP] = ACTIONS(23),
    [anon_sym_DASH] = ACTIONS(25),
    [anon_sym_TILDE] = ACTIONS(27),
    [anon_sym_PIPE] = ACTIONS(29),
    [anon_sym_LPAREN] = ACTIONS(31),
    [anon_sym_AT] = ACTIONS(33),
    [sym_boolean_constant] = ACTIONS(35),
    [sym_default_negation] = ACTIONS(37),
    [sym_double_default_negation] = ACTIONS(39),
    [sym_aggregate_function] = ACTIONS(41),
    [anon_sym_COLON_DASH] = ACTIONS(43),
    [anon_sym_COLON_TILDE] = ACTIONS(45),
    [anon_sym_POUNDmaximize] = ACTIONS(47),
    [anon_sym_POUNDmaximise] = ACTIONS(47),
    [anon_sym_POUNDminimize] = ACTIONS(49),
    [anon_sym_POUNDminimise] = ACTIONS(49),
    [anon_sym_POUNDshow] = ACTIONS(51),
    [anon_sym_POUNDdefined] = ACTIONS(53),
    [anon_sym_POUNDproject] = ACTIONS(55),
    [anon_sym_POUNDprogram] = ACTIONS(57),
    [anon_sym_POUNDscript] = ACTIONS(59),
    [anon_sym_POUNDconst] = ACTIONS(61),
    [anon_sym_POUNDedge] = ACTIONS(63),
    [anon_sym_POUNDheuristic] = ACTIONS(65),
    [anon_sym_POUNDinclude] = ACTIONS(67),
    [anon_sym_POUNDexternal] = ACTIONS(69),
    [anon_sym_POUNDtheory] = ACTIONS(71),
    [anon_sym_POUNDtype] = ACTIONS(73),
    [sym_block_comment] = ACTIONS(5),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 33,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    ACTIONS(180), 1,
      anon_sym_DOT,
    STATE(13), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(620), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(779), 1,
      sym_lower,
    STATE(790), 1,
      sym_conditional_literal,
    STATE(964), 1,
      sym_literal,
    STATE(1011), 1,
      sym_body,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [116] = 33,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    ACTIONS(182), 1,
      anon_sym_DOT,
    STATE(13), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(620), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(779), 1,
      sym_lower,
    STATE(790), 1,
      sym_conditional_literal,
    STATE(841), 1,
      sym_body,
    STATE(964), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [232] = 33,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    ACTIONS(184), 1,
      anon_sym_DOT,
    STATE(13), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(620), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(779), 1,
      sym_lower,
    STATE(790), 1,
      sym_conditional_literal,
    STATE(964), 1,
      sym_literal,
    STATE(1003), 1,
      sym_body,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [348] = 33,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    ACTIONS(186), 1,
      anon_sym_DOT,
    STATE(13), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(620), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(779), 1,
      sym_lower,
    STATE(790), 1,
      sym_conditional_literal,
    STATE(906), 1,
      sym_body,
    STATE(964), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [464] = 33,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    ACTIONS(188), 1,
      anon_sym_DOT,
    STATE(13), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(620), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(779), 1,
      sym_lower,
    STATE(790), 1,
      sym_conditional_literal,
    STATE(964), 1,
      sym_literal,
    STATE(1013), 1,
      sym_body,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [580] = 33,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    ACTIONS(190), 1,
      anon_sym_DOT,
    STATE(13), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(620), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(779), 1,
      sym_lower,
    STATE(790), 1,
      sym_conditional_literal,
    STATE(878), 1,
      sym_body,
    STATE(964), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [696] = 33,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    ACTIONS(192), 1,
      anon_sym_DOT,
    STATE(13), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(620), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(779), 1,
      sym_lower,
    STATE(790), 1,
      sym_conditional_literal,
    STATE(954), 1,
      sym_body,
    STATE(964), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [812] = 33,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    ACTIONS(194), 1,
      anon_sym_DOT,
    STATE(13), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(620), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(779), 1,
      sym_lower,
    STATE(790), 1,
      sym_conditional_literal,
    STATE(947), 1,
      sym_body,
    STATE(964), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [928] = 32,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    STATE(13), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(620), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(779), 1,
      sym_lower,
    STATE(790), 1,
      sym_conditional_literal,
    STATE(824), 1,
      sym_body,
    STATE(964), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [1041] = 31,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(178), 1,
      sym_aggregate_function,
    STATE(14), 1,
      aux_sym_body_repeat1,
    STATE(90), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(700), 1,
      sym_body_literal,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(776), 1,
      sym_conditional_literal,
    STATE(779), 1,
      sym_lower,
    STATE(964), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [1151] = 31,
    ACTIONS(196), 1,
      sym_identifier,
    ACTIONS(199), 1,
      anon_sym_DQUOTE,
    ACTIONS(202), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(205), 1,
      anon_sym_LBRACE,
    ACTIONS(211), 1,
      sym_anonymous,
    ACTIONS(214), 1,
      anon_sym_AMP,
    ACTIONS(217), 1,
      anon_sym_DASH,
    ACTIONS(220), 1,
      anon_sym_TILDE,
    ACTIONS(223), 1,
      anon_sym_PIPE,
    ACTIONS(226), 1,
      anon_sym_LPAREN,
    ACTIONS(229), 1,
      anon_sym_AT,
    ACTIONS(232), 1,
      sym_boolean_constant,
    ACTIONS(235), 1,
      sym_default_negation,
    ACTIONS(238), 1,
      sym_double_default_negation,
    ACTIONS(241), 1,
      sym_aggregate_function,
    STATE(14), 1,
      aux_sym_body_repeat1,
    STATE(91), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(605), 1,
      sym_simple_atom,
    STATE(721), 1,
      sym__conditional_literal_n,
    STATE(769), 1,
      sym__conditional_literal_0,
    STATE(771), 1,
      sym_body_literal,
    STATE(789), 1,
      sym_lower,
    STATE(951), 1,
      sym_conditional_literal,
    STATE(996), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(618), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(208), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [1261] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(248), 1,
      anon_sym_LBRACK,
    ACTIONS(246), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(244), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1314] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(254), 1,
      anon_sym_LBRACK,
    ACTIONS(252), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(250), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1367] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(260), 1,
      anon_sym_LBRACK,
    ACTIONS(258), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(256), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1420] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(266), 1,
      anon_sym_LBRACK,
    ACTIONS(264), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(262), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1473] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(272), 1,
      anon_sym_LBRACK,
    ACTIONS(270), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(268), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1526] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(276), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(274), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1576] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(280), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(278), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1626] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(284), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(282), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1676] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(288), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(286), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1726] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(292), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(290), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1776] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(296), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(294), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1826] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(300), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(298), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1876] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(304), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(302), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1926] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(308), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(306), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [1976] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(312), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(310), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2026] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(316), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(314), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2076] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(320), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(318), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2126] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(324), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(322), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2176] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(328), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(326), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2226] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(332), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(330), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2276] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(336), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(334), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2326] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(340), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(338), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2376] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(344), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(342), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2426] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(348), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(346), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2476] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(352), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(350), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2526] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(356), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(354), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2576] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(360), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(358), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2626] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(364), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(362), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2676] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(368), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(366), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2726] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(372), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(370), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2776] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(376), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(374), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2826] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(380), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(378), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2876] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(384), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(382), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2926] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(388), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(386), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [2976] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(392), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(390), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3026] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(396), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(394), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3076] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(400), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(398), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3126] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(404), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(402), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3176] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(408), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(406), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3226] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(412), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(410), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3276] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(416), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(414), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3326] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(420), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(418), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3376] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(424), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(422), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3426] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(428), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(426), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3476] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(432), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(430), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3526] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(436), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(434), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3576] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(440), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(438), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3626] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(444), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(442), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3676] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(448), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(446), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3726] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(452), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(450), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3776] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(456), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(454), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3826] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(460), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(458), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3876] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(464), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(462), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3926] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(468), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(466), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [3976] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(472), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(470), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [4026] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(476), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(474), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [4076] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(480), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(478), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [4126] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(484), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(482), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [4176] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(488), 4,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
      sym_aggregate_function,
    ACTIONS(486), 35,
      ts_builtin_sym_end,
      anon_sym_PERCENT_STAR_BANG,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      anon_sym_COLON_DASH,
      anon_sym_COLON_TILDE,
      anon_sym_POUNDmaximize,
      anon_sym_POUNDmaximise,
      anon_sym_POUNDminimize,
      anon_sym_POUNDminimise,
      anon_sym_POUNDshow,
      anon_sym_POUNDdefined,
      anon_sym_POUNDproject,
      anon_sym_POUNDprogram,
      anon_sym_POUNDscript,
      anon_sym_POUNDconst,
      anon_sym_POUNDedge,
      anon_sym_POUNDheuristic,
      anon_sym_POUNDinclude,
      anon_sym_POUNDexternal,
      anon_sym_POUNDtheory,
      anon_sym_POUNDtype,
  [4226] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(554), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(496), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [4315] = 26,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(500), 1,
      anon_sym_AMP,
    STATE(84), 1,
      aux_sym_disjunction_repeat1,
    STATE(117), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(485), 1,
      sym_simple_atom,
    STATE(488), 1,
      sym_literal,
    STATE(606), 1,
      sym__conditional_literal_n,
    STATE(682), 1,
      sym__conditional_literal_0,
    STATE(734), 1,
      sym_conditional_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [4408] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(738), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(502), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [4496] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(770), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(504), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [4584] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(774), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(506), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [4672] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(785), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(508), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [4760] = 25,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(510), 1,
      anon_sym_RBRACE2,
    STATE(117), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(485), 1,
      sym_simple_atom,
    STATE(672), 1,
      sym_literal,
    STATE(690), 1,
      sym_set_aggregate_element,
    STATE(822), 1,
      sym_set_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [4850] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(733), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(512), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [4938] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(728), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(514), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5026] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(795), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(516), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5114] = 25,
    ACTIONS(518), 1,
      sym_identifier,
    ACTIONS(521), 1,
      anon_sym_DQUOTE,
    ACTIONS(524), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(530), 1,
      sym_anonymous,
    ACTIONS(533), 1,
      anon_sym_AMP,
    ACTIONS(536), 1,
      anon_sym_DASH,
    ACTIONS(539), 1,
      anon_sym_TILDE,
    ACTIONS(542), 1,
      anon_sym_PIPE,
    ACTIONS(545), 1,
      anon_sym_LPAREN,
    ACTIONS(548), 1,
      anon_sym_AT,
    ACTIONS(551), 1,
      sym_boolean_constant,
    ACTIONS(554), 1,
      sym_default_negation,
    ACTIONS(557), 1,
      sym_double_default_negation,
    STATE(84), 1,
      aux_sym_disjunction_repeat1,
    STATE(117), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(485), 1,
      sym_simple_atom,
    STATE(556), 1,
      sym_literal,
    STATE(791), 1,
      sym__conditional_literal_n,
    STATE(827), 1,
      sym__conditional_literal_0,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(527), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5204] = 25,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(560), 1,
      anon_sym_RBRACE2,
    STATE(117), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(485), 1,
      sym_simple_atom,
    STATE(672), 1,
      sym_literal,
    STATE(690), 1,
      sym_set_aggregate_element,
    STATE(993), 1,
      sym_set_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5294] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(736), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(562), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5382] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(468), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    STATE(726), 1,
      sym_condition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(564), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5470] = 25,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(566), 1,
      anon_sym_RBRACE2,
    STATE(117), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(485), 1,
      sym_simple_atom,
    STATE(672), 1,
      sym_literal,
    STATE(690), 1,
      sym_set_aggregate_element,
    STATE(935), 1,
      sym_set_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5560] = 25,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(568), 1,
      anon_sym_RBRACE2,
    STATE(117), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(485), 1,
      sym_simple_atom,
    STATE(672), 1,
      sym_literal,
    STATE(690), 1,
      sym_set_aggregate_element,
    STATE(957), 1,
      sym_set_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5650] = 22,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(17), 1,
      anon_sym_LBRACE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(178), 1,
      sym_aggregate_function,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(593), 1,
      sym_simple_atom,
    STATE(779), 1,
      sym_lower,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(683), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5733] = 22,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(23), 1,
      anon_sym_AMP,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(570), 1,
      anon_sym_LBRACE,
    ACTIONS(572), 1,
      sym_aggregate_function,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(386), 1,
      sym_term,
    STATE(593), 1,
      sym_simple_atom,
    STATE(789), 1,
      sym_lower,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    STATE(683), 3,
      sym_set_aggregate,
      sym_theory_atom,
      sym_body_aggregate,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5816] = 24,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(496), 1,
      anon_sym_SEMI,
    ACTIONS(498), 1,
      sym_boolean_constant,
    ACTIONS(574), 1,
      sym_identifier,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(578), 1,
      anon_sym_DASH,
    STATE(110), 1,
      sym_literal_sign,
    STATE(344), 1,
      sym__metasp_identifier,
    STATE(412), 1,
      sym_term,
    STATE(502), 1,
      sym_simple_atom,
    STATE(554), 1,
      sym_condition,
    STATE(604), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5903] = 22,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    ACTIONS(584), 1,
      anon_sym_COMMA2,
    ACTIONS(586), 1,
      anon_sym_RPAREN2,
    ACTIONS(588), 1,
      sym_empty_pool_item_first,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(384), 1,
      sym_term,
    STATE(694), 1,
      sym_tuple_pool_item,
    STATE(938), 1,
      sym__tuple_pool_n,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(727), 2,
      sym_projection,
      sym__term_or_projection,
    STATE(731), 2,
      sym__term_comma,
      sym__terms_trail,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [5985] = 22,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    ACTIONS(584), 1,
      anon_sym_COMMA2,
    ACTIONS(588), 1,
      sym_empty_pool_item_first,
    ACTIONS(590), 1,
      anon_sym_RPAREN2,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(384), 1,
      sym_term,
    STATE(704), 1,
      sym_tuple_pool_item,
    STATE(801), 1,
      sym__tuple_pool_n,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(727), 2,
      sym_projection,
      sym__term_or_projection,
    STATE(731), 2,
      sym__term_comma,
      sym__terms_trail,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6067] = 22,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    ACTIONS(584), 1,
      anon_sym_COMMA2,
    ACTIONS(588), 1,
      sym_empty_pool_item_first,
    ACTIONS(592), 1,
      anon_sym_RPAREN2,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(384), 1,
      sym_term,
    STATE(653), 1,
      sym_tuple_pool_item,
    STATE(803), 1,
      sym__tuple_pool_n,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(727), 2,
      sym_projection,
      sym__term_or_projection,
    STATE(731), 2,
      sym__term_comma,
      sym__terms_trail,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6149] = 23,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(500), 1,
      anon_sym_AMP,
    STATE(117), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(485), 1,
      sym_simple_atom,
    STATE(672), 1,
      sym_literal,
    STATE(732), 1,
      sym_set_aggregate_element,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6233] = 22,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(118), 1,
      sym_literal_sign,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(498), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6314] = 22,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(500), 1,
      anon_sym_AMP,
    STATE(117), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(485), 1,
      sym_simple_atom,
    STATE(691), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6395] = 22,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(500), 1,
      anon_sym_AMP,
    STATE(117), 1,
      sym_literal_sign,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(485), 1,
      sym_simple_atom,
    STATE(689), 1,
      sym_literal,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6476] = 22,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(37), 1,
      sym_default_negation,
    ACTIONS(39), 1,
      sym_double_default_negation,
    ACTIONS(498), 1,
      sym_boolean_constant,
    ACTIONS(574), 1,
      sym_identifier,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(578), 1,
      anon_sym_DASH,
    STATE(110), 1,
      sym_literal_sign,
    STATE(344), 1,
      sym__metasp_identifier,
    STATE(412), 1,
      sym_term,
    STATE(498), 1,
      sym_literal,
    STATE(502), 1,
      sym_simple_atom,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6557] = 20,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    ACTIONS(584), 1,
      anon_sym_COMMA2,
    ACTIONS(594), 1,
      sym_empty_pool_item,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(384), 1,
      sym_term,
    STATE(750), 1,
      sym_tuple_pool_item,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(727), 2,
      sym_projection,
      sym__term_or_projection,
    STATE(731), 2,
      sym__term_comma,
      sym__terms_trail,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6633] = 20,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    ACTIONS(596), 1,
      anon_sym_RPAREN2,
    ACTIONS(598), 1,
      sym_empty_pool_item_first,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(383), 1,
      sym_term,
    STATE(705), 1,
      sym__terms_or_projection,
    STATE(986), 1,
      sym__arg_pool_n,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(569), 2,
      sym_projection,
      sym__term_or_projection,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6708] = 20,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    ACTIONS(598), 1,
      sym_empty_pool_item_first,
    ACTIONS(600), 1,
      anon_sym_RPAREN2,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(383), 1,
      sym_term,
    STATE(668), 1,
      sym__terms_or_projection,
    STATE(873), 1,
      sym__arg_pool_n,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(569), 2,
      sym_projection,
      sym__term_or_projection,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6783] = 20,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    ACTIONS(598), 1,
      sym_empty_pool_item_first,
    ACTIONS(602), 1,
      anon_sym_RPAREN2,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(383), 1,
      sym_term,
    STATE(698), 1,
      sym__terms_or_projection,
    STATE(948), 1,
      sym__arg_pool_n,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(569), 2,
      sym_projection,
      sym__term_or_projection,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6858] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(553), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    ACTIONS(616), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6926] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(601), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    ACTIONS(624), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [6994] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(552), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    ACTIONS(626), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7062] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(594), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    ACTIONS(628), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7130] = 19,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(648), 1,
      anon_sym_RBRACE2,
    ACTIONS(650), 1,
      sym_colon,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(352), 1,
      sym_term,
    STATE(680), 1,
      sym_head_aggregate_element,
    STATE(871), 1,
      sym_terms,
    STATE(903), 1,
      sym_head_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7201] = 18,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(498), 1,
      sym_boolean_constant,
    ACTIONS(574), 1,
      sym_identifier,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(578), 1,
      anon_sym_DASH,
    STATE(344), 1,
      sym__metasp_identifier,
    STATE(412), 1,
      sym_term,
    STATE(509), 1,
      sym_simple_atom,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7270] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(678), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(652), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7337] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(679), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(654), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7404] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(614), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(656), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7471] = 18,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    ACTIONS(658), 1,
      sym_empty_pool_item,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(383), 1,
      sym_term,
    STATE(714), 1,
      sym__terms_or_projection,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(569), 2,
      sym_projection,
      sym__term_or_projection,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7540] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(383), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(660), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
    STATE(686), 2,
      sym_projection,
      sym__term_or_projection,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7607] = 19,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(662), 1,
      anon_sym_RBRACE2,
    ACTIONS(664), 1,
      sym_colon,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(352), 1,
      sym_term,
    STATE(696), 1,
      sym_terms,
    STATE(697), 1,
      sym_body_aggregate_element,
    STATE(945), 1,
      sym_body_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7678] = 18,
    ACTIONS(11), 1,
      sym_identifier,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(25), 1,
      anon_sym_DASH,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(35), 1,
      sym_boolean_constant,
    ACTIONS(500), 1,
      anon_sym_AMP,
    STATE(242), 1,
      sym__metasp_identifier,
    STATE(408), 1,
      sym_term,
    STATE(484), 1,
      sym_simple_atom,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(478), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7747] = 18,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(27), 1,
      anon_sym_TILDE,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(490), 1,
      sym_identifier,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(494), 1,
      anon_sym_DASH,
    ACTIONS(498), 1,
      sym_boolean_constant,
    STATE(278), 1,
      sym__metasp_identifier,
    STATE(418), 1,
      sym_term,
    STATE(509), 1,
      sym_simple_atom,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(501), 3,
      sym_symbolic_atom,
      sym_comparison,
      sym_metasp_symbolic_atom,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7816] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(383), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(666), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
    STATE(686), 2,
      sym_projection,
      sym__term_or_projection,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7883] = 19,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      sym_colon,
    ACTIONS(668), 1,
      anon_sym_RBRACE2,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(352), 1,
      sym_term,
    STATE(680), 1,
      sym_head_aggregate_element,
    STATE(871), 1,
      sym_terms,
    STATE(924), 1,
      sym_head_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [7954] = 19,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(664), 1,
      sym_colon,
    ACTIONS(670), 1,
      anon_sym_RBRACE2,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(352), 1,
      sym_term,
    STATE(696), 1,
      sym_terms,
    STATE(697), 1,
      sym_body_aggregate_element,
    STATE(1004), 1,
      sym_body_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8025] = 19,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(664), 1,
      sym_colon,
    ACTIONS(672), 1,
      anon_sym_RBRACE2,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(352), 1,
      sym_term,
    STATE(696), 1,
      sym_terms,
    STATE(697), 1,
      sym_body_aggregate_element,
    STATE(961), 1,
      sym_body_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8096] = 19,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(664), 1,
      sym_colon,
    ACTIONS(674), 1,
      anon_sym_RBRACE2,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(352), 1,
      sym_term,
    STATE(696), 1,
      sym_terms,
    STATE(697), 1,
      sym_body_aggregate_element,
    STATE(970), 1,
      sym_body_aggregate_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8167] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(702), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(676), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8234] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(715), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(678), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8300] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(759), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(680), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8366] = 18,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(682), 1,
      anon_sym_RBRACE2,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(354), 1,
      sym_term,
    STATE(565), 1,
      sym_weight,
    STATE(613), 1,
      sym_optimize_element,
    STATE(857), 1,
      sym_optimize_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8434] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(757), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(684), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8500] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(686), 1,
      sym_relation,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(391), 1,
      sym_term,
    STATE(702), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(676), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8566] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(686), 1,
      sym_relation,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(391), 1,
      sym_term,
    STATE(594), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(628), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8632] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(686), 1,
      sym_relation,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(391), 1,
      sym_term,
    STATE(552), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(626), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8698] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(686), 1,
      sym_relation,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(391), 1,
      sym_term,
    STATE(553), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(616), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8764] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(686), 1,
      sym_relation,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(391), 1,
      sym_term,
    STATE(601), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(624), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8830] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(686), 1,
      sym_relation,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(391), 1,
      sym_term,
    STATE(678), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(652), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8896] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(686), 1,
      sym_relation,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(391), 1,
      sym_term,
    STATE(679), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(654), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [8962] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(686), 1,
      sym_relation,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(391), 1,
      sym_term,
    STATE(614), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(656), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9028] = 17,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    ACTIONS(622), 1,
      sym_relation,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(368), 1,
      sym_term,
    STATE(764), 1,
      sym_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(688), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9094] = 18,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(640), 1,
      anon_sym_TILDE,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(690), 1,
      sym_identifier,
    ACTIONS(692), 1,
      anon_sym_DASH,
    ACTIONS(694), 1,
      anon_sym_DOT,
    STATE(370), 1,
      sym__metasp_identifier,
    STATE(390), 1,
      sym_term,
    STATE(815), 1,
      sym_extended_signature,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(813), 2,
      sym_signature,
      sym_metasp_signature,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9162] = 18,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(696), 1,
      anon_sym_RBRACE2,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(354), 1,
      sym_term,
    STATE(565), 1,
      sym_weight,
    STATE(613), 1,
      sym_optimize_element,
    STATE(819), 1,
      sym_optimize_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9230] = 17,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(664), 1,
      sym_colon,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(352), 1,
      sym_term,
    STATE(696), 1,
      sym_terms,
    STATE(740), 1,
      sym_body_aggregate_element,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9295] = 22,
    ACTIONS(698), 1,
      sym_identifier,
    ACTIONS(700), 1,
      anon_sym_DQUOTE,
    ACTIONS(702), 1,
      anon_sym_LBRACE,
    ACTIONS(706), 1,
      sym_anonymous,
    ACTIONS(708), 1,
      anon_sym_LPAREN,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(712), 1,
      anon_sym_LBRACK,
    ACTIONS(714), 1,
      anon_sym_RBRACE2,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(718), 1,
      sym_colon,
    STATE(348), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(447), 1,
      sym_theory_root_term,
    STATE(448), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(516), 1,
      sym_theory_term,
    STATE(559), 1,
      sym_theory_unparsed_term,
    STATE(677), 1,
      sym_theory_terms,
    STATE(681), 1,
      sym_theory_element,
    STATE(902), 1,
      sym_theory_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(704), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(497), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [9370] = 16,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(582), 1,
      anon_sym_STAR,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(383), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(686), 2,
      sym_projection,
      sym__term_or_projection,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9433] = 17,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(650), 1,
      sym_colon,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(352), 1,
      sym_term,
    STATE(762), 1,
      sym_head_aggregate_element,
    STATE(871), 1,
      sym_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9498] = 22,
    ACTIONS(698), 1,
      sym_identifier,
    ACTIONS(700), 1,
      anon_sym_DQUOTE,
    ACTIONS(702), 1,
      anon_sym_LBRACE,
    ACTIONS(706), 1,
      sym_anonymous,
    ACTIONS(708), 1,
      anon_sym_LPAREN,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(712), 1,
      anon_sym_LBRACK,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(718), 1,
      sym_colon,
    ACTIONS(720), 1,
      anon_sym_RBRACE2,
    STATE(348), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(447), 1,
      sym_theory_root_term,
    STATE(448), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(516), 1,
      sym_theory_term,
    STATE(559), 1,
      sym_theory_unparsed_term,
    STATE(677), 1,
      sym_theory_terms,
    STATE(681), 1,
      sym_theory_element,
    STATE(921), 1,
      sym_theory_elements,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(704), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(497), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [9573] = 15,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(298), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(722), 2,
      anon_sym_LBRACE,
      sym_aggregate_function,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9633] = 16,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(354), 1,
      sym_term,
    STATE(565), 1,
      sym_weight,
    STATE(772), 1,
      sym_optimize_element,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9695] = 20,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(734), 1,
      anon_sym_COMMA2,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(738), 1,
      anon_sym_RPAREN2,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(667), 1,
      sym_theory_term,
    STATE(968), 1,
      sym__theory_terms_trail,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [9764] = 15,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(352), 1,
      sym_term,
    STATE(617), 1,
      sym_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9823] = 5,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    STATE(234), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(744), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(742), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [9862] = 15,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(376), 1,
      sym_term,
    STATE(820), 1,
      sym_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9921] = 15,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(421), 1,
      sym_term,
    STATE(652), 1,
      sym_edge_pair,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [9980] = 15,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(377), 1,
      sym_term,
    STATE(971), 1,
      sym_weight,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10039] = 15,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(421), 1,
      sym_term,
    STATE(741), 1,
      sym_edge_pair,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10098] = 15,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(377), 1,
      sym_term,
    STATE(1012), 1,
      sym_weight,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10157] = 15,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(377), 1,
      sym_term,
    STATE(773), 1,
      sym_weight,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10216] = 20,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(734), 1,
      anon_sym_COMMA2,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(748), 1,
      anon_sym_RPAREN2,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(667), 1,
      sym_theory_term,
    STATE(859), 1,
      sym__theory_terms_trail,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [10285] = 5,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    STATE(230), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(752), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(750), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [10324] = 20,
    ACTIONS(698), 1,
      sym_identifier,
    ACTIONS(700), 1,
      anon_sym_DQUOTE,
    ACTIONS(702), 1,
      anon_sym_LBRACE,
    ACTIONS(706), 1,
      sym_anonymous,
    ACTIONS(708), 1,
      anon_sym_LPAREN,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(712), 1,
      anon_sym_LBRACK,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(718), 1,
      sym_colon,
    STATE(348), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(447), 1,
      sym_theory_root_term,
    STATE(448), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(516), 1,
      sym_theory_term,
    STATE(559), 1,
      sym_theory_unparsed_term,
    STATE(677), 1,
      sym_theory_terms,
    STATE(730), 1,
      sym_theory_element,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(704), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(497), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [10393] = 15,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(377), 1,
      sym_term,
    STATE(746), 1,
      sym_weight,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10452] = 5,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    STATE(233), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(756), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(754), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [10491] = 15,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(376), 1,
      sym_term,
    STATE(900), 1,
      sym_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10550] = 15,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(377), 1,
      sym_term,
    STATE(960), 1,
      sym_weight,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10609] = 19,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(758), 1,
      anon_sym_RPAREN2,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(533), 1,
      sym_theory_term,
    STATE(867), 1,
      sym_theory_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [10675] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(414), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10731] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(420), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10787] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(364), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10843] = 14,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(760), 1,
      anon_sym_DQUOTE,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(265), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(762), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10899] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(311), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [10955] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(310), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11011] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(295), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11067] = 19,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(764), 1,
      anon_sym_RBRACE2,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(533), 1,
      sym_theory_term,
    STATE(854), 1,
      sym_theory_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [11133] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(300), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11189] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(302), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11245] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(303), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11301] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(309), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11357] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(264), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11413] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(768), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(766), 23,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_LPAREN,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [11447] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(394), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11503] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(356), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11559] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(419), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11615] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(273), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11671] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(399), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11727] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(291), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11783] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(406), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11839] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(372), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11895] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(296), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [11951] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(407), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12007] = 19,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(770), 1,
      anon_sym_RBRACK,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(533), 1,
      sym_theory_term,
    STATE(868), 1,
      sym_theory_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [12073] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(402), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12129] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(326), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12185] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(371), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12241] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(334), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12297] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(335), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12353] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(336), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12409] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(337), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12465] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(772), 1,
      sym_identifier,
    STATE(266), 1,
      sym__metasp_identifier,
    STATE(295), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12521] = 14,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(760), 1,
      anon_sym_DQUOTE,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(363), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(762), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12577] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(378), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12633] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(774), 1,
      sym_identifier,
    STATE(248), 1,
      sym__metasp_identifier,
    STATE(295), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12689] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(401), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12745] = 14,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(760), 1,
      anon_sym_DQUOTE,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(349), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(762), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12801] = 14,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(760), 1,
      anon_sym_DQUOTE,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(359), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(762), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12857] = 14,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(760), 1,
      anon_sym_DQUOTE,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(360), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(762), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12913] = 14,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(760), 1,
      anon_sym_DQUOTE,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(361), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(762), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [12969] = 14,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    ACTIONS(760), 1,
      anon_sym_DQUOTE,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(362), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(762), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13025] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(298), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13081] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(312), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13137] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(409), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13193] = 19,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(776), 1,
      anon_sym_RBRACE2,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(533), 1,
      sym_theory_term,
    STATE(967), 1,
      sym_theory_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [13259] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(387), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13315] = 19,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(778), 1,
      anon_sym_RBRACK,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(533), 1,
      sym_theory_term,
    STATE(969), 1,
      sym_theory_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [13381] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(630), 1,
      sym_identifier,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    STATE(254), 1,
      sym__metasp_identifier,
    STATE(366), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13437] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(314), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13493] = 14,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(632), 1,
      anon_sym_DQUOTE,
    ACTIONS(634), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(638), 1,
      sym_anonymous,
    ACTIONS(642), 1,
      anon_sym_PIPE,
    ACTIONS(644), 1,
      anon_sym_LPAREN,
    ACTIONS(646), 1,
      anon_sym_AT,
    ACTIONS(780), 1,
      sym_identifier,
    STATE(310), 1,
      sym_term,
    STATE(365), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(640), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(636), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(268), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13549] = 19,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(782), 1,
      anon_sym_RPAREN2,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(533), 1,
      sym_theory_term,
    STATE(972), 1,
      sym_theory_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [13615] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(288), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13671] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(413), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13727] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(269), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13783] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(580), 1,
      sym_identifier,
    STATE(149), 1,
      sym__metasp_identifier,
    STATE(382), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13839] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(15), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(21), 1,
      sym_anonymous,
    ACTIONS(29), 1,
      anon_sym_PIPE,
    ACTIONS(31), 1,
      anon_sym_LPAREN,
    ACTIONS(33), 1,
      anon_sym_AT,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(784), 1,
      sym_identifier,
    STATE(295), 1,
      sym_term,
    STATE(346), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(27), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(19), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(224), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13895] = 14,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(604), 1,
      sym_identifier,
    ACTIONS(606), 1,
      anon_sym_f_DQUOTE,
    ACTIONS(610), 1,
      sym_anonymous,
    ACTIONS(614), 1,
      anon_sym_PIPE,
    ACTIONS(618), 1,
      anon_sym_LPAREN,
    ACTIONS(620), 1,
      anon_sym_AT,
    STATE(263), 1,
      sym__metasp_identifier,
    STATE(333), 1,
      sym_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(612), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(608), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(322), 9,
      sym_string,
      sym_fstring,
      sym_binary_operation,
      sym_unary_operation,
      sym_abs,
      sym_function,
      sym_external_function,
      sym_tuple,
      sym_metasp_function,
  [13951] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(788), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(786), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [13984] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(792), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(790), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14017] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(796), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(794), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14050] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(800), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(798), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14083] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(804), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(802), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14116] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(808), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(806), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14149] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(812), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(810), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14182] = 18,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(814), 1,
      anon_sym_RPAREN2,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(608), 1,
      sym_theory_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [14245] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(818), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(816), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14278] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(822), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(820), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14311] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(826), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(824), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14344] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(830), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(828), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14377] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(834), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(832), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14410] = 18,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(836), 1,
      anon_sym_RPAREN2,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(608), 1,
      sym_theory_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [14473] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(840), 2,
      aux_sym_fstring_conversion_token1,
      anon_sym_STAR,
    ACTIONS(838), 22,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_spec_token1,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [14506] = 17,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(608), 1,
      sym_theory_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [14566] = 17,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(561), 1,
      sym_theory_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [14626] = 13,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(850), 1,
      anon_sym_COMMA2,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    ACTIONS(854), 1,
      anon_sym_RPAREN2,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    STATE(862), 2,
      sym__const_term_comma,
      sym__const_terms_trail,
    ACTIONS(844), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(393), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [14678] = 17,
    ACTIONS(698), 1,
      sym_identifier,
    ACTIONS(700), 1,
      anon_sym_DQUOTE,
    ACTIONS(702), 1,
      anon_sym_LBRACE,
    ACTIONS(706), 1,
      sym_anonymous,
    ACTIONS(708), 1,
      anon_sym_LPAREN,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(712), 1,
      anon_sym_LBRACK,
    ACTIONS(716), 1,
      sym_default_negation,
    STATE(348), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(447), 1,
      sym_theory_root_term,
    STATE(448), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(559), 1,
      sym_theory_unparsed_term,
    STATE(564), 1,
      sym_theory_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(704), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(497), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [14738] = 17,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(724), 1,
      sym_identifier,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(395), 1,
      sym_theory_root_term,
    STATE(396), 1,
      aux_sym_theory_unparsed_term_repeat1,
    STATE(470), 1,
      sym_theory_unparsed_term,
    STATE(562), 1,
      sym_theory_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [14798] = 7,
    ACTIONS(744), 1,
      anon_sym_STAR,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(860), 1,
      anon_sym_DOT,
    STATE(260), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(856), 6,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(742), 12,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
      sym_aggregate_function,
  [14837] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(864), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(862), 20,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_relation,
      sym_aggregate_function,
      anon_sym_COLON_DASH,
  [14868] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(768), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(766), 20,
      sym_colon,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      sym_aggregate_function,
      anon_sym_COLON_DASH,
  [14899] = 7,
    ACTIONS(752), 1,
      anon_sym_STAR,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(868), 1,
      anon_sym_DOT,
    STATE(262), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(866), 6,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(750), 12,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
      sym_aggregate_function,
  [14938] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(872), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(870), 20,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_relation,
      sym_aggregate_function,
      anon_sym_COLON_DASH,
  [14969] = 7,
    ACTIONS(752), 1,
      anon_sym_STAR,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(876), 1,
      anon_sym_DOT,
    STATE(259), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(874), 6,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(750), 12,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
      sym_aggregate_function,
  [15008] = 7,
    ACTIONS(744), 1,
      anon_sym_STAR,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(880), 1,
      anon_sym_DOT,
    STATE(258), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(878), 6,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(742), 12,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
      sym_aggregate_function,
  [15047] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(788), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(786), 19,
      sym_colon,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      sym_aggregate_function,
      anon_sym_COLON_DASH,
  [15077] = 12,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    ACTIONS(884), 1,
      anon_sym_RPAREN2,
    STATE(315), 1,
      sym__metasp_identifier,
    STATE(920), 1,
      sym_const_terms,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(882), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(392), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [15125] = 5,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    STATE(299), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(756), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(754), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [15159] = 6,
    ACTIONS(886), 1,
      anon_sym_LBRACE,
    ACTIONS(889), 1,
      anon_sym_LPAREN,
    STATE(888), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(768), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(766), 16,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      sym_relation,
      sym_aggregate_function,
      anon_sym_COLON_DASH,
  [15195] = 5,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    STATE(290), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(752), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(750), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [15229] = 5,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    STATE(292), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(744), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(742), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [15263] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(808), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(806), 19,
      sym_colon,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      sym_aggregate_function,
      anon_sym_COLON_DASH,
  [15293] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(804), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(802), 19,
      sym_colon,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      sym_aggregate_function,
      anon_sym_COLON_DASH,
  [15323] = 11,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    ACTIONS(894), 1,
      anon_sym_RPAREN2,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(892), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(416), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [15368] = 5,
    ACTIONS(834), 1,
      anon_sym_STAR,
    ACTIONS(898), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(896), 6,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(832), 12,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
      sym_aggregate_function,
  [15401] = 5,
    ACTIONS(818), 1,
      anon_sym_STAR,
    ACTIONS(902), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(900), 6,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(816), 12,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
      sym_aggregate_function,
  [15434] = 5,
    ACTIONS(834), 1,
      anon_sym_STAR,
    ACTIONS(906), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(904), 6,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(832), 12,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
      sym_aggregate_function,
  [15467] = 11,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    ACTIONS(908), 1,
      anon_sym_RPAREN2,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(892), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(416), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [15512] = 5,
    ACTIONS(818), 1,
      anon_sym_STAR,
    ACTIONS(912), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(910), 6,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(816), 12,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
      sym_aggregate_function,
  [15545] = 5,
    ACTIONS(914), 1,
      anon_sym_LPAREN,
    STATE(328), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(744), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(742), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [15577] = 8,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(928), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(918), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(916), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(926), 9,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [15615] = 16,
    ACTIONS(930), 1,
      aux_sym_fstring_accessor_token1,
    ACTIONS(932), 1,
      aux_sym_fstring_accessor_token2,
    ACTIONS(934), 1,
      aux_sym_fstring_conversion_token1,
    ACTIONS(936), 1,
      aux_sym_fstring_spec_token1,
    ACTIONS(938), 1,
      anon_sym_RBRACE,
    ACTIONS(944), 1,
      anon_sym_STAR,
    ACTIONS(948), 1,
      anon_sym_STAR_STAR,
    ACTIONS(950), 1,
      anon_sym_DOT_DOT,
    STATE(493), 1,
      aux_sym_fstring_accessor_repeat1,
    STATE(545), 1,
      sym_fstring_accessor,
    STATE(665), 1,
      sym_fstring_conversion,
    STATE(865), 1,
      sym_fstring_spec,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(946), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(940), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [15669] = 7,
    ACTIONS(744), 1,
      anon_sym_STAR,
    ACTIONS(880), 1,
      anon_sym_DOT,
    ACTIONS(914), 1,
      anon_sym_LPAREN,
    STATE(318), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(878), 5,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(742), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [15705] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(800), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(798), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [15733] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(796), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(794), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [15761] = 5,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(926), 15,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [15793] = 7,
    ACTIONS(752), 1,
      anon_sym_STAR,
    ACTIONS(868), 1,
      anon_sym_DOT,
    ACTIONS(914), 1,
      anon_sym_LPAREN,
    STATE(316), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(866), 5,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(750), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [15829] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(840), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(838), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [15857] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(960), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(958), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(423), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [15899] = 4,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(926), 17,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [15929] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(960), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(962), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(425), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [15971] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(960), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(964), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(426), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [16013] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(960), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(966), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(428), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [16055] = 5,
    ACTIONS(914), 1,
      anon_sym_LPAREN,
    STATE(327), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(752), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(750), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16087] = 7,
    ACTIONS(744), 1,
      anon_sym_STAR,
    ACTIONS(860), 1,
      anon_sym_DOT,
    ACTIONS(914), 1,
      anon_sym_LPAREN,
    STATE(321), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(856), 5,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(742), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [16123] = 5,
    ACTIONS(914), 1,
      anon_sym_LPAREN,
    STATE(331), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(756), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(754), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16155] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(960), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(968), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(429), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [16197] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(872), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(870), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16225] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(970), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(430), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [16267] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(768), 3,
      anon_sym_STAR,
      anon_sym_DOT,
      anon_sym_COLON2,
    ACTIONS(766), 16,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_LPAREN,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16295] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(864), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(862), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16323] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(812), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(810), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16351] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(792), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(790), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16379] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(960), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(972), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(424), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [16421] = 6,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(926), 13,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [16455] = 7,
    ACTIONS(752), 1,
      anon_sym_STAR,
    ACTIONS(876), 1,
      anon_sym_DOT,
    ACTIONS(914), 1,
      anon_sym_LPAREN,
    STATE(317), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(874), 5,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(750), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [16491] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(818), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(816), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16519] = 4,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(926), 17,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [16549] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(834), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(832), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16577] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(892), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(416), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [16619] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(826), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(824), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16647] = 4,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(976), 17,
      anon_sym_LBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [16677] = 7,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(926), 10,
      anon_sym_LBRACE,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACK,
      sym_relation,
      sym_aggregate_function,
  [16713] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(822), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(820), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16741] = 11,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(984), 1,
      anon_sym_DOT_DOT,
    ACTIONS(986), 1,
      sym_relation,
    ACTIONS(988), 1,
      anon_sym_DOT,
    STATE(431), 1,
      aux_sym_comparison_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(918), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(916), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(982), 6,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
  [16785] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(830), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(828), 17,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16813] = 7,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(928), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(918), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(926), 12,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16849] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(990), 3,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
    ACTIONS(992), 16,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
      sym_aggregate_function,
  [16877] = 6,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(928), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(926), 14,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16911] = 4,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(928), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(926), 16,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [16941] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(994), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(403), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [16983] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(996), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(388), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [17025] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(998), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(404), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [17067] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(1000), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(405), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [17109] = 10,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(842), 1,
      sym_identifier,
    ACTIONS(848), 1,
      anon_sym_PIPE,
    ACTIONS(852), 1,
      anon_sym_LPAREN,
    STATE(315), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(846), 2,
      anon_sym_DASH,
      anon_sym_TILDE,
    ACTIONS(1002), 3,
      sym_supremum,
      sym_infimum,
      sym_number,
    STATE(389), 8,
      sym_string,
      sym__const_term,
      sym_const_binary_operation,
      sym_const_unary_operation,
      sym_const_abs,
      sym_const_function,
      sym_const_tuple,
      sym_metasp_const_function,
  [17151] = 4,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(928), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(926), 16,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17181] = 4,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(978), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(976), 16,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_AT,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17211] = 9,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(984), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1006), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(918), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(916), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1004), 7,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17250] = 11,
    ACTIONS(988), 1,
      anon_sym_DOT,
    ACTIONS(1012), 1,
      anon_sym_STAR,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1020), 1,
      sym_relation,
    STATE(457), 1,
      aux_sym_comparison_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1010), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1014), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1008), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(982), 5,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
  [17293] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(792), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(790), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17319] = 9,
    ACTIONS(1006), 1,
      anon_sym_DOT,
    ACTIONS(1012), 1,
      anon_sym_STAR,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1010), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1014), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1008), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1004), 6,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17357] = 5,
    ACTIONS(1024), 1,
      anon_sym_STAR,
    ACTIONS(1026), 1,
      anon_sym_LPAREN,
    STATE(351), 1,
      sym__const_arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1022), 14,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON2,
  [17387] = 5,
    ACTIONS(818), 1,
      anon_sym_STAR,
    ACTIONS(912), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(910), 5,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(816), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [17417] = 5,
    ACTIONS(818), 1,
      anon_sym_STAR,
    ACTIONS(902), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(900), 5,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(816), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [17447] = 5,
    ACTIONS(834), 1,
      anon_sym_STAR,
    ACTIONS(898), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(896), 5,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(832), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [17477] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1028), 2,
      sym_identifier,
      sym_anonymous,
    ACTIONS(1030), 15,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_aggregate_function,
  [17503] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1032), 3,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
    ACTIONS(1034), 14,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
  [17529] = 5,
    ACTIONS(834), 1,
      anon_sym_STAR,
    ACTIONS(906), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(904), 5,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_COLON_DASH,
    ACTIONS(832), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [17559] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(796), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(794), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17585] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(840), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(838), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17611] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(788), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(786), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17637] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(812), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(810), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17663] = 4,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(978), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(976), 14,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17691] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(818), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(816), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17717] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(834), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(832), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17743] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(822), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(820), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17769] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1036), 3,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
    ACTIONS(1038), 14,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
  [17795] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(830), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(828), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17821] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1036), 3,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
    ACTIONS(1038), 14,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
  [17847] = 7,
    ACTIONS(928), 1,
      anon_sym_DOT,
    ACTIONS(1012), 1,
      anon_sym_STAR,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1010), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1014), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(926), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17881] = 6,
    ACTIONS(928), 1,
      anon_sym_DOT,
    ACTIONS(1012), 1,
      anon_sym_STAR,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1014), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(926), 12,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17913] = 4,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(928), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(926), 14,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17941] = 4,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(928), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(926), 14,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [17969] = 8,
    ACTIONS(928), 1,
      anon_sym_DOT,
    ACTIONS(1012), 1,
      anon_sym_STAR,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1010), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1014), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1008), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(926), 7,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [18005] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(804), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(802), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [18031] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(808), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(806), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [18057] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1040), 3,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
    ACTIONS(1042), 14,
      anon_sym_DQUOTE,
      anon_sym_f_DQUOTE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_TILDE,
      anon_sym_PIPE,
      anon_sym_LPAREN,
      anon_sym_AT,
      sym_boolean_constant,
      sym_double_default_negation,
  [18083] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(800), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(798), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [18109] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(826), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(824), 15,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_DOT_DOT,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      sym_relation,
      anon_sym_COLON_DASH,
  [18135] = 6,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    ACTIONS(752), 1,
      anon_sym_STAR,
    STATE(316), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(866), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(750), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [18166] = 6,
    ACTIONS(744), 1,
      anon_sym_STAR,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    STATE(321), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(856), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(742), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [18197] = 6,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    ACTIONS(752), 1,
      anon_sym_STAR,
    STATE(317), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(874), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(750), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [18228] = 6,
    ACTIONS(744), 1,
      anon_sym_STAR,
    ACTIONS(746), 1,
      anon_sym_LPAREN,
    STATE(318), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(878), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(742), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
      sym_relation,
  [18259] = 10,
    ACTIONS(726), 1,
      anon_sym_DQUOTE,
    ACTIONS(728), 1,
      anon_sym_LBRACE,
    ACTIONS(732), 1,
      sym_anonymous,
    ACTIONS(736), 1,
      anon_sym_LPAREN,
    ACTIONS(740), 1,
      anon_sym_LBRACK,
    ACTIONS(1044), 1,
      sym_identifier,
    STATE(441), 1,
      sym_theory_root_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(730), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(436), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [18298] = 10,
    ACTIONS(700), 1,
      anon_sym_DQUOTE,
    ACTIONS(702), 1,
      anon_sym_LBRACE,
    ACTIONS(706), 1,
      sym_anonymous,
    ACTIONS(708), 1,
      anon_sym_LPAREN,
    ACTIONS(712), 1,
      anon_sym_LBRACK,
    ACTIONS(1046), 1,
      sym_identifier,
    STATE(506), 1,
      sym_theory_root_term,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(704), 4,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
    STATE(497), 5,
      sym_string,
      sym_theory_function,
      sym_theory_tuple,
      sym_theory_list,
      sym_theory_set,
  [18337] = 6,
    ACTIONS(944), 1,
      anon_sym_STAR,
    ACTIONS(948), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(946), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(926), 9,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_DOT_DOT,
  [18367] = 5,
    ACTIONS(1026), 1,
      anon_sym_LPAREN,
    ACTIONS(1050), 1,
      anon_sym_STAR,
    STATE(380), 1,
      sym__const_arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1048), 12,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT,
  [18395] = 3,
    ACTIONS(1054), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1052), 14,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON2,
  [18419] = 10,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(984), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1056), 1,
      anon_sym_COMMA2,
    STATE(529), 1,
      aux_sym_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(918), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(916), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1058), 3,
      sym_colon,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [18457] = 3,
    ACTIONS(1062), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1060), 14,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON2,
  [18481] = 9,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(984), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1066), 1,
      anon_sym_AT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(918), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(916), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1064), 4,
      sym_colon,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [18517] = 3,
    ACTIONS(1070), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1068), 14,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON2,
  [18541] = 10,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1074), 1,
      sym_relation,
    STATE(521), 1,
      aux_sym_comparison_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(982), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [18579] = 3,
    ACTIONS(872), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(870), 14,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
  [18603] = 3,
    ACTIONS(864), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(862), 14,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
  [18627] = 5,
    ACTIONS(944), 1,
      anon_sym_STAR,
    ACTIONS(948), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(946), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(926), 11,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DOT_DOT,
  [18655] = 4,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(948), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(926), 13,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_DOT,
  [18681] = 4,
    ACTIONS(928), 1,
      anon_sym_STAR,
    ACTIONS(948), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(926), 13,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_DOT,
  [18707] = 7,
    ACTIONS(944), 1,
      anon_sym_STAR,
    ACTIONS(948), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(942), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(946), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(940), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(926), 6,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
      anon_sym_DOT_DOT,
  [18739] = 4,
    ACTIONS(948), 1,
      anon_sym_STAR_STAR,
    ACTIONS(978), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(976), 13,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT_DOT,
  [18765] = 8,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(984), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(918), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(916), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1076), 4,
      sym_colon,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [18798] = 6,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(1078), 1,
      anon_sym_SLASH,
    STATE(292), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(744), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(742), 9,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
  [18827] = 8,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(984), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(918), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(916), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1081), 4,
      sym_colon,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [18860] = 6,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(1083), 1,
      anon_sym_SLASH,
    STATE(290), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(752), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(750), 9,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
  [18889] = 9,
    ACTIONS(1012), 1,
      anon_sym_STAR,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1088), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1010), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1014), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1008), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1086), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_COLON_DASH,
  [18924] = 6,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(1090), 1,
      anon_sym_SLASH,
    STATE(290), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(752), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(750), 9,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
  [18953] = 6,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(1093), 1,
      anon_sym_SLASH,
    STATE(292), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(744), 2,
      anon_sym_STAR,
      anon_sym_DOT,
    ACTIONS(742), 9,
      sym_colon,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_DOT_DOT,
  [18982] = 9,
    ACTIONS(1012), 1,
      anon_sym_STAR,
    ACTIONS(1016), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1018), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1098), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1010), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1014), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1008), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1096), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_COLON_DASH,
  [19017] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1004), 4,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      sym_relation,
  [19050] = 3,
    ACTIONS(1102), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1100), 12,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT,
  [19072] = 3,
    ACTIONS(1106), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1104), 12,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT,
  [19094] = 3,
    ACTIONS(1110), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1108), 12,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT,
  [19116] = 10,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1058), 1,
      anon_sym_RBRACK,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1112), 1,
      anon_sym_COMMA2,
    STATE(664), 1,
      aux_sym_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19152] = 9,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1114), 1,
      anon_sym_AT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1064), 2,
      anon_sym_COMMA2,
      anon_sym_RBRACK,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19186] = 10,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1116), 1,
      anon_sym_PIPE,
    ACTIONS(1118), 1,
      anon_sym_SEMI,
    STATE(651), 1,
      aux_sym_abs_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19222] = 6,
    ACTIONS(716), 1,
      sym_default_negation,
    ACTIONS(1124), 1,
      sym_theory_operator,
    STATE(385), 1,
      aux_sym_theory_operators_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1120), 2,
      sym_identifier,
      sym_anonymous,
    ACTIONS(1122), 8,
      anon_sym_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [19250] = 3,
    ACTIONS(1128), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1126), 12,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT,
  [19272] = 3,
    ACTIONS(1132), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1130), 12,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_STAR_STAR,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_DOT,
  [19294] = 10,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1118), 1,
      anon_sym_SEMI,
    ACTIONS(1134), 1,
      anon_sym_PIPE,
    STATE(699), 1,
      aux_sym_abs_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19330] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
    ACTIONS(1136), 3,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [19362] = 9,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1136), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1138), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19396] = 6,
    ACTIONS(1144), 1,
      sym_theory_operator,
    ACTIONS(1147), 1,
      sym_default_negation,
    STATE(385), 1,
      aux_sym_theory_operators_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1140), 2,
      sym_identifier,
      sym_anonymous,
    ACTIONS(1142), 8,
      anon_sym_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_LPAREN,
      anon_sym_LBRACK,
  [19424] = 9,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1152), 1,
      sym_relation,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1150), 2,
      anon_sym_LBRACE,
      sym_aggregate_function,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19458] = 10,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1118), 1,
      anon_sym_SEMI,
    ACTIONS(1154), 1,
      anon_sym_PIPE,
    STATE(706), 1,
      aux_sym_abs_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19494] = 6,
    ACTIONS(1160), 1,
      anon_sym_STAR,
    ACTIONS(1164), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1162), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1156), 6,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
  [19521] = 4,
    ACTIONS(1164), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1166), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1156), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
  [19544] = 9,
    ACTIONS(920), 1,
      anon_sym_STAR,
    ACTIONS(924), 1,
      anon_sym_STAR_STAR,
    ACTIONS(984), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1168), 1,
      anon_sym_DOT,
    ACTIONS(1170), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(918), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(922), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(916), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19577] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1086), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19608] = 9,
    ACTIONS(1160), 1,
      anon_sym_STAR,
    ACTIONS(1164), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1174), 1,
      anon_sym_COMMA2,
    ACTIONS(1176), 1,
      anon_sym_RPAREN2,
    STATE(615), 1,
      aux_sym_const_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1162), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1172), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19641] = 9,
    ACTIONS(1160), 1,
      anon_sym_STAR,
    ACTIONS(1164), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1178), 1,
      anon_sym_COMMA2,
    ACTIONS(1180), 1,
      anon_sym_RPAREN2,
    STATE(692), 1,
      aux_sym_const_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1162), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1172), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19674] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1096), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19705] = 8,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(1186), 1,
      sym_default_negation,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(397), 1,
      aux_sym_theory_unparsed_term_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1184), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1182), 4,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
  [19736] = 8,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(1186), 1,
      sym_default_negation,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(398), 1,
      aux_sym_theory_unparsed_term_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1190), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1188), 4,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
  [19767] = 8,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(1186), 1,
      sym_default_negation,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(398), 1,
      aux_sym_theory_unparsed_term_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1194), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1192), 4,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
  [19798] = 8,
    ACTIONS(1200), 1,
      sym_theory_operator,
    ACTIONS(1203), 1,
      sym_default_negation,
    STATE(347), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(398), 1,
      aux_sym_theory_unparsed_term_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1198), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1196), 4,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
  [19829] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1076), 2,
      anon_sym_COMMA2,
      anon_sym_RBRACK,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19860] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1206), 3,
      sym_identifier,
      sym_anonymous,
      sym_default_negation,
    ACTIONS(1208), 9,
      anon_sym_DQUOTE,
      anon_sym_LBRACE,
      sym_supremum,
      sym_infimum,
      sym_number,
      sym_variable,
      anon_sym_LPAREN,
      sym_theory_operator,
      anon_sym_LBRACK,
  [19881] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1210), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19912] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1212), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [19943] = 4,
    ACTIONS(1164), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1216), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1214), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
  [19966] = 5,
    ACTIONS(1160), 1,
      anon_sym_STAR,
    ACTIONS(1164), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1162), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1156), 8,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
  [19991] = 4,
    ACTIONS(1164), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1166), 1,
      anon_sym_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1156), 10,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
  [20014] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1081), 2,
      anon_sym_COMMA2,
      anon_sym_RBRACK,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20045] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1218), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20075] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1220), 1,
      sym_relation,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20105] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1222), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20135] = 12,
    ACTIONS(1224), 1,
      anon_sym_RBRACE2,
    ACTIONS(1226), 1,
      anon_sym_expressions,
    ACTIONS(1228), 1,
      anon_sym_subtypes,
    ACTIONS(1230), 1,
      anon_sym_macros,
    ACTIONS(1232), 1,
      anon_sym_occurrence,
    STATE(415), 1,
      aux_sym_metasp_type_repeat1,
    STATE(520), 1,
      sym_metasp_type_keyword,
    STATE(527), 1,
      sym_metasp_subtypes,
    STATE(534), 1,
      sym_metasp_macros,
    STATE(541), 1,
      sym_metasp_occurrence,
    STATE(546), 1,
      sym_metasp_expression_definitions,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [20173] = 5,
    ACTIONS(1236), 1,
      anon_sym_LPAREN,
    STATE(453), 1,
      sym__theory_arguments,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1238), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1234), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [20197] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1240), 1,
      sym_relation,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20227] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1242), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20257] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1244), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20287] = 12,
    ACTIONS(1226), 1,
      anon_sym_expressions,
    ACTIONS(1228), 1,
      anon_sym_subtypes,
    ACTIONS(1230), 1,
      anon_sym_macros,
    ACTIONS(1232), 1,
      anon_sym_occurrence,
    ACTIONS(1246), 1,
      anon_sym_RBRACE2,
    STATE(417), 1,
      aux_sym_metasp_type_repeat1,
    STATE(520), 1,
      sym_metasp_type_keyword,
    STATE(527), 1,
      sym_metasp_subtypes,
    STATE(534), 1,
      sym_metasp_macros,
    STATE(541), 1,
      sym_metasp_occurrence,
    STATE(546), 1,
      sym_metasp_expression_definitions,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [20325] = 7,
    ACTIONS(1160), 1,
      anon_sym_STAR,
    ACTIONS(1164), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1162), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1248), 2,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
    ACTIONS(1172), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20353] = 12,
    ACTIONS(1250), 1,
      anon_sym_RBRACE2,
    ACTIONS(1252), 1,
      anon_sym_expressions,
    ACTIONS(1255), 1,
      anon_sym_subtypes,
    ACTIONS(1258), 1,
      anon_sym_macros,
    ACTIONS(1261), 1,
      anon_sym_occurrence,
    STATE(417), 1,
      aux_sym_metasp_type_repeat1,
    STATE(520), 1,
      sym_metasp_type_keyword,
    STATE(527), 1,
      sym_metasp_subtypes,
    STATE(534), 1,
      sym_metasp_macros,
    STATE(541), 1,
      sym_metasp_occurrence,
    STATE(546), 1,
      sym_metasp_expression_definitions,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [20391] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1264), 1,
      sym_relation,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20421] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1266), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20451] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1268), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20481] = 8,
    ACTIONS(952), 1,
      anon_sym_STAR,
    ACTIONS(956), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1072), 1,
      anon_sym_DOT_DOT,
    ACTIONS(1270), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(954), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(974), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(980), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20511] = 9,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(1272), 1,
      sym_identifier,
    ACTIONS(1274), 1,
      anon_sym_DASH,
    STATE(537), 1,
      sym__metasp_identifier,
    STATE(735), 1,
      sym_extended_symbolic_atom,
    STATE(846), 1,
      sym_extended_signature,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(799), 2,
      sym_symbolic_atom,
      sym_metasp_symbolic_atom,
    STATE(813), 2,
      sym_signature,
      sym_metasp_signature,
  [20542] = 6,
    ACTIONS(1278), 1,
      anon_sym_STAR,
    ACTIONS(1282), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1276), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1280), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1156), 4,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_DOT,
  [20567] = 5,
    ACTIONS(1278), 1,
      anon_sym_STAR,
    ACTIONS(1282), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1280), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1156), 6,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_DOT,
  [20590] = 4,
    ACTIONS(1166), 1,
      anon_sym_STAR,
    ACTIONS(1282), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1156), 8,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT,
  [20611] = 4,
    ACTIONS(1166), 1,
      anon_sym_STAR,
    ACTIONS(1282), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1156), 8,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT,
  [20632] = 7,
    ACTIONS(1284), 1,
      anon_sym_STAR_PERCENT,
    ACTIONS(1288), 1,
      sym__doc_token_args,
    STATE(463), 1,
      aux_sym_doc_desc_repeat1,
    STATE(659), 1,
      sym_doc_desc,
    STATE(834), 1,
      sym_doc_args,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1286), 5,
      sym_doc_fragment_string,
      sym_doc_fragment_emph,
      sym_doc_fragment_bold,
      sym_doc_fragment_italic,
      sym_doc_fragment_code,
  [20659] = 4,
    ACTIONS(1216), 1,
      anon_sym_STAR,
    ACTIONS(1282), 1,
      anon_sym_STAR_STAR,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1214), 8,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
      anon_sym_PLUS,
      anon_sym_DASH,
      anon_sym_SLASH,
      anon_sym_BSLASH,
      anon_sym_DOT,
  [20680] = 7,
    ACTIONS(1278), 1,
      anon_sym_STAR,
    ACTIONS(1282), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1292), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1276), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1280), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1290), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20707] = 7,
    ACTIONS(1160), 1,
      anon_sym_STAR,
    ACTIONS(1164), 1,
      anon_sym_STAR_STAR,
    ACTIONS(1294), 1,
      anon_sym_PIPE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1158), 2,
      anon_sym_PLUS,
      anon_sym_DASH,
    ACTIONS(1162), 2,
      anon_sym_SLASH,
      anon_sym_BSLASH,
    ACTIONS(1172), 3,
      anon_sym_CARET,
      anon_sym_QMARK,
      anon_sym_AMP,
  [20734] = 4,
    ACTIONS(986), 1,
      sym_relation,
    STATE(435), 1,
      aux_sym_comparison_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1296), 7,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [20754] = 9,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(1298), 1,
      sym_identifier,
    ACTIONS(1300), 1,
      anon_sym_RBRACE2,
    ACTIONS(1302), 1,
      anon_sym_where,
    STATE(315), 1,
      sym__metasp_identifier,
    STATE(811), 1,
      sym_metasp_macro_where,
    STATE(893), 1,
      sym_metasp_const_function,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(455), 2,
      sym_metasp_macro_definition,
      aux_sym_metasp_macros_repeat1,
  [20784] = 9,
    ACTIONS(1304), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_COMMA2,
    ACTIONS(1308), 1,
      anon_sym_SEMI,
    ACTIONS(1310), 1,
      anon_sym_RBRACE2,
    STATE(638), 1,
      sym_metasp_keyword_arg,
    STATE(639), 1,
      aux_sym_metasp_argument_definition_repeat1,
    STATE(890), 1,
      sym_metasp_argument_definitions,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(454), 2,
      sym_metasp_argument_definition,
      aux_sym_metasp_argument_definitions_repeat1,
  [20814] = 5,
    STATE(464), 1,
      aux_sym_doc_desc_repeat1,
    STATE(743), 1,
      sym_doc_desc,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1312), 2,
      sym__doc_token_minus,
      anon_sym_STAR_PERCENT,
    ACTIONS(1314), 5,
      sym_doc_fragment_string,
      sym_doc_fragment_emph,
      sym_doc_fragment_bold,
      sym_doc_fragment_italic,
      sym_doc_fragment_code,
  [20836] = 4,
    ACTIONS(1316), 1,
      sym_relation,
    STATE(435), 1,
      aux_sym_comparison_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1004), 7,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [20856] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1321), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1319), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [20874] = 9,
    ACTIONS(492), 1,
      anon_sym_AMP,
    ACTIONS(1298), 1,
      sym_identifier,
    ACTIONS(1302), 1,
      anon_sym_where,
    ACTIONS(1323), 1,
      anon_sym_RBRACE2,
    STATE(315), 1,
      sym__metasp_identifier,
    STATE(893), 1,
      sym_metasp_const_function,
    STATE(899), 1,
      sym_metasp_macro_where,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(432), 2,
      sym_metasp_macro_definition,
      aux_sym_metasp_macros_repeat1,
  [20904] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1327), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1325), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [20922] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1331), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1329), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [20940] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1335), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1333), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [20958] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1198), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1196), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [20976] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1339), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1337), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [20994] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1343), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1341), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21012] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1347), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1345), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21030] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1351), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1349), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21048] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1355), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1353), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21066] = 8,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(1184), 1,
      anon_sym_SEMI,
    ACTIONS(1186), 1,
      sym_default_negation,
    STATE(348), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(451), 1,
      aux_sym_theory_unparsed_term_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1182), 3,
      sym_colon,
      anon_sym_COMMA2,
      anon_sym_RBRACE2,
  [21094] = 8,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(1186), 1,
      sym_default_negation,
    ACTIONS(1190), 1,
      anon_sym_SEMI,
    STATE(348), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(452), 1,
      aux_sym_theory_unparsed_term_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1188), 3,
      sym_colon,
      anon_sym_COMMA2,
      anon_sym_RBRACE2,
  [21122] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(872), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(870), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21140] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(864), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(862), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21158] = 8,
    ACTIONS(710), 1,
      sym_theory_operator,
    ACTIONS(1186), 1,
      sym_default_negation,
    ACTIONS(1194), 1,
      anon_sym_SEMI,
    STATE(348), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(452), 1,
      aux_sym_theory_unparsed_term_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1192), 3,
      sym_colon,
      anon_sym_COMMA2,
      anon_sym_RBRACE2,
  [21186] = 8,
    ACTIONS(1198), 1,
      anon_sym_SEMI,
    ACTIONS(1200), 1,
      sym_theory_operator,
    ACTIONS(1203), 1,
      sym_default_negation,
    STATE(348), 1,
      sym_theory_operators,
    STATE(379), 1,
      aux_sym_theory_operators_repeat1,
    STATE(452), 1,
      aux_sym_theory_unparsed_term_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1196), 3,
      sym_colon,
      anon_sym_COMMA2,
      anon_sym_RBRACE2,
  [21214] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1359), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1357), 6,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      sym_theory_operator,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21232] = 8,
    ACTIONS(1304), 1,
      sym_identifier,
    ACTIONS(1306), 1,
      anon_sym_COMMA2,
    ACTIONS(1308), 1,
      anon_sym_SEMI,
    ACTIONS(1361), 1,
      anon_sym_RBRACE2,
    STATE(638), 1,
      sym_metasp_keyword_arg,
    STATE(639), 1,
      aux_sym_metasp_argument_definition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(460), 2,
      sym_metasp_argument_definition,
      aux_sym_metasp_argument_definitions_repeat1,
  [21259] = 8,
    ACTIONS(1363), 1,
      sym_identifier,
    ACTIONS(1366), 1,
      anon_sym_AMP,
    ACTIONS(1369), 1,
      anon_sym_RBRACE2,
    ACTIONS(1371), 1,
      anon_sym_where,
    STATE(315), 1,
      sym__metasp_identifier,
    STATE(893), 1,
      sym_metasp_const_function,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(455), 2,
      sym_metasp_macro_definition,
      aux_sym_metasp_macros_repeat1,
  [21286] = 10,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1373), 1,
      aux_sym_fstring_accessor_token3,
    ACTIONS(1375), 1,
      sym_fstring_align,
    ACTIONS(1377), 1,
      sym_fstring_sign,
    ACTIONS(1379), 1,
      sym_fstring_alternate,
    ACTIONS(1381), 1,
      sym_fstring_grouping,
    ACTIONS(1383), 1,
      sym_fstring_type,
    ACTIONS(1385), 1,
      anon_sym_RBRACE,
    STATE(655), 1,
      sym_fstring_width,
  [21317] = 4,
    ACTIONS(1020), 1,
      sym_relation,
    STATE(465), 1,
      aux_sym_comparison_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1296), 6,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21336] = 4,
    STATE(458), 1,
      aux_sym_doc_desc_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1387), 2,
      sym__doc_token_minus,
      anon_sym_STAR_PERCENT,
    ACTIONS(1389), 5,
      sym_doc_fragment_string,
      sym_doc_fragment_emph,
      sym_doc_fragment_bold,
      sym_doc_fragment_italic,
      sym_doc_fragment_code,
  [21355] = 5,
    ACTIONS(1238), 1,
      anon_sym_SEMI,
    ACTIONS(1392), 1,
      anon_sym_LPAREN,
    STATE(486), 1,
      sym__theory_arguments,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1234), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21376] = 8,
    ACTIONS(1394), 1,
      sym_identifier,
    ACTIONS(1397), 1,
      anon_sym_COMMA2,
    ACTIONS(1400), 1,
      anon_sym_SEMI,
    ACTIONS(1403), 1,
      anon_sym_RBRACE2,
    STATE(638), 1,
      sym_metasp_keyword_arg,
    STATE(639), 1,
      aux_sym_metasp_argument_definition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(460), 2,
      sym_metasp_argument_definition,
      aux_sym_metasp_argument_definitions_repeat1,
  [21403] = 4,
    STATE(461), 1,
      aux_sym_doc_desc_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1387), 2,
      sym__doc_token_args,
      anon_sym_STAR_PERCENT,
    ACTIONS(1405), 5,
      sym_doc_fragment_string,
      sym_doc_fragment_emph,
      sym_doc_fragment_bold,
      sym_doc_fragment_italic,
      sym_doc_fragment_code,
  [21422] = 3,
    ACTIONS(1410), 1,
      sym__doc_token_paren,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1408), 7,
      sym_doc_fragment_string,
      sym__doc_token_args,
      anon_sym_STAR_PERCENT,
      sym_doc_fragment_emph,
      sym_doc_fragment_bold,
      sym_doc_fragment_italic,
      sym_doc_fragment_code,
  [21439] = 4,
    STATE(461), 1,
      aux_sym_doc_desc_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1412), 2,
      sym__doc_token_args,
      anon_sym_STAR_PERCENT,
    ACTIONS(1414), 5,
      sym_doc_fragment_string,
      sym_doc_fragment_emph,
      sym_doc_fragment_bold,
      sym_doc_fragment_italic,
      sym_doc_fragment_code,
  [21458] = 4,
    STATE(458), 1,
      aux_sym_doc_desc_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1412), 2,
      sym__doc_token_minus,
      anon_sym_STAR_PERCENT,
    ACTIONS(1416), 5,
      sym_doc_fragment_string,
      sym_doc_fragment_emph,
      sym_doc_fragment_bold,
      sym_doc_fragment_italic,
      sym_doc_fragment_code,
  [21477] = 4,
    ACTIONS(1418), 1,
      sym_relation,
    STATE(465), 1,
      aux_sym_comparison_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1004), 6,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21496] = 6,
    ACTIONS(1421), 1,
      anon_sym_COMMA2,
    ACTIONS(1425), 1,
      sym_theory_operator,
    ACTIONS(1427), 1,
      sym_default_negation,
    STATE(573), 1,
      sym_theory_atom_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1423), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21518] = 8,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(1429), 1,
      anon_sym_DASH,
    ACTIONS(1431), 1,
      anon_sym_RBRACE2,
    STATE(476), 1,
      aux_sym_metasp_expression_definitions_repeat1,
    STATE(766), 1,
      sym_metasp_signature,
    STATE(830), 1,
      sym__metasp_identifier,
    STATE(877), 1,
      sym_metasp_expression_definition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [21544] = 4,
    ACTIONS(1435), 1,
      anon_sym_COMMA2,
    STATE(475), 1,
      aux_sym_condition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1433), 5,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21562] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1437), 7,
      sym_doc_fragment_string,
      sym__doc_token_args,
      anon_sym_STAR_PERCENT,
      sym_doc_fragment_emph,
      sym_doc_fragment_bold,
      sym_doc_fragment_italic,
      sym_doc_fragment_code,
  [21576] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1182), 7,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21590] = 4,
    ACTIONS(1441), 1,
      anon_sym_COMMA2,
    STATE(471), 1,
      aux_sym_condition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1439), 5,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21608] = 8,
    ACTIONS(1444), 1,
      anon_sym_AMP,
    ACTIONS(1447), 1,
      anon_sym_DASH,
    ACTIONS(1450), 1,
      anon_sym_RBRACE2,
    STATE(472), 1,
      aux_sym_metasp_expression_definitions_repeat1,
    STATE(766), 1,
      sym_metasp_signature,
    STATE(830), 1,
      sym__metasp_identifier,
    STATE(877), 1,
      sym_metasp_expression_definition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [21634] = 7,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(1452), 1,
      sym_identifier,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    STATE(609), 1,
      sym__metasp_identifier,
    STATE(767), 1,
      sym_extended_symbolic_atom,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(799), 2,
      sym_symbolic_atom,
      sym_metasp_symbolic_atom,
  [21658] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1456), 7,
      sym_doc_fragment_string,
      sym__doc_token_args,
      anon_sym_STAR_PERCENT,
      sym_doc_fragment_emph,
      sym_doc_fragment_bold,
      sym_doc_fragment_italic,
      sym_doc_fragment_code,
  [21672] = 4,
    ACTIONS(1435), 1,
      anon_sym_COMMA2,
    STATE(471), 1,
      aux_sym_condition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1458), 5,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21690] = 8,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(1429), 1,
      anon_sym_DASH,
    ACTIONS(1460), 1,
      anon_sym_RBRACE2,
    STATE(472), 1,
      aux_sym_metasp_expression_definitions_repeat1,
    STATE(766), 1,
      sym_metasp_signature,
    STATE(830), 1,
      sym__metasp_identifier,
    STATE(877), 1,
      sym_metasp_expression_definition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [21716] = 7,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(1452), 1,
      sym_identifier,
    ACTIONS(1454), 1,
      anon_sym_DASH,
    STATE(609), 1,
      sym__metasp_identifier,
    STATE(760), 1,
      sym_extended_symbolic_atom,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(799), 2,
      sym_symbolic_atom,
      sym_metasp_symbolic_atom,
  [21740] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1462), 7,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21754] = 6,
    ACTIONS(1425), 1,
      sym_theory_operator,
    ACTIONS(1427), 1,
      sym_default_negation,
    ACTIONS(1464), 1,
      anon_sym_COMMA2,
    STATE(578), 1,
      sym_theory_atom_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1466), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21776] = 6,
    ACTIONS(1425), 1,
      sym_theory_operator,
    ACTIONS(1427), 1,
      sym_default_negation,
    ACTIONS(1468), 1,
      anon_sym_COMMA2,
    STATE(579), 1,
      sym_theory_atom_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1470), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21798] = 9,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1472), 1,
      aux_sym_fstring_accessor_token3,
    ACTIONS(1474), 1,
      sym_fstring_sign,
    ACTIONS(1476), 1,
      sym_fstring_alternate,
    ACTIONS(1478), 1,
      sym_fstring_grouping,
    ACTIONS(1480), 1,
      sym_fstring_type,
    ACTIONS(1482), 1,
      anon_sym_RBRACE,
    STATE(666), 1,
      sym_fstring_width,
  [21826] = 7,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(1484), 1,
      sym_identifier,
    ACTIONS(1486), 1,
      anon_sym_DASH,
    STATE(823), 1,
      sym_extended_signature,
    STATE(830), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(813), 2,
      sym_signature,
      sym_metasp_signature,
  [21850] = 6,
    ACTIONS(1425), 1,
      sym_theory_operator,
    ACTIONS(1427), 1,
      sym_default_negation,
    ACTIONS(1488), 1,
      anon_sym_COMMA2,
    STATE(581), 1,
      sym_theory_atom_upper,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1490), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21872] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1492), 7,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21886] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1494), 7,
      sym_colon,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [21900] = 3,
    ACTIONS(1359), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1357), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21915] = 3,
    ACTIONS(1355), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1353), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21930] = 4,
    ACTIONS(1500), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1498), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1496), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [21947] = 3,
    ACTIONS(1327), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1325), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [21962] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1502), 1,
      anon_sym_DQUOTE,
    ACTIONS(1506), 1,
      anon_sym_LBRACE,
    ACTIONS(1504), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
    STATE(514), 2,
      sym_fstring_field,
      aux_sym_fstring_repeat1,
  [21983] = 7,
    ACTIONS(1472), 1,
      aux_sym_fstring_accessor_token3,
    ACTIONS(1508), 1,
      sym_fstring_alternate,
    ACTIONS(1510), 1,
      sym_fstring_grouping,
    ACTIONS(1512), 1,
      sym_fstring_type,
    ACTIONS(1514), 1,
      anon_sym_RBRACE,
    STATE(612), 1,
      sym_fstring_width,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [22006] = 3,
    ACTIONS(1339), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1337), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22021] = 5,
    ACTIONS(932), 1,
      aux_sym_fstring_accessor_token2,
    ACTIONS(1516), 1,
      aux_sym_fstring_accessor_token1,
    STATE(513), 1,
      aux_sym_fstring_accessor_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1518), 3,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
  [22040] = 3,
    ACTIONS(1343), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1341), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22055] = 3,
    ACTIONS(1347), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1345), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22070] = 3,
    ACTIONS(872), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(870), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22085] = 3,
    ACTIONS(1321), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1319), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22100] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1439), 6,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [22113] = 3,
    ACTIONS(1351), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1349), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22128] = 3,
    ACTIONS(864), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(862), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22143] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1462), 6,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [22156] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1494), 6,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [22169] = 3,
    ACTIONS(1331), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1329), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22184] = 3,
    ACTIONS(1335), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1333), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22199] = 4,
    ACTIONS(1500), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1520), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
    ACTIONS(1496), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [22216] = 3,
    ACTIONS(1198), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1196), 5,
      sym_colon,
      anon_sym_COMMA2,
      sym_theory_operator,
      anon_sym_RBRACE2,
      sym_default_negation,
  [22231] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1506), 1,
      anon_sym_LBRACE,
    ACTIONS(1522), 1,
      anon_sym_DQUOTE,
    ACTIONS(1524), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
    STATE(508), 2,
      sym_fstring_field,
      aux_sym_fstring_repeat1,
  [22252] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1506), 1,
      anon_sym_LBRACE,
    ACTIONS(1526), 1,
      anon_sym_DQUOTE,
    ACTIONS(1504), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
    STATE(514), 2,
      sym_fstring_field,
      aux_sym_fstring_repeat1,
  [22273] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1492), 6,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [22286] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1506), 1,
      anon_sym_LBRACE,
    ACTIONS(1528), 1,
      anon_sym_DQUOTE,
    ACTIONS(1530), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
    STATE(490), 2,
      sym_fstring_field,
      aux_sym_fstring_repeat1,
  [22307] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1506), 1,
      anon_sym_LBRACE,
    ACTIONS(1532), 1,
      anon_sym_DQUOTE,
    ACTIONS(1534), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
    STATE(512), 2,
      sym_fstring_field,
      aux_sym_fstring_repeat1,
  [22328] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1506), 1,
      anon_sym_LBRACE,
    ACTIONS(1536), 1,
      anon_sym_DQUOTE,
    ACTIONS(1504), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
    STATE(514), 2,
      sym_fstring_field,
      aux_sym_fstring_repeat1,
  [22349] = 5,
    ACTIONS(1538), 1,
      aux_sym_fstring_accessor_token1,
    ACTIONS(1541), 1,
      aux_sym_fstring_accessor_token2,
    STATE(513), 1,
      aux_sym_fstring_accessor_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1544), 3,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
  [22368] = 6,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1546), 1,
      anon_sym_DQUOTE,
    ACTIONS(1551), 1,
      anon_sym_LBRACE,
    ACTIONS(1548), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
    STATE(514), 2,
      sym_fstring_field,
      aux_sym_fstring_repeat1,
  [22389] = 7,
    ACTIONS(1472), 1,
      aux_sym_fstring_accessor_token3,
    ACTIONS(1476), 1,
      sym_fstring_alternate,
    ACTIONS(1478), 1,
      sym_fstring_grouping,
    ACTIONS(1480), 1,
      sym_fstring_type,
    ACTIONS(1482), 1,
      anon_sym_RBRACE,
    STATE(666), 1,
      sym_fstring_width,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [22412] = 4,
    ACTIONS(1554), 1,
      anon_sym_COMMA2,
    STATE(531), 1,
      aux_sym_theory_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1556), 3,
      sym_colon,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [22428] = 4,
    ACTIONS(1558), 1,
      anon_sym_COMMA2,
    STATE(517), 1,
      aux_sym_theory_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1561), 3,
      sym_colon,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [22444] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1563), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22456] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1565), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22468] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1567), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22480] = 4,
    ACTIONS(1074), 1,
      sym_relation,
    STATE(523), 1,
      aux_sym_comparison_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1296), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [22496] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1569), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22508] = 4,
    ACTIONS(1571), 1,
      sym_relation,
    STATE(523), 1,
      aux_sym_comparison_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1004), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [22524] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1574), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22536] = 5,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(1576), 1,
      anon_sym_SLASH,
    STATE(723), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(866), 2,
      sym_colon,
      anon_sym_DOT,
  [22554] = 4,
    ACTIONS(1578), 1,
      anon_sym_COMMA2,
    STATE(526), 1,
      aux_sym_theory_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1561), 3,
      anon_sym_RPAREN2,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
  [22570] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1581), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22582] = 5,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(1583), 1,
      anon_sym_SLASH,
    STATE(796), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(874), 2,
      sym_colon,
      anon_sym_DOT,
  [22600] = 4,
    ACTIONS(1056), 1,
      anon_sym_COMMA2,
    STATE(543), 1,
      aux_sym_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1585), 3,
      sym_colon,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [22616] = 6,
    ACTIONS(1472), 1,
      aux_sym_fstring_accessor_token3,
    ACTIONS(1510), 1,
      sym_fstring_grouping,
    ACTIONS(1512), 1,
      sym_fstring_type,
    ACTIONS(1514), 1,
      anon_sym_RBRACE,
    STATE(612), 1,
      sym_fstring_width,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [22636] = 4,
    ACTIONS(1554), 1,
      anon_sym_COMMA2,
    STATE(517), 1,
      aux_sym_theory_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1587), 3,
      sym_colon,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [22652] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1589), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22664] = 4,
    ACTIONS(1591), 1,
      anon_sym_COMMA2,
    STATE(542), 1,
      aux_sym_theory_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1556), 3,
      anon_sym_RPAREN2,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
  [22680] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1593), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22692] = 6,
    ACTIONS(1595), 1,
      sym_identifier,
    ACTIONS(1597), 1,
      anon_sym_AMP,
    ACTIONS(1599), 1,
      anon_sym_RBRACE2,
    STATE(584), 1,
      sym_theory_term_definition,
    STATE(641), 1,
      sym_theory_atom_definition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [22712] = 6,
    ACTIONS(1601), 1,
      sym_theory_operator,
    ACTIONS(1603), 1,
      anon_sym_RBRACE2,
    ACTIONS(1605), 1,
      sym_default_negation,
    STATE(703), 1,
      sym_theory_operator_definition,
    STATE(988), 1,
      sym_theory_operator_definitions,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [22732] = 5,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(1607), 1,
      anon_sym_SLASH,
    STATE(765), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(856), 2,
      sym_colon,
      anon_sym_DOT,
  [22750] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1609), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22762] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1611), 5,
      aux_sym_fstring_accessor_token1,
      aux_sym_fstring_accessor_token2,
      aux_sym_fstring_conversion_token1,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
  [22774] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1613), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22786] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1615), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22798] = 4,
    ACTIONS(1591), 1,
      anon_sym_COMMA2,
    STATE(526), 1,
      aux_sym_theory_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1587), 3,
      anon_sym_RPAREN2,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
  [22814] = 4,
    ACTIONS(1617), 1,
      anon_sym_COMMA2,
    STATE(543), 1,
      aux_sym_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1076), 3,
      sym_colon,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [22830] = 6,
    ACTIONS(1472), 1,
      aux_sym_fstring_accessor_token3,
    ACTIONS(1478), 1,
      sym_fstring_grouping,
    ACTIONS(1480), 1,
      sym_fstring_type,
    ACTIONS(1482), 1,
      anon_sym_RBRACE,
    STATE(666), 1,
      sym_fstring_width,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [22850] = 6,
    ACTIONS(934), 1,
      aux_sym_fstring_conversion_token1,
    ACTIONS(936), 1,
      aux_sym_fstring_spec_token1,
    ACTIONS(1620), 1,
      anon_sym_RBRACE,
    STATE(657), 1,
      sym_fstring_conversion,
    STATE(821), 1,
      sym_fstring_spec,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [22870] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1622), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22882] = 6,
    ACTIONS(1472), 1,
      aux_sym_fstring_accessor_token3,
    ACTIONS(1624), 1,
      sym_fstring_grouping,
    ACTIONS(1626), 1,
      sym_fstring_type,
    ACTIONS(1628), 1,
      anon_sym_RBRACE,
    STATE(627), 1,
      sym_fstring_width,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [22902] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1630), 5,
      anon_sym_RBRACE2,
      anon_sym_expressions,
      anon_sym_subtypes,
      anon_sym_macros,
      anon_sym_occurrence,
  [22914] = 5,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    ACTIONS(1632), 1,
      anon_sym_SLASH,
    STATE(797), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(878), 2,
      sym_colon,
      anon_sym_DOT,
  [22932] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1634), 1,
      anon_sym_DQUOTE,
    STATE(588), 1,
      aux_sym_string_repeat1,
    ACTIONS(1636), 2,
      sym__string_fragment,
      sym__string_escape,
  [22949] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1638), 2,
      anon_sym_DQUOTE,
      anon_sym_LBRACE,
    ACTIONS(1640), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
  [22964] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1642), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [22975] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1644), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [22986] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1646), 4,
      anon_sym_PIPE,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [22997] = 4,
    ACTIONS(1648), 1,
      anon_sym_COMMA2,
    STATE(568), 1,
      aux_sym__terms_or_projection_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1650), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [23012] = 3,
    ACTIONS(1652), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1496), 3,
      anon_sym_PIPE,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [23025] = 5,
    ACTIONS(1595), 1,
      sym_identifier,
    ACTIONS(1597), 1,
      anon_sym_AMP,
    STATE(787), 1,
      sym_theory_term_definition,
    STATE(788), 1,
      sym_theory_atom_definition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23042] = 5,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(1654), 1,
      sym_identifier,
    STATE(315), 1,
      sym__metasp_identifier,
    STATE(858), 1,
      sym_metasp_const_function,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23059] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1182), 4,
      sym_colon,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [23070] = 5,
    ACTIONS(1656), 1,
      anon_sym_SEMI,
    ACTIONS(1658), 1,
      anon_sym_RBRACE2,
    STATE(709), 1,
      aux_sym__theory_definitions_repeat1,
    STATE(710), 1,
      aux_sym__theory_definitions_repeat2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23087] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1660), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [23098] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1662), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [23109] = 4,
    ACTIONS(1664), 1,
      anon_sym_COMMA2,
    STATE(568), 1,
      aux_sym__terms_or_projection_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1666), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [23124] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1561), 4,
      sym_colon,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [23135] = 4,
    ACTIONS(1668), 1,
      anon_sym_COMMA2,
    ACTIONS(1672), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1670), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [23150] = 4,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    STATE(723), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(866), 2,
      sym_colon,
      anon_sym_DOT,
  [23165] = 4,
    ACTIONS(1674), 1,
      anon_sym_STAR_PERCENT,
    ACTIONS(1676), 1,
      sym__doc_token_minus,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(567), 2,
      sym_doc_arg,
      aux_sym_doc_args_repeat1,
  [23180] = 4,
    ACTIONS(1679), 1,
      anon_sym_COMMA2,
    STATE(568), 1,
      aux_sym__terms_or_projection_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1682), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [23195] = 4,
    ACTIONS(1664), 1,
      anon_sym_COMMA2,
    STATE(563), 1,
      aux_sym__terms_or_projection_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1684), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [23210] = 5,
    ACTIONS(1304), 1,
      sym_identifier,
    ACTIONS(1686), 1,
      anon_sym_RBRACE2,
    STATE(577), 1,
      aux_sym_metasp_macro_where_repeat1,
    STATE(898), 1,
      sym_metasp_keyword_arg,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23227] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1688), 2,
      anon_sym_DQUOTE,
      anon_sym_LBRACE,
    ACTIONS(1690), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
  [23242] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1692), 4,
      sym_identifier,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [23253] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1694), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [23264] = 3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1696), 2,
      sym_identifier,
      anon_sym_where,
    ACTIONS(1698), 2,
      anon_sym_AMP,
      anon_sym_RBRACE2,
  [23277] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1700), 2,
      anon_sym_DQUOTE,
      anon_sym_LBRACE,
    ACTIONS(1702), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
  [23292] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1704), 1,
      anon_sym_DQUOTE,
    STATE(580), 1,
      aux_sym_string_repeat1,
    ACTIONS(1706), 2,
      sym__string_fragment,
      sym__string_escape,
  [23309] = 5,
    ACTIONS(1304), 1,
      sym_identifier,
    ACTIONS(1708), 1,
      anon_sym_RBRACE2,
    STATE(585), 1,
      aux_sym_metasp_macro_where_repeat1,
    STATE(898), 1,
      sym_metasp_keyword_arg,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23326] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1710), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [23337] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1712), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [23348] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1714), 1,
      anon_sym_DQUOTE,
    STATE(588), 1,
      aux_sym_string_repeat1,
    ACTIONS(1636), 2,
      sym__string_fragment,
      sym__string_escape,
  [23365] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1716), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [23376] = 5,
    ACTIONS(1718), 1,
      sym_theory_operator,
    ACTIONS(1720), 1,
      anon_sym_RBRACE2,
    ACTIONS(1722), 1,
      sym_default_negation,
    STATE(949), 1,
      sym__theory_operators_sep,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23393] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1724), 4,
      sym_identifier,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [23404] = 5,
    ACTIONS(1656), 1,
      anon_sym_SEMI,
    ACTIONS(1726), 1,
      anon_sym_RBRACE2,
    STATE(560), 1,
      aux_sym__theory_definitions_repeat2,
    STATE(656), 1,
      aux_sym__theory_definitions_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23421] = 5,
    ACTIONS(1728), 1,
      sym_identifier,
    ACTIONS(1731), 1,
      anon_sym_RBRACE2,
    STATE(585), 1,
      aux_sym_metasp_macro_where_repeat1,
    STATE(898), 1,
      sym_metasp_keyword_arg,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23438] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1733), 4,
      sym_identifier,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [23449] = 4,
    ACTIONS(1735), 1,
      anon_sym_STAR_PERCENT,
    ACTIONS(1737), 1,
      sym__doc_token_minus,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(602), 2,
      sym_doc_arg,
      aux_sym_doc_args_repeat1,
  [23464] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1739), 1,
      anon_sym_DQUOTE,
    STATE(588), 1,
      aux_sym_string_repeat1,
    ACTIONS(1741), 2,
      sym__string_fragment,
      sym__string_escape,
  [23481] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1744), 1,
      anon_sym_DQUOTE,
    STATE(603), 1,
      aux_sym_string_repeat1,
    ACTIONS(1746), 2,
      sym__string_fragment,
      sym__string_escape,
  [23498] = 4,
    ACTIONS(1748), 1,
      anon_sym_COMMA2,
    STATE(591), 1,
      aux_sym_condition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1458), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [23513] = 4,
    ACTIONS(1750), 1,
      anon_sym_COMMA2,
    STATE(591), 1,
      aux_sym_condition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1439), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [23528] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1753), 1,
      anon_sym_DQUOTE,
    STATE(595), 1,
      aux_sym_string_repeat1,
    ACTIONS(1755), 2,
      sym__string_fragment,
      sym__string_escape,
  [23545] = 3,
    ACTIONS(1492), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1757), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [23558] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1759), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [23569] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1761), 1,
      anon_sym_DQUOTE,
    STATE(588), 1,
      aux_sym_string_repeat1,
    ACTIONS(1636), 2,
      sym__string_fragment,
      sym__string_escape,
  [23586] = 4,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    STATE(796), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(874), 2,
      sym_colon,
      anon_sym_DOT,
  [23601] = 4,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    STATE(797), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(878), 2,
      sym_colon,
      anon_sym_DOT,
  [23616] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1763), 1,
      anon_sym_DQUOTE,
    STATE(599), 1,
      aux_sym_string_repeat1,
    ACTIONS(1765), 2,
      sym__string_fragment,
      sym__string_escape,
  [23633] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1767), 1,
      anon_sym_DQUOTE,
    STATE(588), 1,
      aux_sym_string_repeat1,
    ACTIONS(1636), 2,
      sym__string_fragment,
      sym__string_escape,
  [23650] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1769), 1,
      anon_sym_DQUOTE,
    STATE(550), 1,
      aux_sym_string_repeat1,
    ACTIONS(1771), 2,
      sym__string_fragment,
      sym__string_escape,
  [23667] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1773), 4,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [23678] = 4,
    ACTIONS(1737), 1,
      sym__doc_token_minus,
    ACTIONS(1775), 1,
      anon_sym_STAR_PERCENT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    STATE(567), 2,
      sym_doc_arg,
      aux_sym_doc_args_repeat1,
  [23693] = 5,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1777), 1,
      anon_sym_DQUOTE,
    STATE(588), 1,
      aux_sym_string_repeat1,
    ACTIONS(1636), 2,
      sym__string_fragment,
      sym__string_escape,
  [23710] = 4,
    ACTIONS(1748), 1,
      anon_sym_COMMA2,
    STATE(590), 1,
      aux_sym_condition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1433), 2,
      anon_sym_PIPE,
      anon_sym_SEMI,
  [23725] = 3,
    ACTIONS(1494), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1779), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [23738] = 4,
    ACTIONS(1781), 1,
      anon_sym_PIPE,
    ACTIONS(1783), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1785), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [23753] = 4,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(1787), 2,
      anon_sym_DQUOTE,
      anon_sym_LBRACE,
    ACTIONS(1789), 2,
      sym__fstring_fragment,
      sym__fstring_escape,
  [23768] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1561), 4,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_RBRACK,
      anon_sym_RBRACE2,
  [23779] = 4,
    ACTIONS(858), 1,
      anon_sym_LPAREN,
    STATE(765), 1,
      sym__arg_pool,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(856), 2,
      sym_colon,
      anon_sym_DOT,
  [23794] = 4,
    ACTIONS(1791), 1,
      anon_sym_SEMI,
    ACTIONS(1794), 1,
      anon_sym_RBRACE2,
    STATE(610), 1,
      aux_sym_theory_operator_definitions_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23808] = 4,
    ACTIONS(1796), 1,
      anon_sym_COMMA2,
    ACTIONS(1798), 1,
      anon_sym_RPAREN2,
    STATE(630), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23822] = 4,
    ACTIONS(1624), 1,
      sym_fstring_grouping,
    ACTIONS(1626), 1,
      sym_fstring_type,
    ACTIONS(1628), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23836] = 4,
    ACTIONS(1800), 1,
      anon_sym_SEMI,
    ACTIONS(1802), 1,
      anon_sym_RBRACE2,
    STATE(701), 1,
      aux_sym_optimize_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23850] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1804), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [23860] = 4,
    ACTIONS(1174), 1,
      anon_sym_COMMA2,
    ACTIONS(1806), 1,
      anon_sym_RPAREN2,
    STATE(616), 1,
      aux_sym_const_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23874] = 4,
    ACTIONS(1248), 1,
      anon_sym_RPAREN2,
    ACTIONS(1808), 1,
      anon_sym_COMMA2,
    STATE(616), 1,
      aux_sym_const_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23888] = 3,
    ACTIONS(1813), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1811), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [23900] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1779), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [23910] = 4,
    ACTIONS(1815), 1,
      anon_sym_SEMI,
    ACTIONS(1818), 1,
      anon_sym_RBRACE2,
    STATE(619), 1,
      aux_sym_optimize_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23924] = 3,
    ACTIONS(1822), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1820), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [23936] = 4,
    ACTIONS(1601), 1,
      sym_theory_operator,
    ACTIONS(1605), 1,
      sym_default_negation,
    STATE(729), 1,
      sym_theory_operator_definition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23950] = 4,
    ACTIONS(1824), 1,
      anon_sym_SEMI,
    ACTIONS(1826), 1,
      anon_sym_RBRACE2,
    STATE(610), 1,
      aux_sym_theory_operator_definitions_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23964] = 4,
    ACTIONS(13), 1,
      anon_sym_DQUOTE,
    ACTIONS(1828), 1,
      anon_sym_LT,
    STATE(940), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23978] = 4,
    ACTIONS(1830), 1,
      sym_identifier,
    ACTIONS(1832), 1,
      anon_sym_RBRACE2,
    STATE(631), 1,
      aux_sym_metasp_subtypes_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [23992] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1834), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON2,
  [24002] = 4,
    ACTIONS(1836), 1,
      anon_sym_COMMA,
    ACTIONS(1838), 1,
      anon_sym_RPAREN,
    STATE(632), 1,
      aux_sym_variables_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24016] = 4,
    ACTIONS(1840), 1,
      sym_fstring_grouping,
    ACTIONS(1842), 1,
      sym_fstring_type,
    ACTIONS(1844), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24030] = 4,
    ACTIONS(1846), 1,
      anon_sym_SEMI,
    ACTIONS(1848), 1,
      anon_sym_RBRACE2,
    STATE(674), 1,
      aux_sym_set_aggregate_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24044] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1450), 3,
      anon_sym_AMP,
      anon_sym_DASH,
      anon_sym_RBRACE2,
  [24054] = 4,
    ACTIONS(1796), 1,
      anon_sym_COMMA2,
    ACTIONS(1850), 1,
      anon_sym_RPAREN2,
    STATE(688), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24068] = 4,
    ACTIONS(1852), 1,
      sym_identifier,
    ACTIONS(1855), 1,
      anon_sym_RBRACE2,
    STATE(631), 1,
      aux_sym_metasp_subtypes_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24082] = 4,
    ACTIONS(1836), 1,
      anon_sym_COMMA,
    ACTIONS(1857), 1,
      anon_sym_RPAREN,
    STATE(637), 1,
      aux_sym_variables_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24096] = 4,
    ACTIONS(1859), 1,
      anon_sym_RPAREN2,
    ACTIONS(1861), 1,
      anon_sym_SEMI,
    STATE(633), 1,
      aux_sym__arg_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24110] = 4,
    ACTIONS(1864), 1,
      sym_theory_operator_arity,
    ACTIONS(1866), 1,
      anon_sym_binary,
    STATE(880), 1,
      sym__theory_operator_arity_binary,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24124] = 4,
    ACTIONS(1866), 1,
      anon_sym_binary,
    ACTIONS(1868), 1,
      sym_theory_operator_arity,
    STATE(882), 1,
      sym__theory_operator_arity_binary,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24138] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1870), 3,
      sym_fstring_grouping,
      sym_fstring_type,
      anon_sym_RBRACE,
  [24148] = 4,
    ACTIONS(1872), 1,
      anon_sym_COMMA,
    ACTIONS(1875), 1,
      anon_sym_RPAREN,
    STATE(637), 1,
      aux_sym_variables_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24162] = 4,
    ACTIONS(1306), 1,
      anon_sym_COMMA2,
    ACTIONS(1877), 1,
      anon_sym_SEMI,
    STATE(642), 1,
      aux_sym_metasp_argument_definition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24176] = 4,
    ACTIONS(1306), 1,
      anon_sym_COMMA2,
    ACTIONS(1877), 1,
      anon_sym_SEMI,
    STATE(643), 1,
      aux_sym_metasp_argument_definition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24190] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1879), 3,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [24200] = 4,
    ACTIONS(1726), 1,
      anon_sym_RBRACE2,
    ACTIONS(1881), 1,
      anon_sym_SEMI,
    STATE(656), 1,
      aux_sym__theory_definitions_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24214] = 4,
    ACTIONS(1306), 1,
      anon_sym_COMMA2,
    ACTIONS(1883), 1,
      anon_sym_SEMI,
    STATE(643), 1,
      aux_sym_metasp_argument_definition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24228] = 4,
    ACTIONS(1885), 1,
      anon_sym_COMMA2,
    ACTIONS(1888), 1,
      anon_sym_SEMI,
    STATE(643), 1,
      aux_sym_metasp_argument_definition_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24242] = 4,
    ACTIONS(1890), 1,
      anon_sym_COMMA2,
    ACTIONS(1892), 1,
      anon_sym_RBRACE2,
    STATE(646), 1,
      aux_sym__theory_operators_sep_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24256] = 4,
    ACTIONS(1890), 1,
      anon_sym_COMMA2,
    ACTIONS(1894), 1,
      anon_sym_RBRACE2,
    STATE(647), 1,
      aux_sym__theory_operators_sep_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24270] = 4,
    ACTIONS(1890), 1,
      anon_sym_COMMA2,
    ACTIONS(1896), 1,
      anon_sym_RBRACE2,
    STATE(648), 1,
      aux_sym__theory_operators_sep_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24284] = 4,
    ACTIONS(1890), 1,
      anon_sym_COMMA2,
    ACTIONS(1898), 1,
      anon_sym_RBRACE2,
    STATE(648), 1,
      aux_sym__theory_operators_sep_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24298] = 4,
    ACTIONS(1900), 1,
      anon_sym_COMMA2,
    ACTIONS(1903), 1,
      anon_sym_RBRACE2,
    STATE(648), 1,
      aux_sym__theory_operators_sep_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24312] = 4,
    ACTIONS(1905), 1,
      anon_sym_RPAREN2,
    ACTIONS(1907), 1,
      anon_sym_SEMI,
    STATE(649), 1,
      aux_sym_edge_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24326] = 4,
    ACTIONS(1910), 1,
      sym_identifier,
    ACTIONS(1912), 1,
      anon_sym_RPAREN2,
    STATE(984), 1,
      sym_parameters,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24340] = 4,
    ACTIONS(1118), 1,
      anon_sym_SEMI,
    ACTIONS(1914), 1,
      anon_sym_PIPE,
    STATE(684), 1,
      aux_sym_abs_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24354] = 4,
    ACTIONS(1916), 1,
      anon_sym_RPAREN2,
    ACTIONS(1918), 1,
      anon_sym_SEMI,
    STATE(671), 1,
      aux_sym_edge_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24368] = 4,
    ACTIONS(1920), 1,
      anon_sym_RPAREN2,
    ACTIONS(1922), 1,
      anon_sym_SEMI,
    STATE(654), 1,
      aux_sym__tuple_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24382] = 4,
    ACTIONS(1922), 1,
      anon_sym_SEMI,
    ACTIONS(1924), 1,
      anon_sym_RPAREN2,
    STATE(685), 1,
      aux_sym__tuple_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24396] = 4,
    ACTIONS(1478), 1,
      sym_fstring_grouping,
    ACTIONS(1480), 1,
      sym_fstring_type,
    ACTIONS(1482), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24410] = 4,
    ACTIONS(1658), 1,
      anon_sym_RBRACE2,
    ACTIONS(1881), 1,
      anon_sym_SEMI,
    STATE(707), 1,
      aux_sym__theory_definitions_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24424] = 4,
    ACTIONS(936), 1,
      aux_sym_fstring_spec_token1,
    ACTIONS(1926), 1,
      anon_sym_RBRACE,
    STATE(864), 1,
      sym_fstring_spec,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24438] = 4,
    ACTIONS(576), 1,
      anon_sym_AMP,
    ACTIONS(1928), 1,
      sym_identifier,
    STATE(939), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24452] = 4,
    ACTIONS(1288), 1,
      sym__doc_token_args,
    ACTIONS(1930), 1,
      anon_sym_STAR_PERCENT,
    STATE(881), 1,
      sym_doc_args,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24466] = 4,
    ACTIONS(1932), 1,
      anon_sym_RPAREN2,
    ACTIONS(1934), 1,
      anon_sym_SEMI,
    STATE(633), 1,
      aux_sym__arg_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24480] = 4,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(1936), 1,
      sym_identifier,
    STATE(549), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24494] = 4,
    ACTIONS(1932), 1,
      anon_sym_RPAREN2,
    ACTIONS(1934), 1,
      anon_sym_SEMI,
    STATE(633), 1,
      aux_sym__arg_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24508] = 4,
    ACTIONS(1938), 1,
      anon_sym_RPAREN,
    ACTIONS(1940), 1,
      sym_doc_var,
    STATE(943), 1,
      sym_variables,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24522] = 4,
    ACTIONS(1112), 1,
      anon_sym_COMMA2,
    ACTIONS(1585), 1,
      anon_sym_RBRACK,
    STATE(669), 1,
      aux_sym_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24536] = 4,
    ACTIONS(936), 1,
      aux_sym_fstring_spec_token1,
    ACTIONS(1620), 1,
      anon_sym_RBRACE,
    STATE(821), 1,
      sym_fstring_spec,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24550] = 4,
    ACTIONS(1510), 1,
      sym_fstring_grouping,
    ACTIONS(1512), 1,
      sym_fstring_type,
    ACTIONS(1514), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24564] = 4,
    ACTIONS(1942), 1,
      anon_sym_COMMA2,
    ACTIONS(1944), 1,
      anon_sym_RPAREN2,
    STATE(670), 1,
      aux_sym_theory_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24578] = 4,
    ACTIONS(1934), 1,
      anon_sym_SEMI,
    ACTIONS(1946), 1,
      anon_sym_RPAREN2,
    STATE(662), 1,
      aux_sym__arg_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24592] = 4,
    ACTIONS(1076), 1,
      anon_sym_RBRACK,
    ACTIONS(1948), 1,
      anon_sym_COMMA2,
    STATE(669), 1,
      aux_sym_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24606] = 4,
    ACTIONS(814), 1,
      anon_sym_RPAREN2,
    ACTIONS(1951), 1,
      anon_sym_COMMA2,
    STATE(526), 1,
      aux_sym_theory_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24620] = 4,
    ACTIONS(1918), 1,
      anon_sym_SEMI,
    ACTIONS(1953), 1,
      anon_sym_RPAREN2,
    STATE(649), 1,
      aux_sym_edge_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24634] = 3,
    ACTIONS(1957), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1955), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [24646] = 4,
    ACTIONS(1959), 1,
      anon_sym_SEMI,
    ACTIONS(1962), 1,
      anon_sym_RBRACE2,
    STATE(673), 1,
      aux_sym_theory_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24660] = 4,
    ACTIONS(1964), 1,
      anon_sym_SEMI,
    ACTIONS(1967), 1,
      anon_sym_RBRACE2,
    STATE(674), 1,
      aux_sym_set_aggregate_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24674] = 4,
    ACTIONS(1969), 1,
      anon_sym_SEMI,
    ACTIONS(1971), 1,
      anon_sym_RBRACE2,
    STATE(673), 1,
      aux_sym_theory_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24688] = 4,
    ACTIONS(1973), 1,
      anon_sym_SEMI,
    ACTIONS(1976), 1,
      anon_sym_RBRACE2,
    STATE(676), 1,
      aux_sym_body_aggregate_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24702] = 3,
    ACTIONS(1980), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1978), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [24714] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1982), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [24724] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1984), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [24734] = 4,
    ACTIONS(1986), 1,
      anon_sym_SEMI,
    ACTIONS(1988), 1,
      anon_sym_RBRACE2,
    STATE(695), 1,
      aux_sym_head_aggregate_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24748] = 4,
    ACTIONS(1969), 1,
      anon_sym_SEMI,
    ACTIONS(1990), 1,
      anon_sym_RBRACE2,
    STATE(675), 1,
      aux_sym_theory_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24762] = 3,
    ACTIONS(1992), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1994), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [24774] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1757), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [24784] = 4,
    ACTIONS(1212), 1,
      anon_sym_PIPE,
    ACTIONS(1996), 1,
      anon_sym_SEMI,
    STATE(684), 1,
      aux_sym_abs_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24798] = 4,
    ACTIONS(1999), 1,
      anon_sym_RPAREN2,
    ACTIONS(2001), 1,
      anon_sym_SEMI,
    STATE(685), 1,
      aux_sym__tuple_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24812] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1682), 3,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [24822] = 4,
    ACTIONS(500), 1,
      anon_sym_AMP,
    ACTIONS(2004), 1,
      sym_identifier,
    STATE(597), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24836] = 4,
    ACTIONS(2006), 1,
      anon_sym_COMMA2,
    ACTIONS(2009), 1,
      anon_sym_RPAREN2,
    STATE(688), 1,
      aux_sym_parameters_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24850] = 3,
    ACTIONS(2013), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2011), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [24862] = 4,
    ACTIONS(1846), 1,
      anon_sym_SEMI,
    ACTIONS(2015), 1,
      anon_sym_RBRACE2,
    STATE(628), 1,
      aux_sym_set_aggregate_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24876] = 3,
    ACTIONS(2019), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2017), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [24888] = 4,
    ACTIONS(2021), 1,
      anon_sym_COMMA2,
    ACTIONS(2023), 1,
      anon_sym_RPAREN2,
    STATE(616), 1,
      aux_sym_const_terms_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24902] = 4,
    ACTIONS(2025), 1,
      anon_sym_SEMI,
    ACTIONS(2028), 1,
      anon_sym_RBRACE2,
    STATE(693), 1,
      aux_sym_head_aggregate_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24916] = 4,
    ACTIONS(1922), 1,
      anon_sym_SEMI,
    ACTIONS(2030), 1,
      anon_sym_RPAREN2,
    STATE(654), 1,
      aux_sym__tuple_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24930] = 4,
    ACTIONS(1986), 1,
      anon_sym_SEMI,
    ACTIONS(2032), 1,
      anon_sym_RBRACE2,
    STATE(693), 1,
      aux_sym_head_aggregate_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24944] = 3,
    ACTIONS(2036), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2034), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [24956] = 4,
    ACTIONS(2038), 1,
      anon_sym_SEMI,
    ACTIONS(2040), 1,
      anon_sym_RBRACE2,
    STATE(713), 1,
      aux_sym_body_aggregate_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24970] = 4,
    ACTIONS(1934), 1,
      anon_sym_SEMI,
    ACTIONS(2042), 1,
      anon_sym_RPAREN2,
    STATE(662), 1,
      aux_sym__arg_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24984] = 4,
    ACTIONS(1118), 1,
      anon_sym_SEMI,
    ACTIONS(2044), 1,
      anon_sym_PIPE,
    STATE(684), 1,
      aux_sym_abs_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [24998] = 3,
    ACTIONS(2046), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1820), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [25010] = 4,
    ACTIONS(1800), 1,
      anon_sym_SEMI,
    ACTIONS(2048), 1,
      anon_sym_RBRACE2,
    STATE(619), 1,
      aux_sym_optimize_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25024] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2050), 3,
      anon_sym_COMMA2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [25034] = 4,
    ACTIONS(1824), 1,
      anon_sym_SEMI,
    ACTIONS(2052), 1,
      anon_sym_RBRACE2,
    STATE(622), 1,
      aux_sym_theory_operator_definitions_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25048] = 4,
    ACTIONS(1922), 1,
      anon_sym_SEMI,
    ACTIONS(2054), 1,
      anon_sym_RPAREN2,
    STATE(654), 1,
      aux_sym__tuple_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25062] = 4,
    ACTIONS(1934), 1,
      anon_sym_SEMI,
    ACTIONS(2056), 1,
      anon_sym_RPAREN2,
    STATE(662), 1,
      aux_sym__arg_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25076] = 4,
    ACTIONS(1118), 1,
      anon_sym_SEMI,
    ACTIONS(2058), 1,
      anon_sym_PIPE,
    STATE(684), 1,
      aux_sym_abs_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25090] = 4,
    ACTIONS(2060), 1,
      anon_sym_SEMI,
    ACTIONS(2063), 1,
      anon_sym_RBRACE2,
    STATE(707), 1,
      aux_sym__theory_definitions_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25104] = 3,
    STATE(950), 1,
      sym_boolean,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2065), 2,
      anon_sym_true,
      anon_sym_false,
  [25116] = 4,
    ACTIONS(1881), 1,
      anon_sym_SEMI,
    ACTIONS(2067), 1,
      anon_sym_RBRACE2,
    STATE(707), 1,
      aux_sym__theory_definitions_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25130] = 4,
    ACTIONS(2069), 1,
      anon_sym_SEMI,
    ACTIONS(2072), 1,
      anon_sym_RBRACE2,
    STATE(710), 1,
      aux_sym__theory_definitions_repeat2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25144] = 4,
    ACTIONS(1830), 1,
      sym_identifier,
    ACTIONS(2074), 1,
      anon_sym_RBRACE2,
    STATE(624), 1,
      aux_sym_metasp_subtypes_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25158] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2076), 3,
      anon_sym_SEMI,
      anon_sym_DOT,
      anon_sym_COLON2,
  [25168] = 4,
    ACTIONS(2038), 1,
      anon_sym_SEMI,
    ACTIONS(2078), 1,
      anon_sym_RBRACE2,
    STATE(676), 1,
      aux_sym_body_aggregate_elements_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25182] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2080), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [25191] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2082), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [25200] = 3,
    ACTIONS(1842), 1,
      sym_fstring_type,
    ACTIONS(1844), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25211] = 3,
    ACTIONS(1922), 1,
      anon_sym_SEMI,
    STATE(654), 1,
      aux_sym__tuple_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25222] = 3,
    ACTIONS(2084), 1,
      anon_sym_DOT,
    ACTIONS(2086), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25233] = 3,
    ACTIONS(1626), 1,
      sym_fstring_type,
    ACTIONS(1628), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25244] = 3,
    ACTIONS(1512), 1,
      sym_fstring_type,
    ACTIONS(1514), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25255] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1785), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [25264] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2088), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [25273] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(910), 2,
      sym_colon,
      anon_sym_DOT,
  [25282] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2090), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25291] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1888), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [25300] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2092), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25309] = 3,
    ACTIONS(2094), 1,
      anon_sym_COMMA2,
    STATE(555), 1,
      aux_sym__terms_or_projection_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25320] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2096), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25329] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1794), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25338] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1962), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25347] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1138), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [25356] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1967), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25365] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2098), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25374] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1498), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [25383] = 3,
    ACTIONS(2100), 1,
      anon_sym_DOT,
    ACTIONS(2102), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25394] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2104), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25403] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1731), 2,
      sym_identifier,
      anon_sym_RBRACE2,
  [25412] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2106), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25421] = 3,
    ACTIONS(2108), 1,
      anon_sym_LPAREN,
    ACTIONS(2110), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25432] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1976), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25441] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2112), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [25450] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2114), 2,
      anon_sym_COMMA,
      anon_sym_RPAREN,
  [25459] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2116), 2,
      sym__doc_token_minus,
      anon_sym_STAR_PERCENT,
  [25468] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2118), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25477] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2120), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25486] = 3,
    ACTIONS(2122), 1,
      anon_sym_COMMA2,
    ACTIONS(2124), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25497] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2126), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25506] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2128), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [25515] = 3,
    ACTIONS(2130), 1,
      anon_sym_DOT,
    ACTIONS(2132), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25526] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1999), 2,
      anon_sym_RPAREN2,
      anon_sym_SEMI,
  [25535] = 3,
    ACTIONS(2134), 1,
      sym_theory_operator,
    ACTIONS(2136), 1,
      sym_default_negation,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25546] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1855), 2,
      sym_identifier,
      anon_sym_RBRACE2,
  [25555] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2009), 2,
      anon_sym_COMMA2,
      anon_sym_RPAREN2,
  [25564] = 3,
    ACTIONS(1595), 1,
      sym_identifier,
    STATE(787), 1,
      sym_theory_term_definition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25575] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1903), 2,
      anon_sym_COMMA2,
      anon_sym_RBRACE2,
  [25584] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2138), 2,
      anon_sym_COMMA2,
      anon_sym_RBRACE2,
  [25593] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2140), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [25602] = 3,
    ACTIONS(1304), 1,
      sym_identifier,
    STATE(725), 1,
      sym_metasp_keyword_arg,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25613] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2142), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [25622] = 3,
    ACTIONS(2144), 1,
      anon_sym_DOT,
    ACTIONS(2146), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25633] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2148), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25642] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2028), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25651] = 3,
    ACTIONS(576), 1,
      anon_sym_AMP,
    STATE(939), 1,
      sym__metasp_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25662] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2150), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [25671] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(904), 2,
      sym_colon,
      anon_sym_DOT,
  [25680] = 3,
    ACTIONS(2152), 1,
      anon_sym_SEMI,
    ACTIONS(2154), 1,
      anon_sym_COLON2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25691] = 3,
    ACTIONS(2156), 1,
      anon_sym_DOT,
    ACTIONS(2158), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25702] = 3,
    ACTIONS(2160), 1,
      sym_fstring_type,
    ACTIONS(2162), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25713] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1994), 2,
      anon_sym_SEMI,
      anon_sym_DOT,
  [25722] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2164), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25731] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1820), 2,
      anon_sym_COMMA2,
      anon_sym_SEMI,
  [25740] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1818), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25749] = 3,
    ACTIONS(2166), 1,
      anon_sym_COMMA2,
    ACTIONS(2168), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25760] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2170), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25769] = 3,
    ACTIONS(2172), 1,
      anon_sym_LBRACE,
    ACTIONS(2174), 1,
      sym_aggregate_function,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25780] = 3,
    ACTIONS(1820), 1,
      anon_sym_SEMI,
    ACTIONS(2046), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25791] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2176), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [25800] = 3,
    ACTIONS(2178), 1,
      anon_sym_DOT,
    ACTIONS(2180), 1,
      anon_sym_COLON_DASH,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25811] = 3,
    ACTIONS(2172), 1,
      anon_sym_LBRACE,
    ACTIONS(2182), 1,
      sym_aggregate_function,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25822] = 3,
    ACTIONS(1480), 1,
      sym_fstring_type,
    ACTIONS(1482), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25833] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(1520), 2,
      anon_sym_DOT,
      anon_sym_COLON_DASH,
  [25842] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2184), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25851] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2186), 2,
      aux_sym_fstring_spec_token1,
      anon_sym_RBRACE,
  [25860] = 3,
    ACTIONS(1934), 1,
      anon_sym_SEMI,
    STATE(660), 1,
      aux_sym__arg_pool_n_repeat1,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25871] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2188), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25880] = 3,
    ACTIONS(1597), 1,
      anon_sym_AMP,
    STATE(788), 1,
      sym_theory_atom_definition,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25891] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2072), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25900] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2063), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25909] = 3,
    ACTIONS(2190), 1,
      anon_sym_LBRACE,
    ACTIONS(2192), 1,
      sym_aggregate_function,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25920] = 3,
    ACTIONS(1820), 1,
      anon_sym_SEMI,
    ACTIONS(1822), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25931] = 3,
    ACTIONS(1781), 1,
      anon_sym_PIPE,
    ACTIONS(1783), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25942] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2194), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25951] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2196), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25960] = 3,
    ACTIONS(2198), 1,
      anon_sym_LBRACE,
    ACTIONS(2200), 1,
      sym_theory_atom_type,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [25971] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2202), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [25980] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(900), 2,
      sym_colon,
      anon_sym_DOT,
  [25989] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(896), 2,
      sym_colon,
      anon_sym_DOT,
  [25998] = 3,
    ACTIONS(2204), 1,
      aux_sym_doc_predicate_token1,
    STATE(427), 1,
      sym_doc_predicate,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26009] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2206), 2,
      sym_colon,
      anon_sym_DOT,
  [26018] = 2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
    ACTIONS(2208), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE2,
  [26027] = 2,
    ACTIONS(2054), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26035] = 2,
    ACTIONS(2210), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26043] = 2,
    ACTIONS(1920), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26051] = 2,
    ACTIONS(2212), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26059] = 2,
    ACTIONS(2214), 1,
      anon_sym_GT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26067] = 2,
    ACTIONS(2216), 1,
      anon_sym_POUNDend,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26075] = 2,
    ACTIONS(2218), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26083] = 2,
    ACTIONS(2220), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26091] = 2,
    ACTIONS(1482), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26099] = 2,
    ACTIONS(2222), 1,
      anon_sym_SLASH,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26107] = 2,
    ACTIONS(2224), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26115] = 2,
    ACTIONS(2226), 1,
      anon_sym_COLON2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26123] = 2,
    ACTIONS(2228), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26131] = 2,
    ACTIONS(2230), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26139] = 2,
    ACTIONS(2232), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26147] = 2,
    ACTIONS(2234), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26155] = 2,
    ACTIONS(1576), 1,
      anon_sym_SLASH,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26163] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2236), 1,
      aux_sym_doc_comment_token1,
  [26173] = 2,
    ACTIONS(2238), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26181] = 2,
    ACTIONS(2240), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26189] = 2,
    ACTIONS(1926), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26197] = 2,
    ACTIONS(2242), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26205] = 2,
    ACTIONS(2244), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26213] = 2,
    ACTIONS(2246), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26221] = 2,
    ACTIONS(2248), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26229] = 2,
    ACTIONS(2250), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26237] = 2,
    ACTIONS(1992), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26245] = 2,
    ACTIONS(2252), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26253] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2254), 1,
      aux_sym_doc_comment_token1,
  [26263] = 2,
    ACTIONS(1607), 1,
      anon_sym_SLASH,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26271] = 2,
    ACTIONS(2256), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26279] = 2,
    ACTIONS(2258), 1,
      sym_theory_atom_type,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26287] = 2,
    ACTIONS(2162), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26295] = 2,
    ACTIONS(2260), 1,
      anon_sym_STAR_PERCENT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26303] = 2,
    ACTIONS(2262), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26311] = 2,
    ACTIONS(2264), 1,
      anon_sym_COLON2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26319] = 2,
    ACTIONS(2266), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26327] = 2,
    ACTIONS(2268), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26335] = 2,
    ACTIONS(2270), 1,
      ts_builtin_sym_end,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26343] = 2,
    ACTIONS(2272), 1,
      aux_sym_fstring_accessor_token4,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26351] = 2,
    ACTIONS(2274), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26359] = 2,
    ACTIONS(2276), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26367] = 2,
    ACTIONS(2278), 1,
      anon_sym_COLON2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26375] = 2,
    ACTIONS(2280), 1,
      anon_sym_COLON2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26383] = 2,
    ACTIONS(2282), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26391] = 2,
    ACTIONS(2284), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26399] = 2,
    ACTIONS(2286), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26407] = 2,
    ACTIONS(2288), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26415] = 2,
    ACTIONS(2290), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26423] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2292), 1,
      aux_sym_doc_comment_token1,
  [26433] = 2,
    ACTIONS(2294), 1,
      aux_sym_fstring_accessor_token3,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26441] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2296), 1,
      aux_sym_fstring_conversion_token2,
  [26451] = 2,
    ACTIONS(2298), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26459] = 2,
    ACTIONS(2300), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26467] = 2,
    ACTIONS(2302), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26475] = 2,
    ACTIONS(2304), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26483] = 2,
    ACTIONS(2306), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26491] = 2,
    ACTIONS(2308), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26499] = 2,
    ACTIONS(2310), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26507] = 2,
    ACTIONS(2312), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26515] = 2,
    ACTIONS(1514), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26523] = 2,
    ACTIONS(1180), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26531] = 2,
    ACTIONS(2314), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26539] = 2,
    ACTIONS(2316), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26547] = 2,
    ACTIONS(1620), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26555] = 2,
    ACTIONS(2318), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26563] = 2,
    ACTIONS(2320), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26571] = 2,
    ACTIONS(2322), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26579] = 2,
    ACTIONS(2324), 1,
      sym_doc_var,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26587] = 2,
    ACTIONS(2326), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26595] = 2,
    ACTIONS(2328), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26603] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2330), 1,
      aux_sym_doc_comment_token1,
  [26613] = 2,
    ACTIONS(2332), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26621] = 2,
    ACTIONS(2334), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26629] = 2,
    ACTIONS(1628), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26637] = 2,
    ACTIONS(2336), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26645] = 2,
    ACTIONS(2338), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26653] = 2,
    ACTIONS(2340), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26661] = 2,
    ACTIONS(2342), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26669] = 2,
    ACTIONS(2344), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26677] = 2,
    ACTIONS(2346), 1,
      anon_sym_STAR_PERCENT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26685] = 2,
    ACTIONS(2348), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26693] = 2,
    ACTIONS(2350), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26701] = 2,
    ACTIONS(2352), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26709] = 2,
    ACTIONS(2354), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26717] = 2,
    ACTIONS(2356), 1,
      anon_sym_COLON2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26725] = 2,
    ACTIONS(2358), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26733] = 2,
    ACTIONS(2360), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26741] = 2,
    ACTIONS(2362), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26749] = 2,
    ACTIONS(2364), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26757] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2366), 1,
      aux_sym_doc_comment_token1,
  [26767] = 2,
    ACTIONS(2368), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26775] = 2,
    ACTIONS(2370), 1,
      anon_sym_COLON2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26783] = 2,
    ACTIONS(2372), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26791] = 2,
    ACTIONS(2374), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26799] = 2,
    ACTIONS(2376), 1,
      anon_sym_COLON2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26807] = 2,
    ACTIONS(2378), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26815] = 2,
    ACTIONS(2380), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26823] = 2,
    ACTIONS(1300), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26831] = 2,
    ACTIONS(2382), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26839] = 2,
    ACTIONS(2384), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26847] = 2,
    ACTIONS(2386), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26855] = 2,
    ACTIONS(2388), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26863] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2390), 1,
      sym_code,
  [26873] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2392), 1,
      aux_sym_doc_comment_token1,
  [26883] = 2,
    ACTIONS(2394), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26891] = 2,
    ACTIONS(2396), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26899] = 2,
    ACTIONS(2398), 1,
      sym_theory_operator_associativity,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26907] = 2,
    ACTIONS(2400), 1,
      sym_theory_operator_associativity,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26915] = 2,
    ACTIONS(2402), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26923] = 2,
    ACTIONS(2404), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26931] = 2,
    ACTIONS(2406), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26939] = 2,
    ACTIONS(2408), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26947] = 2,
    ACTIONS(2410), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26955] = 2,
    ACTIONS(2412), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26963] = 2,
    ACTIONS(2414), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26971] = 2,
    ACTIONS(2416), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26979] = 2,
    ACTIONS(2418), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [26987] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2420), 1,
      aux_sym_doc_comment_token1,
  [26997] = 2,
    ACTIONS(2422), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27005] = 2,
    ACTIONS(2424), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27013] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2426), 1,
      aux_sym_doc_comment_token1,
  [27023] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2428), 1,
      aux_sym_doc_comment_token1,
  [27033] = 2,
    ACTIONS(2430), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27041] = 2,
    ACTIONS(2432), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27049] = 2,
    ACTIONS(2434), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27057] = 2,
    ACTIONS(1844), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27065] = 2,
    ACTIONS(2436), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27073] = 2,
    ACTIONS(2438), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27081] = 2,
    ACTIONS(2440), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27089] = 2,
    ACTIONS(2442), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27097] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2444), 1,
      aux_sym_doc_comment_token1,
  [27107] = 2,
    ACTIONS(2446), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27115] = 2,
    ACTIONS(2448), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27123] = 2,
    ACTIONS(2450), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27131] = 2,
    ACTIONS(2452), 1,
      sym_const_type,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27139] = 2,
    ACTIONS(1583), 1,
      anon_sym_SLASH,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27147] = 2,
    ACTIONS(2030), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27155] = 2,
    ACTIONS(1632), 1,
      anon_sym_SLASH,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27163] = 2,
    ACTIONS(2454), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27171] = 2,
    ACTIONS(2456), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27179] = 2,
    ACTIONS(2458), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27187] = 2,
    ACTIONS(2460), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27195] = 2,
    ACTIONS(2462), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27203] = 2,
    ACTIONS(2464), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27211] = 2,
    ACTIONS(2466), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27219] = 2,
    ACTIONS(2468), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27227] = 2,
    ACTIONS(2470), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27235] = 2,
    ACTIONS(2472), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27243] = 2,
    ACTIONS(2474), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27251] = 2,
    ACTIONS(1820), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27259] = 2,
    ACTIONS(2476), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27267] = 2,
    ACTIONS(2478), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27275] = 2,
    ACTIONS(2480), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27283] = 2,
    ACTIONS(2482), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27291] = 2,
    ACTIONS(2484), 1,
      sym_doc_var,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27299] = 2,
    ACTIONS(2486), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27307] = 2,
    ACTIONS(2488), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27315] = 2,
    ACTIONS(2490), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27323] = 2,
    ACTIONS(2492), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27331] = 2,
    ACTIONS(2494), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27339] = 2,
    ACTIONS(2496), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27347] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2498), 1,
      aux_sym_doc_comment_token1,
  [27357] = 2,
    ACTIONS(1500), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27365] = 2,
    ACTIONS(2500), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27373] = 2,
    ACTIONS(2502), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27381] = 2,
    ACTIONS(2504), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27389] = 2,
    ACTIONS(2506), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27397] = 2,
    ACTIONS(2508), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27405] = 2,
    ACTIONS(2510), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27413] = 2,
    ACTIONS(2512), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27421] = 2,
    ACTIONS(2514), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27429] = 2,
    ACTIONS(2516), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27437] = 2,
    ACTIONS(2518), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27445] = 2,
    ACTIONS(2520), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27453] = 2,
    ACTIONS(2522), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27461] = 2,
    ACTIONS(2524), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27469] = 2,
    ACTIONS(2526), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27477] = 2,
    ACTIONS(2528), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27485] = 2,
    ACTIONS(2530), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27493] = 2,
    ACTIONS(2532), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27501] = 2,
    ACTIONS(2534), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27509] = 2,
    ACTIONS(2536), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27517] = 2,
    ACTIONS(2538), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27525] = 2,
    ACTIONS(2540), 1,
      sym_theory_atom_type,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27533] = 2,
    ACTIONS(2542), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27541] = 2,
    ACTIONS(2544), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27549] = 2,
    ACTIONS(2546), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27557] = 2,
    ACTIONS(2548), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27565] = 2,
    ACTIONS(2550), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27573] = 2,
    ACTIONS(2552), 1,
      sym_theory_atom_type,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27581] = 2,
    ACTIONS(2554), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27589] = 2,
    ACTIONS(2556), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27597] = 2,
    ACTIONS(2558), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27605] = 2,
    ACTIONS(2560), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27613] = 2,
    ACTIONS(1652), 1,
      sym_colon,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27621] = 2,
    ACTIONS(2562), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27629] = 2,
    ACTIONS(2564), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27637] = 2,
    ACTIONS(2566), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27645] = 2,
    ACTIONS(2568), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27653] = 2,
    ACTIONS(2570), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27661] = 2,
    ACTIONS(2572), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27669] = 2,
    ACTIONS(2574), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27677] = 2,
    ACTIONS(2576), 1,
      anon_sym_RBRACE2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27685] = 2,
    ACTIONS(2578), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27693] = 2,
    ACTIONS(2580), 1,
      sym_identifier,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27701] = 3,
    ACTIONS(3), 1,
      sym_line_comment,
    ACTIONS(5), 1,
      sym_block_comment,
    ACTIONS(2582), 1,
      aux_sym_doc_comment_token1,
  [27711] = 2,
    ACTIONS(2584), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27719] = 2,
    ACTIONS(2586), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27727] = 2,
    ACTIONS(2588), 1,
      anon_sym_RPAREN2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27735] = 2,
    ACTIONS(2590), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27743] = 2,
    ACTIONS(2592), 1,
      anon_sym_COMMA2,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27751] = 2,
    ACTIONS(2594), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27759] = 2,
    ACTIONS(2596), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27767] = 2,
    ACTIONS(2598), 1,
      sym_number,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
  [27775] = 2,
    ACTIONS(2600), 1,
      anon_sym_DOT,
    ACTIONS(5), 2,
      sym_block_comment,
      sym_line_comment,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(4)] = 0,
  [SMALL_STATE(5)] = 116,
  [SMALL_STATE(6)] = 232,
  [SMALL_STATE(7)] = 348,
  [SMALL_STATE(8)] = 464,
  [SMALL_STATE(9)] = 580,
  [SMALL_STATE(10)] = 696,
  [SMALL_STATE(11)] = 812,
  [SMALL_STATE(12)] = 928,
  [SMALL_STATE(13)] = 1041,
  [SMALL_STATE(14)] = 1151,
  [SMALL_STATE(15)] = 1261,
  [SMALL_STATE(16)] = 1314,
  [SMALL_STATE(17)] = 1367,
  [SMALL_STATE(18)] = 1420,
  [SMALL_STATE(19)] = 1473,
  [SMALL_STATE(20)] = 1526,
  [SMALL_STATE(21)] = 1576,
  [SMALL_STATE(22)] = 1626,
  [SMALL_STATE(23)] = 1676,
  [SMALL_STATE(24)] = 1726,
  [SMALL_STATE(25)] = 1776,
  [SMALL_STATE(26)] = 1826,
  [SMALL_STATE(27)] = 1876,
  [SMALL_STATE(28)] = 1926,
  [SMALL_STATE(29)] = 1976,
  [SMALL_STATE(30)] = 2026,
  [SMALL_STATE(31)] = 2076,
  [SMALL_STATE(32)] = 2126,
  [SMALL_STATE(33)] = 2176,
  [SMALL_STATE(34)] = 2226,
  [SMALL_STATE(35)] = 2276,
  [SMALL_STATE(36)] = 2326,
  [SMALL_STATE(37)] = 2376,
  [SMALL_STATE(38)] = 2426,
  [SMALL_STATE(39)] = 2476,
  [SMALL_STATE(40)] = 2526,
  [SMALL_STATE(41)] = 2576,
  [SMALL_STATE(42)] = 2626,
  [SMALL_STATE(43)] = 2676,
  [SMALL_STATE(44)] = 2726,
  [SMALL_STATE(45)] = 2776,
  [SMALL_STATE(46)] = 2826,
  [SMALL_STATE(47)] = 2876,
  [SMALL_STATE(48)] = 2926,
  [SMALL_STATE(49)] = 2976,
  [SMALL_STATE(50)] = 3026,
  [SMALL_STATE(51)] = 3076,
  [SMALL_STATE(52)] = 3126,
  [SMALL_STATE(53)] = 3176,
  [SMALL_STATE(54)] = 3226,
  [SMALL_STATE(55)] = 3276,
  [SMALL_STATE(56)] = 3326,
  [SMALL_STATE(57)] = 3376,
  [SMALL_STATE(58)] = 3426,
  [SMALL_STATE(59)] = 3476,
  [SMALL_STATE(60)] = 3526,
  [SMALL_STATE(61)] = 3576,
  [SMALL_STATE(62)] = 3626,
  [SMALL_STATE(63)] = 3676,
  [SMALL_STATE(64)] = 3726,
  [SMALL_STATE(65)] = 3776,
  [SMALL_STATE(66)] = 3826,
  [SMALL_STATE(67)] = 3876,
  [SMALL_STATE(68)] = 3926,
  [SMALL_STATE(69)] = 3976,
  [SMALL_STATE(70)] = 4026,
  [SMALL_STATE(71)] = 4076,
  [SMALL_STATE(72)] = 4126,
  [SMALL_STATE(73)] = 4176,
  [SMALL_STATE(74)] = 4226,
  [SMALL_STATE(75)] = 4315,
  [SMALL_STATE(76)] = 4408,
  [SMALL_STATE(77)] = 4496,
  [SMALL_STATE(78)] = 4584,
  [SMALL_STATE(79)] = 4672,
  [SMALL_STATE(80)] = 4760,
  [SMALL_STATE(81)] = 4850,
  [SMALL_STATE(82)] = 4938,
  [SMALL_STATE(83)] = 5026,
  [SMALL_STATE(84)] = 5114,
  [SMALL_STATE(85)] = 5204,
  [SMALL_STATE(86)] = 5294,
  [SMALL_STATE(87)] = 5382,
  [SMALL_STATE(88)] = 5470,
  [SMALL_STATE(89)] = 5560,
  [SMALL_STATE(90)] = 5650,
  [SMALL_STATE(91)] = 5733,
  [SMALL_STATE(92)] = 5816,
  [SMALL_STATE(93)] = 5903,
  [SMALL_STATE(94)] = 5985,
  [SMALL_STATE(95)] = 6067,
  [SMALL_STATE(96)] = 6149,
  [SMALL_STATE(97)] = 6233,
  [SMALL_STATE(98)] = 6314,
  [SMALL_STATE(99)] = 6395,
  [SMALL_STATE(100)] = 6476,
  [SMALL_STATE(101)] = 6557,
  [SMALL_STATE(102)] = 6633,
  [SMALL_STATE(103)] = 6708,
  [SMALL_STATE(104)] = 6783,
  [SMALL_STATE(105)] = 6858,
  [SMALL_STATE(106)] = 6926,
  [SMALL_STATE(107)] = 6994,
  [SMALL_STATE(108)] = 7062,
  [SMALL_STATE(109)] = 7130,
  [SMALL_STATE(110)] = 7201,
  [SMALL_STATE(111)] = 7270,
  [SMALL_STATE(112)] = 7337,
  [SMALL_STATE(113)] = 7404,
  [SMALL_STATE(114)] = 7471,
  [SMALL_STATE(115)] = 7540,
  [SMALL_STATE(116)] = 7607,
  [SMALL_STATE(117)] = 7678,
  [SMALL_STATE(118)] = 7747,
  [SMALL_STATE(119)] = 7816,
  [SMALL_STATE(120)] = 7883,
  [SMALL_STATE(121)] = 7954,
  [SMALL_STATE(122)] = 8025,
  [SMALL_STATE(123)] = 8096,
  [SMALL_STATE(124)] = 8167,
  [SMALL_STATE(125)] = 8234,
  [SMALL_STATE(126)] = 8300,
  [SMALL_STATE(127)] = 8366,
  [SMALL_STATE(128)] = 8434,
  [SMALL_STATE(129)] = 8500,
  [SMALL_STATE(130)] = 8566,
  [SMALL_STATE(131)] = 8632,
  [SMALL_STATE(132)] = 8698,
  [SMALL_STATE(133)] = 8764,
  [SMALL_STATE(134)] = 8830,
  [SMALL_STATE(135)] = 8896,
  [SMALL_STATE(136)] = 8962,
  [SMALL_STATE(137)] = 9028,
  [SMALL_STATE(138)] = 9094,
  [SMALL_STATE(139)] = 9162,
  [SMALL_STATE(140)] = 9230,
  [SMALL_STATE(141)] = 9295,
  [SMALL_STATE(142)] = 9370,
  [SMALL_STATE(143)] = 9433,
  [SMALL_STATE(144)] = 9498,
  [SMALL_STATE(145)] = 9573,
  [SMALL_STATE(146)] = 9633,
  [SMALL_STATE(147)] = 9695,
  [SMALL_STATE(148)] = 9764,
  [SMALL_STATE(149)] = 9823,
  [SMALL_STATE(150)] = 9862,
  [SMALL_STATE(151)] = 9921,
  [SMALL_STATE(152)] = 9980,
  [SMALL_STATE(153)] = 10039,
  [SMALL_STATE(154)] = 10098,
  [SMALL_STATE(155)] = 10157,
  [SMALL_STATE(156)] = 10216,
  [SMALL_STATE(157)] = 10285,
  [SMALL_STATE(158)] = 10324,
  [SMALL_STATE(159)] = 10393,
  [SMALL_STATE(160)] = 10452,
  [SMALL_STATE(161)] = 10491,
  [SMALL_STATE(162)] = 10550,
  [SMALL_STATE(163)] = 10609,
  [SMALL_STATE(164)] = 10675,
  [SMALL_STATE(165)] = 10731,
  [SMALL_STATE(166)] = 10787,
  [SMALL_STATE(167)] = 10843,
  [SMALL_STATE(168)] = 10899,
  [SMALL_STATE(169)] = 10955,
  [SMALL_STATE(170)] = 11011,
  [SMALL_STATE(171)] = 11067,
  [SMALL_STATE(172)] = 11133,
  [SMALL_STATE(173)] = 11189,
  [SMALL_STATE(174)] = 11245,
  [SMALL_STATE(175)] = 11301,
  [SMALL_STATE(176)] = 11357,
  [SMALL_STATE(177)] = 11413,
  [SMALL_STATE(178)] = 11447,
  [SMALL_STATE(179)] = 11503,
  [SMALL_STATE(180)] = 11559,
  [SMALL_STATE(181)] = 11615,
  [SMALL_STATE(182)] = 11671,
  [SMALL_STATE(183)] = 11727,
  [SMALL_STATE(184)] = 11783,
  [SMALL_STATE(185)] = 11839,
  [SMALL_STATE(186)] = 11895,
  [SMALL_STATE(187)] = 11951,
  [SMALL_STATE(188)] = 12007,
  [SMALL_STATE(189)] = 12073,
  [SMALL_STATE(190)] = 12129,
  [SMALL_STATE(191)] = 12185,
  [SMALL_STATE(192)] = 12241,
  [SMALL_STATE(193)] = 12297,
  [SMALL_STATE(194)] = 12353,
  [SMALL_STATE(195)] = 12409,
  [SMALL_STATE(196)] = 12465,
  [SMALL_STATE(197)] = 12521,
  [SMALL_STATE(198)] = 12577,
  [SMALL_STATE(199)] = 12633,
  [SMALL_STATE(200)] = 12689,
  [SMALL_STATE(201)] = 12745,
  [SMALL_STATE(202)] = 12801,
  [SMALL_STATE(203)] = 12857,
  [SMALL_STATE(204)] = 12913,
  [SMALL_STATE(205)] = 12969,
  [SMALL_STATE(206)] = 13025,
  [SMALL_STATE(207)] = 13081,
  [SMALL_STATE(208)] = 13137,
  [SMALL_STATE(209)] = 13193,
  [SMALL_STATE(210)] = 13259,
  [SMALL_STATE(211)] = 13315,
  [SMALL_STATE(212)] = 13381,
  [SMALL_STATE(213)] = 13437,
  [SMALL_STATE(214)] = 13493,
  [SMALL_STATE(215)] = 13549,
  [SMALL_STATE(216)] = 13615,
  [SMALL_STATE(217)] = 13671,
  [SMALL_STATE(218)] = 13727,
  [SMALL_STATE(219)] = 13783,
  [SMALL_STATE(220)] = 13839,
  [SMALL_STATE(221)] = 13895,
  [SMALL_STATE(222)] = 13951,
  [SMALL_STATE(223)] = 13984,
  [SMALL_STATE(224)] = 14017,
  [SMALL_STATE(225)] = 14050,
  [SMALL_STATE(226)] = 14083,
  [SMALL_STATE(227)] = 14116,
  [SMALL_STATE(228)] = 14149,
  [SMALL_STATE(229)] = 14182,
  [SMALL_STATE(230)] = 14245,
  [SMALL_STATE(231)] = 14278,
  [SMALL_STATE(232)] = 14311,
  [SMALL_STATE(233)] = 14344,
  [SMALL_STATE(234)] = 14377,
  [SMALL_STATE(235)] = 14410,
  [SMALL_STATE(236)] = 14473,
  [SMALL_STATE(237)] = 14506,
  [SMALL_STATE(238)] = 14566,
  [SMALL_STATE(239)] = 14626,
  [SMALL_STATE(240)] = 14678,
  [SMALL_STATE(241)] = 14738,
  [SMALL_STATE(242)] = 14798,
  [SMALL_STATE(243)] = 14837,
  [SMALL_STATE(244)] = 14868,
  [SMALL_STATE(245)] = 14899,
  [SMALL_STATE(246)] = 14938,
  [SMALL_STATE(247)] = 14969,
  [SMALL_STATE(248)] = 15008,
  [SMALL_STATE(249)] = 15047,
  [SMALL_STATE(250)] = 15077,
  [SMALL_STATE(251)] = 15125,
  [SMALL_STATE(252)] = 15159,
  [SMALL_STATE(253)] = 15195,
  [SMALL_STATE(254)] = 15229,
  [SMALL_STATE(255)] = 15263,
  [SMALL_STATE(256)] = 15293,
  [SMALL_STATE(257)] = 15323,
  [SMALL_STATE(258)] = 15368,
  [SMALL_STATE(259)] = 15401,
  [SMALL_STATE(260)] = 15434,
  [SMALL_STATE(261)] = 15467,
  [SMALL_STATE(262)] = 15512,
  [SMALL_STATE(263)] = 15545,
  [SMALL_STATE(264)] = 15577,
  [SMALL_STATE(265)] = 15615,
  [SMALL_STATE(266)] = 15669,
  [SMALL_STATE(267)] = 15705,
  [SMALL_STATE(268)] = 15733,
  [SMALL_STATE(269)] = 15761,
  [SMALL_STATE(270)] = 15793,
  [SMALL_STATE(271)] = 15829,
  [SMALL_STATE(272)] = 15857,
  [SMALL_STATE(273)] = 15899,
  [SMALL_STATE(274)] = 15929,
  [SMALL_STATE(275)] = 15971,
  [SMALL_STATE(276)] = 16013,
  [SMALL_STATE(277)] = 16055,
  [SMALL_STATE(278)] = 16087,
  [SMALL_STATE(279)] = 16123,
  [SMALL_STATE(280)] = 16155,
  [SMALL_STATE(281)] = 16197,
  [SMALL_STATE(282)] = 16225,
  [SMALL_STATE(283)] = 16267,
  [SMALL_STATE(284)] = 16295,
  [SMALL_STATE(285)] = 16323,
  [SMALL_STATE(286)] = 16351,
  [SMALL_STATE(287)] = 16379,
  [SMALL_STATE(288)] = 16421,
  [SMALL_STATE(289)] = 16455,
  [SMALL_STATE(290)] = 16491,
  [SMALL_STATE(291)] = 16519,
  [SMALL_STATE(292)] = 16549,
  [SMALL_STATE(293)] = 16577,
  [SMALL_STATE(294)] = 16619,
  [SMALL_STATE(295)] = 16647,
  [SMALL_STATE(296)] = 16677,
  [SMALL_STATE(297)] = 16713,
  [SMALL_STATE(298)] = 16741,
  [SMALL_STATE(299)] = 16785,
  [SMALL_STATE(300)] = 16813,
  [SMALL_STATE(301)] = 16849,
  [SMALL_STATE(302)] = 16877,
  [SMALL_STATE(303)] = 16911,
  [SMALL_STATE(304)] = 16941,
  [SMALL_STATE(305)] = 16983,
  [SMALL_STATE(306)] = 17025,
  [SMALL_STATE(307)] = 17067,
  [SMALL_STATE(308)] = 17109,
  [SMALL_STATE(309)] = 17151,
  [SMALL_STATE(310)] = 17181,
  [SMALL_STATE(311)] = 17211,
  [SMALL_STATE(312)] = 17250,
  [SMALL_STATE(313)] = 17293,
  [SMALL_STATE(314)] = 17319,
  [SMALL_STATE(315)] = 17357,
  [SMALL_STATE(316)] = 17387,
  [SMALL_STATE(317)] = 17417,
  [SMALL_STATE(318)] = 17447,
  [SMALL_STATE(319)] = 17477,
  [SMALL_STATE(320)] = 17503,
  [SMALL_STATE(321)] = 17529,
  [SMALL_STATE(322)] = 17559,
  [SMALL_STATE(323)] = 17585,
  [SMALL_STATE(324)] = 17611,
  [SMALL_STATE(325)] = 17637,
  [SMALL_STATE(326)] = 17663,
  [SMALL_STATE(327)] = 17691,
  [SMALL_STATE(328)] = 17717,
  [SMALL_STATE(329)] = 17743,
  [SMALL_STATE(330)] = 17769,
  [SMALL_STATE(331)] = 17795,
  [SMALL_STATE(332)] = 17821,
  [SMALL_STATE(333)] = 17847,
  [SMALL_STATE(334)] = 17881,
  [SMALL_STATE(335)] = 17913,
  [SMALL_STATE(336)] = 17941,
  [SMALL_STATE(337)] = 17969,
  [SMALL_STATE(338)] = 18005,
  [SMALL_STATE(339)] = 18031,
  [SMALL_STATE(340)] = 18057,
  [SMALL_STATE(341)] = 18083,
  [SMALL_STATE(342)] = 18109,
  [SMALL_STATE(343)] = 18135,
  [SMALL_STATE(344)] = 18166,
  [SMALL_STATE(345)] = 18197,
  [SMALL_STATE(346)] = 18228,
  [SMALL_STATE(347)] = 18259,
  [SMALL_STATE(348)] = 18298,
  [SMALL_STATE(349)] = 18337,
  [SMALL_STATE(350)] = 18367,
  [SMALL_STATE(351)] = 18395,
  [SMALL_STATE(352)] = 18419,
  [SMALL_STATE(353)] = 18457,
  [SMALL_STATE(354)] = 18481,
  [SMALL_STATE(355)] = 18517,
  [SMALL_STATE(356)] = 18541,
  [SMALL_STATE(357)] = 18579,
  [SMALL_STATE(358)] = 18603,
  [SMALL_STATE(359)] = 18627,
  [SMALL_STATE(360)] = 18655,
  [SMALL_STATE(361)] = 18681,
  [SMALL_STATE(362)] = 18707,
  [SMALL_STATE(363)] = 18739,
  [SMALL_STATE(364)] = 18765,
  [SMALL_STATE(365)] = 18798,
  [SMALL_STATE(366)] = 18827,
  [SMALL_STATE(367)] = 18860,
  [SMALL_STATE(368)] = 18889,
  [SMALL_STATE(369)] = 18924,
  [SMALL_STATE(370)] = 18953,
  [SMALL_STATE(371)] = 18982,
  [SMALL_STATE(372)] = 19017,
  [SMALL_STATE(373)] = 19050,
  [SMALL_STATE(374)] = 19072,
  [SMALL_STATE(375)] = 19094,
  [SMALL_STATE(376)] = 19116,
  [SMALL_STATE(377)] = 19152,
  [SMALL_STATE(378)] = 19186,
  [SMALL_STATE(379)] = 19222,
  [SMALL_STATE(380)] = 19250,
  [SMALL_STATE(381)] = 19272,
  [SMALL_STATE(382)] = 19294,
  [SMALL_STATE(383)] = 19330,
  [SMALL_STATE(384)] = 19362,
  [SMALL_STATE(385)] = 19396,
  [SMALL_STATE(386)] = 19424,
  [SMALL_STATE(387)] = 19458,
  [SMALL_STATE(388)] = 19494,
  [SMALL_STATE(389)] = 19521,
  [SMALL_STATE(390)] = 19544,
  [SMALL_STATE(391)] = 19577,
  [SMALL_STATE(392)] = 19608,
  [SMALL_STATE(393)] = 19641,
  [SMALL_STATE(394)] = 19674,
  [SMALL_STATE(395)] = 19705,
  [SMALL_STATE(396)] = 19736,
  [SMALL_STATE(397)] = 19767,
  [SMALL_STATE(398)] = 19798,
  [SMALL_STATE(399)] = 19829,
  [SMALL_STATE(400)] = 19860,
  [SMALL_STATE(401)] = 19881,
  [SMALL_STATE(402)] = 19912,
  [SMALL_STATE(403)] = 19943,
  [SMALL_STATE(404)] = 19966,
  [SMALL_STATE(405)] = 19991,
  [SMALL_STATE(406)] = 20014,
  [SMALL_STATE(407)] = 20045,
  [SMALL_STATE(408)] = 20075,
  [SMALL_STATE(409)] = 20105,
  [SMALL_STATE(410)] = 20135,
  [SMALL_STATE(411)] = 20173,
  [SMALL_STATE(412)] = 20197,
  [SMALL_STATE(413)] = 20227,
  [SMALL_STATE(414)] = 20257,
  [SMALL_STATE(415)] = 20287,
  [SMALL_STATE(416)] = 20325,
  [SMALL_STATE(417)] = 20353,
  [SMALL_STATE(418)] = 20391,
  [SMALL_STATE(419)] = 20421,
  [SMALL_STATE(420)] = 20451,
  [SMALL_STATE(421)] = 20481,
  [SMALL_STATE(422)] = 20511,
  [SMALL_STATE(423)] = 20542,
  [SMALL_STATE(424)] = 20567,
  [SMALL_STATE(425)] = 20590,
  [SMALL_STATE(426)] = 20611,
  [SMALL_STATE(427)] = 20632,
  [SMALL_STATE(428)] = 20659,
  [SMALL_STATE(429)] = 20680,
  [SMALL_STATE(430)] = 20707,
  [SMALL_STATE(431)] = 20734,
  [SMALL_STATE(432)] = 20754,
  [SMALL_STATE(433)] = 20784,
  [SMALL_STATE(434)] = 20814,
  [SMALL_STATE(435)] = 20836,
  [SMALL_STATE(436)] = 20856,
  [SMALL_STATE(437)] = 20874,
  [SMALL_STATE(438)] = 20904,
  [SMALL_STATE(439)] = 20922,
  [SMALL_STATE(440)] = 20940,
  [SMALL_STATE(441)] = 20958,
  [SMALL_STATE(442)] = 20976,
  [SMALL_STATE(443)] = 20994,
  [SMALL_STATE(444)] = 21012,
  [SMALL_STATE(445)] = 21030,
  [SMALL_STATE(446)] = 21048,
  [SMALL_STATE(447)] = 21066,
  [SMALL_STATE(448)] = 21094,
  [SMALL_STATE(449)] = 21122,
  [SMALL_STATE(450)] = 21140,
  [SMALL_STATE(451)] = 21158,
  [SMALL_STATE(452)] = 21186,
  [SMALL_STATE(453)] = 21214,
  [SMALL_STATE(454)] = 21232,
  [SMALL_STATE(455)] = 21259,
  [SMALL_STATE(456)] = 21286,
  [SMALL_STATE(457)] = 21317,
  [SMALL_STATE(458)] = 21336,
  [SMALL_STATE(459)] = 21355,
  [SMALL_STATE(460)] = 21376,
  [SMALL_STATE(461)] = 21403,
  [SMALL_STATE(462)] = 21422,
  [SMALL_STATE(463)] = 21439,
  [SMALL_STATE(464)] = 21458,
  [SMALL_STATE(465)] = 21477,
  [SMALL_STATE(466)] = 21496,
  [SMALL_STATE(467)] = 21518,
  [SMALL_STATE(468)] = 21544,
  [SMALL_STATE(469)] = 21562,
  [SMALL_STATE(470)] = 21576,
  [SMALL_STATE(471)] = 21590,
  [SMALL_STATE(472)] = 21608,
  [SMALL_STATE(473)] = 21634,
  [SMALL_STATE(474)] = 21658,
  [SMALL_STATE(475)] = 21672,
  [SMALL_STATE(476)] = 21690,
  [SMALL_STATE(477)] = 21716,
  [SMALL_STATE(478)] = 21740,
  [SMALL_STATE(479)] = 21754,
  [SMALL_STATE(480)] = 21776,
  [SMALL_STATE(481)] = 21798,
  [SMALL_STATE(482)] = 21826,
  [SMALL_STATE(483)] = 21850,
  [SMALL_STATE(484)] = 21872,
  [SMALL_STATE(485)] = 21886,
  [SMALL_STATE(486)] = 21900,
  [SMALL_STATE(487)] = 21915,
  [SMALL_STATE(488)] = 21930,
  [SMALL_STATE(489)] = 21947,
  [SMALL_STATE(490)] = 21962,
  [SMALL_STATE(491)] = 21983,
  [SMALL_STATE(492)] = 22006,
  [SMALL_STATE(493)] = 22021,
  [SMALL_STATE(494)] = 22040,
  [SMALL_STATE(495)] = 22055,
  [SMALL_STATE(496)] = 22070,
  [SMALL_STATE(497)] = 22085,
  [SMALL_STATE(498)] = 22100,
  [SMALL_STATE(499)] = 22113,
  [SMALL_STATE(500)] = 22128,
  [SMALL_STATE(501)] = 22143,
  [SMALL_STATE(502)] = 22156,
  [SMALL_STATE(503)] = 22169,
  [SMALL_STATE(504)] = 22184,
  [SMALL_STATE(505)] = 22199,
  [SMALL_STATE(506)] = 22216,
  [SMALL_STATE(507)] = 22231,
  [SMALL_STATE(508)] = 22252,
  [SMALL_STATE(509)] = 22273,
  [SMALL_STATE(510)] = 22286,
  [SMALL_STATE(511)] = 22307,
  [SMALL_STATE(512)] = 22328,
  [SMALL_STATE(513)] = 22349,
  [SMALL_STATE(514)] = 22368,
  [SMALL_STATE(515)] = 22389,
  [SMALL_STATE(516)] = 22412,
  [SMALL_STATE(517)] = 22428,
  [SMALL_STATE(518)] = 22444,
  [SMALL_STATE(519)] = 22456,
  [SMALL_STATE(520)] = 22468,
  [SMALL_STATE(521)] = 22480,
  [SMALL_STATE(522)] = 22496,
  [SMALL_STATE(523)] = 22508,
  [SMALL_STATE(524)] = 22524,
  [SMALL_STATE(525)] = 22536,
  [SMALL_STATE(526)] = 22554,
  [SMALL_STATE(527)] = 22570,
  [SMALL_STATE(528)] = 22582,
  [SMALL_STATE(529)] = 22600,
  [SMALL_STATE(530)] = 22616,
  [SMALL_STATE(531)] = 22636,
  [SMALL_STATE(532)] = 22652,
  [SMALL_STATE(533)] = 22664,
  [SMALL_STATE(534)] = 22680,
  [SMALL_STATE(535)] = 22692,
  [SMALL_STATE(536)] = 22712,
  [SMALL_STATE(537)] = 22732,
  [SMALL_STATE(538)] = 22750,
  [SMALL_STATE(539)] = 22762,
  [SMALL_STATE(540)] = 22774,
  [SMALL_STATE(541)] = 22786,
  [SMALL_STATE(542)] = 22798,
  [SMALL_STATE(543)] = 22814,
  [SMALL_STATE(544)] = 22830,
  [SMALL_STATE(545)] = 22850,
  [SMALL_STATE(546)] = 22870,
  [SMALL_STATE(547)] = 22882,
  [SMALL_STATE(548)] = 22902,
  [SMALL_STATE(549)] = 22914,
  [SMALL_STATE(550)] = 22932,
  [SMALL_STATE(551)] = 22949,
  [SMALL_STATE(552)] = 22964,
  [SMALL_STATE(553)] = 22975,
  [SMALL_STATE(554)] = 22986,
  [SMALL_STATE(555)] = 22997,
  [SMALL_STATE(556)] = 23012,
  [SMALL_STATE(557)] = 23025,
  [SMALL_STATE(558)] = 23042,
  [SMALL_STATE(559)] = 23059,
  [SMALL_STATE(560)] = 23070,
  [SMALL_STATE(561)] = 23087,
  [SMALL_STATE(562)] = 23098,
  [SMALL_STATE(563)] = 23109,
  [SMALL_STATE(564)] = 23124,
  [SMALL_STATE(565)] = 23135,
  [SMALL_STATE(566)] = 23150,
  [SMALL_STATE(567)] = 23165,
  [SMALL_STATE(568)] = 23180,
  [SMALL_STATE(569)] = 23195,
  [SMALL_STATE(570)] = 23210,
  [SMALL_STATE(571)] = 23227,
  [SMALL_STATE(572)] = 23242,
  [SMALL_STATE(573)] = 23253,
  [SMALL_STATE(574)] = 23264,
  [SMALL_STATE(575)] = 23277,
  [SMALL_STATE(576)] = 23292,
  [SMALL_STATE(577)] = 23309,
  [SMALL_STATE(578)] = 23326,
  [SMALL_STATE(579)] = 23337,
  [SMALL_STATE(580)] = 23348,
  [SMALL_STATE(581)] = 23365,
  [SMALL_STATE(582)] = 23376,
  [SMALL_STATE(583)] = 23393,
  [SMALL_STATE(584)] = 23404,
  [SMALL_STATE(585)] = 23421,
  [SMALL_STATE(586)] = 23438,
  [SMALL_STATE(587)] = 23449,
  [SMALL_STATE(588)] = 23464,
  [SMALL_STATE(589)] = 23481,
  [SMALL_STATE(590)] = 23498,
  [SMALL_STATE(591)] = 23513,
  [SMALL_STATE(592)] = 23528,
  [SMALL_STATE(593)] = 23545,
  [SMALL_STATE(594)] = 23558,
  [SMALL_STATE(595)] = 23569,
  [SMALL_STATE(596)] = 23586,
  [SMALL_STATE(597)] = 23601,
  [SMALL_STATE(598)] = 23616,
  [SMALL_STATE(599)] = 23633,
  [SMALL_STATE(600)] = 23650,
  [SMALL_STATE(601)] = 23667,
  [SMALL_STATE(602)] = 23678,
  [SMALL_STATE(603)] = 23693,
  [SMALL_STATE(604)] = 23710,
  [SMALL_STATE(605)] = 23725,
  [SMALL_STATE(606)] = 23738,
  [SMALL_STATE(607)] = 23753,
  [SMALL_STATE(608)] = 23768,
  [SMALL_STATE(609)] = 23779,
  [SMALL_STATE(610)] = 23794,
  [SMALL_STATE(611)] = 23808,
  [SMALL_STATE(612)] = 23822,
  [SMALL_STATE(613)] = 23836,
  [SMALL_STATE(614)] = 23850,
  [SMALL_STATE(615)] = 23860,
  [SMALL_STATE(616)] = 23874,
  [SMALL_STATE(617)] = 23888,
  [SMALL_STATE(618)] = 23900,
  [SMALL_STATE(619)] = 23910,
  [SMALL_STATE(620)] = 23924,
  [SMALL_STATE(621)] = 23936,
  [SMALL_STATE(622)] = 23950,
  [SMALL_STATE(623)] = 23964,
  [SMALL_STATE(624)] = 23978,
  [SMALL_STATE(625)] = 23992,
  [SMALL_STATE(626)] = 24002,
  [SMALL_STATE(627)] = 24016,
  [SMALL_STATE(628)] = 24030,
  [SMALL_STATE(629)] = 24044,
  [SMALL_STATE(630)] = 24054,
  [SMALL_STATE(631)] = 24068,
  [SMALL_STATE(632)] = 24082,
  [SMALL_STATE(633)] = 24096,
  [SMALL_STATE(634)] = 24110,
  [SMALL_STATE(635)] = 24124,
  [SMALL_STATE(636)] = 24138,
  [SMALL_STATE(637)] = 24148,
  [SMALL_STATE(638)] = 24162,
  [SMALL_STATE(639)] = 24176,
  [SMALL_STATE(640)] = 24190,
  [SMALL_STATE(641)] = 24200,
  [SMALL_STATE(642)] = 24214,
  [SMALL_STATE(643)] = 24228,
  [SMALL_STATE(644)] = 24242,
  [SMALL_STATE(645)] = 24256,
  [SMALL_STATE(646)] = 24270,
  [SMALL_STATE(647)] = 24284,
  [SMALL_STATE(648)] = 24298,
  [SMALL_STATE(649)] = 24312,
  [SMALL_STATE(650)] = 24326,
  [SMALL_STATE(651)] = 24340,
  [SMALL_STATE(652)] = 24354,
  [SMALL_STATE(653)] = 24368,
  [SMALL_STATE(654)] = 24382,
  [SMALL_STATE(655)] = 24396,
  [SMALL_STATE(656)] = 24410,
  [SMALL_STATE(657)] = 24424,
  [SMALL_STATE(658)] = 24438,
  [SMALL_STATE(659)] = 24452,
  [SMALL_STATE(660)] = 24466,
  [SMALL_STATE(661)] = 24480,
  [SMALL_STATE(662)] = 24494,
  [SMALL_STATE(663)] = 24508,
  [SMALL_STATE(664)] = 24522,
  [SMALL_STATE(665)] = 24536,
  [SMALL_STATE(666)] = 24550,
  [SMALL_STATE(667)] = 24564,
  [SMALL_STATE(668)] = 24578,
  [SMALL_STATE(669)] = 24592,
  [SMALL_STATE(670)] = 24606,
  [SMALL_STATE(671)] = 24620,
  [SMALL_STATE(672)] = 24634,
  [SMALL_STATE(673)] = 24646,
  [SMALL_STATE(674)] = 24660,
  [SMALL_STATE(675)] = 24674,
  [SMALL_STATE(676)] = 24688,
  [SMALL_STATE(677)] = 24702,
  [SMALL_STATE(678)] = 24714,
  [SMALL_STATE(679)] = 24724,
  [SMALL_STATE(680)] = 24734,
  [SMALL_STATE(681)] = 24748,
  [SMALL_STATE(682)] = 24762,
  [SMALL_STATE(683)] = 24774,
  [SMALL_STATE(684)] = 24784,
  [SMALL_STATE(685)] = 24798,
  [SMALL_STATE(686)] = 24812,
  [SMALL_STATE(687)] = 24822,
  [SMALL_STATE(688)] = 24836,
  [SMALL_STATE(689)] = 24850,
  [SMALL_STATE(690)] = 24862,
  [SMALL_STATE(691)] = 24876,
  [SMALL_STATE(692)] = 24888,
  [SMALL_STATE(693)] = 24902,
  [SMALL_STATE(694)] = 24916,
  [SMALL_STATE(695)] = 24930,
  [SMALL_STATE(696)] = 24944,
  [SMALL_STATE(697)] = 24956,
  [SMALL_STATE(698)] = 24970,
  [SMALL_STATE(699)] = 24984,
  [SMALL_STATE(700)] = 24998,
  [SMALL_STATE(701)] = 25010,
  [SMALL_STATE(702)] = 25024,
  [SMALL_STATE(703)] = 25034,
  [SMALL_STATE(704)] = 25048,
  [SMALL_STATE(705)] = 25062,
  [SMALL_STATE(706)] = 25076,
  [SMALL_STATE(707)] = 25090,
  [SMALL_STATE(708)] = 25104,
  [SMALL_STATE(709)] = 25116,
  [SMALL_STATE(710)] = 25130,
  [SMALL_STATE(711)] = 25144,
  [SMALL_STATE(712)] = 25158,
  [SMALL_STATE(713)] = 25168,
  [SMALL_STATE(714)] = 25182,
  [SMALL_STATE(715)] = 25191,
  [SMALL_STATE(716)] = 25200,
  [SMALL_STATE(717)] = 25211,
  [SMALL_STATE(718)] = 25222,
  [SMALL_STATE(719)] = 25233,
  [SMALL_STATE(720)] = 25244,
  [SMALL_STATE(721)] = 25255,
  [SMALL_STATE(722)] = 25264,
  [SMALL_STATE(723)] = 25273,
  [SMALL_STATE(724)] = 25282,
  [SMALL_STATE(725)] = 25291,
  [SMALL_STATE(726)] = 25300,
  [SMALL_STATE(727)] = 25309,
  [SMALL_STATE(728)] = 25320,
  [SMALL_STATE(729)] = 25329,
  [SMALL_STATE(730)] = 25338,
  [SMALL_STATE(731)] = 25347,
  [SMALL_STATE(732)] = 25356,
  [SMALL_STATE(733)] = 25365,
  [SMALL_STATE(734)] = 25374,
  [SMALL_STATE(735)] = 25383,
  [SMALL_STATE(736)] = 25394,
  [SMALL_STATE(737)] = 25403,
  [SMALL_STATE(738)] = 25412,
  [SMALL_STATE(739)] = 25421,
  [SMALL_STATE(740)] = 25432,
  [SMALL_STATE(741)] = 25441,
  [SMALL_STATE(742)] = 25450,
  [SMALL_STATE(743)] = 25459,
  [SMALL_STATE(744)] = 25468,
  [SMALL_STATE(745)] = 25477,
  [SMALL_STATE(746)] = 25486,
  [SMALL_STATE(747)] = 25497,
  [SMALL_STATE(748)] = 25506,
  [SMALL_STATE(749)] = 25515,
  [SMALL_STATE(750)] = 25526,
  [SMALL_STATE(751)] = 25535,
  [SMALL_STATE(752)] = 25546,
  [SMALL_STATE(753)] = 25555,
  [SMALL_STATE(754)] = 25564,
  [SMALL_STATE(755)] = 25575,
  [SMALL_STATE(756)] = 25584,
  [SMALL_STATE(757)] = 25593,
  [SMALL_STATE(758)] = 25602,
  [SMALL_STATE(759)] = 25613,
  [SMALL_STATE(760)] = 25622,
  [SMALL_STATE(761)] = 25633,
  [SMALL_STATE(762)] = 25642,
  [SMALL_STATE(763)] = 25651,
  [SMALL_STATE(764)] = 25662,
  [SMALL_STATE(765)] = 25671,
  [SMALL_STATE(766)] = 25680,
  [SMALL_STATE(767)] = 25691,
  [SMALL_STATE(768)] = 25702,
  [SMALL_STATE(769)] = 25713,
  [SMALL_STATE(770)] = 25722,
  [SMALL_STATE(771)] = 25731,
  [SMALL_STATE(772)] = 25740,
  [SMALL_STATE(773)] = 25749,
  [SMALL_STATE(774)] = 25760,
  [SMALL_STATE(775)] = 25769,
  [SMALL_STATE(776)] = 25780,
  [SMALL_STATE(777)] = 25791,
  [SMALL_STATE(778)] = 25800,
  [SMALL_STATE(779)] = 25811,
  [SMALL_STATE(780)] = 25822,
  [SMALL_STATE(781)] = 25833,
  [SMALL_STATE(782)] = 25842,
  [SMALL_STATE(783)] = 25851,
  [SMALL_STATE(784)] = 25860,
  [SMALL_STATE(785)] = 25871,
  [SMALL_STATE(786)] = 25880,
  [SMALL_STATE(787)] = 25891,
  [SMALL_STATE(788)] = 25900,
  [SMALL_STATE(789)] = 25909,
  [SMALL_STATE(790)] = 25920,
  [SMALL_STATE(791)] = 25931,
  [SMALL_STATE(792)] = 25942,
  [SMALL_STATE(793)] = 25951,
  [SMALL_STATE(794)] = 25960,
  [SMALL_STATE(795)] = 25971,
  [SMALL_STATE(796)] = 25980,
  [SMALL_STATE(797)] = 25989,
  [SMALL_STATE(798)] = 25998,
  [SMALL_STATE(799)] = 26009,
  [SMALL_STATE(800)] = 26018,
  [SMALL_STATE(801)] = 26027,
  [SMALL_STATE(802)] = 26035,
  [SMALL_STATE(803)] = 26043,
  [SMALL_STATE(804)] = 26051,
  [SMALL_STATE(805)] = 26059,
  [SMALL_STATE(806)] = 26067,
  [SMALL_STATE(807)] = 26075,
  [SMALL_STATE(808)] = 26083,
  [SMALL_STATE(809)] = 26091,
  [SMALL_STATE(810)] = 26099,
  [SMALL_STATE(811)] = 26107,
  [SMALL_STATE(812)] = 26115,
  [SMALL_STATE(813)] = 26123,
  [SMALL_STATE(814)] = 26131,
  [SMALL_STATE(815)] = 26139,
  [SMALL_STATE(816)] = 26147,
  [SMALL_STATE(817)] = 26155,
  [SMALL_STATE(818)] = 26163,
  [SMALL_STATE(819)] = 26173,
  [SMALL_STATE(820)] = 26181,
  [SMALL_STATE(821)] = 26189,
  [SMALL_STATE(822)] = 26197,
  [SMALL_STATE(823)] = 26205,
  [SMALL_STATE(824)] = 26213,
  [SMALL_STATE(825)] = 26221,
  [SMALL_STATE(826)] = 26229,
  [SMALL_STATE(827)] = 26237,
  [SMALL_STATE(828)] = 26245,
  [SMALL_STATE(829)] = 26253,
  [SMALL_STATE(830)] = 26263,
  [SMALL_STATE(831)] = 26271,
  [SMALL_STATE(832)] = 26279,
  [SMALL_STATE(833)] = 26287,
  [SMALL_STATE(834)] = 26295,
  [SMALL_STATE(835)] = 26303,
  [SMALL_STATE(836)] = 26311,
  [SMALL_STATE(837)] = 26319,
  [SMALL_STATE(838)] = 26327,
  [SMALL_STATE(839)] = 26335,
  [SMALL_STATE(840)] = 26343,
  [SMALL_STATE(841)] = 26351,
  [SMALL_STATE(842)] = 26359,
  [SMALL_STATE(843)] = 26367,
  [SMALL_STATE(844)] = 26375,
  [SMALL_STATE(845)] = 26383,
  [SMALL_STATE(846)] = 26391,
  [SMALL_STATE(847)] = 26399,
  [SMALL_STATE(848)] = 26407,
  [SMALL_STATE(849)] = 26415,
  [SMALL_STATE(850)] = 26423,
  [SMALL_STATE(851)] = 26433,
  [SMALL_STATE(852)] = 26441,
  [SMALL_STATE(853)] = 26451,
  [SMALL_STATE(854)] = 26459,
  [SMALL_STATE(855)] = 26467,
  [SMALL_STATE(856)] = 26475,
  [SMALL_STATE(857)] = 26483,
  [SMALL_STATE(858)] = 26491,
  [SMALL_STATE(859)] = 26499,
  [SMALL_STATE(860)] = 26507,
  [SMALL_STATE(861)] = 26515,
  [SMALL_STATE(862)] = 26523,
  [SMALL_STATE(863)] = 26531,
  [SMALL_STATE(864)] = 26539,
  [SMALL_STATE(865)] = 26547,
  [SMALL_STATE(866)] = 26555,
  [SMALL_STATE(867)] = 26563,
  [SMALL_STATE(868)] = 26571,
  [SMALL_STATE(869)] = 26579,
  [SMALL_STATE(870)] = 26587,
  [SMALL_STATE(871)] = 26595,
  [SMALL_STATE(872)] = 26603,
  [SMALL_STATE(873)] = 26613,
  [SMALL_STATE(874)] = 26621,
  [SMALL_STATE(875)] = 26629,
  [SMALL_STATE(876)] = 26637,
  [SMALL_STATE(877)] = 26645,
  [SMALL_STATE(878)] = 26653,
  [SMALL_STATE(879)] = 26661,
  [SMALL_STATE(880)] = 26669,
  [SMALL_STATE(881)] = 26677,
  [SMALL_STATE(882)] = 26685,
  [SMALL_STATE(883)] = 26693,
  [SMALL_STATE(884)] = 26701,
  [SMALL_STATE(885)] = 26709,
  [SMALL_STATE(886)] = 26717,
  [SMALL_STATE(887)] = 26725,
  [SMALL_STATE(888)] = 26733,
  [SMALL_STATE(889)] = 26741,
  [SMALL_STATE(890)] = 26749,
  [SMALL_STATE(891)] = 26757,
  [SMALL_STATE(892)] = 26767,
  [SMALL_STATE(893)] = 26775,
  [SMALL_STATE(894)] = 26783,
  [SMALL_STATE(895)] = 26791,
  [SMALL_STATE(896)] = 26799,
  [SMALL_STATE(897)] = 26807,
  [SMALL_STATE(898)] = 26815,
  [SMALL_STATE(899)] = 26823,
  [SMALL_STATE(900)] = 26831,
  [SMALL_STATE(901)] = 26839,
  [SMALL_STATE(902)] = 26847,
  [SMALL_STATE(903)] = 26855,
  [SMALL_STATE(904)] = 26863,
  [SMALL_STATE(905)] = 26873,
  [SMALL_STATE(906)] = 26883,
  [SMALL_STATE(907)] = 26891,
  [SMALL_STATE(908)] = 26899,
  [SMALL_STATE(909)] = 26907,
  [SMALL_STATE(910)] = 26915,
  [SMALL_STATE(911)] = 26923,
  [SMALL_STATE(912)] = 26931,
  [SMALL_STATE(913)] = 26939,
  [SMALL_STATE(914)] = 26947,
  [SMALL_STATE(915)] = 26955,
  [SMALL_STATE(916)] = 26963,
  [SMALL_STATE(917)] = 26971,
  [SMALL_STATE(918)] = 26979,
  [SMALL_STATE(919)] = 26987,
  [SMALL_STATE(920)] = 26997,
  [SMALL_STATE(921)] = 27005,
  [SMALL_STATE(922)] = 27013,
  [SMALL_STATE(923)] = 27023,
  [SMALL_STATE(924)] = 27033,
  [SMALL_STATE(925)] = 27041,
  [SMALL_STATE(926)] = 27049,
  [SMALL_STATE(927)] = 27057,
  [SMALL_STATE(928)] = 27065,
  [SMALL_STATE(929)] = 27073,
  [SMALL_STATE(930)] = 27081,
  [SMALL_STATE(931)] = 27089,
  [SMALL_STATE(932)] = 27097,
  [SMALL_STATE(933)] = 27107,
  [SMALL_STATE(934)] = 27115,
  [SMALL_STATE(935)] = 27123,
  [SMALL_STATE(936)] = 27131,
  [SMALL_STATE(937)] = 27139,
  [SMALL_STATE(938)] = 27147,
  [SMALL_STATE(939)] = 27155,
  [SMALL_STATE(940)] = 27163,
  [SMALL_STATE(941)] = 27171,
  [SMALL_STATE(942)] = 27179,
  [SMALL_STATE(943)] = 27187,
  [SMALL_STATE(944)] = 27195,
  [SMALL_STATE(945)] = 27203,
  [SMALL_STATE(946)] = 27211,
  [SMALL_STATE(947)] = 27219,
  [SMALL_STATE(948)] = 27227,
  [SMALL_STATE(949)] = 27235,
  [SMALL_STATE(950)] = 27243,
  [SMALL_STATE(951)] = 27251,
  [SMALL_STATE(952)] = 27259,
  [SMALL_STATE(953)] = 27267,
  [SMALL_STATE(954)] = 27275,
  [SMALL_STATE(955)] = 27283,
  [SMALL_STATE(956)] = 27291,
  [SMALL_STATE(957)] = 27299,
  [SMALL_STATE(958)] = 27307,
  [SMALL_STATE(959)] = 27315,
  [SMALL_STATE(960)] = 27323,
  [SMALL_STATE(961)] = 27331,
  [SMALL_STATE(962)] = 27339,
  [SMALL_STATE(963)] = 27347,
  [SMALL_STATE(964)] = 27357,
  [SMALL_STATE(965)] = 27365,
  [SMALL_STATE(966)] = 27373,
  [SMALL_STATE(967)] = 27381,
  [SMALL_STATE(968)] = 27389,
  [SMALL_STATE(969)] = 27397,
  [SMALL_STATE(970)] = 27405,
  [SMALL_STATE(971)] = 27413,
  [SMALL_STATE(972)] = 27421,
  [SMALL_STATE(973)] = 27429,
  [SMALL_STATE(974)] = 27437,
  [SMALL_STATE(975)] = 27445,
  [SMALL_STATE(976)] = 27453,
  [SMALL_STATE(977)] = 27461,
  [SMALL_STATE(978)] = 27469,
  [SMALL_STATE(979)] = 27477,
  [SMALL_STATE(980)] = 27485,
  [SMALL_STATE(981)] = 27493,
  [SMALL_STATE(982)] = 27501,
  [SMALL_STATE(983)] = 27509,
  [SMALL_STATE(984)] = 27517,
  [SMALL_STATE(985)] = 27525,
  [SMALL_STATE(986)] = 27533,
  [SMALL_STATE(987)] = 27541,
  [SMALL_STATE(988)] = 27549,
  [SMALL_STATE(989)] = 27557,
  [SMALL_STATE(990)] = 27565,
  [SMALL_STATE(991)] = 27573,
  [SMALL_STATE(992)] = 27581,
  [SMALL_STATE(993)] = 27589,
  [SMALL_STATE(994)] = 27597,
  [SMALL_STATE(995)] = 27605,
  [SMALL_STATE(996)] = 27613,
  [SMALL_STATE(997)] = 27621,
  [SMALL_STATE(998)] = 27629,
  [SMALL_STATE(999)] = 27637,
  [SMALL_STATE(1000)] = 27645,
  [SMALL_STATE(1001)] = 27653,
  [SMALL_STATE(1002)] = 27661,
  [SMALL_STATE(1003)] = 27669,
  [SMALL_STATE(1004)] = 27677,
  [SMALL_STATE(1005)] = 27685,
  [SMALL_STATE(1006)] = 27693,
  [SMALL_STATE(1007)] = 27701,
  [SMALL_STATE(1008)] = 27711,
  [SMALL_STATE(1009)] = 27719,
  [SMALL_STATE(1010)] = 27727,
  [SMALL_STATE(1011)] = 27735,
  [SMALL_STATE(1012)] = 27743,
  [SMALL_STATE(1013)] = 27751,
  [SMALL_STATE(1014)] = 27759,
  [SMALL_STATE(1015)] = 27767,
  [SMALL_STATE(1016)] = 27775,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [11] = {.entry = {.count = 1, .reusable = false}}, SHIFT(245),
  [13] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(510),
  [17] = {.entry = {.count = 1, .reusable = true}}, SHIFT(85),
  [19] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(224),
  [23] = {.entry = {.count = 1, .reusable = true}}, SHIFT(866),
  [25] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [27] = {.entry = {.count = 1, .reusable = true}}, SHIFT(170),
  [29] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [31] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [33] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [35] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [37] = {.entry = {.count = 1, .reusable = false}}, SHIFT(319),
  [39] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(962),
  [43] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [45] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [47] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [49] = {.entry = {.count = 1, .reusable = true}}, SHIFT(860),
  [51] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [53] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [55] = {.entry = {.count = 1, .reusable = true}}, SHIFT(422),
  [57] = {.entry = {.count = 1, .reusable = true}}, SHIFT(883),
  [59] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [61] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [63] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [65] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [67] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [69] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [71] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [73] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [75] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [77] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(963),
  [80] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [83] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(589),
  [86] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(510),
  [89] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(85),
  [92] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(224),
  [95] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(224),
  [98] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(866),
  [101] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(199),
  [104] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(170),
  [107] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(198),
  [110] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(95),
  [113] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(848),
  [116] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(478),
  [119] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(319),
  [122] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(319),
  [125] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(962),
  [128] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(5),
  [131] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(4),
  [134] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1002),
  [137] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(860),
  [140] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(138),
  [143] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(482),
  [146] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(422),
  [149] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(883),
  [152] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(918),
  [155] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(837),
  [158] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(997),
  [161] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(477),
  [164] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(623),
  [167] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(473),
  [170] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1006),
  [173] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(901),
  [176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1009),
  [182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [184] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [188] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(876),
  [192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [194] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [196] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [199] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(589),
  [202] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(510),
  [205] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(88),
  [208] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(224),
  [211] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(224),
  [214] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(866),
  [217] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(199),
  [220] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(170),
  [223] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(198),
  [226] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(95),
  [229] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(848),
  [232] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(478),
  [235] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(319),
  [238] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(319),
  [241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0), SHIFT_REPEAT(995),
  [244] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 3, 0, 27),
  [246] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 3, 0, 27),
  [248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_show_signature, 3, 0, 26),
  [252] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_show_signature, 3, 0, 26),
  [254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [256] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const, 5, 0, 69),
  [258] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const, 5, 0, 69),
  [260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [262] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 4, 0, 27),
  [264] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 4, 0, 27),
  [266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(217),
  [268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 5, 0, 68),
  [270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 5, 0, 68),
  [272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [274] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const, 8, 0, 101),
  [276] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const, 8, 0, 101),
  [278] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 1, 0),
  [280] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 1, 0),
  [282] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_show_term, 3, 0, 25),
  [284] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_show_term, 3, 0, 25),
  [286] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 2, 0),
  [288] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 2, 0),
  [290] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_defined, 3, 0, 26),
  [292] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_defined, 3, 0, 26),
  [294] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_project_signature, 3, 0, 26),
  [296] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_project_signature, 3, 0, 26),
  [298] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_show, 2, 0, 0),
  [300] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_show, 2, 0, 0),
  [302] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_project_atom, 3, 0, 27),
  [304] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_project_atom, 3, 0, 27),
  [306] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 3, 0, 10),
  [308] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 3, 0, 10),
  [310] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include, 3, 0, 0),
  [312] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include, 3, 0, 0),
  [314] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule, 2, 0, 14),
  [316] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rule, 2, 0, 14),
  [318] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_comment, 4, 0, 31),
  [320] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_doc_comment, 4, 0, 31),
  [322] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_maximize, 4, 0, 0),
  [324] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_maximize, 4, 0, 0),
  [326] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_minimize, 4, 0, 0),
  [328] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_minimize, 4, 0, 0),
  [330] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_show_term, 4, 0, 25),
  [332] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_show_term, 4, 0, 25),
  [334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_project_atom, 4, 0, 27),
  [336] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_project_atom, 4, 0, 27),
  [338] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_statement, 1, 0, 0),
  [340] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_statement, 1, 0, 0),
  [342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_rule, 4, 0, 51),
  [344] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_rule, 4, 0, 51),
  [346] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_comment, 5, 0, 52),
  [348] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_doc_comment, 5, 0, 52),
  [350] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_comment, 5, 0, 53),
  [352] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_doc_comment, 5, 0, 53),
  [354] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_weak_constraint, 5, 0, 61),
  [356] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_weak_constraint, 5, 0, 61),
  [358] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_maximize, 5, 0, 65),
  [360] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_maximize, 5, 0, 65),
  [362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_minimize, 5, 0, 65),
  [364] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_minimize, 5, 0, 65),
  [366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_show_term, 5, 0, 67),
  [368] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_show_term, 5, 0, 67),
  [370] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_project_atom, 5, 0, 68),
  [372] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_project_atom, 5, 0, 68),
  [374] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 5, 0, 10),
  [376] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 5, 0, 10),
  [378] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_include, 5, 0, 0),
  [380] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_include, 5, 0, 0),
  [382] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory, 5, 0, 10),
  [384] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory, 5, 0, 10),
  [386] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_type, 5, 0, 10),
  [388] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_type, 5, 0, 10),
  [390] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_comment, 6, 0, 76),
  [392] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_doc_comment, 6, 0, 76),
  [394] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_weak_constraint, 6, 0, 84),
  [396] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_weak_constraint, 6, 0, 84),
  [398] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_show_signature, 6, 0, 85),
  [400] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_show_signature, 6, 0, 85),
  [402] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_program, 6, 0, 86),
  [404] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_program, 6, 0, 86),
  [406] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edge, 6, 0, 70),
  [408] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_edge, 6, 0, 70),
  [410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_integrity_constraint, 3, 0, 22),
  [412] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_integrity_constraint, 3, 0, 22),
  [414] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edge, 6, 0, 88),
  [416] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_edge, 6, 0, 88),
  [418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 6, 0, 89),
  [420] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 6, 0, 89),
  [422] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory, 6, 0, 10),
  [424] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory, 6, 0, 10),
  [426] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_type, 6, 0, 10),
  [428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_type, 6, 0, 10),
  [430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_weak_constraint, 7, 0, 93),
  [432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_weak_constraint, 7, 0, 93),
  [434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_script, 7, 0, 95),
  [436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_script, 7, 0, 95),
  [438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edge, 7, 0, 96),
  [440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_edge, 7, 0, 96),
  [442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edge, 7, 0, 88),
  [444] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_edge, 7, 0, 88),
  [446] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 7, 0, 97),
  [448] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 7, 0, 97),
  [450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory, 7, 0, 10),
  [452] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory, 7, 0, 10),
  [454] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_weak_constraint, 8, 0, 100),
  [456] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_weak_constraint, 8, 0, 100),
  [458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_integrity_constraint, 2, 0, 0),
  [460] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_integrity_constraint, 2, 0, 0),
  [462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edge, 8, 0, 102),
  [464] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_edge, 8, 0, 102),
  [466] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heuristic, 8, 0, 103),
  [468] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heuristic, 8, 0, 103),
  [470] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external, 8, 0, 104),
  [472] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external, 8, 0, 104),
  [474] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory, 8, 0, 10),
  [476] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory, 8, 0, 10),
  [478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heuristic, 9, 0, 106),
  [480] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heuristic, 9, 0, 106),
  [482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_heuristic, 10, 0, 107),
  [484] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_heuristic, 10, 0, 107),
  [486] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edge, 5, 0, 70),
  [488] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_edge, 5, 0, 70),
  [490] = {.entry = {.count = 1, .reusable = false}}, SHIFT(270),
  [492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [496] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__conditional_literal_0, 2, 0, 6),
  [498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(501),
  [500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [502] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate_element, 2, 0, 41),
  [504] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate_element, 4, 0, 59),
  [506] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate_element, 1, 0, 0),
  [508] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optimize_element, 4, 0, 64),
  [510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [512] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optimize_element, 2, 0, 24),
  [514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_element, 2, 0, 37),
  [516] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_element, 1, 0, 0),
  [518] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(245),
  [521] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(589),
  [524] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(510),
  [527] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(224),
  [530] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(224),
  [533] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(928),
  [536] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(199),
  [539] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(170),
  [542] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(198),
  [545] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(95),
  [548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(848),
  [551] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(478),
  [554] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(319),
  [557] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0), SHIFT_REPEAT(319),
  [560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [562] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate_element, 3, 0, 38),
  [564] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate_element, 2, 0, 6),
  [566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [574] = {.entry = {.count = 1, .reusable = false}}, SHIFT(343),
  [576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [580] = {.entry = {.count = 1, .reusable = false}}, SHIFT(157),
  [582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(722),
  [586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(324),
  [598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(784),
  [600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [604] = {.entry = {.count = 1, .reusable = false}}, SHIFT(277),
  [606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [610] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(190),
  [614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(210),
  [616] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate, 3, 0, 30),
  [618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [624] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate, 4, 0, 49),
  [626] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate, 3, 0, 17),
  [628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate, 2, 0, 0),
  [630] = {.entry = {.count = 1, .reusable = false}}, SHIFT(253),
  [632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [638] = {.entry = {.count = 1, .reusable = false}}, SHIFT(268),
  [640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(169),
  [642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(219),
  [644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [652] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate, 4, 0, 40),
  [654] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate, 4, 0, 50),
  [656] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate, 5, 0, 75),
  [658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__term_comma, 2, 0, 0),
  [662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__terms_trail, 3, 0, 0),
  [668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(129),
  [674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [676] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate, 3, 0, 21),
  [678] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate, 4, 0, 50),
  [680] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate, 3, 0, 21),
  [682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate, 5, 0, 75),
  [686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [688] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate, 4, 0, 40),
  [690] = {.entry = {.count = 1, .reusable = false}}, SHIFT(367),
  [692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [698] = {.entry = {.count = 1, .reusable = false}}, SHIFT(459),
  [700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [706] = {.entry = {.count = 1, .reusable = false}}, SHIFT(497),
  [708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(156),
  [710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(379),
  [712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(188),
  [714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [716] = {.entry = {.count = 1, .reusable = false}}, SHIFT(400),
  [718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [722] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lower, 2, 0, 0),
  [724] = {.entry = {.count = 1, .reusable = false}}, SHIFT(411),
  [726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(600),
  [728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [732] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(856),
  [736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(211),
  [742] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_function, 1, 0, 1),
  [744] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_function, 1, 0, 1),
  [746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [750] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 1, 0, 1),
  [752] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function, 1, 0, 1),
  [754] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external_function, 2, 0, 10),
  [756] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external_function, 2, 0, 10),
  [758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(492),
  [760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(592),
  [762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [766] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__metasp_identifier, 2, 0, 0),
  [768] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__metasp_identifier, 2, 0, 0),
  [770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(504),
  [772] = {.entry = {.count = 1, .reusable = false}}, SHIFT(289),
  [774] = {.entry = {.count = 1, .reusable = false}}, SHIFT(247),
  [776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [780] = {.entry = {.count = 1, .reusable = false}}, SHIFT(369),
  [782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(442),
  [784] = {.entry = {.count = 1, .reusable = false}}, SHIFT(345),
  [786] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arg_pool, 2, 0, 0),
  [788] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arg_pool, 2, 0, 0),
  [790] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring, 2, 0, 0),
  [792] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fstring, 2, 0, 0),
  [794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_term, 1, 0, 0),
  [796] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_term, 1, 0, 0),
  [798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abs, 4, 0, 0),
  [800] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abs, 4, 0, 0),
  [802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arg_pool, 3, 0, 33),
  [804] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arg_pool, 3, 0, 33),
  [806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arg_pool, 3, 0, 34),
  [808] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__arg_pool, 3, 0, 34),
  [810] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring, 3, 0, 0),
  [812] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fstring, 3, 0, 0),
  [814] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_terms_trail, 2, 0, 0),
  [816] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_function, 2, 0, 5),
  [818] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_function, 2, 0, 5),
  [820] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple, 3, 0, 0),
  [822] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple, 3, 0, 0),
  [824] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_abs, 3, 0, 0),
  [826] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_abs, 3, 0, 0),
  [828] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_external_function, 3, 0, 20),
  [830] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_external_function, 3, 0, 20),
  [832] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_function, 2, 0, 5),
  [834] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_function, 2, 0, 5),
  [836] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_terms_trail, 3, 0, 0),
  [838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple, 2, 0, 0),
  [840] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_tuple, 2, 0, 0),
  [842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [844] = {.entry = {.count = 1, .reusable = true}}, SHIFT(393),
  [846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(853),
  [852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(381),
  [856] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_symbolic_atom, 1, 0, 1),
  [858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [860] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_symbolic_atom, 1, 0, 1),
  [862] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 3, 0, 0),
  [864] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 3, 0, 0),
  [866] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbolic_atom, 1, 0, 1),
  [868] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbolic_atom, 1, 0, 1),
  [870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 2, 0, 0),
  [872] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 2, 0, 0),
  [874] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbolic_atom, 2, 0, 7),
  [876] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbolic_atom, 2, 0, 7),
  [878] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_symbolic_atom, 2, 0, 7),
  [880] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_symbolic_atom, 2, 0, 7),
  [882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [886] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__metasp_identifier, 2, 0, 0), SHIFT(141),
  [889] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym__metasp_identifier, 2, 0, 0), SHIFT(104),
  [892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__const_term_comma, 2, 0, 0),
  [896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_symbolic_atom, 3, 0, 19),
  [898] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_symbolic_atom, 3, 0, 19),
  [900] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbolic_atom, 3, 0, 18),
  [902] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbolic_atom, 3, 0, 18),
  [904] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_symbolic_atom, 2, 0, 15),
  [906] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_symbolic_atom, 2, 0, 15),
  [908] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__const_terms_trail, 3, 0, 0),
  [910] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_symbolic_atom, 2, 0, 5),
  [912] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_symbolic_atom, 2, 0, 5),
  [914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [920] = {.entry = {.count = 1, .reusable = false}}, SHIFT(174),
  [922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(175),
  [926] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_binary_operation, 3, 0, 28),
  [928] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_binary_operation, 3, 0, 28),
  [930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(851),
  [934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(852),
  [936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(203),
  [946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [948] = {.entry = {.count = 1, .reusable = true}}, SHIFT(204),
  [950] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [952] = {.entry = {.count = 1, .reusable = false}}, SHIFT(181),
  [954] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [956] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [958] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [962] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [964] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [968] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(430),
  [972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [974] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_unary_operation, 2, 0, 8),
  [978] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_unary_operation, 2, 0, 8),
  [980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(216),
  [982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison, 3, 0, 0),
  [984] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(168),
  [988] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_comparison, 3, 0, 0),
  [990] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0),
  [992] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_body_repeat1, 2, 0, 0),
  [994] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [996] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [998] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [1000] = {.entry = {.count = 1, .reusable = true}}, SHIFT(405),
  [1002] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [1004] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_comparison_repeat1, 2, 0, 0),
  [1006] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_comparison_repeat1, 2, 0, 0),
  [1008] = {.entry = {.count = 1, .reusable = true}}, SHIFT(221),
  [1010] = {.entry = {.count = 1, .reusable = true}}, SHIFT(192),
  [1012] = {.entry = {.count = 1, .reusable = false}}, SHIFT(193),
  [1014] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [1016] = {.entry = {.count = 1, .reusable = true}}, SHIFT(194),
  [1018] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [1020] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [1022] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_const_function, 1, 0, 1),
  [1024] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_const_function, 1, 0, 1),
  [1026] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [1028] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_literal_sign, 1, 0, 0),
  [1030] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal_sign, 1, 0, 0),
  [1032] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0),
  [1034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 0),
  [1036] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 12),
  [1038] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 12),
  [1040] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 13),
  [1042] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_disjunction_repeat1, 2, 0, 13),
  [1044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1046] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [1048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_function, 1, 0, 1),
  [1050] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_function, 1, 0, 1),
  [1052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_const_function, 2, 0, 5),
  [1054] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_const_function, 2, 0, 5),
  [1056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(166),
  [1058] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_terms, 1, 0, 0),
  [1060] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__const_arg_pool, 2, 0, 0),
  [1062] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__const_arg_pool, 2, 0, 0),
  [1064] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_weight, 1, 0, 23),
  [1066] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [1068] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__const_arg_pool, 3, 0, 33),
  [1070] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__const_arg_pool, 3, 0, 33),
  [1072] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [1074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [1076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_terms_repeat1, 2, 0, 0),
  [1078] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_metasp_function, 1, 0, 1), SHIFT(1001),
  [1081] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_weight, 3, 0, 62),
  [1083] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_function, 1, 0, 1), SHIFT(911),
  [1086] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upper, 1, 0, 0),
  [1088] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_upper, 1, 0, 0),
  [1090] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_function, 1, 0, 1), SHIFT(1000),
  [1093] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_metasp_function, 1, 0, 1), SHIFT(934),
  [1096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_upper, 2, 0, 0),
  [1098] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_upper, 2, 0, 0),
  [1100] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_tuple, 3, 0, 87),
  [1102] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_tuple, 3, 0, 87),
  [1104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_abs, 3, 0, 0),
  [1106] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_abs, 3, 0, 0),
  [1108] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_tuple, 3, 0, 0),
  [1110] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_tuple, 3, 0, 0),
  [1112] = {.entry = {.count = 1, .reusable = true}}, SHIFT(182),
  [1114] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [1116] = {.entry = {.count = 1, .reusable = true}}, SHIFT(232),
  [1118] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [1120] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_operators, 1, 0, 0),
  [1122] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_operators, 1, 0, 0),
  [1124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [1126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_function, 2, 0, 5),
  [1128] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_function, 2, 0, 5),
  [1130] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_tuple, 2, 0, 0),
  [1132] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_tuple, 2, 0, 0),
  [1134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [1136] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__term_or_projection, 1, 0, 0),
  [1138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pool_item, 1, 0, 0),
  [1140] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_theory_operators_repeat1, 2, 0, 0),
  [1142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_theory_operators_repeat1, 2, 0, 0),
  [1144] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_theory_operators_repeat1, 2, 0, 0), SHIFT_REPEAT(385),
  [1147] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_theory_operators_repeat1, 2, 0, 0), SHIFT_REPEAT(400),
  [1150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_lower, 1, 0, 0),
  [1152] = {.entry = {.count = 1, .reusable = true}}, SHIFT(145),
  [1154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(342),
  [1156] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_binary_operation, 3, 0, 28),
  [1158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [1160] = {.entry = {.count = 1, .reusable = false}}, SHIFT(307),
  [1162] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [1164] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [1166] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_binary_operation, 3, 0, 28),
  [1168] = {.entry = {.count = 1, .reusable = false}}, SHIFT(22),
  [1170] = {.entry = {.count = 1, .reusable = true}}, SHIFT(6),
  [1172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [1174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_terms, 1, 0, 0),
  [1178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(257),
  [1180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [1182] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_term, 1, 0, 0),
  [1184] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_term, 1, 0, 0),
  [1186] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [1188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_unparsed_term, 1, 0, 0),
  [1190] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_unparsed_term, 1, 0, 0),
  [1192] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_unparsed_term, 2, 0, 0),
  [1194] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_unparsed_term, 2, 0, 0),
  [1196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_theory_unparsed_term_repeat1, 2, 0, 0),
  [1198] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_theory_unparsed_term_repeat1, 2, 0, 0),
  [1200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_theory_unparsed_term_repeat1, 2, 0, 0), SHIFT_REPEAT(379),
  [1203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_theory_unparsed_term_repeat1, 2, 0, 0), SHIFT_REPEAT(400),
  [1206] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_theory_operators_repeat1, 1, 0, 36),
  [1208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_theory_operators_repeat1, 1, 0, 36),
  [1210] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_edge_pair, 3, 0, 0),
  [1212] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_abs_repeat1, 2, 0, 0),
  [1214] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_unary_operation, 2, 0, 8),
  [1216] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_unary_operation, 2, 0, 8),
  [1218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [1220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(206),
  [1222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [1224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [1226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [1228] = {.entry = {.count = 1, .reusable = true}}, SHIFT(836),
  [1230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [1232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [1234] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_function, 1, 0, 1),
  [1236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [1238] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_function, 1, 0, 1),
  [1240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [1242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [1244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [1246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(835),
  [1248] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_const_terms_repeat1, 2, 0, 0),
  [1250] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metasp_type_repeat1, 2, 0, 0),
  [1252] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_type_repeat1, 2, 0, 0), SHIFT_REPEAT(812),
  [1255] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_type_repeat1, 2, 0, 0), SHIFT_REPEAT(836),
  [1258] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_type_repeat1, 2, 0, 0), SHIFT_REPEAT(843),
  [1261] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_type_repeat1, 2, 0, 0), SHIFT_REPEAT(844),
  [1264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [1266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [1268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [1270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [1272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [1274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(661),
  [1276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [1278] = {.entry = {.count = 1, .reusable = false}}, SHIFT(274),
  [1280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [1282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [1284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [1286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [1288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(829),
  [1290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [1292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [1294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [1296] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_comparison, 4, 0, 0),
  [1298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(893),
  [1300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [1302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [1304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [1306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [1308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [1310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
  [1312] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_arg, 6, 0, 110),
  [1314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [1316] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_repeat1, 2, 0, 0), SHIFT_REPEAT(168),
  [1319] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_root_term, 1, 0, 0),
  [1321] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_root_term, 1, 0, 0),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [1325] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_set, 2, 0, 0),
  [1327] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_set, 2, 0, 0),
  [1329] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_tuple, 2, 0, 0),
  [1331] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_tuple, 2, 0, 0),
  [1333] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_list, 2, 0, 0),
  [1335] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_list, 2, 0, 0),
  [1337] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_arguments, 2, 0, 0),
  [1339] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__theory_arguments, 2, 0, 0),
  [1341] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_set, 3, 0, 0),
  [1343] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_set, 3, 0, 0),
  [1345] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_tuple, 3, 0, 0),
  [1347] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_tuple, 3, 0, 0),
  [1349] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_list, 3, 0, 0),
  [1351] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_list, 3, 0, 0),
  [1353] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_arguments, 3, 0, 33),
  [1355] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__theory_arguments, 3, 0, 33),
  [1357] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_function, 2, 0, 5),
  [1359] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_function, 2, 0, 5),
  [1361] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_argument_definitions, 1, 0, 0),
  [1363] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_metasp_macros_repeat1, 2, 0, 0), SHIFT_REPEAT(893),
  [1366] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_macros_repeat1, 2, 0, 0), SHIFT_REPEAT(981),
  [1369] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metasp_macros_repeat1, 2, 0, 0),
  [1371] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_metasp_macros_repeat1, 2, 0, 0),
  [1373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(636),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(481),
  [1377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(515),
  [1379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(544),
  [1381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(780),
  [1383] = {.entry = {.count = 1, .reusable = false}}, SHIFT(809),
  [1385] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fstring_spec, 1, 0, 0),
  [1387] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_doc_desc_repeat1, 2, 0, 0),
  [1389] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_doc_desc_repeat1, 2, 0, 0), SHIFT_REPEAT(458),
  [1392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [1394] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_argument_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(886),
  [1397] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_argument_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(758),
  [1400] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_argument_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(572),
  [1403] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metasp_argument_definitions_repeat1, 2, 0, 0),
  [1405] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_doc_desc_repeat1, 2, 0, 0), SHIFT_REPEAT(461),
  [1408] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_predicate, 2, 0, 1),
  [1410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [1412] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_desc, 1, 0, 0),
  [1414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(461),
  [1416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(458),
  [1418] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_repeat1, 2, 0, 0), SHIFT_REPEAT(213),
  [1421] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom, 5, 0, 57),
  [1423] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_atom, 5, 0, 57),
  [1425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [1427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [1429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [1431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [1433] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition, 1, 0, 0),
  [1435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [1437] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_predicate, 6, 0, 1),
  [1439] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_condition_repeat1, 2, 0, 0),
  [1441] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(97),
  [1444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_expression_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(933),
  [1447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_expression_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(763),
  [1450] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metasp_expression_definitions_repeat1, 2, 0, 0),
  [1452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [1454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(687),
  [1456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_predicate, 7, 0, 105),
  [1458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_condition, 2, 0, 0),
  [1460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(999),
  [1462] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_simple_atom, 1, 0, 0),
  [1464] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom, 4, 0, 10),
  [1466] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_atom, 4, 0, 10),
  [1468] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom, 6, 0, 81),
  [1470] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_atom, 6, 0, 81),
  [1472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [1474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(491),
  [1476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [1478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [1480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(861),
  [1482] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_spec, 2, 0, 0),
  [1484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(817),
  [1486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [1488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom, 5, 0, 58),
  [1490] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_theory_atom, 5, 0, 58),
  [1492] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal, 2, 0, 11),
  [1494] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_literal, 1, 0, 2),
  [1496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [1498] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_disjunction, 2, 0, 0),
  [1500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [1502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(228),
  [1504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(514),
  [1506] = {.entry = {.count = 1, .reusable = false}}, SHIFT(167),
  [1508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [1510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [1512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(875),
  [1514] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_spec, 3, 0, 0),
  [1516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [1518] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_accessor, 1, 0, 0),
  [1520] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head, 1, 0, 0),
  [1522] = {.entry = {.count = 1, .reusable = false}}, SHIFT(286),
  [1524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [1526] = {.entry = {.count = 1, .reusable = false}}, SHIFT(285),
  [1528] = {.entry = {.count = 1, .reusable = false}}, SHIFT(223),
  [1530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [1532] = {.entry = {.count = 1, .reusable = false}}, SHIFT(313),
  [1534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [1536] = {.entry = {.count = 1, .reusable = false}}, SHIFT(325),
  [1538] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fstring_accessor_repeat1, 2, 0, 0), SHIFT_REPEAT(513),
  [1541] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fstring_accessor_repeat1, 2, 0, 0), SHIFT_REPEAT(851),
  [1544] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_fstring_accessor_repeat1, 2, 0, 0),
  [1546] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_fstring_repeat1, 2, 0, 0),
  [1548] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_fstring_repeat1, 2, 0, 0), SHIFT_REPEAT(514),
  [1551] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_fstring_repeat1, 2, 0, 0), SHIFT_REPEAT(167),
  [1554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [1556] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_terms, 1, 0, 0),
  [1558] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_theory_terms_repeat1, 2, 0, 0), SHIFT_REPEAT(240),
  [1561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_theory_terms_repeat1, 2, 0, 0),
  [1563] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_macros, 6, 0, 0),
  [1565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_expression_definitions, 5, 0, 0),
  [1567] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metasp_type_repeat1, 1, 0, 43),
  [1569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_macros, 7, 0, 0),
  [1571] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_comparison_repeat1, 2, 0, 0), SHIFT_REPEAT(185),
  [1574] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_occurrence, 4, 0, 0),
  [1576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [1578] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_theory_terms_repeat1, 2, 0, 0), SHIFT_REPEAT(237),
  [1581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_type_keyword, 1, 0, 45),
  [1583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1000),
  [1585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_terms, 2, 0, 0),
  [1587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_terms, 2, 0, 0),
  [1589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_subtypes, 5, 0, 0),
  [1591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [1593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_type_keyword, 1, 0, 46),
  [1595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [1597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [1599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [1601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [1603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(782),
  [1605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(980),
  [1607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [1609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_macros, 5, 0, 0),
  [1611] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_fstring_accessor_repeat1, 3, 0, 77),
  [1613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_expression_definitions, 6, 0, 0),
  [1615] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_type_keyword, 1, 0, 47),
  [1617] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_terms_repeat1, 2, 0, 0), SHIFT_REPEAT(166),
  [1620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(607),
  [1622] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_type_keyword, 1, 0, 44),
  [1624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(716),
  [1626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [1628] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_spec, 4, 0, 0),
  [1630] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_subtypes, 6, 0, 0),
  [1632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [1634] = {.entry = {.count = 1, .reusable = false}}, SHIFT(450),
  [1636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1638] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fstring_field, 5, 0, 0),
  [1640] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_field, 5, 0, 0),
  [1642] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate, 4, 0, 35),
  [1644] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate, 4, 0, 48),
  [1646] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__conditional_literal_n, 3, 0, 29),
  [1648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [1650] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__terms_trail, 2, 0, 0),
  [1652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [1654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(858),
  [1656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(557),
  [1658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [1660] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom_upper, 2, 0, 0),
  [1662] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom_upper, 2, 0, 36),
  [1664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [1666] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__terms_or_projection, 2, 0, 0),
  [1668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(148),
  [1670] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optimize_element, 1, 0, 24),
  [1672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(81),
  [1674] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_doc_args_repeat1, 2, 0, 0),
  [1676] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_doc_args_repeat1, 2, 0, 0), SHIFT_REPEAT(850),
  [1679] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__terms_or_projection_repeat1, 2, 0, 0), SHIFT_REPEAT(142),
  [1682] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__terms_or_projection_repeat1, 2, 0, 0),
  [1684] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__terms_or_projection, 1, 0, 0),
  [1686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [1688] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fstring_field, 6, 0, 0),
  [1690] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_field, 6, 0, 0),
  [1692] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_argument_definition, 1, 0, 0),
  [1694] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom, 6, 0, 79),
  [1696] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_metasp_macro_definition, 4, 0, 0),
  [1698] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_macro_definition, 4, 0, 0),
  [1700] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fstring_field, 3, 0, 0),
  [1702] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_field, 3, 0, 0),
  [1704] = {.entry = {.count = 1, .reusable = false}}, SHIFT(281),
  [1706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [1708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(931),
  [1710] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom, 5, 0, 56),
  [1712] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom, 7, 0, 91),
  [1714] = {.entry = {.count = 1, .reusable = false}}, SHIFT(284),
  [1716] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom, 6, 0, 80),
  [1718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(644),
  [1720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [1722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [1724] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_argument_definition, 2, 0, 0),
  [1726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [1728] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_macro_where_repeat1, 2, 0, 0), SHIFT_REPEAT(886),
  [1731] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metasp_macro_where_repeat1, 2, 0, 0),
  [1733] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_argument_definition, 3, 0, 0),
  [1735] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_args, 2, 0, 0),
  [1737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [1739] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0),
  [1741] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_string_repeat1, 2, 0, 0), SHIFT_REPEAT(588),
  [1744] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [1746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(603),
  [1748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [1750] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_condition_repeat1, 2, 0, 0), SHIFT_REPEAT(100),
  [1753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(357),
  [1755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [1757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_literal, 2, 0, 11),
  [1759] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate, 3, 0, 16),
  [1761] = {.entry = {.count = 1, .reusable = false}}, SHIFT(358),
  [1763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(496),
  [1765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [1767] = {.entry = {.count = 1, .reusable = false}}, SHIFT(500),
  [1769] = {.entry = {.count = 1, .reusable = false}}, SHIFT(449),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(550),
  [1773] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate, 5, 0, 73),
  [1775] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_args, 3, 0, 0),
  [1777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(243),
  [1779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_literal, 1, 0, 2),
  [1781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [1783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [1785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_literal, 1, 0, 3),
  [1787] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_fstring_field, 4, 0, 0),
  [1789] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_field, 4, 0, 0),
  [1791] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_theory_operator_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(621),
  [1794] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_theory_operator_definitions_repeat1, 2, 0, 0),
  [1796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(979),
  [1798] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 1, 0, 0),
  [1800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [1802] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optimize_elements, 1, 0, 0),
  [1804] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate, 6, 0, 90),
  [1806] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_terms, 2, 0, 0),
  [1808] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_const_terms_repeat1, 2, 0, 0), SHIFT_REPEAT(293),
  [1811] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optimize_element, 3, 0, 64),
  [1813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(79),
  [1815] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_optimize_elements_repeat1, 2, 0, 0), SHIFT_REPEAT(146),
  [1818] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_optimize_elements_repeat1, 2, 0, 0),
  [1820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(301),
  [1822] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body, 1, 0, 0),
  [1824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [1826] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_operator_definitions, 2, 0, 0),
  [1828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [1830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(884),
  [1832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [1834] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_signature, 4, 0, 66),
  [1836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(818),
  [1838] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variables, 2, 0, 0),
  [1840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [1842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [1844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_spec, 5, 0, 0),
  [1846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [1848] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate_elements, 2, 0, 0),
  [1850] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_parameters, 2, 0, 0),
  [1852] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_subtypes_repeat1, 2, 0, 0), SHIFT_REPEAT(884),
  [1855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metasp_subtypes_repeat1, 2, 0, 0),
  [1857] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_variables, 3, 0, 0),
  [1859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__arg_pool_n_repeat1, 2, 0, 54),
  [1861] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__arg_pool_n_repeat1, 2, 0, 54), SHIFT_REPEAT(114),
  [1864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(792),
  [1866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [1868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(793),
  [1870] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_width, 1, 0, 0),
  [1872] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_variables_repeat1, 2, 0, 0), SHIFT_REPEAT(818),
  [1875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variables_repeat1, 2, 0, 0),
  [1877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(583),
  [1879] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_projection, 1, 0, 0),
  [1881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(786),
  [1883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [1885] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_metasp_argument_definition_repeat1, 2, 0, 0), SHIFT_REPEAT(758),
  [1888] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_metasp_argument_definition_repeat1, 2, 0, 0),
  [1890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [1892] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_operators_sep, 1, 0, 0),
  [1894] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_operators_sep, 1, 0, 36),
  [1896] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_operators_sep, 2, 0, 0),
  [1898] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_operators_sep, 2, 0, 36),
  [1900] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__theory_operators_sep_repeat1, 2, 0, 0), SHIFT_REPEAT(751),
  [1903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__theory_operators_sep_repeat1, 2, 0, 0),
  [1905] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_edge_repeat1, 2, 0, 72),
  [1907] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_edge_repeat1, 2, 0, 72), SHIFT_REPEAT(153),
  [1910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [1912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [1914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(225),
  [1916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [1918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [1920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [1922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [1924] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__tuple_pool_n, 2, 0, 0),
  [1926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [1928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [1930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(38),
  [1932] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__arg_pool_n, 2, 0, 32),
  [1934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [1936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [1938] = {.entry = {.count = 1, .reusable = true}}, SHIFT(891),
  [1940] = {.entry = {.count = 1, .reusable = true}}, SHIFT(932),
  [1942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [1944] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_terms_trail, 1, 0, 0),
  [1946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [1948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_terms_repeat1, 2, 0, 0), SHIFT_REPEAT(182),
  [1951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(235),
  [1953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [1955] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate_element, 1, 0, 6),
  [1957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [1959] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_theory_elements_repeat1, 2, 0, 0), SHIFT_REPEAT(158),
  [1962] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_theory_elements_repeat1, 2, 0, 0),
  [1964] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_set_aggregate_elements_repeat1, 2, 0, 0), SHIFT_REPEAT(96),
  [1967] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_set_aggregate_elements_repeat1, 2, 0, 0),
  [1969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(158),
  [1971] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_elements, 2, 0, 0),
  [1973] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_body_aggregate_elements_repeat1, 2, 0, 0), SHIFT_REPEAT(140),
  [1976] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_body_aggregate_elements_repeat1, 2, 0, 0),
  [1978] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_element, 1, 0, 37),
  [1980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(82),
  [1982] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate, 5, 0, 60),
  [1984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate, 5, 0, 74),
  [1986] = {.entry = {.count = 1, .reusable = true}}, SHIFT(143),
  [1988] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate_elements, 1, 0, 0),
  [1990] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_elements, 1, 0, 0),
  [1992] = {.entry = {.count = 1, .reusable = true}}, SHIFT(340),
  [1994] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_conditional_literal, 1, 0, 4),
  [1996] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_abs_repeat1, 2, 0, 0), SHIFT_REPEAT(189),
  [1999] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__tuple_pool_n_repeat1, 2, 0, 0),
  [2001] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__tuple_pool_n_repeat1, 2, 0, 0), SHIFT_REPEAT(101),
  [2004] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [2006] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0), SHIFT_REPEAT(979),
  [2009] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_parameters_repeat1, 2, 0, 0),
  [2011] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate_element, 2, 0, 38),
  [2013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(86),
  [2015] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate_elements, 1, 0, 0),
  [2017] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate_element, 3, 0, 59),
  [2019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [2021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(261),
  [2023] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__const_terms_trail, 2, 0, 0),
  [2025] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_head_aggregate_elements_repeat1, 2, 0, 0), SHIFT_REPEAT(143),
  [2028] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_head_aggregate_elements_repeat1, 2, 0, 0),
  [2030] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [2032] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate_elements, 2, 0, 0),
  [2034] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate_element, 1, 0, 41),
  [2036] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [2038] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [2040] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate_elements, 1, 0, 0),
  [2042] = {.entry = {.count = 1, .reusable = true}}, SHIFT(226),
  [2044] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [2046] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body, 2, 0, 0),
  [2048] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optimize_elements, 2, 0, 0),
  [2050] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate, 4, 0, 39),
  [2052] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_operator_definitions, 1, 0, 0),
  [2054] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [2056] = {.entry = {.count = 1, .reusable = true}}, SHIFT(338),
  [2058] = {.entry = {.count = 1, .reusable = true}}, SHIFT(341),
  [2060] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__theory_definitions_repeat1, 2, 0, 0), SHIFT_REPEAT(786),
  [2063] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__theory_definitions_repeat1, 2, 0, 0),
  [2065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [2067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [2069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym__theory_definitions_repeat2, 2, 0, 0), SHIFT_REPEAT(754),
  [2072] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__theory_definitions_repeat2, 2, 0, 0),
  [2074] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [2076] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_signature, 3, 0, 42),
  [2078] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate_elements, 2, 0, 0),
  [2080] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__arg_pool_n_repeat1, 2, 0, 33),
  [2082] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate, 5, 0, 74),
  [2084] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [2086] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [2088] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_tuple_pool_item, 1, 0, 9),
  [2090] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom_definition, 8, 0, 111),
  [2092] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_set_aggregate_element, 3, 0, 29),
  [2094] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [2096] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_element, 3, 0, 78),
  [2098] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optimize_element, 3, 0, 63),
  [2100] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [2102] = {.entry = {.count = 1, .reusable = true}}, SHIFT(8),
  [2104] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate_element, 4, 0, 82),
  [2106] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate_element, 3, 0, 83),
  [2108] = {.entry = {.count = 1, .reusable = true}}, SHIFT(650),
  [2110] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [2112] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_edge_repeat1, 2, 0, 71),
  [2114] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_variables_repeat1, 4, 0, 0),
  [2116] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_doc_arg, 7, 0, 113),
  [2118] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_operator_definition, 7, 0, 114),
  [2120] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_operator_definition, 7, 0, 115),
  [2122] = {.entry = {.count = 1, .reusable = true}}, SHIFT(150),
  [2124] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [2126] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_term_definition, 4, 0, 98),
  [2128] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_keyword_arg, 3, 0, 116),
  [2130] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [2132] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [2134] = {.entry = {.count = 1, .reusable = true}}, SHIFT(755),
  [2136] = {.entry = {.count = 1, .reusable = true}}, SHIFT(756),
  [2138] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym__theory_operators_sep_repeat1, 2, 0, 117),
  [2140] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate, 6, 0, 90),
  [2142] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate, 4, 0, 39),
  [2144] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [2146] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [2148] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom_definition, 14, 0, 119),
  [2150] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate, 5, 0, 60),
  [2152] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_expression_definition, 1, 0, 99),
  [2154] = {.entry = {.count = 1, .reusable = true}}, SHIFT(990),
  [2156] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [2158] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [2160] = {.entry = {.count = 1, .reusable = true}}, SHIFT(874),
  [2162] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_spec, 6, 0, 0),
  [2164] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_head_aggregate_element, 5, 0, 92),
  [2166] = {.entry = {.count = 1, .reusable = true}}, SHIFT(161),
  [2168] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [2170] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_body_aggregate_element, 2, 0, 55),
  [2172] = {.entry = {.count = 1, .reusable = true}}, SHIFT(80),
  [2174] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [2176] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_disjunction, 1, 0, 0),
  [2178] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [2180] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [2182] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [2184] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_term_definition, 3, 0, 1),
  [2186] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_conversion, 2, 0, 0),
  [2188] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_optimize_element, 5, 0, 94),
  [2190] = {.entry = {.count = 1, .reusable = true}}, SHIFT(89),
  [2192] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [2194] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_operator_definition, 5, 0, 108),
  [2196] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_operator_definition, 5, 0, 109),
  [2198] = {.entry = {.count = 1, .reusable = true}}, SHIFT(582),
  [2200] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [2202] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_element, 2, 0, 55),
  [2204] = {.entry = {.count = 1, .reusable = true}}, SHIFT(919),
  [2206] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extended_symbolic_atom, 1, 0, 0),
  [2208] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_theory_atom_definition, 13, 0, 118),
  [2210] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2212] = {.entry = {.count = 1, .reusable = true}}, SHIFT(154),
  [2214] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [2216] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [2218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [2220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(518),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(989),
  [2224] = {.entry = {.count = 1, .reusable = true}}, SHIFT(863),
  [2226] = {.entry = {.count = 1, .reusable = true}}, SHIFT(825),
  [2228] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_extended_signature, 1, 0, 0),
  [2230] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [2232] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [2234] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [2236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(869),
  [2238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [2240] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [2242] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [2244] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [2246] = {.entry = {.count = 1, .reusable = true}}, SHIFT(37),
  [2248] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [2250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(872),
  [2252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [2254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [2256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(437),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [2260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(39),
  [2262] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [2264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(828),
  [2266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(895),
  [2268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [2270] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [2272] = {.entry = {.count = 1, .reusable = true}}, SHIFT(539),
  [2274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [2276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [2278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(831),
  [2280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [2282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [2284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [2286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [2288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [2290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [2292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [2294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [2296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(783),
  [2298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [2300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(494),
  [2302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [2304] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_terms_trail, 1, 0, 9),
  [2306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [2308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [2310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [2312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [2314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [2316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [2318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(252),
  [2320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(487),
  [2322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(499),
  [2324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [2326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [2328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [2330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(434),
  [2332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [2334] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_fstring_spec, 7, 0, 0),
  [2336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [2338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [2340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [2342] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__theory_operator_arity_binary, 1, 0, 0),
  [2344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [2346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [2348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [2352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(752),
  [2354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [2356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [2360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [2362] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_expression_definition, 4, 0, 99),
  [2364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(914),
  [2366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [2368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1010),
  [2370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(558),
  [2372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(538),
  [2374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [2380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [2386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [2388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(137),
  [2390] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [2392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [2394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [2396] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signature, 4, 0, 66),
  [2398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [2400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [2402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [2406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [2408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2410] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_expression_definition, 5, 0, 112),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [2414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [2416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [2418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(892),
  [2420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [2422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [2424] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [2426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [2428] = {.entry = {.count = 1, .reusable = true}}, SHIFT(826),
  [2430] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [2432] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [2434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_macro_where, 5, 0, 0),
  [2436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(244),
  [2438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [2440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [2442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [2444] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [2446] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2448] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [2452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [2454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [2456] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_boolean, 1, 0, 0),
  [2458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(535),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(958),
  [2464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [2466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [2468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [2470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [2472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [2474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [2476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [2478] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_metasp_macro_where, 6, 0, 0),
  [2480] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [2482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(635),
  [2484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [2486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [2488] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [2490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [2492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [2494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [2496] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [2498] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [2500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [2502] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [2506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [2508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [2510] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [2512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [2514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [2516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [2518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [2520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [2522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [2524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [2526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [2528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(753),
  [2530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [2532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [2534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [2536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [2538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [2542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(339),
  [2544] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [2546] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [2548] = {.entry = {.count = 1, .reusable = true}}, SHIFT(838),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [2552] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [2554] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_signature, 3, 0, 42),
  [2556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [2558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [2560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [2562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(151),
  [2564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [2566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(540),
  [2568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [2570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [2572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [2574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [2576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [2578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [2580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [2582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(663),
  [2584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(152),
  [2586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [2588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(904),
  [2590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [2592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(180),
  [2594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [2596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(548),
  [2598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [2600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
};

enum ts_external_scanner_symbol_identifiers {
  ts_external_token_empty_pool_item_first = 0,
  ts_external_token_empty_pool_item = 1,
  ts_external_token_colon = 2,
  ts_external_token_block_comment = 3,
  ts_external_token_doc_fragment_string = 4,
  ts_external_token__doc_token_args = 5,
  ts_external_token__doc_token_paren = 6,
  ts_external_token__doc_token_minus = 7,
};

static const TSSymbol ts_external_scanner_symbol_map[EXTERNAL_TOKEN_COUNT] = {
  [ts_external_token_empty_pool_item_first] = sym_empty_pool_item_first,
  [ts_external_token_empty_pool_item] = sym_empty_pool_item,
  [ts_external_token_colon] = sym_colon,
  [ts_external_token_block_comment] = sym_block_comment,
  [ts_external_token_doc_fragment_string] = sym_doc_fragment_string,
  [ts_external_token__doc_token_args] = sym__doc_token_args,
  [ts_external_token__doc_token_paren] = sym__doc_token_paren,
  [ts_external_token__doc_token_minus] = sym__doc_token_minus,
};

static const bool ts_external_scanner_states[11][EXTERNAL_TOKEN_COUNT] = {
  [1] = {
    [ts_external_token_empty_pool_item_first] = true,
    [ts_external_token_empty_pool_item] = true,
    [ts_external_token_colon] = true,
    [ts_external_token_block_comment] = true,
    [ts_external_token_doc_fragment_string] = true,
    [ts_external_token__doc_token_args] = true,
    [ts_external_token__doc_token_paren] = true,
    [ts_external_token__doc_token_minus] = true,
  },
  [2] = {
    [ts_external_token_block_comment] = true,
  },
  [3] = {
    [ts_external_token_empty_pool_item_first] = true,
    [ts_external_token_block_comment] = true,
  },
  [4] = {
    [ts_external_token_empty_pool_item] = true,
    [ts_external_token_block_comment] = true,
  },
  [5] = {
    [ts_external_token_colon] = true,
    [ts_external_token_block_comment] = true,
  },
  [6] = {
    [ts_external_token_block_comment] = true,
    [ts_external_token_doc_fragment_string] = true,
    [ts_external_token__doc_token_args] = true,
  },
  [7] = {
    [ts_external_token_block_comment] = true,
    [ts_external_token_doc_fragment_string] = true,
    [ts_external_token__doc_token_minus] = true,
  },
  [8] = {
    [ts_external_token_block_comment] = true,
    [ts_external_token_doc_fragment_string] = true,
    [ts_external_token__doc_token_args] = true,
    [ts_external_token__doc_token_paren] = true,
  },
  [9] = {
    [ts_external_token_block_comment] = true,
    [ts_external_token__doc_token_minus] = true,
  },
  [10] = {
    [ts_external_token_block_comment] = true,
    [ts_external_token__doc_token_args] = true,
  },
};

#ifdef __cplusplus
extern "C" {
#endif
void *tree_sitter_metasp_external_scanner_create(void);
void tree_sitter_metasp_external_scanner_destroy(void *);
bool tree_sitter_metasp_external_scanner_scan(void *, TSLexer *, const bool *);
unsigned tree_sitter_metasp_external_scanner_serialize(void *, char *);
void tree_sitter_metasp_external_scanner_deserialize(void *, const char *, unsigned);

#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_metasp(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .supertype_count = SUPERTYPE_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .field_names = ts_field_names,
    .field_map_slices = ts_field_map_slices,
    .field_map_entries = ts_field_map_entries,
    .supertype_map_slices = ts_supertype_map_slices,
    .supertype_map_entries = ts_supertype_map_entries,
    .supertype_symbols = ts_supertype_symbols,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .external_scanner = {
      &ts_external_scanner_states[0][0],
      ts_external_scanner_symbol_map,
      tree_sitter_metasp_external_scanner_create,
      tree_sitter_metasp_external_scanner_destroy,
      tree_sitter_metasp_external_scanner_scan,
      tree_sitter_metasp_external_scanner_serialize,
      tree_sitter_metasp_external_scanner_deserialize,
    },
    .primary_state_ids = ts_primary_state_ids,
    .name = "metasp",
    .max_reserved_word_set_size = 0,
    .metadata = {
      .major_version = 1,
      .minor_version = 0,
      .patch_version = 0,
    },
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
